(* Content-type: application/vnd.wolfram.mathematica *)

(*** Wolfram Notebook File ***)
(* http://www.wolfram.com/nb *)

(* CreatedBy='Mathematica 13.3' *)

(*CacheID: 234*)
(* Internal cache information:
NotebookFileLineBreakTest
NotebookFileLineBreakTest
NotebookDataPosition[       158,          7]
NotebookDataLength[   1447630,      34558]
NotebookOptionsPosition[   1133701,      28175]
NotebookOutlinePosition[   1350975,      32566]
CellTagsIndexPosition[   1347150,      32424]
WindowTitle->2 | Data Structures and Functions
WindowFrame->Normal*)

(* Beginning of Notebook Content *)
Notebook[{

Cell[CellGroupData[{
Cell[TextData[{
 
 CounterBox["Section"],
 " | Data Structures and Functions"
}], "Section",
 CellChangeTimes->{3.652728456208679*^9, 3.652728527108994*^9, 
  3.858336685562973*^9, 3.8814188061973953`*^9},
 CounterAssignments->{{"Section", 1}},
 CellTags->"p: 15",
 CellID->702470296,ExpressionUUID->"5fb1942b-26df-4888-9847-67421344e9aa"],

Cell[TextData[{
 "Mathematica and the Wolfram Language existed for 23 years and made it \
through nine major releases before the release of ",
 ButtonBox["Association",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Association.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Association.html"],
 ", ",
 ButtonBox["Dataset",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dataset.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dataset.html"],
 ", ",
 ButtonBox["Query",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Query.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Query.html"],
 ", and many of the constructs discussed in this book. A lot of very \
productive computing got done during that time, so before going into the \
capabilities created since the introduction of these constructs with Version \
10 in July 2014, it is worth spending a little time on data structures that \
existed prior thereto. This chapter is not intended as a comprehensive review \
on the Wolfram Language. There are many fine works on that subject. It is \
intended, however, to make clear what is possible without the use of the \
newer tools. Indeed, computation today can often still best be \
done\[LongDash]or at least most rapidly\[LongDash]without the overhead these \
constructs introduce."
}], "Text",
 CellChangeTimes->{{3.7689870068433332`*^9, 3.768987018641286*^9}, {
   3.7689871269576597`*^9, 3.768987219885742*^9}, {3.7689872880192347`*^9, 
   3.7689873584756403`*^9}, {3.768987447298142*^9, 3.768987505026075*^9}, {
   3.7691006962497683`*^9, 3.76910069706072*^9}, {3.7730802331427407`*^9, 
   3.7730802356879954`*^9}, 3.774783623384617*^9, {3.7748829209475584`*^9, 
   3.774882926232087*^9}, {3.774883121659628*^9, 3.7748831239608583`*^9}, {
   3.77488359153061*^9, 3.774883591817639*^9}, {3.774883775374993*^9, 
   3.7748837853819933`*^9}, {3.774955793781618*^9, 3.774955859604618*^9}, {
   3.7749559185866175`*^9, 3.7749559199856176`*^9}, 3.8854689371003995`*^9, {
   3.885481028234845*^9, 3.885481031203965*^9}},
 CellTags->"i:1",
 CellID->426547642,ExpressionUUID->"a50ed8a8-4753-44ea-9496-1ae1d2a3f708"],

Cell[TextData[{
 "This chapter uses a data resource from the ",
 ButtonBox["Wolfram Data Repository",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://datarepository.wolframcloud.com/"], None},
  ButtonNote->"https://datarepository.wolframcloud.com/"],
 " (",
 ButtonBox["wolfr.am/WDR",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/WDR"], None},
  ButtonNote->"https://wolfr.am/WDR"],
 "). To access the data, evaluate the following code."
}], "Text",
 CellChangeTimes->{{3.7788541127442904`*^9, 3.778854133414246*^9}, {
  3.8572256490833893`*^9, 3.857225653440201*^9}, {3.858239527815037*^9, 
  3.858239532155394*^9}, {3.858424346644807*^9, 3.858424359458304*^9}, {
  3.881405116028925*^9, 3.881405126665286*^9}, {3.882456298753354*^9, 
  3.88245631151073*^9}, {3.882456386237452*^9, 3.882456411907556*^9}, {
  3.882456487016274*^9, 3.882456505810841*^9}, {3.882459233780246*^9, 
  3.88245923595151*^9}, {3.885661478339286*^9, 3.8856614783415213`*^9}, {
  3.897744482548462*^9, 3.897744483706575*^9}},
 CellID->1532866539,ExpressionUUID->"2609f246-92e2-415c-beb9-fbfa7cc954f9"],

Cell[TextData[{
 "Acquire the ",
 ButtonBox["ResourceObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceObject.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceObject.html"],
 " from the Wolfram Data Repository: "
}], "CodeCaption",
 CellChangeTimes->{{3.77549691973217*^9, 3.775496924283777*^9}, {
  3.888932934911173*^9, 3.888932972321426*^9}, {3.888935936576232*^9, 
  3.888935936578513*^9}},
 CellID->336964028,ExpressionUUID->"0f329d3e-7fad-453a-b4cf-afcb301eb8f9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ro", "=", 
  RowBox[{
  "ResourceObject", "[", "\"\<Sample Data for Query Book\>\"", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.888932859088291*^9, 3.8889328965549097`*^9}},
 CellLabel->"In[3]:=",
 CellID->443800812,ExpressionUUID->"a65cd152-dccb-4faf-aeaa-7ff3afa64416"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["ResourceObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"], 
               ImageSizeCache -> {12., {0., 12.}}], Appearance -> None, 
              BaseStyle -> {}, ButtonFunction :> (Typeset`open$$ = True), 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            StyleBox[
             GraphicsBox[
              RasterBox[CompressedData["
1:eJztnMeOHUUUhi1gwZJX4C3YskFia8QD2MJYbIxkIyFehp1ztsc55+xxzjnn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               "], {{0, 0}, {180., 180.}}, {0, 255}, ColorFunction -> 
               RGBColor], AspectRatio -> 1, Axes -> False, Background -> None,
               Frame -> None, FrameTicks -> None, ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], PlotRange -> {{0, 180.}, {0, 180.}}], 
             StripOnInput -> False, CacheGraphics -> False], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Sample Data for Query Book\"", "\" \"", 
                    
                    TemplateBox[{
                    "\"\[RightGuillemet]\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"]}, "RowDefault"], 
                  "SummaryItem"]}], 
               TagBox["\"\"", "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"DataResource\"", "SummaryItem"]}], 
               "\[SpanFromLeft]"}, {
               TagBox[
                DynamicModuleBox[{ResourceSystemClient`Private`len$$ = 1}, 
                 RowBox[{
                   TagBox["\"Description: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    ButtonBox[
                    DynamicBox[
                    ToBoxes[
                    Replace[
                    ResourceSystemClient`Private`snipDots[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], Except[
                    Blank[String]] -> 
                    Snippet[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], {0}], StandardForm], 
                    ImageSizeCache -> {466., {2.2265625, 8.94140625}}], 
                    Appearance -> None, BaseStyle -> {}, 
                    ButtonFunction :> (ResourceSystemClient`Private`len$$ = 
                    Ceiling[ResourceSystemClient`Private`len$$ 1.5]), 
                    Evaluator -> Automatic, Method -> "Preemptive"], 
                    "SummaryItem"]}], DynamicModuleValues :> {}], 
                "SummaryItem"], "\[SpanFromLeft]"}}, AutoDelete -> False, 
             BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True -> 
        GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              Appearance -> None, BaseStyle -> {}, 
              ButtonFunction :> (Typeset`open$$ = False), Evaluator -> 
              Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            StyleBox[
             GraphicsBox[
              RasterBox[CompressedData["
1:eJztnMeOHUUUhi1gwZJX4C3YskFia8QD2MJYbIxkIyFehp1ztsc55+xxzjnn
nFMx/0BJFBhcd6qu65y+3ycdCxzOrTrnuz3dVd395cSfx//4ybhx46Z9PvLL
+Am/fj116oTfvvti5H++nzLtp8lTJv3w7ZRfJk2eNPWriZ+O/ObQX/HZSAQA
AAAAAAAAAABwwfTp0wnCVOAz0aXAZ6JLgc9ElwKfiS4FPhNdCnwmuhT4THQp
AAAAALpE63Mrwl9YpnVtCH9hmda1IfyFZVrXhvAXlmldG8JfWKZ1bQh/YZnW
tSH8hWVa14bwFwAAAAAAAAAeqX39+83vwz0FecaWJ8L6RQo++8wTwecUfPaZ
J4LPKfjsM08En1Pw2WeeCD6n4LPPPBF8TsFnn3ki+JyCzz7zRPA5BZ995ong
cwo++8wTwecUfPaZJ4LPKfjsM08En1Pw2WeeCD6n4LPPPBF8TsFnn3ki+JyC
zz7zRPA5BZ995ongcwo++8wTwecUfPaZJ4LPKfjsM08En1Pw2WeeCD6n4LPP
PBF8TsFnn3ki+JyCzz7zRPA5BZ995ongcwo++8wTwecUfPaZJ4LPKfjsM08E
n1Pw2WeeCD6n4LPPPBF8TsFnn3ki+JyCzz7zRPA5BZ995ongc0rXfa6F1Xnh
cwo+52F1Xvicgs95WJ0XPqfgcx5W54XPKfich9V54XMKPudhdV74nILPeVid
Fz6n4HMeVueFzyn4nIfVeeFzCj7nYXVe+JyCz3lYnRc+p+BzHlbnhc8p+JyH
tfFE8DkFn/OwNp4IPqfgcx7WxhPB5xR8zsPaeCL4nILPeVgbTwSfU/A5D2vj
ieBzCj7nYW08EXxOwec8rI0ngs8pVuthzR9r44lY7V8rrNbDmj/WxhOx2r9W
WK2HNX+sjSditX+tsFoPa/5YG0/Eav9aYbUe1vyxNp6I1f61wmo9rPljbTwR
q/1rhdV6WPPH2ngiVvvXCqv1sOaPtfFErPavFVbrYc0fa+OJWO1fK6zWw5o/
1sYTsdq/Vlith1V/rGG1f62wWg98zsNq/1phtR74nIfV/rXCaj3wOQ+r/WuF
1Xrgcx5W+9cKq/XA5zys9q8VVuuBz3lY7V8rrNYDn/Ow2r9WWK0HPudhtX+t
sFoPfM7Dav9aYbUe+JyH1f61wmo98DkPq/1rhdV64HMeVvvXCqv1wOc8rPYP
AAAAAAAAoCa9Xv/WCKgH/UuhHr6hfynUwzf0L4V6+Ib+pVAP39C/FOrhG/qX
Qj18Q/9SqIdv6B8AAAAAwOBy8ODBMH/+fIIwH4cOHfqgz3v37m1yjUsQvca+
ffvwmehM4DPRpcBnokuBz0SXAp+JLgU+E12KHJ8fP34cdu3aFWbOnFn8eevW
rQvXr18Pz549I4hw5syZsGTJkmKv5KYclau56PP3798fZs+eXfz5GzduDLdv
387+bOgO7969CxcuXAjLli0r9kguykm5OVZevnwZDh8+HObNm1c8nrVr144e
r6H7vHnzptrxWO7JQblYi9evX4cTJ06EhQsXFo9vxYoV4dKlS6PfXegW8uT4
8eNhwYIFxZ7INTmnnP3i7du34ezZs2Hp0qXF41UO5VJO8E3Nn+MtvNCxVcfY
lStXuvgeQn+oeZ0llyz83NY5sdYyLJ4nQX/Q2sLu3burroNZ486dO2HTpk3F
89N3fXh4uOg6FvrDgwcPwrZt28KMGTOK+7x58+Zw9+7d1lP6IA8fPgw7duwo
nrO++zoG9LLOCP2h1rFKPZUbcsQbT548Gd1vnDVrVlEN9L3QMeH+/futpzRw
1DqXlANy4enTp62nVMyLFy9Gn3uZO3ducV3Ym+k/uh67fPlylWt99Vy9lwNd
49WrV+HYsWNV1ibXrFkTrl271npKnULrY+fOnQtDQ0PF/VGP1Wv1vOto7+j0
6dNh8eLFxXXT3szFixebr/F4Rv04depUWLRoUXE/tB+o3irnoBH39pcvX16l
jtpfZW8mn/jzUs+WltZfPVQvOa78ydWrV8Pq1auL66q9Ge23sjfz39S8ntF5
n3oH7+fWrVuj13yldWZv5t9obaHGepNCPVKvIA+tzdVYt69xj6F3Hj16FHbu
3Fm8l8e6aTm19lXHcg+4d+7duxe2bt3KvpZBdHzVHnjpfS/qrXrc5WOMzgM2
bNhQfE4xZ86c0Zo/f/689ZQ6i86Hjxw5UuW+RPW8S+eAta6ptd6hGg/C2rEV
tL558uTJKmumcsDrNbrWx7T+XmPNU7VUTQdx7dgKNfe05ISXvZmaz1Wodqoh
a/d2iPccrFq1qri/cW/G4nGq5nNvqpVq5uH7O8jcuHEjrF+/vrjfugfByt5M
zeeZVJubN2+2nhL0iO4V37JlS3H/tY+mdw23uEdMawtaY9BaQ+k8VAut4YFv
dO94jf0ErRXqnTwf4x5e3Tu+Z8+e4r08zVlz154KdAt5KB9L17Dj3kw/HNHz
TNu3b6+yL/qxvnvQFp036Pyh9H6cuDdT42e4zo30PF2tcyPuWxk8ar77RHsz
Y7nG0rVrjeeZuK8QIlp3rfVuqty9mStXrlRZW9T6M/d9w/uIe2165qXUM71/
8J/3t8u58+fPV3k3Ic/lQC/o2US9P7LUOz1TpuePaj1fxjstoQQ9S17jvROl
oTHwXDvUotY6Wi+hz9Jn6rMB+kGtfY7/C+XWZ+izAD4G2oc+cOBAlX3oGMql
nNw/D63QPe9Hjx4teuZf/1Y5uH8erBDfydLLGob+rv6NxftSAUTOGrP+TH+H
PRDwhPYA//48n/5bvwfgGT1z26XnbgEAAAAAAAAAoH/8AXp/T6M=
               "], {{0, 0}, {180., 180.}}, {0, 255}, ColorFunction -> 
               RGBColor], AspectRatio -> 1, Axes -> False, Background -> None,
               Frame -> None, FrameTicks -> None, ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], PlotRange -> {{0, 180.}, {0, 180.}}], 
             StripOnInput -> False, CacheGraphics -> False], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Sample Data for Query Book\"", "\" \"", 
                    
                    TemplateBox[{
                    "\"\[RightGuillemet]\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"]}, "RowDefault"], 
                  "SummaryItem"]}], 
               TagBox["\"\"", "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"DataResource\"", "SummaryItem"]}], 
               "\[SpanFromLeft]"}, {
               TagBox[
                DynamicModuleBox[{ResourceSystemClient`Private`len$$ = 1}, 
                 RowBox[{
                   TagBox["\"Description: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    ButtonBox[
                    DynamicBox[
                    ToBoxes[
                    Replace[
                    ResourceSystemClient`Private`snipDots[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], Except[
                    Blank[String]] -> 
                    Snippet[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], {0}], StandardForm]],
                     Appearance -> None, BaseStyle -> {}, 
                    ButtonFunction :> (ResourceSystemClient`Private`len$$ = 
                    Ceiling[ResourceSystemClient`Private`len$$ 1.5]), 
                    Evaluator -> Automatic, Method -> "Preemptive"], 
                    "SummaryItem"]}], DynamicModuleValues :> {}], 
                "SummaryItem"], "\[SpanFromLeft]"}, {
               RowBox[{
                 TagBox["\"Categories: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{
                    ",", "\",\"", "\"Astronomy\"", "\"History\"", 
                    "\"Human Activities\""}, "RowWithSeparators"], Short], 
                  "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"ContentTypes: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{
                    ",", "\",\"", "\"Text\"", "\"Numerical Data\""}, 
                    "RowWithSeparators"], Short], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Keywords: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{",", "\",\"", "\"Dataset\"", "\"Query\""}, 
                    "RowWithSeparators"], Short], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Documentation: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  TemplateBox[{
                   "\"https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"], "SummaryItem"]}], 
               ""}, {
               RowBox[{
                 TagBox["\"Data Location: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  DynamicModuleBox[{
                   ResourceSystemClient`Private`typesetstorage$$ = 
                    ResourceSystemClient`Private`typesetstorageLocation, 
                    ResourceSystemClient`Private`info$$}, 
                   DynamicBox[
                    ToBoxes[
                    ResourceSystemClient`Private`info$$ = 
                    ResourceSystemClient`Private`resourceInfo[
                    "bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7"]; If[
                    AssociationQ[ResourceSystemClient`Private`info$$], 
                    ResourceSystemClient`Private`typesetstorage$$[
                    Lookup[
                    ResourceSystemClient`Private`info$$, 
                    "ContentElementLocations", None]], 
                    Missing["NotAvailable"]], StandardForm]], 
                   DynamicModuleValues :> {}], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"UUID: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                 "\"bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7\"", "SummaryItem"]}],
                ""}, {
               RowBox[{
                 TagBox["\"Version: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"1.0.1\"", "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Size: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  TemplateBox[{
                   "918.7280000000001`", "\"kB\"", "kilobytes", 
                    "\"Kilobytes\""}, "Quantity"], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Elements: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   RowBox[{"\"aAssociation\"", ",", "\"Content\"", ",", 
                    RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}], 
                    ",", "\"Titanic List of Associations\"", ",", 
                    "\"Titanic List of Associations Dataset\""}], 
                   Short[#, 2]& ], "SummaryItem"]}], ""}}, AutoDelete -> 
             False, BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  ResourceObject[<|
   "Name" -> "Sample Data for Query Book", "UUID" -> 
    "bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7", "ResourceType" -> "DataResource", 
    "Version" -> "1.0.1", "Description" -> 
    "Data to support the Wolfram Media book Query: Getting Information from \
Data with the Wolfram Language", "RepositoryLocation" -> 
    URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
    "ContentSize" -> Quantity[918.7280000000001, "Kilobytes"], 
    "ContentElements" -> {
     "aAssociation", "Content", "Dinghy Association of Associations", 
      "Dinghy Association of Associations Dataset", 
      "Dinghy List of Associations", "Dinghy List of Associations Dataset", 
      "Eastern Cities List", "IDWeight List of Associations", 
      "Lifeboat List of Associations", 
      "Lifeboat List of Associations Dataset", "Mars Association", 
      "MLS List of Associations", "MLS List of Associations Dataset", 
      "MLS List of Lists", "MLS List of Lists Dataset", 
      "Planets Deeply Nested Structure", 
      "Planets Deeply Nested Structure Dataset", "Pops List", 
      "Titanic Cabins 2 List of Associations", 
      "Titanic Cabins 2 List of Associations Dataset", 
      "Titanic Cabins List of Associations", 
      "Titanic Cabins List of Associations Dataset", 
      "Titanic List of Associations", 
      "Titanic List of Associations Dataset"}|>, {
   ResourceSystemBase -> 
    "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.888932908054226*^9, 3.888933667462413*^9, 3.89946053551606*^9, 
   3.899480149933816*^9, {3.899544850701754*^9, 3.8995448729630527`*^9}},
 CellLabel->"Out[3]=",
 CellID->1590202819,ExpressionUUID->"c28bba0f-ac05-47e1-ac7d-aca1004c2ef6"]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Mathematica Expression", "Subsection",
 CellChangeTimes->{3.7747809712549524`*^9},
 CellID->398617365,ExpressionUUID->"450c392e-bea9-43c0-af64-21708afec750"],

Cell[TextData[{
 "In some computer languages, everything is an \[OpenCurlyDoubleQuote]object.\
\[CloseCurlyDoubleQuote] It\[CloseCurlyQuote]s a unifying paradigm that \
simplifies programming. In the Wolfram Language, there\[CloseCurlyQuote]s a \
different unifying paradigm: everything is an ",
 ButtonBox["Expression",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Expression.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Expression.html"],
 ". Among other virtues, the ubiquity of expressions means that knowledge \
gained in working with one area of the Wolfram Language generalizes over \
essentially every other area. Therefore, although it is definitely an \
investment to learn the Wolfram Language (and perhaps to unlearn programming \
paradigms prevalent in other languages), doing so pays extraordinary \
dividends in doing programming across domains."
}], "Text",
 CellTags->{"LastCellOfAPage", "i:2", "p: 16"},
 CellID->685805408,ExpressionUUID->"1dbeb66a-dfaa-42c0-8ab4-97b941c27ddf"],

Cell[TextData[{
 "An expression can be atomic, meaning it is deliberately made difficult to \
break apart. Examples of atomic expressions are numbers (including integers, \
reals, rational numbers, and complex numbers), strings, symbols, and certain \
compound objects, such as a ",
 ButtonBox["Graph",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Graph.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Graph.html"],
 ". This atomicity does not mean these expressions cannot be manipulated by \
the user; it just means one has to use some special capabilities to do so. \
Functions frequently employed in the Wolfram Language, such as ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " or ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ", won\[CloseCurlyQuote]t accomplish anything on atoms. The rational number ",
 Cell[BoxData[
  FormBox[
   FractionBox["2", "3"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "772777aa-cd82-437c-b985-e685f6de13c7"],
 " is atomic, for example, but one can extract the numerator using the ",
 ButtonBox["Numerator",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Numerator.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Numerator.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.76898799805162*^9, 3.7689880920899982`*^9}, {
   3.768988157878234*^9, 3.76898816223213*^9}, {3.7689882107307863`*^9, 
   3.768988270570766*^9}, {3.76898835069142*^9, 3.768988372661274*^9}, {
   3.7689885477509947`*^9, 3.768988560887184*^9}, {3.7691167147367153`*^9, 
   3.769116716220109*^9}, {3.769117238028883*^9, 3.769117328932625*^9}, {
   3.7748846133147783`*^9, 3.7748846267031174`*^9}, {3.774957284182368*^9, 
   3.7749572872136707`*^9}, 3.774957329498899*^9, {3.8561878634739943`*^9, 
   3.856187864846602*^9}, {3.865532698071012*^9, 3.8655327076986017`*^9}, {
   3.8854691430890226`*^9, 3.885469161001012*^9}},
 CellTags->"i:3",
 CellID->786758807,ExpressionUUID->"504d9dd4-055f-4d04-a729-57c38f1c52ca"],

Cell[TextData[{
 "To tell if the Wolfram Language considers an expression to be atomic, use ",
 ButtonBox["AtomQ",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/AtomQ.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/AtomQ.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.76898799805162*^9, 3.7689880920899982`*^9}, {
   3.768988157878234*^9, 3.76898816223213*^9}, {3.7689882107307863`*^9, 
   3.768988270570766*^9}, {3.76898835069142*^9, 3.768988372661274*^9}, {
   3.7689885477509947`*^9, 3.768988560887184*^9}, {3.7691167147367153`*^9, 
   3.769116716220109*^9}, {3.769117238028883*^9, 3.7691173158278027`*^9}, {
   3.773080378420267*^9, 3.7730803870731325`*^9}, {3.7730805325296764`*^9, 
   3.77308057946937*^9}, {3.774780981301957*^9, 3.7747809817109976`*^9}, 
   3.774783628631092*^9, 3.8854691999803867`*^9},
 CellID->412663331,ExpressionUUID->"07a5c61e-ed61-48ff-ba31-03e528faecde"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"AtomQ", "[", "3", "]"}], ",", 
   RowBox[{"AtomQ", "[", "4.2", "]"}], ",", 
   RowBox[{"AtomQ", "[", 
    RowBox[{"2", "/", "3"}], "]"}], ",", 
   RowBox[{"AtomQ", "[", "\[CapitalSigma]", "]"}], ",", 
   RowBox[{"AtomQ", "[", 
    RowBox[{"3", "+", 
     RowBox[{"4", "I"}]}], "]"}], ",", 
   RowBox[{"AtomQ", "[", "\"\<hello world\>\"", "]"}], ",", 
   RowBox[{"AtomQ", "[", "f", "]"}], ",", 
   RowBox[{"AtomQ", "[", 
    RowBox[{"Graph", "[", 
     RowBox[{"{", 
      RowBox[{"1", "\[Rule]", "2"}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"AtomQ", "[", 
    NamespaceBox["LinguisticAssistant",
     DynamicModuleBox[{Typeset`query$$ = "France", Typeset`boxes$$ = 
      TemplateBox[{"\"France\"", 
        RowBox[{"Entity", "[", 
          RowBox[{"\"Country\"", ",", "\"France\""}], "]"}], 
        "\"Entity[\\\"Country\\\", \\\"France\\\"]\"", "\"country\""}, 
       "Entity"], Typeset`allassumptions$$ = {}, Typeset`assumptions$$ = {}, 
      Typeset`open$$ = {1, 2}, Typeset`querystate$$ = {
      "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
       0.627688`6.249288819480442, "Messages" -> {}}}, 
      DynamicBox[ToBoxes[
        AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
         Dynamic[Typeset`query$$], 
         Dynamic[Typeset`boxes$$], 
         Dynamic[Typeset`allassumptions$$], 
         Dynamic[Typeset`assumptions$$], 
         Dynamic[Typeset`open$$], 
         Dynamic[Typeset`querystate$$]], StandardForm],
       ImageSizeCache->{137., {7., 16.}},
       TrackedSymbols:>{
        Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
         Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
      DynamicModuleValues:>{},
      UndoTrackedVariables:>{Typeset`open$$}],
     BaseStyle->{"Deploy"},
     DeleteWithContents->True,
     Editable->False,
     SelectWithContents->True], "]"}], ",", 
   RowBox[{"AtomQ", "[", 
    RowBox[{"Cos", "[", "2", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.768988376173061*^9, 3.7689884292761908`*^9}, {
  3.7691167426939*^9, 3.769116755436385*^9}, {3.856187906159215*^9, 
  3.856187929444727*^9}, {3.856188060110257*^9, 3.856188066896254*^9}},
 CellLabel->"In[3]:=",
 CellID->998454670,ExpressionUUID->"17f66242-35f0-4823-82b4-485af99b345d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "True", ",", "True", ",", "True", ",", "True", ",", "True", ",", "True", 
   ",", "True", ",", "True", ",", "False", ",", "False"}], "}"}]], "Output",
 CellChangeTimes->{3.7689884295708513`*^9, 3.769075768971855*^9, 
  3.769100639842421*^9, 3.769116755972568*^9, 3.769772672792922*^9, 
  3.769952918040498*^9, 3.7699755275415783`*^9, 3.771923575597815*^9, 
  3.771929507449678*^9, 3.856188070780943*^9, 3.85618864418402*^9, 
  3.8814160093235197`*^9},
 CellLabel->"Out[3]=",
 CellID->50388199,ExpressionUUID->"67003e05-2d64-49a1-87ff-9d6e532dee12"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Check Whether Various Expressions Are Atoms", "Subsubsection",
 CellChangeTimes->{{3.769178248452705*^9, 3.769178255185218*^9}, {
  3.774870715590661*^9, 3.7748707260953293`*^9}},
 CellID->109983855,ExpressionUUID->"a4893abb-dbff-4442-b03b-02a4b5f1548d"],

Cell["\<\
Even atomic expressions have something called a head. You can think of the \
head as being something a little bit like the \[OpenCurlyDoubleQuote]type\
\[CloseCurlyDoubleQuote] or \[OpenCurlyDoubleQuote]class\
\[CloseCurlyDoubleQuote] of a value in an object-oriented language, but the \
variety of \[OpenCurlyDoubleQuote]types\[CloseCurlyDoubleQuote] is much \
greater in the built-in Wolfram Language than it is in out-of-the-box \
versions of typical object-oriented languages such as Python, Java, or C++.\
\>", "Text",
 CellChangeTimes->{{3.769167338362142*^9, 3.7691674155952663`*^9}, {
  3.769167447178843*^9, 3.76916745444057*^9}, {3.7691775896356573`*^9, 
  3.769177646834367*^9}, {3.7748846584882956`*^9, 3.7748846605264993`*^9}, {
  3.777053739278511*^9, 3.777053739833417*^9}, {3.86553275048174*^9, 
  3.865532760801478*^9}, {3.885469240815777*^9, 3.8854692441439524`*^9}},
 CellTags->"i:4",
 CellID->1393188976,ExpressionUUID->"44f277d6-bdfb-4562-a481-145dd1f55423"],

Cell["Here are the heads of the previous expressions:", "CodeCaption",
 CellChangeTimes->{{3.769167338362142*^9, 3.7691674155952663`*^9}, {
   3.769167447178843*^9, 3.76916745444057*^9}, {3.7691775896356573`*^9, 
   3.769177646834367*^9}, {3.7748846584882956`*^9, 3.7748846605264993`*^9}, 
   3.777053739278511*^9, {3.777054683827958*^9, 3.777054692364867*^9}, {
   3.777054749571292*^9, 3.7770547502754107`*^9}, {3.856188109239002*^9, 
   3.856188110634589*^9}, {3.885400045771065*^9, 3.8854000488777547`*^9}, {
   3.8854676634603057`*^9, 3.885467668075001*^9}, {3.885652419873994*^9, 
   3.88565242035176*^9}},
 CellID->1657187447,ExpressionUUID->"1174dab3-3b71-4c62-9b2e-77ff2001c88b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Head", "[", "3", "]"}], ",", 
   RowBox[{"Head", "[", "4.2", "]"}], ",", 
   RowBox[{"Head", "[", 
    RowBox[{"2", "/", "3"}], "]"}], ",", 
   RowBox[{"Head", "[", "\[CapitalSigma]", "]"}], ",", 
   RowBox[{"Head", "[", 
    RowBox[{"3", "+", 
     RowBox[{"4", "I"}]}], "]"}], ",", 
   RowBox[{"Head", "[", "\"\<hello world\>\"", "]"}], ",", 
   RowBox[{"Head", "[", "f", "]"}], ",", 
   RowBox[{"Head", "[", 
    RowBox[{"Graph", "[", 
     RowBox[{"{", 
      RowBox[{"1", "\[Rule]", "2"}], "}"}], "]"}], "]"}], ",", 
   RowBox[{"Head", "[", 
    NamespaceBox["LinguisticAssistant",
     DynamicModuleBox[{Typeset`query$$ = "France", Typeset`boxes$$ = 
      TemplateBox[{"\"France\"", 
        RowBox[{"Entity", "[", 
          RowBox[{"\"Country\"", ",", "\"France\""}], "]"}], 
        "\"Entity[\\\"Country\\\", \\\"France\\\"]\"", "\"country\""}, 
       "Entity"], Typeset`allassumptions$$ = {}, Typeset`assumptions$$ = {}, 
      Typeset`open$$ = {1, 2}, Typeset`querystate$$ = {
      "Online" -> True, "Allowed" -> True, "mparse.jsp" -> 
       0.40503`6.059032185480842, "Messages" -> {}}}, 
      DynamicBox[ToBoxes[
        AlphaIntegration`LinguisticAssistantBoxes["", 4, Automatic, 
         Dynamic[Typeset`query$$], 
         Dynamic[Typeset`boxes$$], 
         Dynamic[Typeset`allassumptions$$], 
         Dynamic[Typeset`assumptions$$], 
         Dynamic[Typeset`open$$], 
         Dynamic[Typeset`querystate$$]], StandardForm],
       ImageSizeCache->{137., {7., 16.}},
       TrackedSymbols:>{
        Typeset`query$$, Typeset`boxes$$, Typeset`allassumptions$$, 
         Typeset`assumptions$$, Typeset`open$$, Typeset`querystate$$}],
      DynamicModuleValues:>{},
      UndoTrackedVariables:>{Typeset`open$$}],
     BaseStyle->{"Deploy"},
     DeleteWithContents->True,
     Editable->False,
     SelectWithContents->True], "]"}], ",", 
   RowBox[{"Head", "[", 
    RowBox[{"Cos", "[", "2", "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.769167356792489*^9, 3.769167360289721*^9}, {
  3.76916745946883*^9, 3.7691674765574417`*^9}, {3.8561881140874357`*^9, 
  3.856188130345511*^9}},
 CellLabel->"In[4]:=",
 CellID->1305550552,ExpressionUUID->"2bb3d6ec-b4c5-4289-b556-6e66f6b2a7f1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "Integer", ",", "Real", ",", "Rational", ",", "Symbol", ",", "Complex", ",",
    "String", ",", "Symbol", ",", "Graph", ",", "Entity", ",", "Cos"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.769167358119279*^9, 3.769167476982978*^9, 
  3.769772672834841*^9, 3.769975527554027*^9, 3.771923575646214*^9, 
  3.771929507484473*^9, 3.856188130935338*^9, 3.856188646882165*^9, 
  3.881416024333272*^9},
 CellLabel->"Out[4]=",
 CellID->730622150,ExpressionUUID->"f0259c63-2b86-478b-a068-95587d0edbbe"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Heads of Common Expressions", "Subsubsection",
 CellChangeTimes->{{3.7691782581141167`*^9, 3.769178263027725*^9}, {
  3.774870896494367*^9, 3.774870902814999*^9}, {3.880556899579393*^9, 
  3.880556906227601*^9}},
 CellID->196721535,ExpressionUUID->"3343b2cd-c6fb-4567-9551-11bdeced9576"],

Cell[TextData[{
 "Lots of Wolfram Language expressions are not atomic. They not only have a ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 ", but they also have various elements that can themselves be atoms or \
compound expressions. One often writes the expression in a way that \
emphasizes the head. It comes first. The remaining elements\[LongDash]which \
are sometimes called parts or arguments (or even operands)\[LongDash]are \
separated by commas. Often one refers to an expression written with all the \
heads set forth explicitly as being in ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 ". If many but not all of the heads are set forth explicitly and no use is \
made of advanced two-dimensional typesetting, the expression is often \
referred to as being in ",
 ButtonBox["InputForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/InputForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/InputForm.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.7689880332642307`*^9, 3.7689880365220413`*^9}, {
   3.768988071152667*^9, 3.7689881051232862`*^9}, 3.768988168938095*^9, {
   3.76898827444678*^9, 3.768988288090716*^9}, 3.768988346452022*^9, {
   3.7689884677074413`*^9, 3.768988533014748*^9}, {3.768989991782881*^9, 
   3.768990037445903*^9}, {3.768990230145467*^9, 3.768990248334343*^9}, {
   3.7691168733898907`*^9, 3.7691168967108107`*^9}, {3.76916728805169*^9, 
   3.769167332572115*^9}, {3.769167493423595*^9, 3.769167534283309*^9}, {
   3.769177659011752*^9, 3.769177663985012*^9}, 3.7747836326866865`*^9, {
   3.7748846995113974`*^9, 3.7748847007045164`*^9}, {3.7748847475221977`*^9, 
   3.7748847564930944`*^9}, {3.777054740883685*^9, 3.777054741335307*^9}, {
   3.85618820782522*^9, 3.856188208702924*^9}, 3.856188543669775*^9, {
   3.856189237082717*^9, 3.856189299993207*^9}, {3.856189330602849*^9, 
   3.856189369830297*^9}, {3.856523283019229*^9, 3.856523327920223*^9}, {
   3.8565233769744797`*^9, 3.85652338235818*^9}, {3.865532873977667*^9, 
   3.8655328823233852`*^9}, {3.8854698298024535`*^9, 
   3.8854698328163424`*^9}, {3.8856615595370007`*^9, 3.885661566667741*^9}, {
   3.896338045608777*^9, 3.8963380463128643`*^9}},
 CellTags->{"LastCellOfAPage", "i:5"},
 CellID->590421032,ExpressionUUID->"a3f2149e-424c-40cf-89de-5f7013756d48"],

Cell["\<\
Here are some examples; the semicolon at the end of the input suppresses the \
output:\
\>", "CodeCaption",
 CellChangeTimes->{{3.7689880332642307`*^9, 3.7689880365220413`*^9}, {
   3.768988071152667*^9, 3.7689881051232862`*^9}, 3.768988168938095*^9, {
   3.76898827444678*^9, 3.768988288090716*^9}, 3.768988346452022*^9, {
   3.7689884677074413`*^9, 3.768988533014748*^9}, {3.768989991782881*^9, 
   3.768990037445903*^9}, {3.768990230145467*^9, 3.768990248334343*^9}, {
   3.7691168733898907`*^9, 3.7691168967108107`*^9}, {3.76916728805169*^9, 
   3.769167332572115*^9}, {3.769167493423595*^9, 3.769167534283309*^9}, {
   3.769177659011752*^9, 3.769177663985012*^9}, 3.7747836326866865`*^9, {
   3.7748846995113974`*^9, 3.7748847007045164`*^9}, {3.7748847475221977`*^9, 
   3.7748847564930944`*^9}, {3.777054740883685*^9, 3.77705474693934*^9}, {
   3.8561882298450212`*^9, 3.856188243907385*^9}, 3.885469925422762*^9},
 CellTags->"p: 17",
 CellID->889805339,ExpressionUUID->"77cec30f-065c-4b2c-8f01-c09c8686e77a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", "6", "]"}], ",", 
    RowBox[{"h", "[", 
     RowBox[{"3", ",", "4"}], "]"}], ",", 
    RowBox[{"Sin", "[", "3", "]"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{"8", ",", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "x", "]"}], "\[Rule]", 
       RowBox[{"4", "+", 
        RowBox[{
         SuperscriptBox["\[ExponentialE]", "x"], " ", 
         TemplateBox[{"1"},
          "C"]}]}]}], "}"}], "}"}]}], "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.768990372827149*^9, 3.768990378112108*^9}, {
   3.768990531751986*^9, 3.768990534291813*^9}, {3.7689906025759563`*^9, 
   3.768990602796958*^9}, {3.768990639646942*^9, 3.768990639956184*^9}, {
   3.769008219042132*^9, 3.7690082244080143`*^9}, {3.76917827601408*^9, 
   3.769178306707288*^9}, 3.8561882154601727`*^9},
 CellLabel->"In[5]:=",
 CellID->1831835684,ExpressionUUID->"c8641900-79f9-43e7-a5d1-098ca5c81612"],

Cell[TextData[{
 "As explained more fully in some of the basic references on the subject, \
such as Section 33 of Stephen Wolfram\[CloseCurlyQuote]s ",
 StyleBox[ButtonBox["An Elementary Introduction to the Wolfram Language",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.wolfram.com/language/elementary-introduction/2nd-ed/33-\
expressions-and-their-structure.html"], None},
  ButtonNote->
   "https://www.wolfram.com/language/elementary-introduction/2nd-ed/33-\
expressions-and-their-structure.html"],
  FontSlant->"Italic"],
 ", there is also syntactic sugar to simplify inputs and avoid explicitly \
writing out the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 ". The Wolfram Language front end also sometimes uses syntactic sugar in \
representing outputs. The most common example is the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " data container. Although one can certainly write it as ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["List",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/List.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/List.html"], "[", 
   RowBox[{"3", ",", "4"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "8ecaed99-5021-41ee-88b2-b43ae890bff3"],
 ", the more common way is to surround the arguments in curly braces like \
this: ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"3", ",", "4"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "4c2a4b9a-3b80-45eb-95e3-12c7c326dcb4"],
 ". Notice that by default the Wolfram Language front end represents Lists \
using this syntactic sugar."
}], "Text",
 CellChangeTimes->{{3.856188251300633*^9, 3.8561883523120832`*^9}, {
   3.856188382638261*^9, 3.8561884366617613`*^9}, {3.856188482773497*^9, 
   3.85618860609381*^9}, {3.856188911584176*^9, 3.8561889402584743`*^9}, {
   3.856189185440741*^9, 3.856189215597134*^9}, {3.856519215612945*^9, 
   3.8565192156172123`*^9}, {3.85651929224864*^9, 3.8565193103431473`*^9}, {
   3.85651939544107*^9, 3.8565194170669403`*^9}, {3.856519582223823*^9, 
   3.856519582787621*^9}, {3.856523409259713*^9, 3.856523415074943*^9}, {
   3.8565234503103857`*^9, 3.856523510898868*^9}, {3.877536336440906*^9, 
   3.877536337593719*^9}, {3.8853953616925354`*^9, 3.8853953632034855`*^9}, {
   3.8854699517942553`*^9, 3.885470008677039*^9}, 3.8896301475048285`*^9, {
   3.889630596648286*^9, 3.889630607250304*^9}, {3.896338104848901*^9, 
   3.896338121752537*^9}},
 CellTags->"i:6",
 CellID->1372229709,ExpressionUUID->"00ebf5bb-a424-47e2-b99e-99e828abdbcf"],

Cell[TextData[{
 "Expressions with a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " get placed in curly braces by default:"
}], "CodeText",
 CellChangeTimes->{{3.880556940618279*^9, 3.880556968706173*^9}},
 CellID->82217185,ExpressionUUID->"985d047b-6f92-4695-88ed-be9042b9f47a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"List", "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.8561886088964987`*^9, 3.856188609896553*^9}},
 CellLabel->"In[6]:=",
 CellID->1141266688,ExpressionUUID->"cfc7aced-184a-4803-9bc2-214f9c052a01"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "4"}], "}"}]], "Output",
 CellChangeTimes->{3.856188610491501*^9, 3.856188652243116*^9, 
  3.8814160442022457`*^9},
 CellLabel->"Out[6]=",
 CellID->961298532,ExpressionUUID->"8ba27a33-11cd-4a93-9eed-b8f29249e97a"]
}, Open  ]],

Cell[TextData[{
 "The Wolfram Language typically represents many of its operators using \
syntactic sugar. The following input shows some of the many occasions in \
which the Wolfram Language front end takes expressions input using ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 " but renders them in a more pleasing standard form (called ",
 ButtonBox["StandardForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/StandardForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/StandardForm.html"],
 ")."
}], "Text",
 CellChangeTimes->{{3.856188694375746*^9, 3.856188739490903*^9}, {
  3.8561888408663473`*^9, 3.85618887120804*^9}, {3.856189386154498*^9, 
  3.856189430736565*^9}, {3.856523530283279*^9, 3.856523543570499*^9}, {
  3.8854701249020042`*^9, 3.885470137514758*^9}, {3.889630643109538*^9, 
  3.889630649459571*^9}},
 CellTags->"i:7",
 CellID->910539663,ExpressionUUID->"8a37c9d7-4439-4ffa-a0ef-c7575efb5c4e"],

Cell[TextData[{
 ButtonBox["StandardForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/StandardForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/StandardForm.html"],
 " representation of expressions:"
}], "CodeText",
 CellChangeTimes->{{3.880557026036799*^9, 3.8805570561888742`*^9}},
 CellID->1810807761,ExpressionUUID->"0ea16ac6-f2a9-4ca2-bc59-37d0b25a3fe6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Plus", "[", 
    RowBox[{"a", ",", " ", "b"}], "]"}], ",", 
   StyleBox[
    RowBox[{"Plus", "[", 
     RowBox[{
      RowBox[{"Times", "[", 
       RowBox[{
        RowBox[{"Power", "[", 
         RowBox[{"5", ",", 
          RowBox[{"Rational", "[", 
           RowBox[{
            RowBox[{"-", "1"}], ",", "2"}], "]"}]}], "]"}], ",", "x"}], "]"}],
       ",", 
      RowBox[{"Power", "[", 
       RowBox[{"y", ",", "2"}], "]"}], ",", 
      RowBox[{"Power", "[", 
       RowBox[{"z", ",", 
        RowBox[{"-", "1"}]}], "]"}]}], "]"}],
    ShowSpecialCharacters->False,
    ShowStringCharacters->True,
    NumberMarks->True], " ", ",", " ", 
   RowBox[{"Blank", "[", "j", "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.899206965247006*^9, 3.89920698889277*^9}},
 CellLabel->"In[542]:=",
 CellID->1315079915,ExpressionUUID->"358c2798-2446-427d-a028-ff7dd5b73a17"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"a", "+", "b"}], ",", 
   RowBox[{
    FractionBox["x", 
     SqrtBox["5"]], "+", 
    SuperscriptBox["y", "2"], "+", 
    FractionBox["1", "z"]}], ",", "_j"}], "}"}]], "Output",
 CellChangeTimes->{3.8992069935181227`*^9},
 CellLabel->"Out[542]=",
 CellID->646436481,ExpressionUUID->"8121912a-9373-4403-9608-3c20955bf830"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html?v=13.2"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 " Function"
}], "Subsection",
 CellChangeTimes->{{3.7689875398213167`*^9, 3.768987544475573*^9}, {
   3.773080732443666*^9, 3.7730807345798798`*^9}, 3.8896307843680677`*^9, 
   3.893526808349698*^9, {3.893526865244945*^9, 3.8935268652475557`*^9}, {
   3.893766507324959*^9, 3.893766515973692*^9}},
 CellID->1336777596,ExpressionUUID->"3c6a2bb0-3898-4b8e-96f0-4d8f5f19d387"],

Cell[TextData[{
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " is the basic function for probing the structure of a Wolfram Language \
expression. It relies on the idea of creating an indexing between the \
recognizable components of the expression and an integer (or list of \
integers). Thus, in the expression ",
 Cell[BoxData[
  RowBox[{"h", "[", 
   RowBox[{"3", ",", "4"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "debaf414-310f-4b6f-80f5-c8f43366ec7e"],
 ", the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " ",
 Cell[BoxData[
 "h"], "InlineCodeText",ExpressionUUID->
  "112f83e9-80c0-4111-bdad-75d6041f4f03"],
 " is the zeroth part, the integer 3 is the first part, and the integer 4 is \
the second part. Here\[CloseCurlyQuote]s how I can ask for just the second \
part of the expression."
}], "Text",
 CellChangeTimes->{{3.768990387553709*^9, 3.768990389487206*^9}, {
   3.768990494327932*^9, 3.7689905709568663`*^9}, {3.7691169112735987`*^9, 
   3.7691169122195263`*^9}, {3.769117357014567*^9, 3.769117392975687*^9}, {
   3.769167598938292*^9, 3.7691677409219923`*^9}, {3.7748853804764867`*^9, 
   3.774885383684808*^9}, {3.774885478207259*^9, 3.774885510361474*^9}, {
   3.774885733403776*^9, 3.774885735216957*^9}, {3.7748857911425495`*^9, 
   3.7748858113995748`*^9}, {3.774966580255329*^9, 3.774966584309329*^9}, 
   3.7754886568649836`*^9, 3.7770550776035147`*^9, {3.8655921092788963`*^9, 
   3.8655921211212673`*^9}, {3.8757844202254963`*^9, 3.8757844202826967`*^9}, 
   3.8854703096131783`*^9, 3.889630795964818*^9},
 CellTags->"i:8",
 CellID->247141058,ExpressionUUID->"ab7f8a5d-e5ed-481c-9081-cd00896fa107"],

Cell[TextData[{
 "Get a numbered ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " of an expression:"
}], "CodeCaption",
 CellChangeTimes->{{3.769178317207699*^9, 3.769178337487061*^9}, 
   3.7730812870311193`*^9, {3.7770550160830917`*^9, 3.777055018743353*^9}},
 CellID->890813444,ExpressionUUID->"06c22fb9-c464-40ad-a90b-693abba7ad45"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"3", ",", "4"}], "]"}], ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.768990522170156*^9, 3.768990538562778*^9}},
 CellLabel->"In[8]:=",
 CellID->466388508,ExpressionUUID->"9f9a2433-631d-46d9-985f-3c3904fd676a"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.768990539038698*^9, 3.769075769006381*^9, 
  3.7691006398944473`*^9, 3.769772672885848*^9, 3.769975527609606*^9, 
  3.7719235756906424`*^9, 3.7719295075598993`*^9, 3.881416055019884*^9},
 CellLabel->"Out[8]=",
 CellID->827012536,ExpressionUUID->"b471f653-0c54-46f9-aae0-835f252f0738"]
}, Open  ]],

Cell[TextData[{
 "And here I ask for the third part of the second part of ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}]], "InlineCodeText",
  ExpressionUUID->"1aab4ace-d212-4f34-ab3b-e05346c09aad"],
 ". By the way, I\[CloseCurlyQuote]m going to use this example expression a \
lot in the chapter, but, rather than assigning it to a symbol (or variable) \
and asking you to keep looking at this page to remember what it means, I ask \
you to kind of memorize and recognize it. "
}], "Text",
 CellChangeTimes->{{3.768990577674349*^9, 3.768990646061501*^9}, {
   3.76900825513167*^9, 3.769008295410552*^9}, {3.769117038276601*^9, 
   3.7691170656135807`*^9}, {3.769117403369104*^9, 3.769117403521785*^9}, {
   3.769178152386944*^9, 3.7691781737143517`*^9}, {3.774885850833518*^9, 
   3.7748858510005345`*^9}, 3.774966597465329*^9, {3.85619717475922*^9, 
   3.856197182328101*^9}, 3.856523778569849*^9},
 CellTags->"LastCellOfAPage",
 CellID->276342406,ExpressionUUID->"ea725a32-3aa8-42b2-8c2a-fb56e97fa64e"],

Cell[TextData[{
 "Get ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " of an expression beyond the first level:"
}], "CodeCaption",
 CellChangeTimes->{{3.769178344134918*^9, 3.769178351180545*^9}, 
   3.7747809972865553`*^9, {3.777055027634781*^9, 3.7770550453874493`*^9}},
 CellTags->"p: 18",
 CellID->2041117656,ExpressionUUID->"3271066d-5989-4611-8420-122bc08663c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", "2", ",", "3"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.768990620425428*^9, 3.76899064981678*^9}, {
   3.769008242368908*^9, 3.7690082464785547`*^9}, {3.769008307353217*^9, 
   3.769008307961384*^9}, 3.769116959319419*^9},
 CellLabel->"In[9]:=",
 CellID->1627172828,ExpressionUUID->"e19488c3-2a11-447f-af2a-ed4bb4ddf3ed"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{{3.768990635166204*^9, 3.768990650211672*^9}, 
   3.769008252971183*^9, 3.769008308485108*^9, 3.769075769037752*^9, 
   3.769100639943132*^9, 3.769117410590106*^9, 3.7697726729281054`*^9, 
   3.769975527653009*^9, 3.771923575746739*^9, 3.771929507571315*^9, 
   3.881416067570257*^9},
 CellLabel->"Out[9]=",
 CellID->1553943897,ExpressionUUID->"e32aa0f3-7075-4c17-a9d8-078205d47e07"]
}, Open  ]],

Cell[TextData[{
 "The first argument to ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " is the structure to be probed. The second argument is like a set of \
directions to navigate to that structure\[CloseCurlyQuote]s desired component."
}], "Text",
 CellChangeTimes->{{3.769167750418309*^9, 3.769167760499523*^9}, {
   3.774783993034005*^9, 3.774783993882005*^9}, 3.8565238206846437`*^9},
 CellID->279149526,ExpressionUUID->"ccfc0900-1f15-48d6-8088-8b288349cc92"],

Cell[TextData[{
 "To see what is going on in the example code and to understand the structure \
of Wolfram Language expressions in general, it is often useful to use a \
visualization function known as ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.768990659695448*^9, 3.768990731911305*^9}, {
   3.76900832080961*^9, 3.769008334006412*^9}, 3.769117423445428*^9, 
   3.773080798083229*^9, {3.7747836348474703`*^9, 3.774783635014454*^9}, {
   3.7748863404920125`*^9, 3.7748863442904925`*^9}, 3.777055158580141*^9, {
   3.777055236874647*^9, 3.7770552376901503`*^9}, {3.856523864823063*^9, 
   3.856523902918076*^9}, 3.856523980899468*^9},
 CellTags->"i:9",
 CellID->1836959298,ExpressionUUID->"7a578177-bcf0-4713-871b-aedcc4111c0d"],

Cell[TextData[{
 "Visualize the ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " of the expression ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"8", ",", " ", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", " ", "y", ",", " ", "9"}], "]"}]}], "]"}]], 
  "InlineCode",ExpressionUUID->"ff5ddb76-598e-47bf-9895-8ba93ef3b5ab"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7730808037767982`*^9, 3.7730808425526757`*^9, 3.773157947795763*^9, 
   3.774781000383865*^9, {3.774966624828329*^9, 3.774966633590329*^9}, 
   3.777055166483733*^9, {3.8561972118039227`*^9, 3.856197261416758*^9}, 
   3.856197298811461*^9, 3.8775365312255583`*^9, {3.8856483072131634`*^9, 
   3.885648372960268*^9}, {3.8856484201143312`*^9, 3.8856484240964165`*^9}, {
   3.88566178470881*^9, 3.88566178821035*^9}, {3.889631378986609*^9, 
   3.8896313816654544`*^9}},
 CellID->67674739,ExpressionUUID->"023e5eb4-221d-4d93-8abe-07b2127513bb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TreeForm", "[", 
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7689907334043407`*^9, 3.768990740264448*^9}, {
   3.76900831253179*^9, 3.769008314833232*^9}, 3.769116964777871*^9, {
   3.771923597596808*^9, 3.771923599337797*^9}, 3.856197293378014*^9},
 CellLabel->"In[10]:=",
 CellID->1550012214,ExpressionUUID->"64d72f14-72f8-4e65-9e9b-d7ae32f4df84"],

Cell[BoxData[
 InterpretationBox[
  GraphicsBox[
   TagBox[
    GraphicsComplexBox[{{0.4082482904638631, 1.6329931618554523`}, {0., 
     0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
     0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}, {
      {RGBColor[0.55, 0.45, 0.45], 
       LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 5}, {3, 6}}]}, {
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["g", "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 1],
         TagBox[
          RowBox[{"g", "[", 
            RowBox[{"8", ",", 
              RowBox[{"h", "[", 
                RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], HoldForm]],
        Annotation[#, 
         HoldForm[
          $CellContext`g[8, 
           $CellContext`h[$CellContext`x, $CellContext`y, 9]]], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["8",
             HoldForm], "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 2],
         TagBox["8", HoldForm]],
        Annotation[#, 
         HoldForm[8], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox["h", "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 3],
         TagBox[
          RowBox[{"h", "[", 
            RowBox[{"x", ",", "y", ",", "9"}], "]"}], HoldForm]],
        Annotation[#, 
         HoldForm[
          $CellContext`h[$CellContext`x, $CellContext`y, 9]], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["x",
             HoldForm], "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 4],
         TagBox["x", HoldForm]],
        Annotation[#, 
         HoldForm[$CellContext`x], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["y",
             HoldForm], "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 5],
         TagBox["y", HoldForm]],
        Annotation[#, 
         HoldForm[$CellContext`y], "Tooltip"]& ], 
       TagBox[
        TooltipBox[InsetBox[
          FrameBox[
           StyleBox[
            TagBox["9",
             HoldForm], "StandardForm", "Output",
            StripOnInput->False,
            LineColor->GrayLevel[0],
            FrontFaceColor->GrayLevel[0],
            GraphicsColor->GrayLevel[0],
            FontSize->Scaled[0.05],
            FontColor->GrayLevel[0],
            $CellContext`BackFaceColor -> GrayLevel[0]],
           Background->RGBColor[1., 1., 0.871],
           FrameStyle->GrayLevel[0.5],
           StripOnInput->False], 6],
         TagBox["9", HoldForm]],
        Annotation[#, 
         HoldForm[9], "Tooltip"]& ]}}],
    Annotation[#, 
     VertexCoordinateRules -> {{0.4082482904638631, 1.6329931618554523`}, {0.,
       0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
      0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}]& ],
   AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
   FormatType:>StandardForm,
   FrameTicks->Automatic,
   ImageSize->{163.305419921875, Automatic},
   PlotRange->All,
   PlotRangePadding->Scaled[0.1]],
  TreeForm[
   $CellContext`g[8, 
    $CellContext`h[$CellContext`x, $CellContext`y, 9]]],
  Editable->False]], "Output",
 CellChangeTimes->{3.768990740554907*^9, 3.769008336623632*^9, 
  3.769075769082707*^9, 3.769100639982374*^9, 3.769772672977825*^9, 
  3.769975527700123*^9, 3.7719235757900763`*^9, 3.7719295076626062`*^9, 
  3.8561972941145077`*^9, 3.88141607445927*^9},
 CellLabel->"Out[10]//TreeForm=",
 CellID->2073804615,ExpressionUUID->"45923161-e0d4-44bd-942a-8d28742ad155"]
}, Open  ]],

Cell[TextData[{
 "You can see now that the symbol ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "b0071545-7873-43a1-92ef-eb1143168447"],
 " has two descendants, ",
 Cell[BoxData[
 "8"], "InlineCodeText",ExpressionUUID->
  "d9990124-034a-4e6b-9d55-664c3b5f7adb"],
 " and ",
 Cell[BoxData[
  RowBox[{"h", "[", 
   RowBox[{"x", ",", "y", ",", "9"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "d028006f-fb7f-470b-a75e-a5068be3b791"],
 " and that the symbol ",
 Cell[BoxData[
 "h"], "InlineCodeText",ExpressionUUID->
  "e4a91834-9cac-45a1-8f47-f1821db4a60f"],
 " has three descendants, ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "7bb7146c-872d-4436-9714-4da984bdf4ae"],
 ", ",
 Cell[BoxData[
 "y"], "InlineCodeText",ExpressionUUID->
  "f5f6fb1b-9da7-4455-b96c-c28f3c12fe9f"],
 ", and ",
 Cell[BoxData[
 "9"], "InlineCodeText",ExpressionUUID->
  "2d9abcdb-0e55-4f62-99d1-391a019ca7d8"],
 ", so by saying ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Part",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Part.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"], "[", 
   RowBox[{
    RowBox[{"g", "[", 
     RowBox[{"8", ",", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "y", ",", "z"}], "]"}]}], "]"}], ",", "2", ",", 
    "3"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "b7bdbe31-17e0-4848-871f-300882c84cac"],
 ", one is essentially giving directions to a tree-descent algorithm. First, \
take the second argument and then take the third argument of what you find. \
That yields ",
 Cell[BoxData[
 "9"], "InlineCodeText",ExpressionUUID->
  "a3409ca5-ca31-413d-bc19-074cdb321b22"],
 "."
}], "Text",
 CellChangeTimes->{{3.76899074626799*^9, 3.768990848419694*^9}, {
   3.769008340366699*^9, 3.769008351959306*^9}, 3.774783637598195*^9, {
   3.774886376197934*^9, 3.774886408505703*^9}, {3.7748892957630053`*^9, 
   3.7748892992590055`*^9}, {3.774966662445329*^9, 3.774966714275329*^9}, 
   3.774966780797329*^9, 3.7749675492673087`*^9, {3.7749678905964384`*^9, 
   3.774967909128291*^9}, {3.775488542815984*^9, 3.775488561110984*^9}, 
   3.7754886829839835`*^9, {3.885470776169543*^9, 3.88547079706406*^9}},
 CellID->2078642588,ExpressionUUID->"cc5c120d-252e-4493-84d5-53eb7dae8c67"],

Cell[TextData[{
 "One can also use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " to get multiple parts of an expression. Here I first retrieve the second \
part of the expression, then the first part, and then the second part again. \
The results of the retrieval are separated by commas and the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " of the entire expression is preserved."
}], "Text",
 CellChangeTimes->{{3.768991111258621*^9, 3.7689911245945272`*^9}, {
   3.7689913251088448`*^9, 3.768991371915872*^9}, {3.768991438469208*^9, 
   3.768991445017836*^9}, 3.769117087175824*^9, {3.76916779755175*^9, 
   3.7691677989931087`*^9}, 3.7748893061640053`*^9, 3.774963305982541*^9, {
   3.777055321646202*^9, 3.777055324876445*^9}, {3.8561973889773397`*^9, 
   3.8561973924655037`*^9}, {3.885470936701706*^9, 3.885470938234644*^9}, 
   3.8855549337239485`*^9, 3.889631401237458*^9},
 CellID->482007120,ExpressionUUID->"a550081b-e4fd-462d-898d-967930eb6ed4"],

Cell["Retrieve multiple parts of an expression:", "CodeCaption",
 CellChangeTimes->{{3.769178966867383*^9, 3.769178974149056*^9}, 
   3.773157965943578*^9},
 CellID->1899507007,ExpressionUUID->"3ecaf931-116c-45f1-b628-78c757bf3423"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "1", ",", "2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.768991307563583*^9, 3.768991320827485*^9}, {
   3.7689913749032*^9, 3.768991381878787*^9}, {3.768991430443839*^9, 
   3.768991430595518*^9}, {3.769008357061432*^9, 3.769008357888763*^9}, 
   3.769116969375601*^9},
 CellLabel->"In[11]:=",
 CellID->785349356,ExpressionUUID->"6f8cbb11-e172-4e5a-87bb-1eaf5e5bf6f5"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "y", ",", "9"}], "]"}], ",", "8", ",", 
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.768991321172347*^9, {3.768991377705134*^9, 3.768991382322731*^9}, {
   3.768991431277734*^9, 3.7689914485434313`*^9}, 3.769008358422679*^9, 
   3.769075769090774*^9, 3.7691006400497923`*^9, 3.769117458095964*^9, 
   3.769772672991282*^9, 3.769975527713356*^9, 3.771923575802109*^9, 
   3.7719295076724033`*^9, 3.8814160846639757`*^9},
 CellLabel->"Out[11]=",
 CellID->615515707,ExpressionUUID->"3af0518f-20aa-47ba-9597-eead1d38c8b6"]
}, Open  ]],

Cell[TextData[{
 "Thus far, I have used positive integers to designate the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 ". But one can also designate parts using negative integers, which count \
backwards from the end of the expression."
}], "Text",
 CellChangeTimes->{{3.7689914850742073`*^9, 3.768991531530038*^9}, {
   3.768991585502571*^9, 3.768991595450223*^9}, {3.769167815219688*^9, 
   3.7691678279462767`*^9}, {3.7749673245108356`*^9, 3.774967325694954*^9}, {
   3.774969994911133*^9, 3.7749699957431326`*^9}, {3.85619741619084*^9, 
   3.856197421884926*^9}, 3.8854713645708666`*^9, {3.8896316943434343`*^9, 
   3.8896316999460697`*^9}},
 CellTags->{"LastCellOfAPage", "i:10"},
 CellID->932131830,ExpressionUUID->"adc9c446-ac64-481c-ae7f-749221b317a3"],

Cell["Here I ask for the second from the last part:", "CodeCaption",
 CellChangeTimes->{{3.7749699824811325`*^9, 3.774969991671133*^9}, 
   3.7770553792534122`*^9},
 CellTags->"p: 19",
 CellID->427695515,ExpressionUUID->"7f73b7ec-9ca4-4277-b69d-3d0764bef296"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"-", "2"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.768991533514721*^9, 3.768991541659472*^9}, {
   3.769008362766304*^9, 3.769008363233801*^9}, 3.7691169710915613`*^9},
 CellLabel->"In[12]:=",
 CellID->446461945,ExpressionUUID->"01f866d1-d48a-44d3-a368-967896d7f455"],

Cell[BoxData["8"], "Output",
 CellChangeTimes->{3.768991542093454*^9, 3.76900836375628*^9, 
  3.769075769115176*^9, 3.769100640088238*^9, 3.769772673033412*^9, 
  3.769975527756823*^9, 3.771923575836285*^9, 3.771929507704343*^9, 
  3.8814162391358747`*^9},
 CellLabel->"Out[12]=",
 CellID->222991843,ExpressionUUID->"d450349f-5b0f-4966-8f7f-f06be0978911"]
}, Open  ]],

Cell["\<\
Or I could ask for the third from the last part of the last part.\
\>", "Text",
 CellChangeTimes->{{3.7689915479333677`*^9, 3.7689915641612387`*^9}},
 CellID->378046997,ExpressionUUID->"04d32a5f-2afb-4fc6-840e-7db6556fea57"],

Cell["Use negative part numbers:", "CodeCaption",
 CellChangeTimes->{{3.769178976707429*^9, 3.7691789815492973`*^9}, {
  3.7731579764396276`*^9, 3.7731579845224357`*^9}, {3.7749700177101326`*^9, 
  3.7749700261251326`*^9}, {3.7749705679837832`*^9, 3.774970568991884*^9}},
 CellID->1928208512,ExpressionUUID->"5f625981-2143-4943-8c3d-8f5c5df38c81"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"-", "1"}], ",", 
   RowBox[{"-", "3"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.768991533514721*^9, 3.768991570949563*^9}, {
   3.769008369169874*^9, 3.769008370295211*^9}, 3.769116972067437*^9},
 CellLabel->"In[13]:=",
 CellID->1579250753,ExpressionUUID->"f137e36b-cc0a-4017-af8f-f25e45b14506"],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{3.768991571720706*^9, 3.7690083711733093`*^9, 
  3.7690757691416483`*^9, 3.7691006400962152`*^9, 3.7697726730477133`*^9, 
  3.7699755277695093`*^9, 3.771923575846443*^9, 3.771929507712463*^9, 
  3.881416243995151*^9},
 CellLabel->"Out[13]=",
 CellID->809342058,ExpressionUUID->"67f7331d-6006-495f-86bc-c11a1d9299c9"]
}, Open  ]],

Cell[TextData[{
 "Also, if I want the head of an expression, I use part ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "03e8fae4-9e3b-41c4-9f67-09c37fd33de2"],
 ". Indeed, so far as I can figure out, ",
 StyleBox["Head", "FormattedFunction"],
 " is really just a short way of asking for part ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "40e580ee-8de3-419d-ae71-bcbd35abcfd9"],
 ". Here are two examples."
}], "Text",
 CellChangeTimes->{{3.769167831865115*^9, 3.769167935788113*^9}, {
  3.7748722634596405`*^9, 3.774872264179641*^9}, {3.774970057114133*^9, 
  3.7749700682951326`*^9}, {3.777055478761894*^9, 3.7770555183634233`*^9}, {
  3.865533514593149*^9, 3.865533522636338*^9}, {3.865592156037998*^9, 
  3.8655921601387568`*^9}},
 CellTags->"i:11",
 CellID->1005068699,ExpressionUUID->"901883db-5cb9-4c41-8b88-a471c5708350"],

Cell[TextData[{
 "Use part ",
 Cell[BoxData[
  FormBox["0", TraditionalForm]],ExpressionUUID->
  "66d6db82-68eb-4c61-bc9b-4cca43581e56"],
 " to get the heads:"
}], "CodeCaption",
 CellChangeTimes->{{3.769178987750991*^9, 3.7691790005034227`*^9}, {
   3.773157994406424*^9, 3.7731579949954824`*^9}, 3.774781008022629*^9, {
   3.7749701256651325`*^9, 3.774970125864133*^9}, {3.7749705805930443`*^9, 
   3.7749705818971744`*^9}, {3.777055530446776*^9, 3.7770555327289047`*^9}, {
   3.8856524341899476`*^9, 3.8856524347334604`*^9}, {3.885652828459104*^9, 
   3.885652828891955*^9}},
 CellID->342325258,ExpressionUUID->"d16cd3ce-86a0-4e63-943f-33cac02c2514"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Part", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", "0"}], "]"}], 
   ",", 
   RowBox[{"Part", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", "2", ",", 
     "0"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.76916784102606*^9, 3.769167887302575*^9}},
 CellLabel->"In[14]:=",
 CellID->1204062296,ExpressionUUID->"9b345531-a5ca-4e99-a16a-d81c97bfb1f5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"g", ",", "h"}], "}"}]], "Output",
 CellChangeTimes->{{3.7691678495281057`*^9, 3.769167887775589*^9}, 
   3.769772673089286*^9, 3.7699755278126783`*^9, 3.7719235758585567`*^9, 
   3.7719295077241373`*^9, 3.881416250709722*^9},
 CellLabel->"Out[14]=",
 CellID->1076063832,ExpressionUUID->"8e47787a-cc40-45fd-bf1d-c18e283865e0"]
}, Open  ]],

Cell["\<\
There is syntactic sugar that many people use when trying to determine the \
Parts of Wolfram Language expressions: the double square bracket. One \
provides the expression and then follows that with the part number (or \
sequence of numbers) inside a mirrored opening and closing pair of double \
square brackets. Here is how one might get the second part of an expression.\
\>", "Text",
 CellChangeTimes->{{3.768995007419154*^9, 3.7689951384248123`*^9}, {
   3.769167954897727*^9, 3.769167955368968*^9}, {3.8561974617880983`*^9, 
   3.856197463867467*^9}, {3.8854717430682373`*^9, 3.8854717470981083`*^9}, 
   3.8854717836813507`*^9, {3.8856528974207506`*^9, 3.885652897587256*^9}},
 CellTags->"i:12",
 CellID->1717012398,ExpressionUUID->"a2b16fe6-44b4-4138-ae28-07ccce2bf1cf"],

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"[", "\[NegativeThinSpace]", 
    StyleBox["...",
     FontColor->GrayLevel[0.6]], "]"}], "]"}]], "InlineCode",ExpressionUUID->
  "c3f708fd-7c98-408b-b0f4-92f075d43264"],
 " notation:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179005386415*^9, 3.769179009729538*^9}, {
   3.7731581498569674`*^9, 3.7731581504260244`*^9}, 3.7747810111029367`*^9, 
   3.7749705290118866`*^9, {3.7749707325522385`*^9, 3.774970733054289*^9}, {
   3.7754890965099835`*^9, 3.7754890968659835`*^9}, {3.7770556123077183`*^9, 
   3.777055612307745*^9}, 3.896338654157254*^9},
 CellID->417260322,ExpressionUUID->"1d18a8da-46ec-4155-af91-c0ab68c7daec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.768995068247128*^9, 3.768995069361113*^9}, {
   3.7690083756968*^9, 3.769008376253519*^9}, 3.769116977495183*^9},
 CellLabel->"In[15]:=",
 CellID->2089608447,ExpressionUUID->"0272148d-d893-49a5-8a20-b419236dcef6"],

Cell[BoxData[
 RowBox[{"h", "[", 
  RowBox[{"x", ",", "y", ",", "9"}], "]"}]], "Output",
 CellChangeTimes->{3.768995069919612*^9, 3.769008376700395*^9, 
  3.769075769149291*^9, 3.7691006401340513`*^9, 3.769772673102585*^9, 
  3.7699755278263493`*^9, 3.771923575892632*^9, 3.7719295077558937`*^9, 
  3.881416255835925*^9},
 CellLabel->"Out[15]=",
 CellID->1032471710,ExpressionUUID->"8baf630f-f761-4422-8dd6-c21c6b8f54b3"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s how to get the negative third part of the second part.\
\>", "Text",
 CellChangeTimes->{{3.768995141714422*^9, 3.768995176083104*^9}, {
  3.7747837906690054`*^9, 3.7747837927490053`*^9}},
 CellID->101605691,ExpressionUUID->"a1c5d69b-6de7-47f8-ae59-be37c983f1b1"],

Cell[TextData[{
 "Combine negative ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " specifications with ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"[", "\[NegativeThinSpace]", 
    StyleBox["...",
     FontColor->GrayLevel[0.6]], "]"}], "]"}]], "InlineCode",ExpressionUUID->
  "ef328034-0a37-4a95-a5d9-468feed461cb"],
 " notation:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179089446266*^9, 3.769179103722004*^9}, {
   3.7731581540553875`*^9, 3.773158154774459*^9}, 3.774781014095236*^9, 
   3.774970538463832*^9, {3.774970744903474*^9, 3.774970745423526*^9}, {
   3.7754891007449837`*^9, 3.7754891011139836`*^9}, {3.7770556259070473`*^9, 
   3.777055625907073*^9}, {3.8856492554222603`*^9, 3.885649273577081*^9}, {
   3.889631747627887*^9, 3.889631752756673*^9}, {3.8958145864877443`*^9, 
   3.895814586487802*^9}, 3.89633866092575*^9, 3.89766969317983*^9},
 CellID->530410008,ExpressionUUID->"971c2489-8dc8-4d1f-bc3f-66666300f355"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"2", ",", 
    RowBox[{"-", "3"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.768995184077094*^9, 3.7689951843720837`*^9}, {
   3.7690083803029547`*^9, 3.769008383796637*^9}, 3.769116980065843*^9},
 CellLabel->"In[16]:=",
 CellID->437349272,ExpressionUUID->"df0de466-17ad-4e57-9d4b-d5981a50e74c"],

Cell[BoxData["x"], "Output",
 CellChangeTimes->{3.769008388648101*^9, 3.7690757691759043`*^9, 
  3.769100640142826*^9, 3.7697726731438503`*^9, 3.769975527869149*^9, 
  3.7719235759057093`*^9, 3.7719295077642384`*^9, 3.8814162601189528`*^9},
 CellLabel->"Out[16]=",
 CellID->197153837,ExpressionUUID->"5c302b8b-e1b4-4247-95f3-46dfc10aaff5"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s how to get both the second part and the negative \
second part.\
\>", "Text",
 CellChangeTimes->{{3.768995194520327*^9, 3.7689952034987373`*^9}, {
  3.769179029421928*^9, 3.769179047996504*^9}, {3.774784002081005*^9, 
  3.774784002474005*^9}},
 CellID->1840174470,ExpressionUUID->"c68fc838-cc5a-4671-935d-d9b9b475880b"],

Cell[TextData[{
 "Retrieve multiple parts with ",
 Cell[BoxData[
  RowBox[{"[", 
   RowBox[{"[", "\[NegativeThinSpace]", 
    StyleBox["...",
     FontColor->GrayLevel[0.6]], "]"}], "]"}]], "InlineCode",ExpressionUUID->
  "a0cf008f-c0b7-4923-8ce2-bf69e58d1f25"],
 " notation:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179107506558*^9, 3.7691791173557673`*^9}, {
   3.7731581706310444`*^9, 3.773158171210102*^9}, 3.774781016527479*^9, {
   3.7749707477917624`*^9, 3.7749707560345864`*^9}, {3.7754891038829837`*^9, 
   3.7754891042259836`*^9}, {3.777055645426972*^9, 3.777055645427*^9}, {
   3.8856492814049134`*^9, 3.8856492876545753`*^9}, {3.89581459557932*^9, 
   3.895814617722858*^9}, {3.895814662698969*^9, 3.895814662698995*^9}, 
   3.896338667437337*^9},
 CellID->433393526,ExpressionUUID->"ca3126e1-ab0c-4685-82bb-bba7d7c00c01"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     RowBox[{"-", "2"}]}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.768995211431541*^9, 3.7689952132703133`*^9}, {
   3.7690083928556747`*^9, 3.769008393385276*^9}, 3.76911698093707*^9, {
   3.76917903584531*^9, 3.769179050632092*^9}},
 CellLabel->"In[17]:=",
 CellID->1900316843,ExpressionUUID->"1674c363-a6d6-48aa-8abd-0ed80ae80673"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"h", "[", 
    RowBox[{"x", ",", "y", ",", "9"}], "]"}], ",", "8"}], "]"}]], "Output",
 CellChangeTimes->{
  3.768995213585383*^9, 3.769008393813888*^9, 3.7690757691830597`*^9, 
   3.7691006401812773`*^9, {3.769179036925357*^9, 3.769179051127605*^9}, 
   3.769772673156837*^9, 3.7699755278827953`*^9, 3.77192357595922*^9, 
   3.7719295077983303`*^9, 3.8814162677128487`*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[17]=",
 CellID->1134670365,ExpressionUUID->"85384623-4d2f-4b75-b6b9-a738f1b307ce"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 StyleBox[ButtonBox["Span",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Span.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Span.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 " and ",
 StyleBox[ButtonBox["All",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 " ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 " Specifications"
}], "Subsubsection",
 CellTags->"p: 20",
 CellID->1306406695,ExpressionUUID->"f918684b-a944-476b-aa75-a2d0ae62bf15"],

Cell[TextData[{
 "One other way to specify Parts is with ",
 ButtonBox["Span",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Span.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Span.html"],
 ". Here I build the characters \[OpenCurlyDoubleQuote]a\
\[CloseCurlyDoubleQuote] to \[OpenCurlyDoubleQuote]z\[CloseCurlyDoubleQuote] \
and then get out the third character (\[OpenCurlyDoubleQuote]c\
\[CloseCurlyDoubleQuote]) and every fourth character thereafter, not \
exceeding the ",
 Cell[BoxData[
  FormBox[
   SuperscriptBox["15", "th"], TraditionalForm]],ExpressionUUID->
  "32f6cc2f-5337-4dd0-a54c-eb9e85e7d2c4"],
 " character."
}], "Text",
 CellChangeTimes->{{3.769418690190735*^9, 3.769418748324746*^9}, 
   3.76941880983479*^9, {3.769418842582252*^9, 3.769418921007485*^9}, 
   3.7731581976127424`*^9, 3.7747836403670053`*^9, 3.7749719704150124`*^9, {
   3.777055718777667*^9, 3.777055723105234*^9}, {3.87578449241188*^9, 
   3.875784497114938*^9}, {3.885471946381792*^9, 3.885472000630333*^9}},
 CellTags->"i:13",
 CellID->431835590,ExpressionUUID->"3c6ba220-9a90-4636-b243-7ad35ad42815"],

Cell[TextData[{
 ButtonBox["CharacterRange",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/CharacterRange.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/CharacterRange.html"],
 " yields all the characters between two elements of a kind:"
}], "CodeCaption",
 CellChangeTimes->{{3.7731584910110793`*^9, 3.773158541866164*^9}},
 CellTags->"i:14",
 CellID->58107445,ExpressionUUID->"d1ac31e6-3eb0-497d-a518-be2c498e98ca"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterRange", "[", 
   RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"Span", "[", 
    RowBox[{"3", ",", "15", ",", "4"}], "]"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769418757063037*^9, 3.769418905430238*^9}},
 CellLabel->"In[18]:=",
 CellID->1312297989,ExpressionUUID->"d3f78d9c-fe6a-449a-9c0f-a305da933d77"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"c\"\>", ",", "\<\"g\"\>", ",", "\<\"k\"\>", ",", "\<\"o\"\>"}],
   "}"}]], "Output",
 CellChangeTimes->{
  3.769418806413725*^9, {3.7694188608621187`*^9, 3.769418906116811*^9}, 
   3.769772673198699*^9, 3.769975527926222*^9, 3.7719235759695873`*^9, 
   3.771929507808919*^9, 3.881416275473708*^9},
 CellLabel->"Out[18]=",
 CellID->1569769643,ExpressionUUID->"adb83dd4-04ed-4af2-a563-fbc473957009"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s syntactic sugar for ",
 ButtonBox["Span",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Span.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Span.html"],
 ", which makes use of double semicolons:"
}], "CodeCaption",
 CellChangeTimes->{{3.769418924985495*^9, 3.769418943833686*^9}, 
   3.7731581903230133`*^9, {3.7747810776835938`*^9, 3.7747810784666724`*^9}, {
   3.774783816590005*^9, 3.774783817974005*^9}, 3.8854725183362226`*^9},
 CellTags->"i:15",
 CellID->1378388831,ExpressionUUID->"8f750d26-6fec-4d73-be13-90d061e5799d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterRange", "[", 
   RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"3", ";;", "15", ";;", "4"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7694189472558928`*^9, 3.769418958976521*^9}},
 CellLabel->"In[19]:=",
 CellID->1140561712,ExpressionUUID->"0d1f8391-ede5-42e0-95f1-c04cf0f92f3e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"c\"\>", ",", "\<\"g\"\>", ",", "\<\"k\"\>", ",", "\<\"o\"\>"}],
   "}"}]], "Output",
 CellChangeTimes->{3.769418959456428*^9, 3.769772673213174*^9, 
  3.769975527970428*^9, 3.771923576003212*^9, 3.771929507840849*^9, 
  3.8814162797382936`*^9},
 CellLabel->"Out[19]=",
 CellID->1870452427,ExpressionUUID->"201e9ce6-178c-4fa6-abd7-7738810bb3a1"]
}, Open  ]],

Cell[TextData[{
 "If I omit the final value of ",
 ButtonBox["Span",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Span.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Span.html"],
 ", it is assumed to be 1:"
}], "CodeCaption",
 CellChangeTimes->{{3.769418962814445*^9, 3.769418982700403*^9}, {
   3.769419164579822*^9, 3.769419174902184*^9}, 3.7731582077137527`*^9, {
   3.7731586374467216`*^9, 3.77315863963194*^9}, {3.7747810804988756`*^9, 
   3.774781080801906*^9}},
 CellID->895416376,ExpressionUUID->"54799772-d4e1-4aba-9e3b-81a945064f6d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterRange", "[", 
   RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
  RowBox[{"[", 
   RowBox[{"4", ";;", "7"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7694189472558928`*^9, 3.7694189927043333`*^9}},
 CellLabel->"In[20]:=",
 CellID->411930243,ExpressionUUID->"f6b49a0a-ce81-4de9-bf62-5339285048cc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"d\"\>", ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"g\"\>"}],
   "}"}]], "Output",
 CellChangeTimes->{3.769418994280283*^9, 3.769772673254911*^9, 
  3.76997552798417*^9, 3.7719235760132*^9, 3.7719295078510857`*^9, 
  3.881416284681592*^9},
 CellLabel->"Out[20]=",
 CellID->1618809395,ExpressionUUID->"a0ee61a3-4b87-4951-a6c0-e14a3c74ddbb"]
}, Open  ]],

Cell["\<\
If I omit the first or second value, it is taken to mean the lowest or \
highest possible value given the data on which it is operating:\
\>", "CodeCaption",
 CellChangeTimes->{{3.769418997214427*^9, 3.7694190345803022`*^9}, {
  3.774781082922118*^9, 3.7747810832181473`*^9}, {3.774972628661336*^9, 
  3.7749726298373365`*^9}},
 CellID->2336424,ExpressionUUID->"7a5ded73-c706-4f45-a29c-b96476f0e0de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"CharacterRange", "[", 
     RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{"23", ";;"}], "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{"CharacterRange", "[", 
     RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
    RowBox[{"[", 
     RowBox[{";;", "5"}], "]"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.769419036909588*^9, 3.7694190930000343`*^9}},
 CellLabel->"In[21]:=",
 CellID->1105442357,ExpressionUUID->"3361b4fa-f298-42fe-b71c-c8bfbcaa06e6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"w\"\>", ",", "\<\"x\"\>", ",", "\<\"y\"\>", 
     ",", "\<\"z\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>",
      ",", "\<\"e\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7694190547243443`*^9, 3.769419094590684*^9}, 
   3.7697726732984133`*^9, 3.769975528027957*^9, 3.771923576025276*^9, 
   3.77192950788389*^9, 3.881416289174917*^9},
 CellLabel->"Out[21]=",
 CellID->1033630717,ExpressionUUID->"273207e4-64bb-4c0d-a962-4f8b6cd54522"]
}, Open  ]],

Cell[TextData[{
 "I can also use ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " to designate every possible part:"
}], "CodeCaption",
 CellChangeTimes->{{3.7694191029019747`*^9, 3.769419113070981*^9}, 
   3.7694191924652843`*^9, 3.7731586319981766`*^9, {3.774781085291355*^9, 
   3.7747811080436296`*^9}, {3.7749726391553364`*^9, 3.774972651779336*^9}, {
   3.889631832005659*^9, 3.8896318325033045`*^9}},
 CellID->207099372,ExpressionUUID->"32f193dc-593f-400a-85a9-03c5f29300e1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"CharacterRange", "[", 
   RowBox[{"\"\<a\>\"", ",", "\"\<z\>\""}], "]"}], "[", 
  RowBox[{"[", "All", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7694191154902897`*^9, 3.769419127065248*^9}},
 CellLabel->"In[22]:=",
 CellID->2084639956,ExpressionUUID->"08cf841f-b4d2-43a9-852d-b911e57187a5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"a\"\>", ",", "\<\"b\"\>", ",", "\<\"c\"\>", ",", "\<\"d\"\>", 
   ",", "\<\"e\"\>", ",", "\<\"f\"\>", ",", "\<\"g\"\>", ",", "\<\"h\"\>", 
   ",", "\<\"i\"\>", ",", "\<\"j\"\>", ",", "\<\"k\"\>", ",", "\<\"l\"\>", 
   ",", "\<\"m\"\>", ",", "\<\"n\"\>", ",", "\<\"o\"\>", ",", "\<\"p\"\>", 
   ",", "\<\"q\"\>", ",", "\<\"r\"\>", ",", "\<\"s\"\>", ",", "\<\"t\"\>", 
   ",", "\<\"u\"\>", ",", "\<\"v\"\>", ",", "\<\"w\"\>", ",", "\<\"x\"\>", 
   ",", "\<\"y\"\>", ",", "\<\"z\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.769419127771302*^9, 3.769772673312944*^9, 
  3.769975528040881*^9, 3.771923576059474*^9, 3.7719295078933067`*^9, 
  3.8814162945149603`*^9},
 CellLabel->"Out[22]=",
 CellID->2038967451,ExpressionUUID->"9f28b140-a61d-449e-be9b-8f7e64f369af"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["The Function", "Subsection",
 CellChangeTimes->{{3.768987515689805*^9, 3.768987521969487*^9}, {
  3.768990345528006*^9, 3.768990345921283*^9}},
 CellID->1248382117,ExpressionUUID->"3414d6c1-c73d-42b7-bce5-07b124c5c333"],

Cell[CellGroupData[{

Cell["Single Functions", "Subsubsection",
 CellChangeTimes->{{3.769009133213776*^9, 3.769009137692235*^9}},
 CellID->1298300964,ExpressionUUID->"73c644c4-5c22-49ab-bfb0-2628fb1942ea"],

Cell["\<\
Like almost all modern computer languages, the Wolfram Language has the \
notion of a function. Essentially, a function is a set of instructions \
specifying how to transform one Wolfram Language expression into another. As \
of Version 13.3, Mathematica comes with thousands of them, and one can do a \
tremendous amount with these functions. The point of Wolfram Language \
programming, however, is often to augment the built-in functions with \
functions of one\[CloseCurlyQuote]s own creation. The Wolfram Language \
provides a rich vocabulary. You create the sentences or, as I sometimes think \
of it, the poetry.\
\>", "Text",
 CellTags->{"LastCellOfAPage", "i:16"},
 CellID->643009229,ExpressionUUID->"6a1c8591-a8ff-40d5-96a4-b8ae67d10d23"],

Cell["\<\
The Wolfram Language contains a variety of ways to specify a function. I\
\[CloseCurlyQuote]m going to start with one that takes an expression and \
squares it. Here is one way to write it. It\[CloseCurlyQuote]s not \
necessarily the quickest way, but it is the most explicit.\
\>", "Text",
 CellChangeTimes->{{3.768992181630535*^9, 3.768992254148286*^9}, {
  3.774972067313701*^9, 3.7749720675547256`*^9}},
 CellTags->{"i:17", "p: 21"},
 CellID->918400099,ExpressionUUID->"57db0482-361c-4f5a-a5e4-ea89b0842b60"],

Cell["A canonical way of defining a function:", "CodeCaption",
 CellChangeTimes->{{3.769179128175878*^9, 3.7691791358562183`*^9}, 
   3.7747811293727627`*^9},
 CellID->1487034866,ExpressionUUID->"6dff4acf-daed-427f-b8d2-647ec2603777"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.768992256273322*^9, 3.768992266339718*^9}, {
  3.7689926082787933`*^9, 3.7689926092446947`*^9}},
 CellLabel->"In[23]:=",
 CellID->1585492904,ExpressionUUID->"3f2c824b-c362-4cd1-9c30-a1ea56f8c178"],

Cell[TextData[{
 "The idea is that this variant of ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " has two arguments. The first argument is a symbol that is used to \
designate the data that the function will confront. Here I picked the \
traditional ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "82ab886d-e856-4fe4-9a3c-620391c376e3"],
 ", but I could have selected anything that can be parsed as a symbol, such \
as ",
 Cell[BoxData[
 "z"], "InlineCodeText",ExpressionUUID->
  "7c5d5de5-be5d-4b14-97e7-a805b925ec74"],
 ", ",
 Cell[BoxData[
 "zebra"], "InlineCodeText",ExpressionUUID->
  "a8ea2feb-92b9-45b5-888f-11b8e24aed1b"],
 ", ",
 Cell[BoxData[
 "\[Phi]"], "InlineCodeText",ExpressionUUID->
  "9cdd5717-d139-4dd0-8e2d-b3619e94efa3"],
 ", ",
 Cell[BoxData[
 "\[Beta]2"], "InlineCodeText",ExpressionUUID->
  "e8aa2e08-9d66-40f8-83e2-bf1024cabe86"],
 ", ",
 Cell[BoxData[
 "\[GothicQ]"], "InlineCodeText",ExpressionUUID->
  "033594c9-23bb-45a0-9bd7-dd0728a9c50c"],
 ", or even ",
 Cell[BoxData[
 "\[Wolf]"], "InlineCodeText",ExpressionUUID->
  "11de6ca1-794b-4260-8140-2f9e8dd36533"],
 ". The second argument says how the data is to be transformed using the name \
for the data specified in the first argument. That transformation can be \
simple, as it is here, or extremely complex."
}], "Text",
 CellChangeTimes->{{3.76899227267629*^9, 3.76899239391356*^9}, {
   3.768992505472184*^9, 3.768992520908186*^9}, {3.7689925779138308`*^9, 
   3.768992664825684*^9}, 3.769117887726534*^9, {3.774972682553336*^9, 
   3.774972730890336*^9}, {3.7754893781169834`*^9, 3.7754893995889835`*^9}, {
   3.777055880351877*^9, 3.777055893063764*^9}, {3.875784600390585*^9, 
   3.875784603383357*^9}, 3.885486804725216*^9, {3.8854871347440996`*^9, 
   3.8854871377845483`*^9}, {3.885487182559664*^9, 3.885487188993882*^9}, 
   3.8855549499013147`*^9, {3.8896900049092503`*^9, 3.88969015583356*^9}},
 CellID->1402145552,ExpressionUUID->"a75138aa-9c0c-4a6a-8ccb-5377e16d0f68"],

Cell[TextData[{
 "Many alternative ways exist to specify a function. Here\[CloseCurlyQuote]s \
one that I like. It uses a kind of infix notation in which the function arrow \
separates a left-hand side, which is the first argument to the traditional ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " specification and a right-hand side, which is the second argument to the \
traditional ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " specification. It\[CloseCurlyQuote]s designed to look like the way \
functions (or \[OpenCurlyDoubleQuote]mappings\[CloseCurlyDoubleQuote]) are \
sometimes denoted in traditional Western math texts."
}], "Text",
 CellChangeTimes->{{3.7689926763080673`*^9, 3.768992697383684*^9}, {
  3.768992755376693*^9, 3.7689928466359177`*^9}, {3.769117905024547*^9, 
  3.769117925328907*^9}, {3.774973246767336*^9, 3.774973267757336*^9}, {
  3.777055935417301*^9, 3.7770559374085417`*^9}, {3.85619784375696*^9, 
  3.856197852668372*^9}},
 CellTags->"i:18",
 CellID->1522233933,ExpressionUUID->"ad7dbd58-79b9-4f9a-8cf6-a7a32f36465b"],

Cell[TextData[{
 "Use the infix ",
 ButtonBox["\[Function]",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " operator to define a function:"
}], "CodeText",
 CellChangeTimes->{{3.769179141798004*^9, 3.76917915678314*^9}, 
   3.7731587717481503`*^9, 3.7749729077223363`*^9, {3.8937615673758*^9, 
   3.893761567375819*^9}},
 CellID->599898325,ExpressionUUID->"271c9697-1339-4a4f-a9d8-6fb7765c6fde"],

Cell[BoxData[
 RowBox[{
  RowBox[{"x", "\[Function]", 
   SuperscriptBox["x", "2"]}], ";"}]], "Input",
 CellChangeTimes->{{3.768992699725951*^9, 3.76899270315353*^9}, {
  3.7689927338602943`*^9, 3.768992752720789*^9}},
 CellLabel->"In[24]:=",
 CellID->1213025220,ExpressionUUID->"c8ae6bcf-2342-4270-b2c0-6105ede87da1"],

Cell["\<\
Notice that in the code, nothing really happened yet. The function just lies \
in wait, hoping that data will one day arrive. It is what computer scientists \
call a \[OpenCurlyDoubleQuote]lambda expression.\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.7689928728833027`*^9, 3.7689929252667294`*^9}, 
   3.774783642790005*^9, {3.7749729203963366`*^9, 3.7749729212753363`*^9}, 
   3.777056001921319*^9},
 CellID->1252611569,ExpressionUUID->"bb8e7288-c525-456e-9390-890674c23482"],

Cell["\<\
Here\[CloseCurlyQuote]s how one applies a function to data. The standard way \
is to put the function first and then include the data surrounded in square \
brackets with different elements of data separated by commas if there is more \
than one element. Here\[CloseCurlyQuote]s an example.\
\>", "Text",
 CellChangeTimes->{{3.768992956460924*^9, 3.768993006277807*^9}, {
  3.7747838226760054`*^9, 3.774783823580005*^9}},
 CellTags->"i:19",
 CellID->860448642,ExpressionUUID->"0296603f-8332-45a7-b3ab-ec9c4f60e8dc"],

Cell["Apply a function to a value:", "CodeCaption",
 CellChangeTimes->{{3.769179164404345*^9, 3.7691791681163673`*^9}, 
   3.7731587729472704`*^9},
 CellID->320761331,ExpressionUUID->"9bc3daf4-939c-4bad-95d5-ea281f482738"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "[", "3", "]"}]], "Input",
 CellChangeTimes->{{3.768993007767017*^9, 3.768993019715479*^9}},
 CellLabel->"In[25]:=",
 CellID->405447196,ExpressionUUID->"e5deef0f-11b3-4bfb-9883-a584f5db222d"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.7689930201184*^9, 3.7690757692384253`*^9, 
  3.7691006402035923`*^9, 3.769772673372839*^9, 3.769975528098884*^9, 
  3.7719235761413183`*^9, 3.7719295079667387`*^9, 3.881416319280591*^9},
 CellLabel->"Out[25]=",
 CellID->442648017,ExpressionUUID->"26cdb8e3-9625-4a07-9d2b-ef32c1901106"]
}, Open  ]],

Cell[TextData[{
 "Notice also that in the earlier code, I gave the data a local name ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "b1e183ec-b08c-460d-922d-51d883c6ddbd"],
 ". Suppose I previously defined ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "7a8244b6-de0a-462e-8edf-25914c58fefe"],
 " to be 7. What happens when I write the following?"
}], "Text",
 CellChangeTimes->{{3.768992852748837*^9, 3.7689928609668407`*^9}, {
   3.768992928734251*^9, 3.768992947363894*^9}, {3.76899304514356*^9, 
   3.76899305195743*^9}, 3.7691791805116787`*^9, {3.774974234177336*^9, 
   3.7749742408793364`*^9}, {3.775488584195984*^9, 3.7754886022909837`*^9}, {
   3.7754894483659835`*^9, 3.7754894532959833`*^9}, 3.777056079960688*^9, {
   3.877536860461155*^9, 3.877536861876788*^9}, {3.8854679817283945`*^9, 
   3.8854679910212545`*^9}, {3.885488175188546*^9, 3.8854881779534087`*^9}},
 CellTags->"i:20",
 CellID->385411241,ExpressionUUID->"aa99f80e-8105-4f02-b825-aaef2a52e51b"],

Cell["Function variables are localized:", "CodeCaption",
 CellChangeTimes->{{3.769179203815522*^9, 3.769179208804343*^9}, 
   3.773158781965172*^9},
 CellID->1229764635,ExpressionUUID->"28a4c438-5ee9-41fe-9b4b-05d6571a34ae"],

Cell[CellGroupData[{

Cell[BoxData[{
 RowBox[{
  RowBox[{"x", "=", "7"}], ";"}], "\n", 
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "[", "3", "]"}]}], "Input",
 CellChangeTimes->{{3.768993056935672*^9, 3.768993057694441*^9}, {
  3.769179187879315*^9, 3.769179217906547*^9}},
 CellLabel->"In[26]:=",
 CellID->796048135,ExpressionUUID->"90bb3db7-6db8-415d-9116-ec7b556abd7b"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.7689930876520023`*^9, 3.769075769273384*^9, 
  3.769100640246297*^9, 3.769772673414742*^9, 3.769975528111112*^9, 
  3.771923576176642*^9, 3.77192950797579*^9, 3.881416323645136*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[27]=",
 CellID->1082927782,ExpressionUUID->"12b4b5b4-5ef7-45a4-b62f-91367f9d69e0"]
}, Open  ]],

Cell[TextData[{
 "The answer is still 9. It is not 49. This is so because the symbol \
designated as the first argument to ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " is \[OpenCurlyDoubleQuote]local.\[CloseCurlyDoubleQuote] It does not have \
the same meaning as a symbol with the same name defined more globally in one\
\[CloseCurlyQuote]s Wolfram Language session. Think of it as being like a \
file name. One might have a file named \[OpenCurlyDoubleQuote]memo.docx\
\[CloseCurlyDoubleQuote] sitting in a \[OpenCurlyDoubleQuote]Documents\
\[CloseCurlyDoubleQuote] directory and a file named \
\[OpenCurlyDoubleQuote]memo.docx\[CloseCurlyDoubleQuote] sitting in one\
\[CloseCurlyQuote]s \[OpenCurlyDoubleQuote]Projects\[CloseCurlyDoubleQuote] \
directory. The fact that the two files have the same name does not mean they \
are the same thing. You can think of ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " as creating a kind of temporary \[OpenCurlyDoubleQuote]directory\
\[CloseCurlyDoubleQuote] (or, to use a more Wolfram-like term, \
\[OpenCurlyDoubleQuote]scope\[CloseCurlyDoubleQuote]) in which names have \
different meanings than they do when used elsewhere."
}], "Text",
 CellChangeTimes->{{3.7689930902242126`*^9, 3.768993303682633*^9}, 
   3.774783644790005*^9, 3.774973374522336*^9, 3.774974031713336*^9, {
   3.856197881434918*^9, 3.8561978819287643`*^9}, {3.8896906021889176`*^9, 
   3.8896906051792183`*^9}},
 CellTags->"p: 22",
 CellID->357884135,ExpressionUUID->"418f989e-cc4f-41f9-aeec-bf08c5706f74"],

Cell[TextData[{
 "Of course, one can make use of globally defined variables in functions if \
one chooses. Here I write a function that adds its argument to the \
pre-defined global value of ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "fd382e9d-4ed7-4265-add3-c83662826660"],
 "."
}], "Text",
 CellChangeTimes->{{3.769179227719432*^9, 3.769179242173258*^9}, {
  3.774974080201336*^9, 3.774974084649336*^9}, {3.8963387823102713`*^9, 
  3.8963387858911543`*^9}},
 CellID->1127747226,ExpressionUUID->"6a501838-a616-47d1-ac67-c9223b5d2b1f"],

Cell["\<\
Make use of global symbols inside a function with local symbols:\
\>", "CodeCaption",
 CellChangeTimes->{{3.769179274064077*^9, 3.769179284060424*^9}, 
   3.773158787940769*^9},
 CellID->1638048248,ExpressionUUID->"8ac4555c-ec1d-4a09-a51a-ddf641ca03d9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"z", ",", 
    RowBox[{"x", "+", "z"}]}], "]"}], "[", "8", "]"}]], "Input",
 CellChangeTimes->{{3.769179260912157*^9, 3.769179267507824*^9}},
 CellLabel->"In[28]:=",
 CellID->50149414,ExpressionUUID->"ff0480fa-9759-4cf9-8bcf-35a819346187"],

Cell[BoxData["15"], "Output",
 CellChangeTimes->{3.769179268028356*^9, 3.769772673428646*^9, 
  3.769975528154193*^9, 3.771923576188916*^9, 3.771929508012147*^9, 
  3.8814163347078953`*^9},
 CellLabel->"Out[28]=",
 CellID->1357344321,ExpressionUUID->"2a640931-0fcc-4493-8a20-85512ab7f8a4"]
}, Open  ]],

Cell[TextData[{
 "When functions have one argument, one can save a little bit of typing by \
using the ",
 ButtonBox["@",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Prefix.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Prefix.html"],
 " symbol to denote function application."
}], "Text",
 CellChangeTimes->{{3.7689934625351257`*^9, 3.768993487570594*^9}, {
   3.769117969993862*^9, 3.769117972368559*^9}, 3.7754920868704147`*^9, {
   3.777056207048357*^9, 3.777056207608118*^9}},
 CellTags->"i:21",
 CellID->2004445345,ExpressionUUID->"46ae72d4-f8c1-4792-9b5c-4766d446a26e"],

Cell[TextData[{
 "The ",
 ButtonBox["@",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Prefix.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Prefix.html"],
 " syntactic sugar:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774872666461641*^9, {3.7749743004693365`*^9, 3.774974311145336*^9}},
 CellID->24148734,ExpressionUUID->"92435d63-c5dc-44ef-af63-b60e94b97bdd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{"x", ",", 
    SuperscriptBox["x", "2"]}], "]"}], "@", "3"}]], "Input",
 CellChangeTimes->{{3.768993491457645*^9, 3.7689935003611727`*^9}},
 CellLabel->"In[29]:=",
 CellID->1136942926,ExpressionUUID->"73a294d6-61b1-4fc4-89ec-467e4e0e3b3f"],

Cell[BoxData["9"], "Output",
 CellChangeTimes->{3.7689935009360723`*^9, 3.7690757692820177`*^9, 
  3.769100640283435*^9, 3.769772673475988*^9, 3.7699755281678343`*^9, 
  3.77192357623802*^9, 3.771929508023396*^9, 3.881416339707141*^9},
 CellLabel->"Out[29]=",
 CellID->2144914409,ExpressionUUID->"031d3af2-98e7-4254-9360-160b81e2337a"]
}, Open  ]],

Cell["\<\
Here\[CloseCurlyQuote]s how to write a function of more than one argument. \
Place the names of the locally defined symbols inside curly braces as the \
first argument and then just write the transformation as the second argument. \
Here\[CloseCurlyQuote]s a Pythagorean function that finds the square root of \
the sum of the squares of two pieces of data.\
\>", "Text",
 CellChangeTimes->{{3.768994405565433*^9, 3.768994496178294*^9}, {
   3.768994588929904*^9, 3.768994594377927*^9}, 3.769117987203754*^9, {
   3.7747838268200054`*^9, 3.774783827588005*^9}, {3.774974354378336*^9, 
   3.7749743553873363`*^9}, {3.7754894811619835`*^9, 
   3.7754894825609837`*^9}, {3.885489080609121*^9, 3.885489081603471*^9}},
 CellTags->"i:22",
 CellID->290266276,ExpressionUUID->"4c1a606f-e31d-455c-9ac4-03579a549b31"],

Cell["A function with two variables:", "CodeCaption",
 CellChangeTimes->{{3.769179306952915*^9, 3.769179315823441*^9}, {
  3.773158855475522*^9, 3.773158861102085*^9}},
 CellID->813178404,ExpressionUUID->"1b5310a9-8e5c-4ee1-968a-dcebd3e56d4f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], "]"}], ";"}]], "Input",
 CellChangeTimes->{{3.768994498255756*^9, 3.7689945131828747`*^9}, {
  3.76899463671307*^9, 3.768994639847897*^9}},
 CellLabel->"In[30]:=",
 CellID->1569938395,ExpressionUUID->"b3079c7b-d948-4c21-b8e5-657e33070a95"],

Cell["\<\
Apply a function of two variables to a comma-separated sequence with real \
data:\
\>", "CodeCaption",
 CellChangeTimes->{{3.769179319152405*^9, 3.769179329199655*^9}, {
  3.7731589129562693`*^9, 3.773158915626537*^9}, {3.7749746039723363`*^9, 
  3.774974629010336*^9}},
 CellID->944882402,ExpressionUUID->"3756f455-f75c-487c-987d-6775f21295b0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], "]"}], "[", 
  RowBox[{"3", ",", "4"}], "]"}]], "Input",
 CellChangeTimes->{{3.768994498255756*^9, 3.768994544378263*^9}, {
  3.76899464435045*^9, 3.76899464462078*^9}},
 CellLabel->"In[31]:=",
 CellID->1970517723,ExpressionUUID->"ff496740-4678-4f0e-8458-0d0a2cea6dd4"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.768994544862924*^9, 3.768994645167262*^9, 
  3.76907576931455*^9, 3.7691006403294353`*^9, 3.7697726735265083`*^9, 
  3.7699755282185993`*^9, 3.771923576281808*^9, 3.7719295080618067`*^9, 
  3.881416348125482*^9},
 CellLabel->"Out[31]=",
 CellID->361820142,ExpressionUUID->"d1a0f065-f204-4af3-8ae1-5def5821b242"]
}, Open  ]],

Cell["\<\
The data doesn\[CloseCurlyQuote]t have to be numeric. Here I apply the \
function to symbolic expressions.\
\>", "Text",
 CellChangeTimes->{{3.768994909747704*^9, 3.768994928337164*^9}, {
   3.769118004015469*^9, 3.769118008198938*^9}, 3.885554969001865*^9},
 CellID->2146050074,ExpressionUUID->"bf345389-27c9-4ab6-9467-dbbd37b89dea"],

Cell["Apply a function to symbolic variables:", "CodeCaption",
 CellChangeTimes->{{3.769179336269785*^9, 3.769179342281444*^9}, 
   3.773158924287403*^9},
 CellID->911218462,ExpressionUUID->"2b65614a-0603-496a-b4a3-f74220b767a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    SqrtBox[
     RowBox[{
      SuperscriptBox["x", "2"], "+", 
      SuperscriptBox["y", "2"]}]]}], "]"}], "[", 
  RowBox[{"a", ",", "b"}], "]"}]], "Input",
 CellChangeTimes->{{3.7689949346463833`*^9, 3.7689949360948887`*^9}},
 CellLabel->"In[32]:=",
 CellID->1675742353,ExpressionUUID->"02933a06-cacf-4eb3-b3f2-4d26657a77b9"],

Cell[BoxData[
 SqrtBox[
  RowBox[{
   SuperscriptBox["a", "2"], "+", 
   SuperscriptBox["b", "2"]}]]], "Output",
 CellChangeTimes->{3.768994936532365*^9, 3.769075769339601*^9, 
  3.769100640340395*^9, 3.769772673539946*^9, 3.769975528261464*^9, 
  3.771923576319108*^9, 3.7719295080983562`*^9, 3.881416354705062*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[32]=",
 CellID->2088562438,ExpressionUUID->"01c3ca49-2fc2-4c3d-b6e7-6cda74aa0449"]
}, Open  ]],

Cell["\<\
It\[CloseCurlyQuote]s not necessary to provide the function with an explicit \
name for the data. Here\[CloseCurlyQuote]s another way of defining a \
function. It isn\[CloseCurlyQuote]t assigned to a symbol and is thus called \
an \[OpenCurlyDoubleQuote]anonymous function.\[CloseCurlyDoubleQuote] \
Basically, you designate the arguments through numbered \
\[OpenCurlyDoubleQuote]slots.\[CloseCurlyDoubleQuote] Here\[CloseCurlyQuote]s \
our first squaring function.\
\>", "Text",
 CellChangeTimes->{{3.768993332823284*^9, 3.7689933654349623`*^9}, {
   3.7689940936094427`*^9, 3.768994113412251*^9}, {3.768994167108379*^9, 
   3.768994180342073*^9}, {3.768994568435145*^9, 3.768994575064386*^9}, {
   3.7747838304520054`*^9, 3.774783831812005*^9}, 3.7749747225513363`*^9, 
   3.777056773997312*^9, {3.8561979207417107`*^9, 3.856197932970811*^9}, {
   3.889690706086175*^9, 3.889690706180937*^9}},
 CellTags->{"i:23", "p: 23"},
 CellID->2101180113,ExpressionUUID->"6edbeb82-e1e4-4d74-af10-682899d2e88b"],

Cell[TextData[{
 "Use the ",
 ButtonBox["&",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " postfix operator to define a function: "
}], "CodeCaption",
 CellChangeTimes->{{3.774872965984496*^9, 3.774872975263424*^9}, 
   3.7749747465373363`*^9},
 CellID->757841845,ExpressionUUID->"f1580907-89c6-4ced-8581-acde4ec40e79"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox[
    RowBox[{"Slot", "[", "1", "]"}], "2"], "&"}], ";"}]], "Input",
 CellChangeTimes->{{3.768993368036759*^9, 3.76899337244482*^9}, {
  3.768994228636373*^9, 3.768994242571658*^9}},
 CellLabel->"In[33]:=",
 CellID->1313067923,ExpressionUUID->"d8a237e0-e062-4d52-aed4-5dd905287b0f"],

Cell[TextData[{
 "This says when you confront a sequence of expressions, take the first of \
them and square it. The ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Slot",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"], "[", 
   "1", "]"}]], "InlineCodeText",ExpressionUUID->
  "2d2c15e0-3bee-4f04-9770-8bf5deb43066"],
 " means to take the first expression in the sequence and not, for example, \
the second or third. The ampersand terminating the expression means that one \
is defining a function. "
}], "Text",
 CellChangeTimes->{{3.768994707678834*^9, 3.768994709840459*^9}, {
  3.7749747740973363`*^9, 3.774974781638336*^9}},
 CellID->1190625289,ExpressionUUID->"949840ea-741d-4e16-9812-28ed0354b9d4"],

Cell["And here\[CloseCurlyQuote]s our second variant of the Pythagorean \
function.", "Text",
 CellChangeTimes->{{3.768994576718111*^9, 3.7689946070381947`*^9}, {
  3.769118034346985*^9, 3.769118036196896*^9}, {3.774783835227005*^9, 
  3.7747838360750055`*^9}},
 CellID->586609477,ExpressionUUID->"2bb6b431-4455-43a1-aa56-ae30cd51b775"],

Cell[TextData[{
 "Use the ",
 ButtonBox["&",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " operator with multivariable functions:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179382337144*^9, 3.769179399520337*^9}, 
   3.7747811442132463`*^9, 3.7749747974333363`*^9},
 CellID->522703068,ExpressionUUID->"f4dc088d-0eac-4c29-b824-b19b9e9e0524"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox[
      RowBox[{"Slot", "[", "1", "]"}], "2"], "+", 
     SuperscriptBox[
      RowBox[{"Slot", "[", "2", "]"}], "2"]}]], "&"}], ";"}]], "Input",
 CellChangeTimes->{3.76899482491925*^9},
 CellLabel->"In[34]:=",
 CellID->48056562,ExpressionUUID->"71a2450c-6d30-4dec-a060-ef3c32bbf63a"],

Cell["\<\
Also, the little ampersand operator at the end has low precedence, so I \
generally wrap my \[OpenCurlyDoubleQuote]slot functions\
\[CloseCurlyDoubleQuote] defined with ampersands inside parentheses. \
Sometimes you can get away with not doing it, but I think \
it\[CloseCurlyQuote]s good practice to wrap ampersand-defined functions in \
parentheses as a matter of course. Here are two examples.\
\>", "Text",
 CellChangeTimes->{{3.768993375145125*^9, 3.76899344965722*^9}, {
   3.768994014718422*^9, 3.768994057278454*^9}, {3.768994193460932*^9, 
   3.7689941966651373`*^9}, {3.768994246656746*^9, 3.7689942488736677`*^9}, 
   3.768994706084743*^9, {3.7691180497518*^9, 3.769118089045665*^9}, {
   3.769179426423853*^9, 3.7691794301119757`*^9}, {3.774974805736336*^9, 
   3.774974809455336*^9}, 3.856197962118349*^9, 3.8775370299249372`*^9},
 CellTags->"i:24",
 CellID->232786262,ExpressionUUID->"8cf48b15-ad40-46aa-8e77-45a15ab0ded9"],

Cell[TextData[{
 "Wrap ",
 ButtonBox["&",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " functions in parentheses:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179404058467*^9, 3.769179417016181*^9}, {
   3.7748729903289304`*^9, 3.7748729915690546`*^9}, 3.774974840284336*^9},
 CellID->613544091,ExpressionUUID->"9b59fd15-87a4-4d69-b81c-5f7dd0629510"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      SuperscriptBox[
       RowBox[{"Slot", "[", "1", "]"}], "2"], "&"}], ")"}], ",", 
    RowBox[{"(", 
     RowBox[{
      SqrtBox[
       RowBox[{
        SuperscriptBox[
         RowBox[{"Slot", "[", "1", "]"}], "2"], "+", 
        SuperscriptBox[
         RowBox[{"Slot", "[", "2", "]"}], "2"]}]], "&"}], ")"}]}], "}"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.768994058957103*^9, 3.7689940707390614`*^9}, {
  3.7689942552206173`*^9, 3.768994257185402*^9}, {3.769179434245092*^9, 
  3.769179452811796*^9}},
 CellLabel->"In[35]:=",
 CellID->1870984247,ExpressionUUID->"0fc44996-9d84-4492-8f1c-1b5496d1334d"],

Cell[TextData[{
 "If you\[CloseCurlyQuote]ve looked at Wolfram Language code before, you may \
be wondering why you haven\[CloseCurlyQuote]t seen things that have a ",
 ButtonBox["Slot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"],
 " head. That\[CloseCurlyQuote]s because there\[CloseCurlyQuote]s frequently \
used syntactic sugar, the ",
 ButtonBox["Slot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"],
 " symbol (",
 Cell[BoxData[
  ButtonBox[
   StyleBox["#",
    FontColor->GrayLevel[0]],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
   ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"]], 
  "InlineCodeText",ExpressionUUID->"6879e894-17a7-4143-ab8f-9bf8f8b4a1d1"],
 "). You can write the previous code as follows. "
}], "Text",
 CellChangeTimes->{{3.768994219128924*^9, 3.7689942251126223`*^9}, {
   3.7689942607138033`*^9, 3.76899432099611*^9}, {3.7689943733088703`*^9, 
   3.7689943859115353`*^9}, {3.7689948399381313`*^9, 3.768994841330934*^9}, {
   3.769118102711051*^9, 3.7691181101200533`*^9}, 3.7749748492543364`*^9, {
   3.774974887501336*^9, 3.774974926243336*^9}, 3.856197974900605*^9, {
   3.877537080178958*^9, 3.8775370837845488`*^9}, 3.877696097412517*^9},
 CellTags->"i:25",
 CellID->29196308,ExpressionUUID->"be4b7efb-76be-43d6-9a0a-c9477e411b7c"],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["#",
    FontColor->GrayLevel[0]],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
   ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"]], 
  "InlineCode",ExpressionUUID->"35ba519c-ded3-4f56-b922-143227396776"],
 " syntactic sugar:"
}], "CodeCaption",
 CellID->602116721,ExpressionUUID->"4e36a2a6-a766-4022-86b3-3234f9ddfaf8"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["#1", "2"], "&"}], ";"}]], "Input",
 CellChangeTimes->{{3.768994323026498*^9, 3.768994337706559*^9}, {
  3.768994843929536*^9, 3.76899485671319*^9}},
 CellLabel->"In[36]:=",
 CellID->1076077040,ExpressionUUID->"a9b62e55-dd36-4c84-b267-416f01d8cbdf"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SqrtBox[
    RowBox[{
     SuperscriptBox["#1", "2"], "+", 
     SuperscriptBox["#2", "2"]}]], "&"}], ";"}]], "Input",
 CellChangeTimes->{3.768994858581746*^9},
 CellLabel->"In[37]:=",
 CellID->1667019893,ExpressionUUID->"b3707299-14c9-41eb-b309-238be479367d"],

Cell[TextData[{
 "Indeed, if a function has just one argument, one can omit the number 1 and \
just use the ",
 ButtonBox["Slot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"],
 " symbol itself."
}], "Text",
 CellChangeTimes->{{3.7689941203041353`*^9, 3.768994139756122*^9}, {
  3.7689942034942837`*^9, 3.768994207571969*^9}, {3.768994347180174*^9, 
  3.76899435339865*^9}, {3.774975167491336*^9, 3.7749751732453365`*^9}},
 CellID->1531682889,ExpressionUUID->"ca81d940-27a5-4b45-aab7-4eb1a0971332"],

Cell[TextData[{
 "Just use ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["#",
    FontColor->GrayLevel[0]],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
   ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"]], 
  "InlineCode",ExpressionUUID->"d98addc4-899c-453a-93da-f2e0fd41933b"],
 " for single-variable functions:"
}], "CodeCaption",
 CellID->653372160,ExpressionUUID->"68c0ec02-2b89-443c-99ff-413b49f248bd"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   SuperscriptBox["#", "2"], "&"}], ";"}]], "Input",
 CellChangeTimes->{{3.76899436102575*^9, 3.768994364304133*^9}, 
   3.769118123720636*^9},
 CellLabel->"In[38]:=",
 CellID->1107838834,ExpressionUUID->"bb5265da-9ffc-43d8-8810-1f78b2b003aa"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Function Composition", "Subsubsection",
 CellChangeTimes->{{3.76900912113885*^9, 3.769009127545644*^9}},
 CellID->394832717,ExpressionUUID->"6e5965ac-999a-408a-a15b-cb8e8f87cd53"],

Cell[TextData[{
 "Suppose I have one function that says to take a number, multiply it by 3, \
and then add 1 and I have a second function that says to take the hyperbolic \
tangent of that number. (Don\[CloseCurlyQuote]t worry if you don\
\[CloseCurlyQuote]t know what a hyperbolic tangent is; it\[CloseCurlyQuote]s \
just a function over the real numbers that produces values between ",
 Cell[BoxData[
  FormBox[
   RowBox[{"-", "1"}], TraditionalForm]], "InlineMath",ExpressionUUID->
  "422e5eee-ae42-4b1b-8a59-1f8a2fb8bfc0"],
 " and 1). "
}], "Text",
 CellChangeTimes->{{3.7690091523535967`*^9, 3.769009227761565*^9}, {
   3.769010688894947*^9, 3.76901069272493*^9}, {3.7690107349194527`*^9, 
   3.769010764359729*^9}, 3.769118138483144*^9, 3.7731589812671003`*^9, {
   3.7749751953143363`*^9, 3.774975223008336*^9}, 3.8855504773419247`*^9},
 CellTags->{"LastCellOfAPage", "i:26"},
 CellID->872447341,ExpressionUUID->"09fca2cb-88e7-4ceb-add8-476a98b0982a"],

Cell["Here\[CloseCurlyQuote]s how I could write the functions:", "CodeCaption",
 CellChangeTimes->{{3.773158992817255*^9, 3.773158995645538*^9}},
 CellTags->"p: 24",
 CellID->265070891,ExpressionUUID->"90633732-7bf4-47c9-aa5b-2f4d1c166688"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f1", "=", 
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     RowBox[{
      RowBox[{"3", "x"}], "+", "1"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.7690092301546793`*^9, 3.769009255470293*^9}},
 CellLabel->"In[39]:=",
 CellID->1095109029,ExpressionUUID->"5ab91f41-f6a6-40e1-ab5c-41c6cae4068a"],

Cell[BoxData[
 RowBox[{
  RowBox[{"f2", "=", 
   RowBox[{"Function", "[", 
    RowBox[{"x", ",", 
     RowBox[{"Tanh", "[", "x", "]"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.76900924313369*^9, 3.769009257249082*^9}, {
  3.7690106729067574`*^9, 3.769010682099416*^9}, {3.769010718227783*^9, 
  3.769010720065916*^9}},
 CellLabel->"In[40]:=",
 CellID->1917193191,ExpressionUUID->"e58d9b60-501d-48cd-91cf-e50accab3b28"],

Cell[TextData[{
 "Now I want to find out what happens when I take the number ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "11105058-1fd0-4e6e-ad3b-471c14364044"],
 ", apply the first function, and then take the result of that application \
and apply the second function to it. I could write the following. It works \
just fine."
}], "Text",
 CellChangeTimes->{{3.769009261019228*^9, 3.7690093086991987`*^9}, {
  3.7690107060048122`*^9, 3.769010708252213*^9}, {3.7731589674947233`*^9, 
  3.773158968124786*^9}, {3.774783647925005*^9, 3.774783650606005*^9}, {
  3.774975239934336*^9, 3.7749752459693365`*^9}, {3.774975386390336*^9, 
  3.7749753889503365`*^9}, {3.885550521995801*^9, 3.8855505235765934`*^9}},
 CellID->835391362,ExpressionUUID->"4bfa33ac-dc1e-4ec0-bc71-39ef6466411b"],

Cell["This is also called function chaining:", "CodeCaption",
 CellChangeTimes->{{3.769179507895927*^9, 3.769179518829314*^9}, {
   3.7731590163636093`*^9, 3.77315901986796*^9}, 3.774781167605585*^9, {
   3.865535804198091*^9, 3.865535804344757*^9}},
 CellID->1744487226,ExpressionUUID->"b674ad1e-05c8-4f26-a653-dc2d2ace08c7"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"f2", "[", 
  RowBox[{"f1", "[", 
   RowBox[{"1", "/", "2"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769009293393551*^9, 3.769009298447693*^9}, {
  3.7690107102866983`*^9, 3.769010711923613*^9}},
 CellLabel->"In[41]:=",
 CellID->1028916997,ExpressionUUID->"21aac23b-47a5-4a79-a16b-1b25d6ede027"],

Cell[BoxData[
 RowBox[{"Tanh", "[", 
  FractionBox["5", "2"], "]"}]], "Output",
 CellChangeTimes->{
  3.769009298787545*^9, {3.7690107125466413`*^9, 3.769010721854005*^9}, 
   3.76907576947209*^9, 3.769100640520632*^9, 3.769772673710773*^9, 
   3.7699755283589077`*^9, 3.771923576540875*^9, 3.771929508320966*^9, 
   3.88141639466286*^9},
 CellLabel->"Out[41]=",
 CellID->661424598,ExpressionUUID->"26496fbb-02b1-4777-97aa-23fe0842b363"]
}, Open  ]],

Cell[TextData[{
 "However, I could also first ask that the functions be \
\[OpenCurlyDoubleQuote]composed\[CloseCurlyDoubleQuote] and then apply the \
composed function to ",
 Cell[BoxData[
  FormBox[
   FractionBox["1", "2"], TraditionalForm]], "InlineMath",ExpressionUUID->
  "8b8ac610-afb3-4e2a-ae96-2149c3fca4fc"],
 ". To do this, I use the ",
 ButtonBox["Composition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Composition.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Composition.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.769009310962105*^9, 3.769009333497965*^9}, {
   3.76900939787316*^9, 3.769009403738064*^9}, {3.769010789283527*^9, 
   3.7690107917060337`*^9}, 3.7747836530300055`*^9, {3.774784127219005*^9, 
   3.7747841292660055`*^9}, {3.774975404517336*^9, 3.774975423052336*^9}},
 CellTags->"i:27",
 CellID->867761911,ExpressionUUID->"e39cbd51-9a4e-4ea9-b9d5-e8ae7a6b9ae6"],

Cell["A standard function composition applied to a value:", "CodeCaption",
 CellChangeTimes->{{3.769179526623003*^9, 3.76917955405365*^9}, 
   3.77315910337831*^9},
 CellID->753595102,ExpressionUUID->"17fd4020-ba06-4078-814b-78c24fe16a09"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Composition", "[", 
   RowBox[{"f2", ",", "f1"}], "]"}], "[", 
  RowBox[{"1", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.769009338932247*^9, 3.76900935401512*^9}, {
  3.769010785996107*^9, 3.7690107873708982`*^9}},
 CellLabel->"In[42]:=",
 CellID->900875438,ExpressionUUID->"b093e066-3579-49c8-a286-af25db4772b1"],

Cell[BoxData[
 RowBox[{"Tanh", "[", 
  FractionBox["5", "2"], "]"}]], "Output",
 CellChangeTimes->{{3.769009349894327*^9, 3.769009354584318*^9}, 
   3.769010793340878*^9, 3.769075769482092*^9, 3.769100640528298*^9, 
   3.769772673724374*^9, 3.769975528402343*^9, 3.7719235765752363`*^9, 
   3.771929508352367*^9, 3.881416405785078*^9},
 CellLabel->"Out[42]=",
 CellID->1029740592,ExpressionUUID->"0826f100-c1a1-47ac-b91d-0e2978bc0c34"]
}, Open  ]],

Cell[TextData[{
 "Notice that the last function to be applied comes first in the argument \
sequence. If I want the functions to be applied in the same order as the \
arguments, I use the ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.7690093591595097`*^9, 3.769009416215144*^9}, 
   3.774783655581005*^9, 3.7749755759203362`*^9},
 CellTags->"i:28",
 CellID->1107578992,ExpressionUUID->"21fbd00c-5681-4a91-8064-a9e8c7745a8f"],

Cell[TextData[{
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of two functions and application to a value:"
}], "CodeCaption",
 CellChangeTimes->{{3.769179533018918*^9, 3.769179547196147*^9}, 
   3.773159110460018*^9, 3.774975582291336*^9},
 CellID->989926529,ExpressionUUID->"a4e723bf-7f78-40ea-8565-20201775fdb0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"RightComposition", "[", 
   RowBox[{"f1", ",", "f2"}], "]"}], "[", 
  RowBox[{"1", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.769009417738001*^9, 3.769009423398603*^9}, {
  3.7690107963374166`*^9, 3.769010797851882*^9}},
 CellLabel->"In[43]:=",
 CellID->453738476,ExpressionUUID->"0ef6143a-ce7c-4745-9c39-7cb69641f9f0"],

Cell[BoxData[
 RowBox[{"Tanh", "[", 
  FractionBox["5", "2"], "]"}]], "Output",
 CellChangeTimes->{3.76900942384831*^9, 3.769010798312293*^9, 
  3.769075769507065*^9, 3.769100640539426*^9, 3.769772673767663*^9, 
  3.769975528416175*^9, 3.771923576587283*^9, 3.771929508361244*^9, 
  3.881416434835341*^9},
 CellLabel->"Out[43]=",
 CellID->1708246479,ExpressionUUID->"2d2a6c2c-71dc-45ee-b804-a3b2a35f9a41"]
}, Open  ]],

Cell[TextData[{
 "These composition operations are sufficiently common\[LongDash]and I will \
use them extensively throughout this book\[LongDash]that the Wolfram Language \
provides syntactic sugar. I first show the conventional (left) ",
 ButtonBox["Composition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Composition.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Composition.html"],
 " syntactic sugar. The parentheses are required."
}], "Text",
 CellChangeTimes->{{3.769009427052957*^9, 3.7690094948792*^9}, {
   3.7690095414447813`*^9, 3.769009546326006*^9}, {3.7749755930183363`*^9, 
   3.774975600317336*^9}, {3.774975677822336*^9, 3.774975678190336*^9}, 
   3.774975741152336*^9, {3.8561979995818777`*^9, 3.8561980021799*^9}, {
   3.8855506067070384`*^9, 3.8855506068925304`*^9}},
 CellTags->"i:29",
 CellID->969184320,ExpressionUUID->"4929c1e9-02a0-42c4-b12b-caba7c0a09c9"],

Cell[TextData[{
 "The ",
 ButtonBox["@*",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Composition.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Composition.html"],
 " syntactic sugar for standard ",
 ButtonBox["Composition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Composition.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Composition.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.77478118084791*^9, 3.7748753083236322`*^9, 
  3.774975686856336*^9, 3.775389361672106*^9},
 CellID->154141905,ExpressionUUID->"32efa313-e73d-4951-820a-e8ac7794c504"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f2", " ", "@*", "f1"}], ")"}], "[", "0.5", "]"}]], "Input",
 CellChangeTimes->{{3.769009500652956*^9, 3.769009538742592*^9}},
 CellLabel->"In[44]:=",
 CellID->826737048,ExpressionUUID->"5b44205d-9ff8-4d0d-a4d3-63c791232e57"],

Cell[BoxData["0.9866142981514303`"], "Output",
 CellChangeTimes->{{3.7690095339716253`*^9, 3.769009539063354*^9}, 
   3.76907576951579*^9, 3.76910064057397*^9, 3.769772673781515*^9, 
   3.769975528459239*^9, 3.771923576621475*^9, 3.771929508371862*^9, 
   3.881416446225082*^9},
 CellLabel->"Out[44]=",
 CellID->329265210,ExpressionUUID->"f42b261a-a464-466f-a400-3f5f7619652b"]
}, Open  ]],

Cell[TextData[{
 "It may be a matter of style, but I find that I don\[CloseCurlyQuote]t use \
the conventional ",
 ButtonBox["Composition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Composition.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Composition.html"],
 " that much. What I do use a lot in this book and in my research is ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 ". Here\[CloseCurlyQuote]s the ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " sugar that I will be using ",
 StyleBox["all the time",
  FontSlant->"Italic"],
 " in this book. Separate the functions to be composed with a ",
 Cell[BoxData[
  ButtonBox[
   StyleBox["/*",
    FontColor->GrayLevel[0]],
   BaseStyle->"Hyperlink",
   ButtonData->{
     URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
     None},
   ButtonNote->
    "https://reference.wolfram.com/language/ref/RightComposition.html"]], 
  "InlineCodeText",ExpressionUUID->"947ad446-032a-4717-b1db-5bed126608c4"],
 "."
}], "Text",
 CellChangeTimes->{{3.769009552377997*^9, 3.769009567009486*^9}, {
   3.769118184476201*^9, 3.76911823509006*^9}, {3.774783838915005*^9, 
   3.7747838425720053`*^9}, {3.7749757158603363`*^9, 3.774975772185336*^9}, {
   3.8757847402510157`*^9, 3.8757847556304417`*^9}, {3.8855506297237983`*^9, 
   3.8855506299133234`*^9}, 3.895814706701158*^9},
 CellTags->{"LastCellOfAPage", "i:30"},
 CellID->592772282,ExpressionUUID->"3df484e1-6d58-4182-af4b-857dfadd946a"],

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["/*",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"], 
  "InlineCode"],
 " syntactic sugar for ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.769179577269402*^9, 3.7691795866240673`*^9}, 
   3.774875587700632*^9, 3.774975784673336*^9, {3.774975829389336*^9, 
   3.774975832666336*^9}, {3.8565268232208567`*^9, 3.8565268415765333`*^9}, {
   3.885550660471409*^9, 3.885550685261714*^9}, 3.8958147165791597`*^9},
 CellTags->"p: 25",
 CellID->703232801,ExpressionUUID->"593b0635-acc4-4ae5-bd2d-aedd14481001"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f1", "/*", "f2"}], ")"}], "[", 
  RowBox[{"1", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.769009574019326*^9, 3.7690095792198353`*^9}, {
  3.76901080751437*^9, 3.7690108088830547`*^9}},
 CellLabel->"In[45]:=",
 CellID->1296352807,ExpressionUUID->"9a7a713a-c293-4a75-b74a-6ed47ed96ea2"],

Cell[BoxData[
 RowBox[{"Tanh", "[", 
  FractionBox["5", "2"], "]"}]], "Output",
 CellChangeTimes->{3.769009579699456*^9, 3.7690108094936037`*^9, 
  3.769075769541152*^9, 3.769100640585153*^9, 3.7697726738248997`*^9, 
  3.7699755284720716`*^9, 3.771923576631731*^9, 3.771929508404307*^9, 
  3.881416451777409*^9},
 CellLabel->"Out[45]=",
 CellID->192554715,ExpressionUUID->"ed19ddf2-928d-4d3e-b120-e7a8143c467c"]
}, Open  ]],

Cell[TextData[{
 "Note that if I want the numeric value, I can just add the ",
 ButtonBox["N",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/N.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/N.html"],
 " function at the end of the ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " pipeline."
}], "Text",
 CellChangeTimes->{{3.7690108114022017`*^9, 3.7690108397695713`*^9}, 
   3.7749759009383364`*^9, 3.8565268672747793`*^9},
 CellID->1618610007,ExpressionUUID->"f66538a4-80fa-4848-b418-1836e29de881"],

Cell[TextData[{
 "Apply a three-function ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " to a value:"
}], "CodeCaption",
 CellChangeTimes->{{3.7747811934220085`*^9, 3.774781197878009*^9}, {
   3.7748755993556323`*^9, 3.7748756003946323`*^9}, 3.777350991483971*^9},
 CellID->34950019,ExpressionUUID->"0a2b7379-5041-4c8d-90b4-c0327ff1dccf"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"f1", "/*", "f2", "/*", "N"}], ")"}], "[", 
  RowBox[{"1", "/", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.769010841250264*^9, 3.769010849289115*^9}},
 CellLabel->"In[46]:=",
 CellID->1530695480,ExpressionUUID->"2dbe7d43-ce45-4948-9f8f-af062b9d0607"],

Cell[BoxData["0.9866142981514303`"], "Output",
 CellChangeTimes->{3.769010849626799*^9, 3.769075769550284*^9, 
  3.769100640620332*^9, 3.769772673838421*^9, 3.769975528515205*^9, 
  3.7719235766695766`*^9, 3.771929508413418*^9, 3.881416456331666*^9},
 CellLabel->"Out[46]=",
 CellID->1004480746,ExpressionUUID->"34d09b22-7be3-4248-ba56-7bee7143ad44"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "The ",
 StyleBox[ButtonBox["List",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]
}], "Subsection",
 CellChangeTimes->{{3.7689875238368883`*^9, 3.7689875271839247`*^9}, 
   3.8896907529489536`*^9, {3.893766930421627*^9, 3.8937669653895607`*^9}},
 CellID->764063548,ExpressionUUID->"f82827a7-6812-43f6-a3c0-1ca339a7cf53"],

Cell[TextData[{
 "Prior to the introduction of Associations in Version 10, and quite arguably \
even today, the fundamental data structure in the Wolfram Language was the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". Here\[CloseCurlyQuote]s the most typical way of writing a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". One puts the elements of the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " inside curly braces and separates them with commas. "
}], "Text",
 CellChangeTimes->{{3.768987573631884*^9, 3.7689876639629793`*^9}, 
   3.775389535958533*^9, {3.877537300352304*^9, 3.877537318546751*^9}, {
   3.8855511370421524`*^9, 3.8855511374949803`*^9}},
 CellTags->"i:31",
 CellID->1811325823,ExpressionUUID->"6d416926-7540-4ebc-9a0e-2dd5eb7c7894"],

Cell[TextData[{
 "Use ",
 Cell[BoxData[
  RowBox[{"{", 
   StyleBox[
    ButtonBox[
     StyleBox["...",
      FontColor->GrayLevel[0.6]],
     BaseStyle->"Hyperlink",
     ButtonData->{
       URL["https://reference.wolfram.com/language/ref/RepeatedNull.html"], 
       None},
     ButtonNote->
      "https://reference.wolfram.com/language/ref/RepeatedNull.html"],
    FontColor->GrayLevel[0.6]], "}"}]], "InlineCode",ExpressionUUID->
  "ff3ff2b4-1b6b-467f-96c9-56f595c7561f"],
 " to bracket a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ":"
}], "CodeCaption",
 CellID->496083972,ExpressionUUID->"52bb63f6-3215-4993-80d3-1f2590a5a896"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{"3", ",", "4", ",", "5"}], "}"}], ";"}]], "Input",
 CellChangeTimes->{{3.768987639343369*^9, 3.768987672927223*^9}, 
   3.769118263299183*^9},
 CellLabel->"In[47]:=",
 CellID->224927289,ExpressionUUID->"76699f35-953b-4f45-a2f0-b0515a7b6f4c"],

Cell[TextData[{
 "One can also write it in ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 " in which the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " of the expression is clearly revealed. The Wolfram Language front end \
typically outputs Lists (even those input in ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 ") using curly braces."
}], "Text",
 CellChangeTimes->{{3.7689876845735083`*^9, 3.7689877438624887`*^9}, 
   3.775389586496586*^9, {3.856526977350806*^9, 3.856526980696926*^9}, 
   3.877537337679287*^9, {3.889630657941496*^9, 3.889630667098833*^9}, 
   3.8896908038637857`*^9},
 CellTags->"i:32",
 CellID->781727503,ExpressionUUID->"ad24de9a-a73b-4ca1-a6eb-999f66413fa8"],

Cell[TextData[{
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 " of a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and its output in ",
 ButtonBox["StandardForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/StandardForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/StandardForm.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747812173890085`*^9, 3.7748756126666327`*^9, 3.7753896050824447`*^9, {
   3.885551245111397*^9, 3.8855512537731037`*^9}},
 CellID->56744392,ExpressionUUID->"64d2bc88-a02f-44c7-a44b-861587165190"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"List", "[", 
  RowBox[{"3", ",", "4", ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.768987708430107*^9, 3.7689877116142893`*^9}},
 CellLabel->"In[48]:=",
 CellID->189190575,ExpressionUUID->"c8e56a31-8d72-4c31-bfc2-5a60abdeee10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "4", ",", "5"}], "}"}]], "Output",
 CellChangeTimes->{3.768987711945554*^9, 3.769075769580818*^9, 
  3.769100640664701*^9, 3.769772673886869*^9, 3.769975528587843*^9, 
  3.771923576713784*^9, 3.771929508457512*^9, 3.881416466745061*^9},
 CellLabel->"Out[48]=",
 CellID->172088276,ExpressionUUID->"3f1b4f9e-0bbd-4a07-b555-f5dba425df35"]
}, Open  ]],

Cell[TextData[{
 "Lists can contain elements that themselves have different heads. Here I \
create a heterogeneous ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " that mixes integers, reals, symbols, and strings."
}], "Text",
 CellChangeTimes->{{3.768987758285284*^9, 3.768987806303739*^9}, 
   3.7753896222011566`*^9, {3.8655359800664186`*^9, 3.865535980135366*^9}, 
   3.877537352168256*^9, 3.885554984352414*^9, {3.8856538734538736`*^9, 
   3.8856538800654774`*^9}},
 CellTags->"i:33",
 CellID->1450196465,ExpressionUUID->"af3e74ef-95bc-42b1-9352-f3c4875a574b"],

Cell["Lists may be (and often are) heterogeneous:", "CodeCaption",
 CellChangeTimes->{3.7747812273490086`*^9, 3.774875615042632*^9},
 CellID->601579293,ExpressionUUID->"969343f1-516b-4632-9491-70421548fc96"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"heteroList", "=", 
  RowBox[{"{", 
   RowBox[{"3", ",", "4.2", ",", "f", ",", "\"\<hello world\>\""}], 
   "}"}]}]], "Input",
 CellChangeTimes->{{3.768987808517748*^9, 3.768987820906538*^9}},
 CellLabel->"In[49]:=",
 CellID->1660077452,ExpressionUUID->"56dec8aa-16d8-414c-aa0a-f0f0c9a4c21c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "4.2`", ",", "f", ",", "\<\"hello world\"\>"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.7689878230494747`*^9, 3.769075769607877*^9, 
  3.769100640673765*^9, 3.769772673928339*^9, 3.7699755286319113`*^9, 
  3.771923576725583*^9, 3.771929508494021*^9, 3.8814164722440033`*^9},
 CellLabel->"Out[49]=",
 CellID->500294549,ExpressionUUID->"628a8f3f-16f4-42c4-8478-bed032c4652f"]
}, Open  ]],

Cell[TextData[{
 "I can use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " to extract pieces of Lists. Here I create a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " that contains Parts of Lists."
}], "Text",
 CellChangeTimes->{{3.768987832625205*^9, 3.768987848712635*^9}, {
   3.7689949629440413`*^9, 3.768994986294928*^9}, {3.768996542641226*^9, 
   3.768996553145954*^9}, 3.7753896336152973`*^9, 3.877537370395101*^9, 
   3.8855549885282483`*^9},
 CellID->814193940,ExpressionUUID->"2d8d6aea-8793-46c9-bf7b-37245a32efed"],

Cell["Get Parts out of Lists:", "CodeCaption",
 CellChangeTimes->{
  3.774781240629009*^9, {3.7748756185136323`*^9, 3.7748756195226326`*^9}},
 CellID->202843215,ExpressionUUID->"8231123b-83b9-4299-b051-3c1c65e89e0a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"List", "[", 
  RowBox[{
   RowBox[{"Part", "[", 
    RowBox[{"heteroList", ",", "2"}], "]"}], ",", 
   RowBox[{"heteroList", "[", 
    RowBox[{"[", "1", "]"}], "]"}], ",", 
   RowBox[{"heteroList", "[", 
    RowBox[{"[", 
     RowBox[{"{", 
      RowBox[{"4", ",", "3"}], "}"}], "]"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.768994987740367*^9, 3.768994992989633*^9}, {
  3.768996554951888*^9, 3.768996604667923*^9}},
 CellLabel->"In[50]:=",
 CellID->391750896,ExpressionUUID->"ce07c42a-8323-4210-a91d-3952080f24ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"4.2`", ",", "3", ",", 
   RowBox[{"{", 
    RowBox[{"\<\"hello world\"\>", ",", "f"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.768994993533334*^9, {3.768996581491357*^9, 3.7689966049722*^9}, 
   3.769075769617463*^9, 3.7691006407128897`*^9, 3.769772673942712*^9, 
   3.769975528644577*^9, 3.77192357676066*^9, 3.771929508505459*^9, 
   3.8814164768780737`*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[50]=",
 CellID->1910323796,ExpressionUUID->"39d1caf2-4331-4fcb-8834-e957b96b7d2c"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Nested Lists", "Subsubsection",
 CellChangeTimes->{{3.7689875291555777`*^9, 3.7689875331621103`*^9}},
 CellTags->"p: 26",
 CellID->2119931017,ExpressionUUID->"8a05e491-2edf-4d99-bcb9-c6a58c970659"],

Cell[TextData[{
 "As shown earlier, a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " can have a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " as an element. Indeed, a typical data structure might be a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists. Here\[CloseCurlyQuote]s one in which the inner Lists have \
different numbers of elements\[LongDash]a \[OpenCurlyDoubleQuote]ragged\
\[CloseCurlyDoubleQuote] ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 StyleBox[".", "FormattedFunction"]
}], "Text",
 CellChangeTimes->{{3.769005311373501*^9, 3.7690053701822863`*^9}, {
   3.7753897535182867`*^9, 3.7753897542793627`*^9}, 3.777351188134942*^9, {
   3.8561980204738197`*^9, 3.856198021124978*^9}, {3.8570403220016813`*^9, 
   3.857040359042844*^9}, 3.8570404100435*^9, 3.865536024560998*^9, {
   3.885467999003708*^9, 3.885468000268687*^9}, {3.8855538563079433`*^9, 
   3.8855538799556775`*^9}},
 CellTags->"i:34",
 CellID->779415342,ExpressionUUID->"47eb0d05-c63c-4cf7-9e30-d5438770ba4f"],

Cell[TextData[{
 "A ragged ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists:"
}], "CodeCaption",
 CellChangeTimes->{3.7747812516040087`*^9, 3.7748756264496326`*^9, 
  3.8775373961861687`*^9},
 CellID->740456988,ExpressionUUID->"b6159391-a483-4ab5-ad34-60722d618616"],

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", "4"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"5", ",", "6", ",", "7"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"8", ",", "9", ",", "10", ",", "11"}], "}"}]}], "}"}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769005371983987*^9, 3.7690053810660667`*^9}},
 CellLabel->"In[51]:=",
 CellID->2130889941,ExpressionUUID->"b47c6448-9afd-4782-a076-84f87841ee15"],

Cell[TextData[{
 "It\[CloseCurlyQuote]s very typical to have a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " in which each inner ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " has the same number of elements. Sometimes we call these matrices or \
arrays. Here\[CloseCurlyQuote]s an example. I\[CloseCurlyQuote]ll assign the \
expression to the symbol ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "cbbb2eb8-25e3-4508-9d95-c9816b1fd3c8"],
 "."
}], "Text",
 CellChangeTimes->{{3.7690053832540903`*^9, 3.769005410499353*^9}, {
   3.769005559387578*^9, 3.769005571016035*^9}, {3.769118315055183*^9, 
   3.7691183160374928`*^9}, {3.769179761851076*^9, 3.769179791121581*^9}, {
   3.774783845154005*^9, 3.774783845852005*^9}, {3.7753897880945654`*^9, 
   3.7753898092005653`*^9}, {3.7754899199039836`*^9, 3.775489926695984*^9}, 
   3.7773512241186953`*^9, {3.856198076802792*^9, 3.856198078603134*^9}, {
   3.8775374039627123`*^9, 3.8775374088636303`*^9}},
 CellID->282457368,ExpressionUUID->"bc47541a-1fc6-4305-b9c7-69ff10c1caef"],

Cell[TextData[{
 "A ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists in which the inner Lists have the same number of elements:"
}], "CodeCaption",
 CellChangeTimes->{3.774781267579009*^9, 3.774875632009632*^9, 
  3.877537422398058*^9},
 CellID->242438384,ExpressionUUID->"c3ef57b1-0b49-4be6-9935-83dd21dabd66"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nestedList", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.7101881771505834, 0.7989108398643558, 0.8028079784985009], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.4734587847670556, 0.5326072265762373, 0.5352053189990007],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.7101881771505834`", ",", "0.7989108398643558`", ",", 
               "0.8028079784985009`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.7101881771505834, 0.7989108398643558, 0.8028079784985009]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.7101881771505834, 0.7989108398643558, 0.8028079784985009],
        Editable->False,
        Selectable->False], ",", "5", ",", "0.08", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
       "\"\<Thurgood Marshall\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.00180317540330166, 0.8926700334391704, 
              0.00014246188160593753`], RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.00120211693553444, 0.5951133556261137, 0.0000949745877372917],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.00180317540330166`", ",", "0.8926700334391704`", ",", 
               "0.00014246188160593753`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.00180317540330166, 0.8926700334391704, 
               0.00014246188160593753`]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`],
        Editable->False,
        Selectable->False], ",", "2", ",", "0.83", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "43"}], ",", 
          RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\"\<Elena Kagan\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.5202427055382031, 0.33813420051434595`, 0.0495895795536585], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.34682847035880204`, 0.2254228003428973, 0.033059719702439004`],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.5202427055382031`", ",", "0.33813420051434595`", ",", 
               "0.0495895795536585`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.5202427055382031, 0.33813420051434595`, 0.0495895795536585],
        Editable->False,
        Selectable->False], ",", "4", ",", "0.07", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "22"}], ",", 
          RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
       "\"\<Oliver Ellsworth\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.71799307373688, 0.8971633609144036, 0.09594209586818336], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.47866204915792004`, 0.5981089072762691, 0.06396139724545558],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.71799307373688`", ",", "0.8971633609144036`", ",", 
               "0.09594209586818336`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.71799307373688, 0.8971633609144036, 0.09594209586818336]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.71799307373688, 0.8971633609144036, 0.09594209586818336],
        Editable->False,
        Selectable->False], ",", "4", ",", "0.35", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
       "\"\<William Rehnquist\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.7038241862975507, 0.5975069401834057, 0.11356773283085175`], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.46921612419836717`, 0.39833796012227046`, 0.0757118218872345],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.7038241862975507`", ",", "0.5975069401834057`", ",", 
               "0.11356773283085175`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.7038241862975507, 0.5975069401834057, 0.11356773283085175`],
        Editable->False,
        Selectable->False], ",", "9", ",", "0.87", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"14", ",", "64"}], "}"}], "]"}], ",", 
       "\"\<Oliver Wendell Holmes, Jr.\>\""}], "}"}]}], "}"}]}], " ", 
  ";"}]], "Input",
 CellChangeTimes->{{3.769005574313508*^9, 3.76900559693547*^9}, {
  3.769008413443055*^9, 3.769008415592638*^9}, {3.769082298927299*^9, 
  3.769082299906001*^9}, {3.769083224008518*^9, 3.76908325645605*^9}, {
  3.769083287216634*^9, 3.769083340421455*^9}, {3.769118323996113*^9, 
  3.769118337415814*^9}},
 CellLabel->"In[67]:=",
 CellID->926554033,ExpressionUUID->"d2d9a0fd-e75f-4efe-943a-ffd40612d944"],

Cell[TextData[{
 "The ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " setting can be used with ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " and in other circumstances. Here I extract the second element of ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " the inner Lists. If one thinks of these Lists of Lists as being like a \
conventional matrix or array, one can think of these inner Lists as being \
like a row of data."
}], "Text",
 CellChangeTimes->{{3.769005607831356*^9, 3.769005670038863*^9}, {
   3.7691183500274973`*^9, 3.7691183756465073`*^9}, {3.774783848465005*^9, 
   3.774783849403005*^9}, {3.7753898205535655`*^9, 3.7753898402465653`*^9}, {
   3.856198118045219*^9, 3.85619812285878*^9}, {3.856198156407015*^9, 
   3.856198157203527*^9}, {3.8561982077985888`*^9, 3.856198245159552*^9}, 
   3.877537461474564*^9, 3.8855548990052795`*^9},
 CellTags->"i:35",
 CellID->1189708234,ExpressionUUID->"5bb1635a-df43-4f10-9562-d93be55ff154"],

Cell[TextData[{
 "Use ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " as an argument to ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774781277322009*^9, 3.774875635120632*^9, {3.775389846650565*^9, 
   3.7753898504845657`*^9}},
 CellID->166129341,ExpressionUUID->"eca38608-9ec5-4d1c-b4b4-b0fe77f8a051"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Part", "[", 
  RowBox[{"nestedList", ",", "All", ",", "2"}], "]"}]], "Input",
 CellChangeTimes->{{3.769005671873015*^9, 3.769005676536375*^9}},
 CellLabel->"In[53]:=",
 CellID->206051621,ExpressionUUID->"65103f99-ef63-4909-91f7-f8406344bcbc"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "2", ",", "4", ",", "4", ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{3.7690056769928513`*^9, 3.769075769717808*^9, 
  3.769083347736446*^9, 3.7691006408123302`*^9, 3.769772674017028*^9, 
  3.769975528743046*^9, 3.7719235768537207`*^9, 3.771929508593842*^9, 
  3.8814164963506308`*^9},
 CellLabel->"Out[53]=",
 CellID->1778589521,ExpressionUUID->"296f4533-29c3-4e51-8cda-fa1850cdf873"]
}, Open  ]],

Cell[TextData[{
 "There are some attractive ways of formatting these Lists of Lists in which \
all the inner Lists have the same number of elements. There is the built-in ",
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.7690973566384974`*^9, 3.769097388099242*^9}, 
   3.7753898605635653`*^9},
 CellTags->"i:36",
 CellID->1451164714,ExpressionUUID->"2b277dad-67e3-4dce-9076-8a9a69d0cd15"],

Cell[TextData[{
 "Use ",
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " to make an attractive matrix:"
}], "CodeCaption",
 CellChangeTimes->{3.774781290456009*^9, 3.7748756380326324`*^9, 
  3.7753898640745654`*^9},
 CellID->210163303,ExpressionUUID->"45998334-ced3-42ea-b156-b83056db897e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", "nestedList", "]"}]], "Input",
 CellChangeTimes->{{3.769097391324782*^9, 3.769097396502688*^9}},
 CellLabel->"In[54]:=",
 CellID->366146117,ExpressionUUID->"204509ba-8521-4a99-85ba-9c2d9e1031aa"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], "5", "0.08`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], 
      "]"}], "\<\"Thurgood Marshall\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], "2", "0.83`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], "\<\"Elena Kagan\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], "4", "0.07`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], "\<\"Oliver Ellsworth\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], "4", "0.35`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], "\<\"William Rehnquist\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], "9", "0.87`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], 
      "]"}], "\<\"Oliver Wendell Holmes, Jr.\"\>"}
   },
   AutoDelete->False,
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.7690973969134083`*^9, 3.769100640824626*^9, 
  3.769772674061618*^9, 3.7699755287902737`*^9, 3.771923576900343*^9, 
  3.7719295086323357`*^9, 3.8814165022463903`*^9},
 CellLabel->"Out[54]=",
 CellID->145845957,ExpressionUUID->"9981317a-32de-4026-8e29-e01c479911d8"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " can be used with ",
 ButtonBox["Dividers",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dividers.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dividers.html"],
 " if desired. (I like ",
 ButtonBox["Dividers",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dividers.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dividers.html"],
 ".)"
}], "Text",
 CellChangeTimes->{{3.769097402264694*^9, 3.76909740933033*^9}, {
  3.769118412717265*^9, 3.769118438396809*^9}, {3.7753898744285655`*^9, 
  3.7753898868135653`*^9}, {3.8855548626476192`*^9, 3.8855548643779707`*^9}},
 CellTags->{"LastCellOfAPage", "i:37"},
 CellID->764986273,ExpressionUUID->"995b208a-cab2-48c0-a1c6-856cd7b92b2f"],

Cell[TextData[{
 "Use ",
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " with ",
 ButtonBox["Dividers",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dividers.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dividers.html"],
 " to make the structure of a matrix more clear:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774781301633009*^9, 3.7748756421366324`*^9, {3.775389902822565*^9, 
   3.7753899064965653`*^9}},
 CellTags->"p: 27",
 CellID->303065152,ExpressionUUID->"633c3e5a-75d2-4635-94d0-1fb745da4b39"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{"nestedList", ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690974113026257`*^9, 3.769097416363546*^9}},
 CellLabel->"In[55]:=",
 CellID->573066320,ExpressionUUID->"8d4a6a4f-a205-47b8-a224-371fd147a2b1"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], "5", "0.08`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], 
      "]"}], "\<\"Thurgood Marshall\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], "2", "0.83`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], "\<\"Elena Kagan\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], "4", "0.07`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], "\<\"Oliver Ellsworth\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], "4", "0.35`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], "\<\"William Rehnquist\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], "9", "0.87`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], 
      "]"}], "\<\"Oliver Wendell Holmes, Jr.\"\>"}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.76909741671553*^9, 3.76910064087083*^9, 
  3.769772674090054*^9, 3.769975528819523*^9, 3.771923576953569*^9, 
  3.7719295086542807`*^9, 3.8814165086089773`*^9},
 CellLabel->"Out[55]=",
 CellID->708300154,ExpressionUUID->"5ef7259f-0e30-40c2-bcba-a8211a18c0d4"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s also ",
 ButtonBox["TableForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TableForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TableForm.html"],
 ", which can be used with headings. Here I give each of the rows a heading \
(an integer running from 1 to 5) and each of the columns a heading that \
attempts to describe the contents of the associated values."
}], "Text",
 CellChangeTimes->{{3.769097419408266*^9, 3.7690974524189873`*^9}, {
   3.769118447217153*^9, 3.769118476577373*^9}, {3.774783852418005*^9, 
   3.774783855698005*^9}, 3.7753900117555656`*^9},
 CellTags->"i:38",
 CellID->1096113171,ExpressionUUID->"9d4f7fac-6535-443d-a447-a1dd68baae4a"],

Cell[TextData[{
 "Use ",
 ButtonBox["TableForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TableForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TableForm.html"],
 " to attach headings to matrices:"
}], "CodeCaption",
 CellChangeTimes->{3.7747813136230087`*^9, 3.7748756453366327`*^9, 
  3.7753901187315655`*^9},
 CellID->478809283,ExpressionUUID->"8dfb85c2-46bc-4fc7-b644-6b2aad09bb79"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"TableForm", "[", 
  RowBox[{"nestedList", ",", 
   RowBox[{"TableHeadings", "\[Rule]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"Range", "[", "5", "]"}], ",", 
      RowBox[{"{", 
       RowBox[{
       "\"\<A color\>\"", ",", "\"\<An integer\>\"", ",", "\"\<A real\>\"", 
        ",", "\"\<A place\>\"", ",", "\"\<Justice\>\""}], "}"}]}], "}"}]}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.7690974263999987`*^9, 3.769097514089703*^9}},
 CellLabel->"In[56]:=",
 CellID->625197812,ExpressionUUID->"62475009-07a0-480a-9146-ed2ad64faef2"],

Cell[BoxData[
 TagBox[
  TagBox[GridBox[{
     {
      StyleBox["\[Null]",
       ShowStringCharacters->False], 
      TagBox["\<\"A color\"\>",
       HoldForm], 
      TagBox["\<\"An integer\"\>",
       HoldForm], 
      TagBox["\<\"A real\"\>",
       HoldForm], 
      TagBox["\<\"A place\"\>",
       HoldForm], 
      TagBox["\<\"Justice\"\>",
       HoldForm]},
     {
      TagBox["1",
       HoldForm], 
      TemplateBox[<|
       "color" -> RGBColor[
         0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
       "RGBColorSwatchTemplate"], "5", "0.08`", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "86"}], "}"}], 
       "]"}], "\<\"Thurgood Marshall\"\>"},
     {
      TagBox["2",
       HoldForm], 
      TemplateBox[<|
       "color" -> RGBColor[
         0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
       "RGBColorSwatchTemplate"], "2", "0.83`", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "43"}], ",", 
         RowBox[{"-", "113"}]}], "}"}], "]"}], "\<\"Elena Kagan\"\>"},
     {
      TagBox["3",
       HoldForm], 
      TemplateBox[<|
       "color" -> RGBColor[
         0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
       "RGBColorSwatchTemplate"], "4", "0.07`", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "22"}], ",", 
         RowBox[{"-", "40"}]}], "}"}], "]"}], "\<\"Oliver Ellsworth\"\>"},
     {
      TagBox["4",
       HoldForm], 
      TemplateBox[<|
       "color" -> RGBColor[
         0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
       "RGBColorSwatchTemplate"], "4", "0.35`", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{"17", ",", "78"}], "}"}], "]"}], "\<\"William Rehnquist\"\>"},
     {
      TagBox["5",
       HoldForm], 
      TemplateBox[<|
       "color" -> RGBColor[
         0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
       "RGBColorSwatchTemplate"], "9", "0.87`", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{"14", ",", "64"}], "}"}], 
       "]"}], "\<\"Oliver Wendell Holmes, Jr.\"\>"}
    },
    GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
    GridBoxDividers->{
     "Columns" -> {False, True, {False}, False}, 
      "Rows" -> {False, True, {False}, False}},
    GridBoxSpacings->{"Columns" -> {
        Offset[0.27999999999999997`], {
         Offset[2.0999999999999996`]}, 
        Offset[0.27999999999999997`]}, "Rows" -> {
        Offset[0.2], {
         Offset[0.4]}, 
        Offset[0.2]}}],
   {OutputFormsDump`HeadedRows, OutputFormsDump`HeadedColumns}],
  Function[BoxForm`e$, 
   TableForm[
   BoxForm`e$, 
    TableHeadings -> {{1, 2, 3, 4, 5}, {
      "A color", "An integer", "A real", "A place", "Justice"}}]]]], "Output",
 CellChangeTimes->{
  3.769097431536436*^9, {3.7690974800489807`*^9, 3.769097514449188*^9}, 
   3.769100640894238*^9, 3.769772674147772*^9, 3.7699755288792057`*^9, 
   3.771923576979055*^9, 3.771929508701477*^9, 3.8814165150470047`*^9},
 CellLabel->"Out[56]//TableForm=",
 CellID->158831440,ExpressionUUID->"c56f0a78-11a9-429f-842e-50a7b1c00b5d"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s also a ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " called ",
 ButtonBox["DatasetForm",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
DatasetForm"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
DatasetForm"],
 " that makes the data look like a Wolfram Language dataset, without all of \
the overhead\[LongDash]often useful overhead\[LongDash]that comes with the \
real ",
 ButtonBox["Dataset",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dataset.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dataset.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.769097517941866*^9, 3.7690975841390343`*^9}, {
   3.774783862673005*^9, 3.7747838634190054`*^9}, {3.7753903082535653`*^9, 
   3.7753903365005655`*^9}, 3.7753903765105653`*^9, {3.777351425868821*^9, 
   3.77735142666744*^9}, {3.7773537388066893`*^9, 3.777353740012648*^9}, {
   3.777353915301382*^9, 3.777353916412156*^9}, {3.8775375314897614`*^9, 
   3.8775375961335907`*^9}, {3.8855561972750645`*^9, 3.885556200721002*^9}, {
   3.897573034029578*^9, 3.897573044865293*^9}, {3.897574047438897*^9, 
   3.897574070286771*^9}},
 CellTags->"i:39",
 CellID->1772517426,ExpressionUUID->"52f8ee55-f480-468f-b7bc-1c9c998520a2"],

Cell[TextData[{
 "Use the ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " ",
 ButtonBox["DatasetForm",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
DatasetForm"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
DatasetForm"],
 " to emulate the presentation of a true dataset:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774781323865009*^9, 3.774875648153632*^9, 3.7753903802445655`*^9, 
   3.777353875101975*^9, {3.8757848217814074`*^9, 3.875784822456709*^9}, {
   3.877537604644208*^9, 3.8775376131945553`*^9}},
 CellID->288590451,ExpressionUUID->"86d1ec2d-4792-432c-a6d1-99baaefdbbe8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  InterpretationBox[
   TagBox[
    TagBox[
     DynamicModuleBox[{Typeset`open = False}, 
      FrameBox[
       PaneSelectorBox[{False->GridBox[{
          {
           PaneBox[GridBox[{
              {
               StyleBox[
                StyleBox[
                 AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                  BoxBaselineShift->-0.25,
                  BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                 
                 FontColor->RGBColor[
                  0.8745098039215686, 0.2784313725490196, 
                   0.03137254901960784]],
                ShowStringCharacters->False,
                FontFamily->"Source Sans Pro Black",
                FontSize->0.6538461538461539 Inherited,
                FontWeight->"Heavy",
                PrivateFontOptions->{"OperatorSubstitution"->False}], 
               StyleBox[
                RowBox[{
                 StyleBox["DatasetForm", "ResourceFunctionLabel"], " "}],
                ShowAutoStyles->False,
                ShowStringCharacters->False,
                FontSize->Rational[12, 13] Inherited,
                FontColor->GrayLevel[0.1]]}
             },
             GridBoxSpacings->{"Columns" -> {{0.25}}}],
            Alignment->Left,
            BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
            BaselinePosition->Baseline,
            FrameMargins->{{3, 0}, {0, 0}}], 
           ItemBox[
            PaneBox[
             TogglerBox[Dynamic[Typeset`open], {True->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "IconizeCloser"],
               ImageSizeCache->{11., {2., 9.}}], False->
              
              DynamicBox[FEPrivate`FrontEndResource[
               "FEBitmaps", "IconizeOpener"],
               ImageSizeCache->{11., {2., 9.}}]},
              Appearance->None,
              BaselinePosition->Baseline,
              ContentPadding->False,
              FrameMargins->0],
             Alignment->Left,
             BaselinePosition->Baseline,
             FrameMargins->{{1, 1}, {0, 0}}],
            Frame->{{
               RGBColor[
               0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                0.5], False}, {False, False}}]}
         },
         BaselinePosition->{1, 1},
         GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
         GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
        GridBox[{
          {GridBox[{
             {
              PaneBox[GridBox[{
                 {
                  StyleBox[
                   StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                   ShowStringCharacters->False,
                   FontFamily->"Source Sans Pro Black",
                   FontSize->0.6538461538461539 Inherited,
                   FontWeight->"Heavy",
                   PrivateFontOptions->{"OperatorSubstitution"->False}], 
                  StyleBox[
                   RowBox[{
                    StyleBox["DatasetForm", "ResourceFunctionLabel"], " "}],
                   ShowAutoStyles->False,
                   ShowStringCharacters->False,
                   FontSize->Rational[12, 13] Inherited,
                   FontColor->GrayLevel[0.1]]}
                },
                GridBoxSpacings->{"Columns" -> {{0.25}}}],
               Alignment->Left,
               BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
               BaselinePosition->Baseline,
               FrameMargins->{{3, 0}, {0, 0}}], 
              ItemBox[
               PaneBox[
                TogglerBox[Dynamic[Typeset`open], {True->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeCloser"]], False->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeOpener"]]},
                 Appearance->None,
                 BaselinePosition->Baseline,
                 ContentPadding->False,
                 FrameMargins->0],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{1, 1}, {0, 0}}],
               Frame->{{
                  RGBColor[
                  0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                   0.5], False}, {False, False}}]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
          {
           StyleBox[
            PaneBox[GridBox[{
               {
                RowBox[{
                 TagBox["\<\"Version (latest): \"\>",
                  "IconizedLabel"], " ", 
                 TagBox["\<\"1.0.0\"\>",
                  "IconizedItem"]}]},
               {
                TagBox[
                 
                 TemplateBox[{
                  "\"Documentation \[RightGuillemet]\"", 
                   "https://resources.wolframcloud.com/FunctionRepository/\
resources/a2034fb9-e46f-4b36-ac04-a3ea684b9d1e/"},
                  "HyperlinkURL"],
                 "IconizedItem"]}
              },
              DefaultBaseStyle->"Column",
              GridBoxAlignment->{"Columns" -> {{Left}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
             Alignment->Left,
             BaselinePosition->Baseline,
             FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
            FontFamily->"Roboto",
            FontSize->11]}
         },
         BaselinePosition->{1, 1},
         GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
         GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
              GrayLevel[0.8]}, False}},
         GridBoxItemSize->{
          "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
        Typeset`open],
        BaselinePosition->Baseline,
        ImageSize->Automatic],
       Background->RGBColor[
        0.9686274509803922, 0.9764705882352941, 0.984313725490196],
       BaselinePosition->Baseline,
       DefaultBaseStyle->{},
       FrameMargins->{{0, 0}, {1, 0}},
       FrameStyle->RGBColor[
        0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
       RoundingRadius->4]],
     #& ,
     TagBoxNote->" "],
    {"FunctionResourceBox", 
     RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
     "DatasetForm"},
    TagBoxNote->"FunctionResourceBox"],
   ResourceFunction[
    ResourceObject[<|
     "Name" -> "DatasetForm", "ShortName" -> "DatasetForm", "UUID" -> 
      "a2034fb9-e46f-4b36-ac04-a3ea684b9d1e", "ResourceType" -> "Function", 
      "Version" -> "1.0.0", "Description" -> 
      "Display data formatted like a dataset", "RepositoryLocation" -> 
      URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
      "SymbolName" -> 
      "FunctionRepository`$9011b47ab6d048f099e90511f6c24686`DatasetForm", 
      "FunctionLocation" -> 
      CloudObject[
       "https://www.wolframcloud.com/obj/d6b6cd3f-340f-4c5a-91b5-\
d391d60da0b9"]|>, ResourceSystemBase -> Automatic]],
   Selectable->False], "[", "nestedList", "]"}]], "Input",
 CellChangeTimes->{{3.7690975297276583`*^9, 3.769097545399867*^9}, 
   3.769118488440421*^9, 3.877537646148262*^9},
 CellLabel->"In[57]:=",
 CellID->2087513403,ExpressionUUID->"6cc9d457-ca6f-45ab-91f5-5b85c0eee452"],

Cell[BoxData[
 InterpretationBox[
  DynamicModuleBox[{TypeSystem`NestedGrid`PackagePrivate`$state$$ = <|
   "InitialData" -> {{
       RGBColor[0.7101881771505834, 0.7989108398643558, 0.8028079784985009], 
       5, 0.08, 
       GeoPosition[{-4, 86}], "Thurgood Marshall"}, {
       RGBColor[
       0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`], 2, 
       0.83, 
       GeoPosition[{-43, -113}], "Elena Kagan"}, {
       RGBColor[0.5202427055382031, 0.33813420051434595`, 0.0495895795536585],
        4, 0.07, 
       GeoPosition[{-22, -40}], "Oliver Ellsworth"}, {
       RGBColor[0.71799307373688, 0.8971633609144036, 0.09594209586818336], 4,
        0.35, 
       GeoPosition[{17, 78}], "William Rehnquist"}, {
       RGBColor[0.7038241862975507, 0.5975069401834057, 0.11356773283085175`],
        9, 0.87, 
       GeoPosition[{14, 64}], "Oliver Wendell Holmes, Jr."}}, 
    "AllowEmbedding" -> True, "InitialShape" -> 
    TypeSystem`PackageScope`Limited[
      TypeSystem`PackageScope`MatrixShape[5, 5], 5, 5, {All}], "InitialType" -> 
    TypeSystem`Vector[
      TypeSystem`Vector[TypeSystem`AnyType, 5], 5], "Meta" -> <||>, 
    "RowTarget" -> 20, "ColumnTarget" -> 10, "Shape" -> 
    TypeSystem`PackageScope`Limited[
      TypeSystem`PackageScope`MatrixShape[5, 5], 5, 5, {All}], "Type" -> 
    TypeSystem`Vector[
      TypeSystem`Vector[TypeSystem`AnyType, 5], 5], "Path" -> {}, 
    "DisplayedRowCount" -> 5, "DisplayedColumnCount" -> 5, "DataRowCount" -> 
    5, "DataColumnCount" -> 5, "SortPaths" -> {}, "SortDirections" -> {}, 
    "HiddenItemsMap" -> Null, "UpdateType" -> 1|>, 
   TypeSystem`NestedGrid`PackagePrivate`$outputID$$, 
   TypeSystem`NestedGrid`PackagePrivate`$path$$ = {}, 
   TypeSystem`NestedGrid`PackagePrivate`$vPos$$ = 1, 
   TypeSystem`NestedGrid`PackagePrivate`$hPos$$ = 1, 
   TypeSystem`NestedGrid`PackagePrivate`$grid$$ = 
   DynamicModule[{TypeSystem`NestedGrid`PackagePrivate`renderedGrid = Deploy[
       Style[
        Grid[{{
           Item[
            Pane[
             Annotation[
              RawBoxes[
               StyleBox[
                
                TemplateBox[<|
                 "color" -> 
                  RGBColor[
                   0.7101881771505834, 0.7989108398643558, 
                    0.8028079784985009]|>, "RGBColorSwatchTemplate"], 
                FontFamily -> Dynamic[
                  CurrentValue[{"StyleHints", "CodeFont"}]], 
                ShowStringCharacters -> True]], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{1, 1}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["5"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{1, 2}, "Item", 
               False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["0.08"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{1, 3}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["\"4.0\[Degree]S 86.0\[Degree]E\""], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{1, 4}, "Item", 
               False], "Mouse"], ImageSize -> {{106, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation["Thurgood Marshall", 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{1, 5}, "Item", 
               False], "Mouse"], ImageSize -> {{190.4, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}]}, {
           Item[
            Pane[
             Annotation[
              RawBoxes[
               StyleBox[
                
                TemplateBox[<|
                 "color" -> 
                  RGBColor[
                   0.00180317540330166, 0.8926700334391704, 
                    0.00014246188160593753`]|>, "RGBColorSwatchTemplate"], 
                FontFamily -> Dynamic[
                  CurrentValue[{"StyleHints", "CodeFont"}]], 
                ShowStringCharacters -> True]], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{2, 1}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["2"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{2, 2}, "Item", 
               False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["0.83"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{2, 3}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["\"43.0\[Degree]S 113.0\[Degree]W\""], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{2, 4}, "Item", 
               False], "Mouse"], ImageSize -> {{106, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation["Elena Kagan", 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{2, 5}, "Item", 
               False], "Mouse"], 
             ImageSize -> {{123.20000000000002`, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}]}, {
           Item[
            Pane[
             Annotation[
              RawBoxes[
               StyleBox[
                
                TemplateBox[<|
                 "color" -> 
                  RGBColor[
                   0.5202427055382031, 0.33813420051434595`, 
                    0.0495895795536585]|>, "RGBColorSwatchTemplate"], 
                FontFamily -> Dynamic[
                  CurrentValue[{"StyleHints", "CodeFont"}]], 
                ShowStringCharacters -> True]], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{3, 1}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["4"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{3, 2}, "Item", 
               False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["0.07"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{3, 3}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["\"22.0\[Degree]S 40.0\[Degree]W\""], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{3, 4}, "Item", 
               False], "Mouse"], ImageSize -> {{106, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation["Oliver Ellsworth", 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{3, 5}, "Item", 
               False], "Mouse"], 
             ImageSize -> {{179.20000000000002`, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}]}, {
           Item[
            Pane[
             Annotation[
              RawBoxes[
               StyleBox[
                
                TemplateBox[<|
                 "color" -> 
                  RGBColor[
                   0.71799307373688, 0.8971633609144036, 
                    0.09594209586818336]|>, "RGBColorSwatchTemplate"], 
                FontFamily -> Dynamic[
                  CurrentValue[{"StyleHints", "CodeFont"}]], 
                ShowStringCharacters -> True]], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{4, 1}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["4"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{4, 2}, "Item", 
               False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["0.35"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{4, 3}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["\"17.0\[Degree]N 78.0\[Degree]E\""], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{4, 4}, "Item", 
               False], "Mouse"], ImageSize -> {{106, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation["William Rehnquist", 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{4, 5}, "Item", 
               False], "Mouse"], ImageSize -> {{190.4, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}]}, {
           Item[
            Pane[
             Annotation[
              RawBoxes[
               StyleBox[
                
                TemplateBox[<|
                 "color" -> 
                  RGBColor[
                   0.7038241862975507, 0.5975069401834057, 
                    0.11356773283085175`]|>, "RGBColorSwatchTemplate"], 
                FontFamily -> Dynamic[
                  CurrentValue[{"StyleHints", "CodeFont"}]], 
                ShowStringCharacters -> True]], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{5, 1}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["9"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{5, 2}, "Item", 
               False], "Mouse"], ImageSize -> {{34, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["0.87"], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{5, 3}, "Item", 
               False], "Mouse"], ImageSize -> {{60, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation[
              RawBoxes["\"14.0\[Degree]N 64.0\[Degree]E\""], 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{5, 4}, "Item", 
               False], "Mouse"], ImageSize -> {{106, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}], 
           Item[
            Pane[
             Annotation["Oliver Wendell Holmes, Jr.", 
              TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
               TypeSystem`NestedGrid`PackagePrivate`localHold[
               "ced9f62b-31ac-43bc-9e19-866e39ac471b"]][{5, 5}, "Item", 
               False], "Mouse"], 
             ImageSize -> {{291.20000000000005`, Full}, Automatic}, 
             ImageMargins -> {{5, 3}, {4, 5}}], 
            ItemSize -> {Full, Automatic}]}}, 
         BaseStyle -> {
          ContextMenu -> 
           Dynamic[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
             Which[TypeSystem`NestedGrid`PackagePrivate`$lastOutputID =!= 
               TypeSystem`NestedGrid`PackagePrivate`localHold[
                TypeSystem`NestedGrid`PackagePrivate`$outputID$$], {}, 
               TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger === 
               TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger, 
               TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu, True, 
               TypeSystem`NestedGrid`PackagePrivate`$lastContextMenuTrigger = 
                TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger; 
               TypeSystem`NestedGrid`PackagePrivate`$lastContextMenu = 
                Block[{TypeSystem`NestedGrid`PackagePrivate`$globalScrollPos = \
{TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$}}, 
                  
                  With[{TypeSystem`NestedGrid`PackagePrivate`lastPath$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$ = 
                    TypeSystem`NestedGrid`PackagePrivate`$\
lastPathIsLeafHeader, TypeSystem`NestedGrid`PackagePrivate`headerHidden$ = And[
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`$lastPathType, 
                    Alternatives["RowHeader", "ColumnHeader"]], 
                    TypeSystem`NestedGrid`PackagePrivate`headerHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]], 
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`allHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`anyHidden$ = 
                    TypeSystem`NestedGrid`PackagePrivate`anyHiddenQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ = 
                    TypeSystem`NestedGrid`PackagePrivate`columnSortDirection[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortPaths"], 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$[
                    "SortDirections"]], 
                    TypeSystem`NestedGrid`PackagePrivate`haveData$ = Not[
                    FailureQ[
                    TypeSystem`NestedGrid`PackagePrivate`datasetInitialData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$]]], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$ = Not[
                    FreeQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, Keys]]}, 
                   Join[{
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    Not[TypeSystem`NestedGrid`PackagePrivate`anyHidden$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$], 
                    Nothing, 
                    MenuItem[
                    "Show " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "remove"]], MenuEvaluator -> Automatic]], 
                    If[
                    Or[
                    Not[TypeSystem`NestedGrid`PackagePrivate`haveData$], 
                    TypeSystem`NestedGrid`PackagePrivate`pathEmptyQ[
                    TypeSystem`NestedGrid`PackagePrivate`$lastPath, 
                    TypeSystem`NestedGrid`PackagePrivate`$state$$], 
                    TypeSystem`NestedGrid`PackagePrivate`isKeyDummy$, 
                    And[
                    TypeSystem`NestedGrid`PackagePrivate`allHidden$, 
                    TypeSystem`NestedGrid`PackagePrivate`headerHidden$]], 
                    Nothing, 
                    MenuItem[
                    "Hide " <> 
                    Which[TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "Item", "", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "RowHeader", "Row", 
                    TypeSystem`NestedGrid`PackagePrivate`lastPathType$ == 
                    "ColumnHeader", "Column", True, ""], 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateHiddenItems[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, "add"]], 
                    MenuEvaluator -> Automatic]], Delimiter}, 
                    If[
                    And[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MatchQ[TypeSystem`NestedGrid`PackagePrivate`lastPathType$, 
                    Alternatives["ColumnHeader", "KeyDummy"]], 
                    TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
                    Not[TypeSystem`NestedGrid`PackagePrivate`allHidden$]], {
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Ascending", 
                    MenuItem["Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Ascending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    "Descending", 
                    MenuItem["Reverse Sort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, 
                    "Descending"]], MenuEvaluator -> Automatic], Nothing], 
                    If[
                    TypeSystem`NestedGrid`PackagePrivate`sortDirection$ =!= 
                    None, 
                    MenuItem["Unsort", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`updateSort[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$path$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
                    TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
                    TypeSystem`NestedGrid`PackagePrivate`localHold[
                    TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
                    TypeSystem`NestedGrid`PackagePrivate`lastPath$, None]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter}, {}], {
                    MenuItem["Copy Position to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Copy Data to Clipboard", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`copyClip]], 
                    MenuEvaluator -> Automatic], Nothing], Delimiter, 
                    MenuItem["Paste Position in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentPosition[
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], 
                    If[TypeSystem`NestedGrid`PackagePrivate`haveData$, 
                    MenuItem["Paste Data in New Cell", 
                    KernelExecute[
                    TypeSystem`NestedGrid`PackagePrivate`toCurrentData[
                    TypeSystem`NestedGrid`PackagePrivate`$state$$, 
                    TypeSystem`NestedGrid`PackagePrivate`cellPaste]], 
                    MenuEvaluator -> Automatic], Nothing]}]]]]], FontFamily -> 
           "Source Sans Pro", FontSize -> 14, FontWeight -> Plain}, Dividers -> 
         All, FrameStyle -> GrayLevel[0.7490196078431373], Spacings -> {1, 0},
          Alignment -> Left, 
         BaseStyle -> {
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
           Plain}], LineBreakWithin -> False, ContextMenu -> {}, NumberMarks -> 
        False, ShowAutoStyles -> False]], 
     TypeSystem`NestedGrid`PackagePrivate`initialQ = True}, 
    Dynamic[
     TypeSystem`NestedGrid`PackagePrivate`setupViewPath[
     TypeSystem`NestedGrid`PackagePrivate`$path$$, If[
        Not[TypeSystem`NestedGrid`PackagePrivate`initialQ], 
        Module[{
         TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = $Failed, 
          TypeSystem`NestedGrid`PackagePrivate`tmpData$ = 
          TypeSystem`NestedGrid`PackagePrivate`datasetData[
           TypeSystem`NestedGrid`PackagePrivate`$state$$]}, 
         TypeSystem`NestedGrid`PackagePrivate`tmpGrid$ = If[
            FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpData$], 
            TypeSystem`NestedGrid`PackagePrivate`renderedGrid, 
            TypeSystem`NestedGrid`PackagePrivate`renderGrid[
            TypeSystem`NestedGrid`PackagePrivate`$state$$, 
             TypeSystem`NestedGrid`PackagePrivate`$path$$, 
             TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
             TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
             TypeSystem`NestedGrid`PackagePrivate`localHold[
             TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
            TypeSystem`NestedGrid`PackagePrivate`tmpData$]]; If[
           Not[
            FailureQ[TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]], 
           TypeSystem`NestedGrid`PackagePrivate`renderedGrid = 
           TypeSystem`NestedGrid`PackagePrivate`tmpGrid$]; Null]]; 
      TypeSystem`NestedGrid`PackagePrivate`initialQ = False; 
      TypeSystem`NestedGrid`PackagePrivate`$vPos$$; 
      TypeSystem`NestedGrid`PackagePrivate`$hPos$$; If[
        FailureQ[TypeSystem`NestedGrid`PackagePrivate`renderedGrid], 
        TypeSystem`SparseGrid[
         TypeSystem`H["(data no longer present)"]], 
        TypeSystem`NestedGrid`PackagePrivate`renderedGrid]], 
     TrackedSymbols :> {
      TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$}], 
    DynamicModuleValues :> {}], 
   TypeSystem`NestedGrid`PackagePrivate`$topBar$$ = Dynamic[
    TypeSystem`NestedGrid`PackagePrivate`makeFramedBar[
     TypeSystem`PackageScope`SubViewPathbar[
     TypeSystem`NestedGrid`PackagePrivate`$path$$, 
      TypeSystem`NestedGrid`PackagePrivate`updateState[
      TypeSystem`NestedGrid`PackagePrivate`$state$$, 
       TypeSystem`NestedGrid`PackagePrivate`$path$$, 
       TypeSystem`NestedGrid`PackagePrivate`$vPos$$, 
       TypeSystem`NestedGrid`PackagePrivate`$hPos$$, 
       TypeSystem`NestedGrid`PackagePrivate`$grid$$, 
       TypeSystem`NestedGrid`PackagePrivate`localHold[
       TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]]], 
    TrackedSymbols :> {TypeSystem`NestedGrid`PackagePrivate`$path$$}], 
   TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$ = Style[
    Framed[
     Dynamic[
      Replace[
      TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$, {
       TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][Null, 
          Blank[]] -> "", TypeSystem`NestedGrid`PackagePrivate`$SliceMarker[
          TypeSystem`NestedGrid`PackagePrivate`localHold[
          TypeSystem`NestedGrid`PackagePrivate`$outputID$$]][
          Pattern[TypeSystem`NestedGrid`PackagePrivate`path$, 
           Blank[]], 
          Pattern[TypeSystem`NestedGrid`PackagePrivate`pathType$, 
           Blank[]], 
          Pattern[TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$, 
           Blank[]]] :> (
         Increment[TypeSystem`NestedGrid`PackagePrivate`$contextMenuTrigger]; 
         TypeSystem`NestedGrid`PackagePrivate`$lastPath = 
          TypeSystem`NestedGrid`PackagePrivate`path$; 
         TypeSystem`NestedGrid`PackagePrivate`$lastPathType = 
          TypeSystem`NestedGrid`PackagePrivate`pathType$; 
         TypeSystem`NestedGrid`PackagePrivate`$lastPathIsLeafHeader = 
          TypeSystem`NestedGrid`PackagePrivate`isLeafHeader$; 
         TypeSystem`NestedGrid`PackagePrivate`$lastOutputID = 
          TypeSystem`NestedGrid`PackagePrivate`localHold[
           TypeSystem`NestedGrid`PackagePrivate`$outputID$$]; 
         TypeSystem`NestedGrid`PackagePrivate`makePathTrail[
          TypeSystem`NestedGrid`PackagePrivate`path$, 
           TypeSystem`NestedGrid`PackagePrivate`makePathElements]), Null :> 
        Spacer[10], Blank[] :> Spacer[10]}], 
      TrackedSymbols :> {
       TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$}], FrameStyle -> 
     None, ImageMargins -> 0, FrameMargins -> 0, Alignment -> Top, 
     ImageSize -> {Automatic, 15}], FontSize -> 1], 
   TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = Null}, 
   DynamicWrapperBox[
    DynamicBox[ToBoxes[
      Dataset`DatasetContent[
      2, "Path" -> Hold[TypeSystem`NestedGrid`PackagePrivate`$path$$], "Grid" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$grid$$], "State" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$state$$], "VPos" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$vPos$$], "HPos" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$hPos$$], "TopBar" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$topBar$$], "BottomBar" -> 
       Hold[TypeSystem`NestedGrid`PackagePrivate`$bottomBar$$], "OutputID" -> 
       Hold[
         TypeSystem`NestedGrid`PackagePrivate`localHold[
         TypeSystem`NestedGrid`PackagePrivate`$outputID$$]]], StandardForm],
     ImageSizeCache->{664., {73.3837890625, 80.6162109375}},
     TrackedSymbols:>{
      TypeSystem`NestedGrid`PackagePrivate`$state$$, 
       TypeSystem`NestedGrid`PackagePrivate`$grid$$}], 
    TypeSystem`NestedGrid`PackagePrivate`mouseAnnotation$$ = MouseAnnotation[],
    ImageSizeCache->{664., {73.3837890625, 80.6162109375}}],
   BaseStyle->{LineBreakWithin -> False},
   DynamicModuleValues:>{},
   Initialization:>(TypeSystem`NestedGrid`PackagePrivate`$outputID$$ = 
    CreateUUID[]),
   UnsavedVariables:>{TypeSystem`NestedGrid`PackagePrivate`$outputID$$}],
  {{
    RGBColor[0.7101881771505834, 0.7989108398643558, 0.8028079784985009], 5, 
    0.08, 
    GeoPosition[{-4, 86}], "Thurgood Marshall"}, {
    RGBColor[
    0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`], 2, 
    0.83, 
    GeoPosition[{-43, -113}], "Elena Kagan"}, {
    RGBColor[0.5202427055382031, 0.33813420051434595`, 0.0495895795536585], 4,
     0.07, 
    GeoPosition[{-22, -40}], "Oliver Ellsworth"}, {
    RGBColor[0.71799307373688, 0.8971633609144036, 0.09594209586818336], 4, 
    0.35, 
    GeoPosition[{17, 78}], "William Rehnquist"}, {
    RGBColor[0.7038241862975507, 0.5975069401834057, 0.11356773283085175`], 9,
     0.87, 
    GeoPosition[{14, 64}], "Oliver Wendell Holmes, Jr."}}]], "Output",
 CellChangeTimes->{{3.7690975399843063`*^9, 3.769097545924911*^9}, 
   3.769100640951354*^9, 3.769772674404602*^9, 3.7699755291496468`*^9, 
   3.771923577308816*^9, 3.771929509078157*^9, 3.881416523087006*^9},
 CellLabel->"Out[57]=",
 CellID->850191113,ExpressionUUID->"7857257f-3a5c-4718-8073-b69483b98b18"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Levels", "Subsection",
 CellChangeTimes->{{3.768987550058066*^9, 3.768987553401206*^9}},
 CellID->1365955183,ExpressionUUID->"1fda4ca4-f25b-4f76-bd61-82d00c0a6170"],

Cell[TextData[{
 "Wolfram Language expression parts have levels. In the expression ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}]], "InlineCodeText",
  ExpressionUUID->"7d50f5ce-eb66-4f2b-b3ab-565af693c861"],
 ", ",
 Cell[BoxData[
 "8"], "InlineCodeText",ExpressionUUID->
  "68950c78-69f1-483f-b57c-66b769b125c4"],
 " and ",
 Cell[BoxData[
  RowBox[{"h", "[", 
   RowBox[{"x", ",", "y", ",", "9"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "a495f0db-e9c9-46b8-becd-bec1d3e46ef8"],
 " lie at the first level because they are arguments to the function ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "07238c2b-ee15-4949-a83e-a0240756db70"],
 ", which lies at the top of the expression. One can find this out by using \
the ",
 ButtonBox["Level",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
 " function. The second argument, here an integer wrapped in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ", represents a request for ",
 StyleBox["only",
  FontSlant->"Italic"],
 " those parts of the expression lying at a level corresponding to the \
integer. This second argument is called a \[OpenCurlyDoubleQuote]level \
specification.\[CloseCurlyDoubleQuote]"
}], "Text",
 CellChangeTimes->{{3.769005701250998*^9, 3.76900582101635*^9}, {
   3.7690058864756193`*^9, 3.769005980125705*^9}, {3.769008452391776*^9, 
   3.7690084593510847`*^9}, 3.774783658142005*^9, {3.775390403827565*^9, 
   3.7753904622125654`*^9}, {3.777351515413726*^9, 3.777351521341152*^9}, {
   3.856198265324518*^9, 3.856198266579526*^9}, 3.856198300182427*^9, {
   3.877537680984693*^9, 3.87753770573845*^9}, {3.889692625265187*^9, 
   3.8896926280291567`*^9}},
 CellTags->{"LastCellOfAPage", "i:40"},
 CellID->1008574251,ExpressionUUID->"e960addd-9b6d-4178-afe7-e5f68876d769"],

Cell["Get the parts of an expression at level 1 (the \
\[OpenCurlyDoubleQuote]top level\[CloseCurlyDoubleQuote]):", "CodeCaption",
 CellChangeTimes->{
  3.7747813354860086`*^9, 3.7748756538396325`*^9, {3.7753904961345654`*^9, 
   3.7753904971985655`*^9}, {3.7753907686705656`*^9, 3.7753907697035656`*^9}, 
   3.777351607277038*^9, 3.777351647428337*^9, {3.8856536235450716`*^9, 
   3.885653625541824*^9}},
 CellTags->"p: 28",
 CellID->279242158,ExpressionUUID->"276737a9-ae1c-4740-997c-ef0fcdf61add"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Level", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", "1", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769005786711604*^9, 3.7690058110035686`*^9}, {
   3.769005875316573*^9, 3.769005876419018*^9}, {3.769008428318919*^9, 
   3.769008428933515*^9}, 3.769116997227902*^9},
 CellLabel->"In[58]:=",
 CellID->1019010786,ExpressionUUID->"ebbaf352-34d9-4f68-a207-a794451fb84c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", 
   RowBox[{"h", "[", 
    RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769005811430488*^9, 3.7690058767503033`*^9, 
  3.769008429650858*^9, 3.769075769745685*^9, 3.769100641069965*^9, 
  3.7697726745035553`*^9, 3.7699755292384653`*^9, 3.771923577376123*^9, 
  3.771929509144307*^9, 3.881416534031254*^9},
 CellLabel->"Out[58]=",
 CellID->1859117186,ExpressionUUID->"396c290b-9cad-4f34-b337-b2bc4ea40646"]
}, Open  ]],

Cell[TextData[{
 "But ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "bc53099a-2a38-4e77-853e-b019871cf45d"],
 ", ",
 Cell[BoxData[
 "y"], "InlineCodeText",ExpressionUUID->
  "9d263235-6c75-4c3b-a801-3f0b4e4faa09"],
 ", and ",
 Cell[BoxData[
 "9"], "InlineCodeText",ExpressionUUID->
  "eddbe36b-5223-49ad-a8ad-d473fd87a60a"],
 " are arguments in the expression ",
 Cell[BoxData[
  RowBox[{"h", "[", 
   RowBox[{"x", ",", "y", ",", "9"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "93c903b7-4e20-448e-8104-3d3d63b9fd84"],
 ", which lies at the first level. So ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "c1a9f74c-d8ef-44be-ba8b-cf1347e79837"],
 ", ",
 Cell[BoxData[
 "y"], "InlineCodeText",ExpressionUUID->
  "7a877e02-e717-46de-b5ca-df0423770bab"],
 ", and ",
 Cell[BoxData[
 "9"], "InlineCodeText",ExpressionUUID->
  "d5d0029d-26e9-4e34-86f8-9340dd68a09d"],
 " lie at the second level."
}], "Text",
 CellChangeTimes->{{3.7690058230921993`*^9, 3.769005857168445*^9}, {
  3.7690084476273527`*^9, 3.769008447717484*^9}, {3.7753905027535653`*^9, 
  3.7753905411665654`*^9}, {3.8561983381504087`*^9, 3.85619833853452*^9}},
 CellID->332195477,ExpressionUUID->"2213a7f1-406d-481d-9d33-7def6cd6eb51"],

Cell["Get the parts of an expression at level 2:", "CodeCaption",
 CellChangeTimes->{
  3.774781346782009*^9, 3.7748756563276324`*^9, {3.7753905454435654`*^9, 
   3.7753905459555655`*^9}, {3.7753907600635653`*^9, 
   3.7753907611915655`*^9}, {3.777351683460595*^9, 3.777351686113749*^9}, {
   3.8856536863768034`*^9, 3.885653691018562*^9}},
 CellID->112790141,ExpressionUUID->"2636509e-1536-42c1-93e1-79dd7487fa04"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Level", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.76900585853304*^9, 3.7690058727710037`*^9}, {
   3.769008433458865*^9, 3.7690084339292316`*^9}, 3.769117001474242*^9},
 CellLabel->"In[59]:=",
 CellID->1899383386,ExpressionUUID->"11a48138-3b45-4ded-85ef-ced2b0c0d1ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"7", ",", "y", ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{{3.769005868422526*^9, 3.76900587311314*^9}, 
   3.76900843492502*^9, 3.769075769773038*^9, 3.769100641079309*^9, 
   3.769772674547475*^9, 3.7699755292855787`*^9, 3.7719235774111023`*^9, 
   3.771929509176709*^9, 3.8814165389087563`*^9},
 CellLabel->"Out[59]=",
 CellID->699765098,ExpressionUUID->"29b6863c-4293-4872-9ff2-792152ad13db"]
}, Open  ]],

Cell[TextData[{
 "If one does not wrap the level specification in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ", ",
 ButtonBox["Level",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
 " produces all expressions lying from level 1 to the level indicated by the \
integer. "
}], "Text",
 CellChangeTimes->{{3.769005950245222*^9, 3.769006027011397*^9}, 
   3.7753905897325654`*^9, 3.877537741862804*^9, {3.88555639885992*^9, 
   3.8855564093345737`*^9}, {3.8856537002865276`*^9, 3.885653705209417*^9}},
 CellID->592155847,ExpressionUUID->"3694d896-8496-47da-a974-d2b50621bdbc"],

Cell["Get the parts of an expression at all levels up through 2:", \
"CodeCaption",
 CellChangeTimes->{
  3.774781355126009*^9, 3.7748756593036327`*^9, {3.7753907158255653`*^9, 
   3.7753907162175655`*^9}, {3.7753907642065654`*^9, 3.7753907654225655`*^9}},
 CellID->28169798,ExpressionUUID->"6e7af4f9-27bc-45c0-a35e-dc98e58b6754"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Level", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", "2"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.76900585853304*^9, 3.7690058727710037`*^9}, {
   3.7690060295491247`*^9, 3.769006032652095*^9}, {3.769008439544386*^9, 
   3.7690084401183243`*^9}, 3.769117004225079*^9},
 CellLabel->"In[60]:=",
 CellID->924100331,ExpressionUUID->"c9ef4949-8309-4067-b808-6bd82d6d7836"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"8", ",", "7", ",", "y", ",", "9", ",", 
   RowBox[{"h", "[", 
    RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769006033308366*^9, 3.76900844047873*^9, 
  3.7690757697821074`*^9, 3.7691006411144857`*^9, 3.769772674562107*^9, 
  3.7699755292985773`*^9, 3.771923577511037*^9, 3.7719295092126837`*^9, 
  3.881416546314019*^9},
 CellLabel->"Out[60]=",
 CellID->719684050,ExpressionUUID->"97a80cfa-49d0-4351-bc05-40c83d010370"]
}, Open  ]],

Cell[TextData[{
 "To get the whole expression back, use level specification ",
 Cell[BoxData[
  RowBox[{"{", "0", "}"}]], "InlineCodeText",ExpressionUUID->
  "69534bf7-0223-406e-8abf-4c66b72b3a7e"],
 "."
}], "Text",
 CellChangeTimes->{{3.769006056204101*^9, 3.769006072177743*^9}, 
   3.7753907340015655`*^9},
 CellID->752528013,ExpressionUUID->"29961850-88a0-46b6-a74b-bfc9959aecf3"],

Cell["Level 0 gets the whole expression:", "CodeCaption",
 CellChangeTimes->{
  3.774781365133009*^9, 3.7748756618086324`*^9, 3.885556628277161*^9, {
   3.885653720493924*^9, 3.885653725109682*^9}},
 CellID->49967241,ExpressionUUID->"1d17dfcb-4858-4bd3-8aa4-1f447db6760d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Level", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", "0", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.76900585853304*^9, 3.7690058727710037`*^9}, {
   3.7690060295491247`*^9, 3.769006046753779*^9}, {3.7690084662410517`*^9, 
   3.7690084668761*^9}, 3.769117008500025*^9},
 CellLabel->"In[61]:=",
 CellID->1207117308,ExpressionUUID->"2acf3541-d5c0-449a-a1ee-dd165921a1f7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "]"}], "}"}]], "Output",
 CellChangeTimes->{{3.7690060432721367`*^9, 3.769006047022745*^9}, 
   3.769008467572242*^9, 3.7690757698087063`*^9, 3.769100641124065*^9, 
   3.7697726746037273`*^9, 3.769975529342095*^9, 3.77192357752627*^9, 
   3.771929509224515*^9, 3.8814165509399233`*^9},
 CellLabel->"Out[61]=",
 CellID->1028379244,ExpressionUUID->"5abde7e6-a440-4b52-a7af-fbf05a1da073"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
 "Position: ",
 StyleBox[ButtonBox["Part",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]],
 " and ",
 StyleBox[ButtonBox["Level",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
  FontColor->RGBColor[
   0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]]
}], "Subsection",
 CellChangeTimes->{{3.76901411790296*^9, 3.7690141244758673`*^9}, {
  3.77185442695863*^9, 3.771854430716223*^9}, {3.889692674920709*^9, 
  3.889692685787508*^9}, {3.893767914329328*^9, 3.893767933236697*^9}},
 CellID->425278697,ExpressionUUID->"0595fde7-078b-4cb0-b182-d1ca4f8eed78"],

Cell[TextData[{
 "The ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " function lets one find the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " numbers of an expression that match some pattern; by looking at the number \
of elements in a ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " number, one can also determine the ",
 ButtonBox["Level",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
 " at which the matching expression lies. Here I find the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " numbers of the expression ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"4", ",", "5", ",", "6"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "3317c89a-4247-4268-9282-150603b022f3"],
 ". I do so by asking for matches for ",
 ButtonBox["_",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Blank.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Blank.html"],
 " (",
 ButtonBox["Blank",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Blank.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Blank.html"],
 "), which matches any single expression. I need to include the ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Heads",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Heads.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Heads.html"], 
   ButtonBox[
    StyleBox["->",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Rule.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Rule.html"], 
   ButtonBox[
    StyleBox["False",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/False.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/False.html"]}]], 
  "InlineCodeText",ExpressionUUID->"5e633be2-20c7-4581-9dfe-1b239f9c046d"],
 " option unless I want to see the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " ",
 Cell[BoxData[
  RowBox[{"{", "0", "}"}]], "InlineCodeText",ExpressionUUID->
  "18133ea4-eab9-4492-8450-60dc973ad80a"],
 " included; ",
 ButtonBox["Heads",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Heads.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Heads.html"],
 " are generally \[OpenCurlyDoubleQuote]part 0\[CloseCurlyDoubleQuote] of an \
expression."
}], "Text",
 CellChangeTimes->{{3.769014126727963*^9, 3.769014233213542*^9}, {
   3.769015619792612*^9, 3.769015622539236*^9}, {3.7690157617919207`*^9, 
   3.7690157753135777`*^9}, {3.769015809116529*^9, 3.769015835027294*^9}, {
   3.769118584849093*^9, 3.7691186210730753`*^9}, {3.771854434968852*^9, 
   3.7718544644451447`*^9}, 3.7747836604930053`*^9, {3.7753907870835657`*^9, 
   3.7753908586115656`*^9}, {3.7753914142065544`*^9, 3.775391429846118*^9}, {
   3.7753915390020323`*^9, 3.775391544994632*^9}, {3.875784855856431*^9, 
   3.8757848613261766`*^9}, {3.877537768057192*^9, 3.877537786516073*^9}, {
   3.8855566917356386`*^9, 3.885556715699851*^9}, {3.8856503448794127`*^9, 
   3.8856503473797646`*^9}, {3.8856530678663635`*^9, 3.8856530680966964`*^9}, 
   3.889692719061621*^9},
 CellTags->"i:41",
 CellID->1290938635,ExpressionUUID->"6071cd4f-024e-4620-85ce-d038ee2cf3fa"],

Cell[TextData[{
 "Use ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " to get the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " indices of an expression that match a pattern:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782262002009*^9, 3.7748756644236326`*^9, 3.775391553270459*^9, {
   3.8775378277133207`*^9, 3.877537833213561*^9}},
 CellID->241990379,ExpressionUUID->"84905a27-bcdb-4b65-84d1-404572d90145"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", "_", ",", 
   RowBox[{"Heads", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769014236406576*^9, 3.769014245349311*^9}, {
  3.769015779697483*^9, 3.769015805204728*^9}, {3.769118633603911*^9, 
  3.769118636304015*^9}},
 CellLabel->"In[62]:=",
 CellID->2055454417,ExpressionUUID->"82c537d7-2d23-4e13-9ed2-8fab03cafb3a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769014245868615*^9, 3.769015789192124*^9, 
  3.769075769816245*^9, 3.769100641135261*^9, 3.769772674673511*^9, 
  3.769975529354926*^9, 3.771923577563285*^9, 3.771929509258483*^9, 
  3.881416556985607*^9},
 CellLabel->"Out[62]=",
 CellID->2801802,ExpressionUUID->"baa25597-a8b9-4ecb-b4d9-9c92abffb3dd"]
}, Open  ]],

Cell[TextData[{
 "Here I find all the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " numbers of the expression that are integers. I don\[CloseCurlyQuote]t need \
the ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Heads",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Heads.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Heads.html"], 
   ButtonBox[
    StyleBox["->",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Rule.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Rule.html"], 
   ButtonBox[
    StyleBox["False",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/False.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/False.html"]}]], 
  "InlineCodeText",ExpressionUUID->"52f8e2ff-e8e8-4ae3-9ee4-72c43d3a58c2"],
 " option because the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " of ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " is not an ",
 ButtonBox["Integer",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Integer.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Integer.html"],
 " and therefore does not match."
}], "Text",
 CellChangeTimes->{{3.769014126727963*^9, 3.7690142162292233`*^9}, {
  3.7690156257258387`*^9, 3.769015631496852*^9}, {3.7691186590715714`*^9, 
  3.7691186832542477`*^9}, {3.7753919933034706`*^9, 3.775391999358471*^9}, {
  3.777351759590725*^9, 3.7773517605803022`*^9}, {3.856261568106979*^9, 
  3.856261584281329*^9}, {3.877537837174945*^9, 3.877537856047015*^9}, {
  3.8855567463848495`*^9, 3.885556761805895*^9}, {3.88565397409478*^9, 
  3.885653974859761*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1498922560,ExpressionUUID->"d147055a-0010-49de-81e0-5ad268e097ba"],

Cell[TextData[{
 "Get the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " indices of an expression that have an ",
 ButtonBox["Integer",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Integer.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Integer.html"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782272402009*^9, 3.7748756665676327`*^9, 3.7773518360976477`*^9, {
   3.8775378604030933`*^9, 3.8775378712961283`*^9}, {3.8855567894694405`*^9, 
   3.885556797857897*^9}},
 CellTags->"p: 29",
 CellID->184227891,ExpressionUUID->"55c61946-2418-4290-bc94-fb6c0c0cc0dd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   "_Integer"}], "]"}]], "Input",
 CellChangeTimes->{{3.769014164993869*^9, 3.769014179842239*^9}, {
   3.76901563393215*^9, 3.7690156377867126`*^9}, 3.769118652081789*^9, {
   3.769180016310014*^9, 3.769180028986744*^9}, {3.8562616055099792`*^9, 
   3.856261624096075*^9}},
 CellLabel->"In[63]:=",
 CellID->1953882829,ExpressionUUID->"a7dfce08-555e-492b-9dfc-c056fbbc984c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "4"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769014173605424*^9, 3.76901418036263*^9}, 
   3.769015638345264*^9, 3.769075769844276*^9, 3.7691006411711197`*^9, {
   3.769118648821701*^9, 3.7691186530099*^9}, 3.7691800309504128`*^9, 
   3.769772674686248*^9, 3.769975529398394*^9, 3.77192357757539*^9, 
   3.771929509269443*^9, 3.856261624907523*^9, 3.881416563083664*^9},
 CellLabel->"Out[63]=",
 CellID->1080048314,ExpressionUUID->"727b0430-3ea0-4459-bd1e-d0447ec190d7"]
}, Open  ]],

Cell[TextData[{
 "I can also tell ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " to look only at a particular ",
 ButtonBox["Level",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
 " of the expression. Here I ask it to first find integers at level 1 of ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"8", ",", 
    RowBox[{"h", "[", 
     RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}]], 
  "InlineCodeText",ExpressionUUID->"2b482320-d56c-4755-96cb-9e091fb5c084"],
 " and then to find all parts of the same expression at level 1 (but to \
ignore ",
 ButtonBox["Heads",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Heads.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Heads.html"],
 ")."
}], "Text",
 CellChangeTimes->{{3.769015673461108*^9, 3.769015706719016*^9}, {
   3.769180113207699*^9, 3.7691801396700697`*^9}, {3.769180187631504*^9, 
   3.769180192953663*^9}, {3.775392014635471*^9, 3.7753920377394705`*^9}, {
   3.7753940437677045`*^9, 3.775394065704898*^9}, {3.8655362795696793`*^9, 
   3.8655362840687857`*^9}, 3.877537880482885*^9, {3.885557074481391*^9, 
   3.885557099551901*^9}, 3.885652235501381*^9, {3.8856537541562414`*^9, 
   3.8856537858350935`*^9}},
 CellTags->"i:42",
 CellID->1660103225,ExpressionUUID->"95e0008b-092d-46ae-acb1-21f381c9ca32"],

Cell[TextData[{
 "Restrict ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " to look only at a certain ",
 ButtonBox["Level",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Level.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Level.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782285009009*^9, 3.7748756698906326`*^9, 3.7753923829594707`*^9, {
   3.7773518996861553`*^9, 3.777351902869587*^9}},
 CellID->513024105,ExpressionUUID->"7c82288c-c4b2-4f7f-875a-8805fc952d16"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   "_Integer", ",", 
   RowBox[{"{", "1", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769015708236596*^9, 3.7690157145869093`*^9}, {
  3.7691187027562532`*^9, 3.769118705461643*^9}, {3.769180131806727*^9, 
  3.7691801542921543`*^9}, {3.856261633557959*^9, 3.856261636695616*^9}},
 CellLabel->"In[64]:=",
 CellID->1709748384,ExpressionUUID->"dc96c89b-d114-4f1f-8b12-609989026c54"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"{", "1", "}"}], "}"}]], "Output",
 CellChangeTimes->{3.76918015567964*^9, 3.769772674727108*^9, 
  3.769975529412726*^9, 3.771923577611661*^9, 3.771929509349987*^9, 
  3.856261638975272*^9, 3.8814165742157717`*^9},
 CellLabel->"Out[64]=",
 CellID->614550584,ExpressionUUID->"8fd0c0bb-4918-42c6-9d91-81a48c87d51e"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", "_", 
   ",", 
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"Heads", "\[Rule]", "False"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769015708236596*^9, 3.7690157145869093`*^9}, {
  3.7691187027562532`*^9, 3.769118705461643*^9}, {3.769180131806727*^9, 
  3.769180161882205*^9}, {3.8562616500270452`*^9, 3.856261651670788*^9}},
 CellLabel->"In[65]:=",
 CellID->1163936563,ExpressionUUID->"34f154ee-9e11-489a-b98f-d80f8b896bd9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769180162181795*^9, 3.7697726747399473`*^9, 
  3.76997552945572*^9, 3.771923577624054*^9, 3.771929509360485*^9, 
  3.8562616522907057`*^9, 3.88141657684333*^9},
 CellLabel->"Out[65]=",
 CellID->61129908,ExpressionUUID->"aba2ebee-e0d5-4181-9747-30ebeb813a94"]
}, Open  ]],

Cell[TextData[{
 "Because ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " wraps the found positions in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and because the ",
 ButtonBox["Extract",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Extract.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Extract.html"],
 " function wants part numbers wrapped in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ", the two functions complement each other: the output from ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " (or output in the form returned by ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 ") can be used as the input to ",
 ButtonBox["Extract",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Extract.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Extract.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.875784885537616*^9, 3.875784901329835*^9}, {
  3.875784957738515*^9, 3.8757849963577757`*^9}, {3.8757850854920187`*^9, 
  3.875785101501123*^9}, {3.8757852312166348`*^9, 3.8757852672191753`*^9}, {
  3.885557135680526*^9, 3.8855571363807807`*^9}},
 CellTags->"i:43",
 CellID->997560408,ExpressionUUID->"de0c1359-7cd5-4ae2-991a-70ffd2e25ebb"],

Cell["\<\
Find the subexpressions in one expression that have the same position as the \
integers in another expression:\
\>", "CodeText",
 CellChangeTimes->{{3.875785107479082*^9, 3.8757851485372963`*^9}},
 CellID->601735443,ExpressionUUID->"f74b0b32-2f29-43af-bf8f-7a8f3ca28142"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Extract", "[", 
  RowBox[{
   RowBox[{"r", "[", 
    RowBox[{"3", ",", 
     RowBox[{"s", "[", 
      RowBox[{"p", ",", "1", ",", "y", ",", "7"}], "]"}]}], "]"}], ",", 
   RowBox[{"Position", "[", 
    RowBox[{
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
     "_Integer"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.875785001459062*^9, 3.8757850730949993`*^9}},
 CellLabel->"In[66]:=",
 CellID->1512527923,ExpressionUUID->"6c09cbfe-bc5e-4e61-a40b-ef5f446dcb27"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "1", ",", "7"}], "}"}]], "Output",
 CellChangeTimes->{3.875785078556345*^9, 3.881416582169702*^9},
 CellLabel->"Out[66]=",
 CellID->1782610583,ExpressionUUID->"4c821ecf-be6b-4ae3-aabc-57d10325c9ea"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Functional Programming Constructs", "Subsection",
 CellChangeTimes->{3.7748804223324203`*^9},
 CellID->305459416,ExpressionUUID->"1459df95-b03d-4d99-af8a-8f11e03a86a7"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Map",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Map.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.769008902303006*^9, 3.769008904672237*^9}, 
   3.8896927456532*^9, {3.893767980104249*^9, 3.893768012337941*^9}},
 CellTags->"i:44",
 CellID->1909995810,ExpressionUUID->"c7e9e824-c0c7-4dc5-9d04-4d370e9d8c63"],

Cell[TextData[{
 "One of the paradigmatic features of Wolfram Language programming is its \
strong support for \[OpenCurlyDoubleQuote]functional programming,\
\[CloseCurlyDoubleQuote] in which functions frequently accept (indeed, \
demand) that some of their arguments also be functions. Perhaps this is best \
seen with an immediate example. I\[CloseCurlyQuote]ll use what is surely the \
Wolfram Language\[CloseCurlyQuote]s most common functional programming \
construct, the ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.7690077558912287`*^9, 3.7690078593400717`*^9}, {
  3.769118809316156*^9, 3.7691188127626534`*^9}, {3.7753924348214707`*^9, 
  3.775392458148471*^9}, {3.8562616694008408`*^9, 3.856261671481303*^9}},
 CellTags->"i:45",
 CellID->553735833,ExpressionUUID->"deaabc33-1969-4c7e-9e45-7b99da9dea8e"],

Cell[TextData[{
 "Here I ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " the function ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"0302715b-3479-439b-bf8a-d18d3ef3e384"],
 " over the expression ",
 Cell[BoxData[
  RowBox[{"g", "[", 
   RowBox[{"1", ",", " ", "4", ",", " ", "9"}], "]"}]], "InlineCode",
  ExpressionUUID->"d54331d5-4872-46b5-b520-4b8b7f57fc39"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7690078760440493`*^9, 3.769007888443636*^9}, {
   3.769007977920815*^9, 3.7690079804304047`*^9}, {3.7690084857855053`*^9, 
   3.769008486825543*^9}, {3.775392463967471*^9, 3.7753924681194706`*^9}, {
   3.7754901054219837`*^9, 3.7754901541709833`*^9}, {3.7754906651419835`*^9, 
   3.7754906788929834`*^9}, {3.7773519798435297`*^9, 3.7773520295870733`*^9}, 
   3.8855550081562915`*^9, {3.8896957329992065`*^9, 3.8896957329992065`*^9}},
 CellID->2035395226,ExpressionUUID->"8e0ee743-f9fb-44f0-bcd9-d29356aa6b7e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"f", ",", 
   RowBox[{"g", "[", 
    RowBox[{"1", ",", "4", ",", "9"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769007861432325*^9, 3.769007873359524*^9}, {
  3.769007974288351*^9, 3.7690079760038767`*^9}},
 CellLabel->"In[67]:=",
 CellID->2048594276,ExpressionUUID->"ee8f759c-401b-45f6-a095-817d0832fe86"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"f", "[", "1", "]"}], ",", 
   RowBox[{"f", "[", "4", "]"}], ",", 
   RowBox[{"f", "[", "9", "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.769007890275606*^9, 3.7690084893482647`*^9, 
  3.769075769979217*^9, 3.769100641228571*^9, 3.769772674781502*^9, 
  3.769975529469306*^9, 3.771923577658737*^9, 3.7719295093985167`*^9, 
  3.881416589286498*^9},
 CellLabel->"Out[67]=",
 CellID->1967075738,ExpressionUUID->"e63d9899-dd7d-423c-a268-b9fe3d0ea111"]
}, Open  ]],

Cell[TextData[{
 "The head of the expression remains unchanged; it is still ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "128e4906-7c8a-45c7-b213-11ff456ffbed"],
 ", but each of the first\[Hyphen]level parts of ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "04bfbc16-410b-4696-b4b4-aecf9534c965"],
 " now has the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "caa3b9a4-7703-48b7-a260-a7bfcd28a367"],
 " applied to it. Here\[CloseCurlyQuote]s a practical use for it."
}], "Text",
 CellChangeTimes->{{3.769007893768351*^9, 3.76900790128187*^9}, {
  3.76900793882828*^9, 3.769007970637836*^9}, {3.769118819952935*^9, 
  3.769118821481555*^9}, {3.7753935470054708`*^9, 3.775393584852471*^9}, {
  3.7754903500549836`*^9, 3.7754903504159837`*^9}, {3.8655363330244904`*^9, 
  3.865536333079677*^9}, {3.896339841394307*^9, 3.896339849788658*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1592898165,ExpressionUUID->"9098402d-b8dd-4816-b906-fa5d0340e837"],

Cell[TextData[{
 "Vectorize computations with ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747823140310087`*^9, 3.7748756757746325`*^9, 3.7753935947184706`*^9, {
   3.7754906921079836`*^9, 3.7754906990839834`*^9}},
 CellTags->"p: 30",
 CellID->345461069,ExpressionUUID->"16a1d0a9-b162-4300-bf39-0f1b35bd20f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Sqrt", ",", 
   RowBox[{"g", "[", 
    RowBox[{"1", ",", "4", ",", "9"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769007983032618*^9, 3.769007994926991*^9}},
 CellLabel->"In[68]:=",
 CellID->521059780,ExpressionUUID->"ec29c792-09e2-47b5-b34e-1cb7fc79c83c"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{"1", ",", "2", ",", "3"}], "]"}]], "Output",
 CellChangeTimes->{3.769007996028187*^9, 3.769008491300899*^9, 
  3.769075769985898*^9, 3.769100641269051*^9, 3.7697726747956963`*^9, 
  3.769975529512382*^9, 3.771923577671668*^9, 3.771929509408762*^9, 
  3.881416594964047*^9},
 CellLabel->"Out[68]=",
 CellID->1704077162,ExpressionUUID->"e9cc4e60-1ba3-49d4-9c01-22c8518e19d5"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " provides another way to show what is happening. Basically, the ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " here causes the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "41adceda-b1db-4c52-b133-b512528c5b7c"],
 " to insert itself between the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "95134e9d-bec1-4a42-ab8e-e5036b4af41a"],
 " and each of the first-level parts of ",
 Cell[BoxData[
 "g"], "InlineCodeText",ExpressionUUID->
  "45931812-43c2-4e29-9382-dd2a9ac907f1"],
 "."
}], "Text",
 CellChangeTimes->{{3.769008011943131*^9, 3.7690080748304567`*^9}, {
   3.769118841640757*^9, 3.76911888191096*^9}, {3.775393599004471*^9, 
   3.775393635162471*^9}, 3.877538014145082*^9, {3.885557349143624*^9, 
   3.8855573492613463`*^9}},
 CellTags->"i:46",
 CellID->298487107,ExpressionUUID->"f0e94f6c-e1e9-4c88-8017-437bd04e0d8c"],

Cell[TextData[{
 "Visualize how ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " works:"
}], "CodeCaption",
 CellChangeTimes->{3.774782324631009*^9, 3.7748756784946327`*^9, 
  3.7753936391244707`*^9},
 CellID->61660882,ExpressionUUID->"d5a721d3-7bbf-4111-87b8-9077eb88b1f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"TreeForm", "[", 
     RowBox[{"g", "[", 
      RowBox[{"1", ",", "4", ",", "9"}], "]"}], "]"}], ",", 
    RowBox[{"TreeForm", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"f", ",", 
       RowBox[{"g", "[", 
        RowBox[{"1", ",", "4", ",", "9"}], "]"}]}], "]"}], "]"}]}], "}"}], "//",
   "Framed"}]], "Input",
 CellChangeTimes->{{3.7690080310825872`*^9, 3.7690080492779503`*^9}, {
  3.771923631224278*^9, 3.7719236324484577`*^9}},
 CellLabel->"In[69]:=",
 CellID->954497156,ExpressionUUID->"6579734a-093e-4285-aac2-83968b1a0329"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.7745966692414834, 0.7745966692414834}, {0., 
        0.}, {0.7745966692414834, 0.}, {1.5491933384829668`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], LineBox[{{1, 2}, {1, 3}, {1, 4}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"1", ",", "4", ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[1, 4, 9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["1",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["1", HoldForm]],
           Annotation[#, 
            HoldForm[1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["4",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox["4", HoldForm]],
           Annotation[#, 
            HoldForm[4], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.7745966692414834, 0.7745966692414834}, {
         0., 0.}, {0.7745966692414834, 0.}, {1.5491933384829668`, 0.}}]& ],
      AspectRatio->NCache[2 3^Rational[-1, 2], 1.1547005383792517`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{186.84521484375, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[1, 4, 9]],
     Editable->False], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.8660254037844387, 1.7320508075688774`}, {0., 
        0.8660254037844387}, {0., 0.}, {0.8660254037844387, 
        0.8660254037844387}, {0.8660254037844387, 0.}, {1.7320508075688774`, 
        0.8660254037844387}, {1.7320508075688774`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 4}, {1, 6}, {2, 3}, {4, 5}, {6, 7}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{
                 RowBox[{"f", "[", "1", "]"}], ",", 
                 RowBox[{"f", "[", "4", "]"}], ",", 
                 RowBox[{"f", "[", "9", "]"}]}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[
              $CellContext`f[1], 
              $CellContext`f[4], 
              $CellContext`f[9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox[
             RowBox[{"f", "[", "1", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[1]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["1",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox["1", HoldForm]],
           Annotation[#, 
            HoldForm[1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox[
             RowBox[{"f", "[", "4", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[4]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["4",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["4", HoldForm]],
           Annotation[#, 
            HoldForm[4], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox[
             RowBox[{"f", "[", "9", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 7],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.8660254037844387, 1.7320508075688774`}, {
         0., 0.8660254037844387}, {0., 0.}, {0.8660254037844387, 
         0.8660254037844387}, {0.8660254037844387, 0.}, {1.7320508075688774`, 
         0.8660254037844387}, {1.7320508075688774`, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{171.264404296875, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[
       $CellContext`f[1], 
       $CellContext`f[4], 
       $CellContext`f[9]]],
     Editable->False]}], "}"}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.76900805045407*^9, 3.769008493251335*^9, 
  3.769075770011916*^9, 3.769100641313693*^9, 3.769772674839765*^9, 
  3.769975529562603*^9, 3.7719235777107267`*^9, 3.77192363323954*^9, 
  3.771929509444129*^9, 3.88141660088391*^9},
 CellLabel->"Out[69]=",
 CellID->82050695,ExpressionUUID->"0a5d27aa-5d9d-451c-ac1e-77c5bf6443d0"]
}, Open  ]],

Cell[TextData[{
 "Here is the ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "6df5c16b-2605-40ff-9093-cf5b078a1d19"],
 " function Mapped over an expression I\[CloseCurlyQuote]ve been recycling in \
this chapter."
}], "Text",
 CellChangeTimes->{{3.7690081241316977`*^9, 3.769008147724471*^9}, 
   3.7753936463054705`*^9},
 CellID->659213111,ExpressionUUID->"f6a3f43f-8bd6-4fc4-b124-79039a66f7ba"],

Cell[TextData[{
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " over complicated expressions:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747823356065893`*^9, 3.7748756815036325`*^9, 3.7754924624999743`*^9, {
   3.856264656902792*^9, 3.856264697060631*^9}},
 CellID->586079971,ExpressionUUID->"3c43a4b3-3fc9-45e2-97c1-63949ea906f2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"f", ",", 
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769008149825925*^9, 3.769008159123097*^9}, {
  3.769008498885139*^9, 3.769008500182138*^9}, {3.7691188903015633`*^9, 
  3.769118890982279*^9}, {3.8562646840795794`*^9, 3.856264687815124*^9}},
 CellLabel->"In[70]:=",
 CellID->670712328,ExpressionUUID->"9cb643c6-da01-4e12-8f6c-8d465d1afd84"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{
   RowBox[{"f", "[", "8", "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"h", "[", 
     RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}], "]"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.769008159721197*^9, 3.769008500607698*^9, 
  3.7690757700431547`*^9, 3.769100641353578*^9, 3.7691188919110003`*^9, 
  3.769772674871553*^9, 3.769975529637083*^9, 3.771923577725707*^9, 
  3.771929509457056*^9, 3.85626469930341*^9, 3.8814166112002907`*^9},
 CellLabel->"Out[70]=",
 CellID->1786279908,ExpressionUUID->"a6d9c112-2561-46a6-b42b-765b96ba6a58"]
}, Open  ]],

Cell[TextData[{
 "Again, I will show the original expression and the expression after ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " is applied in ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " just to clarify what is going on."
}], "Text",
 CellChangeTimes->{{3.769008509991047*^9, 3.769008559060937*^9}, {
  3.7753936609204707`*^9, 3.775393666965471*^9}},
 CellID->823382524,ExpressionUUID->"b329b65c-6836-4e03-b1eb-793384ef3140"],

Cell[TextData[{
 "Visualize ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " working on multilevel expressions:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747823474467735`*^9, {3.7748756835186324`*^9, 3.7748756892216325`*^9}, 
   3.775393672786471*^9, 3.775393708733471*^9},
 CellID->420237797,ExpressionUUID->"3dc83ba6-bc29-411a-b01e-46d48c6607a1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"TreeForm", "[", 
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"TreeForm", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"f", ",", 
       RowBox[{"g", "[", 
        RowBox[{"8", ",", 
         RowBox[{"h", "[", 
          RowBox[{"q", ",", 
           RowBox[{"8", "y"}], ",", "9"}], "]"}]}], "]"}]}], "]"}], "]"}]}], 
   "}"}], "//", "Framed"}]], "Input",
 CellChangeTimes->{{3.7690085229459667`*^9, 3.769008539165083*^9}, {
  3.7691188962202377`*^9, 3.769118899502514*^9}, {3.771923639055663*^9, 
  3.7719236400492277`*^9}, {3.85626470468857*^9, 3.8562647075120792`*^9}},
 CellLabel->"In[71]:=",
 CellID->162508876,ExpressionUUID->"46cb5c30-99c4-4566-a976-b3d028d079cf"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4082482904638631, 1.6329931618554523`}, {0., 
        0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
        0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 5}, {3, 6}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"8", ",", 
                 RowBox[{"h", "[", 
                   RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "]"}], 
             HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[8, 
              $CellContext`h[7, $CellContext`y, 9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["h", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"h", "[", 
               RowBox[{"7", ",", "y", ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`h[7, $CellContext`y, 9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["7",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["7", HoldForm]],
           Annotation[#, 
            HoldForm[7], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4082482904638631, 1.6329931618554523`}, {
         0., 0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {
         0., 0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{179.74615478515625`, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[8, 
       $CellContext`h[7, $CellContext`y, 9]]],
     Editable->False], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.43301270189221935`, 3.464101615137755}, {0., 
        2.598076211353316}, {0., 1.7320508075688774`}, {0.8660254037844387, 
        2.598076211353316}, {0.8660254037844387, 1.7320508075688774`}, {0., 
        0.8660254037844388}, {0.8660254037844387, 0.8660254037844388}, {
        0.43301270189221935`, 0.}, {1.299038105676658, 0.}, {
        1.7320508075688774`, 0.8660254037844388}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 4}, {2, 3}, {4, 5}, {5, 6}, {5, 7}, {5, 10}, {
           7, 8}, {7, 9}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{
                 RowBox[{"f", "[", "8", "]"}], ",", 
                 RowBox[{"f", "[", 
                   RowBox[{"h", "[", 
                    RowBox[{"q", ",", 
                    RowBox[{"8", " ", "y"}], ",", "9"}], "]"}], "]"}]}], 
               "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[
              $CellContext`f[8], 
              $CellContext`f[
               $CellContext`h[$CellContext`q, 8 $CellContext`y, 9]]]], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox[
             RowBox[{"f", "[", "8", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[8]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox[
             RowBox[{"f", "[", 
               RowBox[{"h", "[", 
                 RowBox[{"q", ",", 
                   RowBox[{"8", " ", "y"}], ",", "9"}], "]"}], "]"}], 
             HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[
              $CellContext`h[$CellContext`q, 8 $CellContext`y, 9]]], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["h", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox[
             RowBox[{"h", "[", 
               RowBox[{"q", ",", 
                 RowBox[{"8", " ", "y"}], ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`h[$CellContext`q, 8 $CellContext`y, 9]], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["q",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox["q", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`q], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 7],
            TagBox[
             RowBox[{"8", " ", "y"}], HoldForm]],
           Annotation[#, 
            HoldForm[8 $CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 8],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 9],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 10],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.43301270189221935`, 3.464101615137755}, {
         0., 2.598076211353316}, {0., 1.7320508075688774`}, {
         0.8660254037844387, 2.598076211353316}, {0.8660254037844387, 
         1.7320508075688774`}, {0., 0.8660254037844388}, {0.8660254037844387, 
         0.8660254037844388}, {0.43301270189221935`, 0.}, {1.299038105676658, 
         0.}, {1.7320508075688774`, 0.8660254037844388}}]& ],
      AspectRatio->NCache[Rational[10, 7]^Rational[1, 2], 1.1952286093343936`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{195.5257568359375, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[
       $CellContext`f[8], 
       $CellContext`f[
        $CellContext`h[$CellContext`q, 8 $CellContext`y, 9]]]],
     Editable->False]}], "}"}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.769008539736326*^9, 3.76907577007299*^9, 
  3.769100641398569*^9, 3.769118903991111*^9, 3.769772674916443*^9, 
  3.769975529684518*^9, 3.771923577765726*^9, 3.771923640492942*^9, 
  3.771929509493443*^9, 3.8562647081658163`*^9, 3.88141662198606*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[71]=",
 CellID->890892849,ExpressionUUID->"e2a76795-7c93-4a1f-88f9-eea89d71f0e3"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s also a three-argument form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " in which the third argument is a level specification. Here I ask that the \
function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "7bf1591e-eddf-453a-9ec7-5b11c2a6ae81"],
 " be applied only to those parts of the expression that lie at level 2."
}], "Text",
 CellChangeTimes->{{3.7690080945918903`*^9, 3.769008120666912*^9}, {
   3.769008191878422*^9, 3.769008197830675*^9}, {3.769008567288439*^9, 
   3.769008570920672*^9}, {3.769008780391474*^9, 3.769008793618272*^9}, {
   3.774783866569005*^9, 3.7747838699140053`*^9}, {3.775393713675471*^9, 
   3.7753937443624706`*^9}, {3.775394092449572*^9, 3.7753940927456017`*^9}, {
   3.7773520975311823`*^9, 3.777352113075407*^9}, 3.8855550162361293`*^9, {
   3.8855574113729343`*^9, 3.885557417553371*^9}, {3.8856507383413877`*^9, 
   3.8856507386157103`*^9}, {3.8856540841441517`*^9, 3.885654087050389*^9}},
 CellTags->{"i:47", "p: 31"},
 CellID->1091975022,ExpressionUUID->"9bdc4065-d01f-4bd0-965c-f9cd09706c05"],

Cell[TextData[{
 "Use a level specification with ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.7747823589209204`*^9, 3.7748756924786325`*^9, 
  3.7753941003923664`*^9},
 CellID->499480920,ExpressionUUID->"2ef9969b-04cc-42e0-be22-cc959929d8f1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"f", ",", 
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690081840991077`*^9, 3.769008187645032*^9}, {
  3.769008806312545*^9, 3.769008806813217*^9}, {3.769118908180688*^9, 
  3.769118908791655*^9}},
 CellLabel->"In[72]:=",
 CellID->1580004596,ExpressionUUID->"687f958b-74b4-4a41-9573-c83bd5195530"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{"8", ",", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"f", "[", "7", "]"}], ",", 
     RowBox[{"f", "[", "y", "]"}], ",", 
     RowBox[{"f", "[", "9", "]"}]}], "]"}]}], "]"}]], "Output",
 CellChangeTimes->{
  3.769008187935112*^9, {3.769008796158222*^9, 3.769008807279464*^9}, 
   3.769075770101289*^9, 3.769100641439683*^9, 3.7691189096132*^9, 
   3.769772674933025*^9, 3.769975529699585*^9, 3.771923577780274*^9, 
   3.771929509506401*^9, 3.8814166279943647`*^9},
 CellLabel->"Out[72]=",
 CellID->450748411,ExpressionUUID->"970224e2-f281-4e7c-8f79-edaa7acedb4d"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " shows where the insertion takes place."
}], "Text",
 CellChangeTimes->{{3.769008837073757*^9, 3.7690088462766647`*^9}, 
   3.7753941037517023`*^9, {3.8562623564090347`*^9, 3.85626235843364*^9}},
 CellID->141699391,ExpressionUUID->"7fe3237b-8e4f-477c-b9c7-a7dc885a45c5"],

Cell[TextData[{
 "Visualize ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " working at deeper levels:"
}], "CodeCaption",
 CellChangeTimes->{3.774782370569085*^9, 3.7748756954616327`*^9, 
  3.7753941088852158`*^9},
 CellID->48761906,ExpressionUUID->"f9cae6e7-5ce6-469c-b43e-5aa5010acc2b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"TreeForm", "[", 
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"TreeForm", "[", 
     RowBox[{"Map", "[", 
      RowBox[{"f", ",", 
       RowBox[{"g", "[", 
        RowBox[{"8", ",", 
         RowBox[{"h", "[", 
          RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", "2", "}"}]}], "]"}], "]"}]}], "}"}], "//", 
  "Framed"}]], "Input",
 CellChangeTimes->{{3.769008808999778*^9, 3.769008817393338*^9}, {
  3.769118914421011*^9, 3.769118917575941*^9}, {3.77192364399973*^9, 
  3.771923645079385*^9}, {3.85626472490357*^9, 3.856264727862956*^9}},
 CellLabel->"In[73]:=",
 CellID->300098921,ExpressionUUID->"625879aa-8b7b-4cb7-ab2a-3d858af918a3"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4082482904638631, 1.6329931618554523`}, {0., 
        0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
        0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 5}, {3, 6}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"8", ",", 
                 RowBox[{"h", "[", 
                   RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "]"}], 
             HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[8, 
              $CellContext`h[7, $CellContext`y, 9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["h", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"h", "[", 
               RowBox[{"7", ",", "y", ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`h[7, $CellContext`y, 9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["7",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["7", HoldForm]],
           Annotation[#, 
            HoldForm[7], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4082482904638631, 1.6329931618554523`}, {
         0., 0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {
         0., 0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{182.25653076171875`, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[8, 
       $CellContext`h[7, $CellContext`y, 9]]],
     Editable->False], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.8032193289024989, 2.4096579867074968`}, {
        0.40160966445124946`, 1.6064386578049978`}, {1.2048289933537484`, 
        1.6064386578049978`}, {0., 0.8032193289024989}, {0., 0.}, {
        0.8032193289024989, 0.8032193289024989}, {0.8032193289024989, 0.}, {
        1.6064386578049978`, 0.8032193289024989}, {1.6064386578049978`, 0.}, {
        2.4096579867074963`, 0.8032193289024989}, {2.4096579867074963`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 6}, {3, 8}, {3, 10}, {4, 5}, {
           6, 7}, {8, 9}, {10, 11}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"8", ",", 
                 RowBox[{"h", "[", 
                   RowBox[{
                    RowBox[{"f", "[", "q", "]"}], ",", 
                    RowBox[{"f", "[", "8", "]"}], ",", 
                    RowBox[{"f", "[", "y", "]"}], ",", 
                    RowBox[{"f", "[", "9", "]"}]}], "]"}]}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[8, 
              $CellContext`h[
               $CellContext`f[$CellContext`q], 
               $CellContext`f[8], 
               $CellContext`f[$CellContext`y], 
               $CellContext`f[9]]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["h", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"h", "[", 
               RowBox[{
                 RowBox[{"f", "[", "q", "]"}], ",", 
                 RowBox[{"f", "[", "8", "]"}], ",", 
                 RowBox[{"f", "[", "y", "]"}], ",", 
                 RowBox[{"f", "[", "9", "]"}]}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`h[
              $CellContext`f[$CellContext`q], 
              $CellContext`f[8], 
              $CellContext`f[$CellContext`y], 
              $CellContext`f[9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox[
             RowBox[{"f", "[", "q", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[$CellContext`q]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["q",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["q", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`q], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox[
             RowBox[{"f", "[", "8", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[8]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 7],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 8],
            TagBox[
             RowBox[{"f", "[", "y", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[$CellContext`y]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 9],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 10],
            TagBox[
             RowBox[{"f", "[", "9", "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 11],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.8032193289024989, 2.4096579867074968`}, {
         0.40160966445124946`, 1.6064386578049978`}, {1.2048289933537484`, 
         1.6064386578049978`}, {0., 0.8032193289024989}, {0., 0.}, {
         0.8032193289024989, 0.8032193289024989}, {0.8032193289024989, 0.}, {
         1.6064386578049978`, 0.8032193289024989}, {1.6064386578049978`, 
         0.}, {2.4096579867074963`, 0.8032193289024989}, {2.4096579867074963`,
          0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{192.4635009765625, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[8, 
       $CellContext`h[
        $CellContext`f[$CellContext`q], 
        $CellContext`f[8], 
        $CellContext`f[$CellContext`y], 
        $CellContext`f[9]]]],
     Editable->False]}], "}"}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.76900881795716*^9, 3.769075770136241*^9, 
  3.7691006414825583`*^9, 3.769118918410709*^9, 3.7697726749785748`*^9, 
  3.7699755297473087`*^9, 3.7719235778220053`*^9, 3.771923645505354*^9, 
  3.7719295095428658`*^9, 3.8562647285343924`*^9, 3.8814166346614523`*^9},
 CellLabel->"Out[73]=",
 CellID->692679997,ExpressionUUID->"55fe0635-e549-49dd-89c0-7de2b941ae43"]
}, Open  ]],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s a common use of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ". One has some sort of array of data and one wants to do the same thing to \
every element in the array. Here I ask for the ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " of every expression at the first level, then the second level, and then \
the third level of ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "983c46b6-3b26-46fd-a2a6-416db1f551d2"],
 ". "
}], "Text",
 CellChangeTimes->{{3.76900891396278*^9, 3.769009003946604*^9}, {
   3.769009073867975*^9, 3.769009074544176*^9}, 3.769119694915539*^9, {
   3.774783873689005*^9, 3.7747838743610053`*^9}, 3.7753941172060475`*^9, {
   3.775394508282151*^9, 3.775394542364559*^9}, {3.7753951219254656`*^9, 
   3.7753951259584656`*^9}, {3.7773521887088957`*^9, 3.777352223602553*^9}, 
   3.877538083245286*^9, 3.885555022486772*^9},
 CellID->493352970,ExpressionUUID->"f3ad1def-1987-4d65-ab71-d71db1d29e75"],

Cell[TextData[{
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " applied at different levels of the same expression:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782382993327*^9, 3.7748756989016323`*^9, {3.7753951395494657`*^9, 
   3.7753951492914658`*^9}},
 CellID->192307659,ExpressionUUID->"4bbe17a8-c290-45f1-8b74-6996188e5f41"],

Cell[BoxData[
 RowBox[{
  RowBox[{"nestedList", "=", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.7101881771505834, 0.7989108398643558, 0.8028079784985009], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.4734587847670556, 0.5326072265762373, 0.5352053189990007],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.7101881771505834`", ",", "0.7989108398643558`", ",", 
               "0.8028079784985009`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.7101881771505834, 0.7989108398643558, 0.8028079784985009]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.7101881771505834, 0.7989108398643558, 0.8028079784985009],
        Editable->False,
        Selectable->False], ",", "5", ",", "0.08", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
       "\"\<Thurgood Marshall\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.00180317540330166, 0.8926700334391704, 
              0.00014246188160593753`], RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.00120211693553444, 0.5951133556261137, 0.0000949745877372917],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.00180317540330166`", ",", "0.8926700334391704`", ",", 
               "0.00014246188160593753`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.00180317540330166, 0.8926700334391704, 
               0.00014246188160593753`]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`],
        Editable->False,
        Selectable->False], ",", "2", ",", "0.83", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "43"}], ",", 
          RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\"\<Elena Kagan\>\""}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.5202427055382031, 0.33813420051434595`, 0.0495895795536585], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.34682847035880204`, 0.2254228003428973, 0.033059719702439004`],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.5202427055382031`", ",", "0.33813420051434595`", ",", 
               "0.0495895795536585`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.5202427055382031, 0.33813420051434595`, 0.0495895795536585],
        Editable->False,
        Selectable->False], ",", "4", ",", "0.07", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "22"}], ",", 
          RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
       "\"\<Oliver Ellsworth\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.71799307373688, 0.8971633609144036, 0.09594209586818336], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.47866204915792004`, 0.5981089072762691, 0.06396139724545558],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.71799307373688`", ",", "0.8971633609144036`", ",", 
               "0.09594209586818336`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.71799307373688, 0.8971633609144036, 0.09594209586818336]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.71799307373688, 0.8971633609144036, 0.09594209586818336],
        Editable->False,
        Selectable->False], ",", "4", ",", "0.35", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
       "\"\<William Rehnquist\>\""}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       InterpretationBox[
        ButtonBox[
         TooltipBox[
          GraphicsBox[{
            {GrayLevel[0], RectangleBox[{0, 0}]}, 
            {GrayLevel[0], RectangleBox[{1, -1}]}, 
            {RGBColor[
             0.7038241862975507, 0.5975069401834057, 0.11356773283085175`], 
             RectangleBox[{0, -1}, {2, 1}]}},
           AspectRatio->1,
           DefaultBaseStyle->"ColorSwatchGraphics",
           Frame->True,
           
           FrameStyle->RGBColor[
            0.46921612419836717`, 0.39833796012227046`, 0.0757118218872345],
           FrameTicks->None,
           
           ImageSize->
            Dynamic[{
             Automatic, 
              1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
               Magnification])}],
           PlotRangePadding->None],
          StyleBox[
           RowBox[{"RGBColor", "[", 
             
             RowBox[{"0.7038241862975507`", ",", "0.5975069401834057`", ",", 
               "0.11356773283085175`"}], "]"}], NumberMarks -> False]],
         Appearance->None,
         BaseStyle->{},
         BaselinePosition->Baseline,
         ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
           If[
            Not[
             AbsoluteCurrentValue["Deployed"]], 
            SelectionMove[Typeset`box$, All, Expression]; 
            FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
            FrontEnd`Private`$ColorSelectorInitialColor = 
             RGBColor[
              0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]; 
            FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
            MathLink`CallFrontEnd[
              FrontEnd`AttachCell[Typeset`box$, 
               FrontEndResource["RGBColorValueSelector"], {
               0, {Left, Bottom}}, {Left, Top}, 
               "ClosingActions" -> {
                "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
         DefaultBaseStyle->{},
         Evaluator->Automatic,
         Method->"Preemptive"],
        RGBColor[0.7038241862975507, 0.5975069401834057, 0.11356773283085175`],
        Editable->False,
        Selectable->False], ",", "9", ",", "0.87", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"14", ",", "64"}], "}"}], "]"}], ",", 
       "\"\<Oliver Wendell Holmes, Jr.\>\""}], "}"}]}], "}"}]}], " ", 
  ";"}]], "Input",
 CellLabel->"In[543]:=",
 CellID->310986164,ExpressionUUID->"44c21efb-4567-4117-904f-d14f09b9b4b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{"Head", ",", "nestedList"}], "]"}], " "}]], "Input",
 CellChangeTimes->{3.899207161511581*^9},
 CellLabel->"In[544]:=",
 CellID->1916745197,ExpressionUUID->"3b710e29-4d68-4cdd-929d-1e887bab2b08"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"List", ",", "List", ",", "List", ",", "List", ",", "List"}], 
  "}"}]], "Output",
 CellChangeTimes->{3.8992072455842543`*^9},
 CellLabel->"Out[544]=",
 CellID->334337332,ExpressionUUID->"6c8bef09-4723-4c2e-9c06-f8137717a315"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Head", ",", "nestedList", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellLabel->"In[545]:=",
 CellID->1390318372,ExpressionUUID->"0dcdebe5-4423-48d1-b8d3-8c54e9b94355"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8992072472622004`*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[545]=",
 CellID->311315197,ExpressionUUID->"1d631abd-a1c5-4e00-bdd8-d716d98544ff"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Head", ",", "nestedList", ",", 
   RowBox[{"{", "3", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769008944834558*^9, 3.769008959473894*^9}, {
  3.7690090066053343`*^9, 3.7690090201179047`*^9}, {3.769009055774007*^9, 
  3.769009067196348*^9}},
 CellTags->"p: 32",
 CellLabel->"In[76]:=",
 CellID->2138288348,ExpressionUUID->"765935a0-697e-43cf-a8c4-a6d6bcc7e6d6"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "5", ",", 
     "0.08`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "2", ",", 
     "0.83`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.07`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.35`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "9", ",", 
     "0.87`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769008951139957*^9, 3.769008959907666*^9}, 
   3.7690090204613113`*^9, 3.769009067616324*^9, 3.769075770179241*^9, 
   3.769083362848083*^9, 3.7691006415420227`*^9, 3.7697726750807037`*^9, 
   3.769975529852025*^9, 3.771923577912325*^9, 3.7719295096281633`*^9, 
   3.881416649539568*^9},
 CellLabel->"Out[76]=",
 CellID->766684527,ExpressionUUID->"98dbaae4-724f-4431-921b-125cbca4702d"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s also what is called an \
\[OpenCurlyDoubleQuote]operator form\[CloseCurlyDoubleQuote] of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ". Here one uses the function to be applied as the single argument to ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ". One then applies this operator to data. Here\[CloseCurlyQuote]s a simple \
example."
}], "Text",
 CellChangeTimes->{{3.769009603638728*^9, 3.769009612199172*^9}, {
   3.769010229003491*^9, 3.7690102762315903`*^9}, {3.769010404524721*^9, 
   3.7690104144226303`*^9}, {3.769119727807912*^9, 3.769119729624413*^9}, 
   3.774783662797005*^9, {3.7747838769530053`*^9, 3.774783877673005*^9}, {
   3.774784855007721*^9, 3.7747848566248827`*^9}, {3.7753951574274654`*^9, 
   3.7753951630434656`*^9}, 3.877538111895588*^9},
 CellTags->"i:48",
 CellID->1754054077,ExpressionUUID->"f9c69dbf-78e1-43c3-a7ec-40f8b2ed7ab3"],

Cell[TextData[{
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " has an operator form:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747823954975777`*^9, 3.7748757022536325`*^9, {3.7753951717464657`*^9, 
   3.775395174409466*^9}, 3.7754925000877323`*^9},
 CellID->787405553,ExpressionUUID->"767846c2-7ea6-4346-ad4e-84d91e4063c0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", "Sqrt", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"1", ",", "4", ",", "9"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.769010417386417*^9, 3.7690104365099697`*^9}},
 CellLabel->"In[77]:=",
 CellID->1441744213,ExpressionUUID->"62dcc9c6-d18e-4d55-bb7e-378cd3a0edd2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.769010436948175*^9, 3.769075770186783*^9, 
  3.769083367387094*^9, 3.769100641555236*^9, 3.76977267509415*^9, 
  3.769975529865065*^9, 3.77192357795164*^9, 3.77192950964014*^9, 
  3.881416654287599*^9},
 CellLabel->"Out[77]=",
 CellID->98315348,ExpressionUUID->"3be55859-44ed-4832-8f49-a9a5ab4d801a"]
}, Open  ]],

Cell[TextData[{
 "One can\[CloseCurlyQuote]t directly use this operator form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " when one wants a function to apply beyond the first level of the \
expression. One can either use the ",
 ButtonBox["MapLevel",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
MapLevel"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/MapLevel"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " or, without it, one has to do something a little awkward. Here I ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " the ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    RowBox[{"Map", "\[ThickSpace]"}],
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Map.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"], 
   StyleBox["[", "InlineCodeText"], "\[ThickSpace]", 
   ButtonBox["Head",
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Head.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"], 
   "\[ThickSpace]", 
   StyleBox["]", "InlineCodeText"]}]],ExpressionUUID->
  "0026dd73-f389-489a-8d02-fdbac23bd52d"],
 " function over ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "89ac4b31-cb40-4cb2-83a3-9536766de652"],
 ", which is the same thing as operating at level 2. I use a doubly nested \
operator form to ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " at level 3."
}], "Text",
 CellTags->"i:49",
 CellID->1335418946,ExpressionUUID->"ca7143cd-b56f-4d4d-ab84-a159a6dcb461"],

Cell[TextData[{
 "A \[OpenCurlyDoubleQuote]sneaky\[CloseCurlyDoubleQuote] way to use ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " at deeper levels with operator forms:"
}], "CodeCaption",
 CellChangeTimes->{3.7747824079858265`*^9, 3.7748757052616324`*^9, 
  3.7753952188124657`*^9},
 CellID->235030631,ExpressionUUID->"c6966a14-4c1a-4e05-9224-010318f624cc"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{"Map", "[", "Head", "]"}], "]"}], "[", "nestedList", 
  "]"}]], "Input",
 CellChangeTimes->{{3.769010533407655*^9, 3.7690105501559963`*^9}},
 CellLabel->"In[78]:=",
 CellID->1720926597,ExpressionUUID->"99fb0534-1065-41d7-8dc4-bc8b8118f48f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
    "RGBColor", ",", "Integer", ",", "Real", ",", "GeoPosition", ",", 
     "String"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769010550659987*^9, 3.769075770213993*^9, 
  3.769083371030677*^9, 3.769100641590954*^9, 3.769772675135644*^9, 
  3.769975529909205*^9, 3.771923577962039*^9, 3.7719295096775093`*^9, 
  3.881416659494947*^9},
 CellLabel->"Out[78]=",
 CellID->434343204,ExpressionUUID->"be2b8d0a-7caa-420a-81e1-fb2a68607d81"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{"Map", "[", 
    RowBox[{"Map", "[", "Head", "]"}], "]"}], "]"}], "[", "nestedList", 
  "]"}]], "Input",
 CellChangeTimes->{{3.7690105804483356`*^9, 3.769010595050592*^9}},
 CellLabel->"In[79]:=",
 CellID->522834485,ExpressionUUID->"4f90e5a4-c079-4159-bf6a-83aa6965fa37"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "5", ",", 
     "0.08`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "2", ",", 
     "0.83`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.07`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.35`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "9", ",", 
     "0.87`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769010595685741*^9, 3.769075770221799*^9, 
  3.7690833742746267`*^9, 3.769100641604623*^9, 3.769772675150032*^9, 
  3.769975529922388*^9, 3.7719235779973793`*^9, 3.771929509688662*^9, 
  3.881416664354039*^9},
 CellLabel->"Out[79]=",
 CellID->1292018600,ExpressionUUID->"239fba63-011d-4c6d-a4a1-1c130ed0f9f0"]
}, Open  ]],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s how you can use the ",
 ButtonBox["MapLevel",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
MapLevel"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/MapLevel"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " to use an operator form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " at deeper levels."
}], "Text",
 CellChangeTimes->{{3.856268021584455*^9, 3.856268054770035*^9}, {
   3.856272042728653*^9, 3.856272064584495*^9}, {3.856530430344803*^9, 
   3.8565304442568274`*^9}, {3.877538172822338*^9, 3.877538190324348*^9}, {
   3.88555832619645*^9, 3.8855583267190533`*^9}, 3.897574130952125*^9},
 CellTags->"LastCellOfAPage",
 CellID->1535474437,ExpressionUUID->"75ce24a0-fc8c-4d9f-b8e3-08d0cb19a5d2"],

Cell[TextData[{
 "The ",
 ButtonBox["MapLevel",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
MapLevel"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/MapLevel"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.856268098049282*^9, 3.856268114180687*^9}, {
  3.877538200301811*^9, 3.877538204852076*^9}},
 CellTags->"p: 33",
 CellID->1551121061,ExpressionUUID->"a0550e92-b927-4b7c-b2ff-08290cadd485"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    TagBox[
     TagBox[
      DynamicModuleBox[{Typeset`open = False}, 
       FrameBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[GridBox[{
               {
                StyleBox[
                 StyleBox[
                  AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                   BoxBaselineShift->-0.25,
                   BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                  
                  FontColor->RGBColor[
                   0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                 ShowStringCharacters->False,
                 FontFamily->"Source Sans Pro Black",
                 FontSize->0.6538461538461539 Inherited,
                 FontWeight->"Heavy",
                 PrivateFontOptions->{"OperatorSubstitution"->False}], 
                StyleBox[
                 RowBox[{
                  StyleBox["MapLevel", "ResourceFunctionLabel"], " "}],
                 ShowAutoStyles->False,
                 ShowStringCharacters->False,
                 FontSize->Rational[12, 13] Inherited,
                 FontColor->GrayLevel[0.1]]}
              },
              GridBoxSpacings->{"Columns" -> {{0.25}}}],
             Alignment->Left,
             BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
             BaselinePosition->Baseline,
             FrameMargins->{{3, 0}, {0, 0}}], 
            ItemBox[
             PaneBox[
              TogglerBox[Dynamic[Typeset`open], {True->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeCloser"],
                ImageSizeCache->{11., {2., 9.}}], False->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeOpener"],
                ImageSizeCache->{11., {2., 9.}}]},
               Appearance->None,
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{1, 1}, {0, 0}}],
             Frame->{{
                RGBColor[
                0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                 0.5], False}, {False, False}}]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
         GridBox[{
           {GridBox[{
              {
               PaneBox[GridBox[{
                  {
                   StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                   StyleBox[
                    RowBox[{
                    StyleBox["MapLevel", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                 },
                 GridBoxSpacings->{"Columns" -> {{0.25}}}],
                Alignment->Left,
                BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                BaselinePosition->Baseline,
                FrameMargins->{{3, 0}, {0, 0}}], 
               ItemBox[
                PaneBox[
                 TogglerBox[Dynamic[Typeset`open], {True->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeCloser"]], False->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeOpener"]]},
                  Appearance->None,
                  BaselinePosition->Baseline,
                  ContentPadding->False,
                  FrameMargins->0],
                 Alignment->Left,
                 BaselinePosition->Baseline,
                 FrameMargins->{{1, 1}, {0, 0}}],
                Frame->{{
                   RGBColor[
                   0.8313725490196079, 0.8470588235294118, 0.8509803921568627,
                     0.5], False}, {False, False}}]}
             },
             BaselinePosition->{1, 1},
             GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
           {
            StyleBox[
             PaneBox[GridBox[{
                {
                 RowBox[{
                  TagBox["\<\"Version (latest): \"\>",
                   "IconizedLabel"], " ", 
                  TagBox["\<\"1.0.0\"\>",
                   "IconizedItem"]}]},
                {
                 TagBox[
                  
                  TemplateBox[{
                   "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/643eb83e-c32c-41a8-830c-78e9282acb6c/"},
                   "HyperlinkURL"],
                  "IconizedItem"]}
               },
               DefaultBaseStyle->"Column",
               GridBoxAlignment->{"Columns" -> {{Left}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
             FontFamily->"Roboto",
             FontSize->11]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
               GrayLevel[0.8]}, False}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open],
         BaselinePosition->Baseline,
         ImageSize->Automatic],
        Background->RGBColor[
         0.9686274509803922, 0.9764705882352941, 0.984313725490196],
        BaselinePosition->Baseline,
        DefaultBaseStyle->{},
        FrameMargins->{{0, 0}, {1, 0}},
        FrameStyle->RGBColor[
         0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
        RoundingRadius->4]],
      #& ,
      TagBoxNote->" "],
     {"FunctionResourceBox", 
      RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
      "MapLevel"},
     TagBoxNote->"FunctionResourceBox"],
    ResourceFunction[
     ResourceObject[<|
      "Name" -> "MapLevel", "ShortName" -> "MapLevel", "UUID" -> 
       "643eb83e-c32c-41a8-830c-78e9282acb6c", "ResourceType" -> "Function", 
       "Version" -> "1.0.0", "Description" -> 
       "Create an operator that maps a function over data at a specified \
level", "RepositoryLocation" -> 
       URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
       "SymbolName" -> 
       "FunctionRepository`$5c8c3349f3044fe1a584634b09381ccc`MapLevel", 
       "FunctionLocation" -> 
       CloudObject[
        "https://www.wolframcloud.com/obj/835b686f-f639-48e9-8faa-\
fe7a755e6bb7"]|>, {
      ResourceSystemBase -> 
       "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}]],
    Selectable->False], "[", 
   RowBox[{"Head", ",", 
    RowBox[{"{", "3", "}"}]}], "]"}], "[", "nestedList", "]"}]], "Input",
 CellChangeTimes->{{3.8562680614170237`*^9, 3.856268091051291*^9}, {
  3.881416677790723*^9, 3.881416700130308*^9}},
 CellLabel->"In[82]:=",
 CellID->2101992953,ExpressionUUID->"e140afbd-804a-4f50-9640-9d5c32b407ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "5", ",", 
     "0.08`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "2", ",", 
     "0.83`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.07`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "4", ",", 
     "0.35`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"RGBColor", "[", 
      RowBox[{"Real", ",", "Real", ",", "Real"}], "]"}], ",", "9", ",", 
     "0.87`", ",", 
     RowBox[{"GeoPosition", "[", "List", "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.856268074667596*^9, 3.856268091439219*^9}, 
   3.881416670124442*^9, 3.881416704855762*^9},
 CellLabel->"Out[82]=",
 CellID->1882880621,ExpressionUUID->"d8258422-caa4-4e23-8be4-26094630527b"]
}, Open  ]],

Cell[TextData[{
 "One can use composed functions inside ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ". Here I ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " the composition in which I first apply ",
 Cell[BoxData[
 "f1"], "InlineCodeText",ExpressionUUID->
  "5025ff15-c75e-450c-8902-e31e9788858d"],
 " (",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Function",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Function.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"], 
   "[", 
   RowBox[{"x", "+", 
    RowBox[{"3", "x"}], "+", "1"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "a22e70c3-9c25-4092-8749-3bbf498cfefe"],
 ") and then apply ",
 Cell[BoxData[
 "f2"], "InlineCodeText",ExpressionUUID->
  "64c43841-8d37-4f1d-9a03-b34ba92fefb6"],
 " (",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Function",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Function.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"], 
   "[", 
   RowBox[{"x", ",", 
    RowBox[{
     ButtonBox[
      StyleBox["Tanh",
       FontColor->GrayLevel[0]],
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["https://reference.wolfram.com/language/ref/Tanh.html"], None},
      ButtonNote->"https://reference.wolfram.com/language/ref/Tanh.html"], 
     "[", "x", "]"}]}], "]"}]], "InlineCodeText",ExpressionUUID->
  "8b4172de-056c-4ca7-af15-746d5d5ef7a1"],
 ") over some values."
}], "Text",
 CellChangeTimes->{{3.7690095940870543`*^9, 3.769009601069042*^9}, {
   3.769010894868958*^9, 3.7690109174298067`*^9}, 3.7753952415874653`*^9, {
   3.775395281289466*^9, 3.7753952849004655`*^9}, {3.8562623838485518`*^9, 
   3.856262409173233*^9}, {3.865592370869931*^9, 3.865592402018272*^9}, {
   3.877538221510581*^9, 3.8775383541569157`*^9}, {3.885558379053361*^9, 
   3.8855585885097537`*^9}},
 CellTags->"i:50",
 CellID->599170125,ExpressionUUID->"4ae8c18b-1aa4-4e55-8f57-384dd5cb5197"],

Cell[TextData[{
 "Composed functions work well with ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.7747824184028683`*^9, 3.7748757080136323`*^9, 
  3.7753952907714653`*^9},
 CellID->181301775,ExpressionUUID->"91606ca6-9a44-4398-94cf-b4462eb3d0d0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{"f1", "/*", "f2"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", "3", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769010644100458*^9, 3.7690106482553473`*^9}, {
  3.7690109197258663`*^9, 3.7690109300632153`*^9}, {3.769010978860176*^9, 
  3.769010979428567*^9}},
 CellLabel->"In[83]:=",
 CellID->357355651,ExpressionUUID->"4212e2a0-7355-4e13-9ab0-2480e151ca0a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"Tanh", "[", 
    FractionBox["5", "2"], "]"}], ",", 
   RowBox[{"Tanh", "[", "10", "]"}], ",", 
   RowBox[{"Tanh", "[", "1", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769010648523769*^9, 3.7690109304584837`*^9, 
  3.769010980190918*^9, 3.7690757702491837`*^9, 3.7691006416404257`*^9, 
  3.769772675192081*^9, 3.7699755299662457`*^9, 3.7719235780092*^9, 
  3.771929509721466*^9, 3.8814167147536488`*^9},
 CellLabel->"Out[83]=",
 CellID->613083487,ExpressionUUID->"9f898989-617f-4b30-9330-30e9862accc2"]
}, Open  ]],

Cell[TextData[{
 "If I want numeric values, I just add the built-in ",
 ButtonBox["N",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/N.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/N.html"],
 " function to the end of the pipeline:"
}], "CodeText",
 CellChangeTimes->{{3.769010940208894*^9, 3.769010958634186*^9}, {
  3.7753953018024654`*^9, 3.7753953062904654`*^9}, {3.8896929933915277`*^9, 
  3.889692994070053*^9}},
 CellID->566498279,ExpressionUUID->"8e746747-a150-4338-8a0d-91cbd8998af2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{"f1", "/*", "f2", "/*", "N"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"1", "/", "2"}], ",", "3", ",", "0"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769010961318283*^9, 3.769010975530171*^9}},
 CellLabel->"In[84]:=",
 CellID->1189100753,ExpressionUUID->"355eacfb-350b-444f-b398-55b7bb52590f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "0.9866142981514303`", ",", "0.9999999958776927`", ",", 
   "0.7615941559557649`"}], "}"}]], "Output",
 CellChangeTimes->{{3.7690109719109583`*^9, 3.769010975865139*^9}, 
   3.7690757702567453`*^9, 3.769100641652583*^9, 3.769772675205139*^9, 
   3.769975529978771*^9, 3.771923578043147*^9, 3.77192950972995*^9, 
   3.881416718449297*^9},
 CellLabel->"Out[84]=",
 CellID->1561412736,ExpressionUUID->"d3dc7d5d-fcc8-459e-9270-4b4cc5c2288c"]
}, Open  ]],

Cell[TextData[{
 "Finally, one should be aware of frequently used syntactic sugar for mapping \
at the first level: the ",
 ButtonBox["/@",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " notation. Here\[CloseCurlyQuote]s a shorter way of Mapping ",
 Cell[BoxData[
 "z"], "InlineCodeText",ExpressionUUID->
  "f517d7fa-bb3e-4b2f-828e-173506ec9b6c"],
 " over the expression ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "249f63cc-d37a-439d-b16e-823a729cee97"],
 ". One can\[CloseCurlyQuote]t use the ",
 ButtonBox["/@",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " infix notation if one wants to ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " at deeper levels of an expression."
}], "Text",
 CellChangeTimes->{{3.769168017033092*^9, 3.7691681329549007`*^9}, {
   3.7753953189554653`*^9, 3.7753953353734655`*^9}, {3.775490963552346*^9, 
   3.775490968853936*^9}, 3.777053542343377*^9, {3.8565305676126413`*^9, 
   3.8565305867813187`*^9}, {3.865536734650826*^9, 3.865536740723629*^9}, {
   3.877538391426684*^9, 3.877538399651064*^9}, {3.8855615861874585`*^9, 
   3.8855615901957765`*^9}, {3.8855620101663637`*^9, 3.8855620134775352`*^9}},
 CellID->113603876,ExpressionUUID->"656469c4-ffff-43a0-aca4-58bef42b0c68"],

Cell[TextData[{
 "The ",
 ButtonBox["/@",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " syntactic sugar for ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782434746502*^9, 3.7748757124376326`*^9, {3.775395342435466*^9, 
   3.775395345218466*^9}},
 CellID->78954144,ExpressionUUID->"ea5a7b1b-5560-4af5-8bdc-5ef66add7af4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"z", "/@", 
  RowBox[{"{", 
   RowBox[{"1", ",", "2", ",", "3"}], "}"}]}]], "Input",
 CellChangeTimes->{{3.769168080240807*^9, 3.769168092400566*^9}},
 CellLabel->"In[85]:=",
 CellID->1946098998,ExpressionUUID->"8f1b3917-4328-4b74-bbf0-b978fe7f3f56"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"z", "[", "1", "]"}], ",", 
   RowBox[{"z", "[", "2", "]"}], ",", 
   RowBox[{"z", "[", "3", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7691680853455877`*^9, 3.769168093154757*^9}, 
   3.769772675246428*^9, 3.769975530021599*^9, 3.7719235780561028`*^9, 
   3.771929509764267*^9, 3.881416725695256*^9},
 CellLabel->"Out[85]=",
 CellID->997953597,ExpressionUUID->"42718461-f28d-4fd3-a2f5-ad6e7e81556e"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Map\[CloseCurlyQuote]s Cousins", "Subsubsection",
 CellChangeTimes->{{3.7690110277945223`*^9, 3.769011032908099*^9}, {
  3.7747838866640053`*^9, 3.774783887531005*^9}, {3.7748757199166327`*^9, 
  3.7748757201476326`*^9}},
 CellID->1782190060,ExpressionUUID->"9829ec01-932b-484e-9166-a746d966b8ca"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["MapThread",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 FontColor->GrayLevel[0.45]]], "Subsubsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->1659344783,ExpressionUUID->"41cff5d0-e94f-403e-b0c1-a210c2cf26c3"],

Cell[TextData[{
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " has a large number of cousin functions. Let\[CloseCurlyQuote]s start with ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 ". One can use the function when one has two or more similar Lists that all \
have the same number of elements. Consider, for example, the data structures \
in the following ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". They have the same ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " (",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 "), and they each have three elements."
}], "Text",
 CellChangeTimes->{{3.7690110363801928`*^9, 3.76901105255573*^9}, {
  3.769012669831965*^9, 3.7690127549859858`*^9}, {3.7690128829120913`*^9, 
  3.7690129170917253`*^9}, {3.769119801563561*^9, 3.769119806508933*^9}, {
  3.7753953558114653`*^9, 3.7753953630074654`*^9}, {3.7753977609424605`*^9, 
  3.7753977642654605`*^9}, {3.87753843835391*^9, 3.8775384493122053`*^9}, {
  3.8855620615354953`*^9, 3.8855620671361375`*^9}},
 CellTags->"i:51",
 CellID->1219127502,ExpressionUUID->"e83ebe2c-15dd-428b-ae95-65d3822bf700"],

Cell[TextData[{
 "A data structure that is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists:"
}], "CodeText",
 CellChangeTimes->{{3.888933188582424*^9, 3.8889332107983017`*^9}},
 CellID->1472305551,ExpressionUUID->"bf6acba1-8341-4c7d-aa52-03d56a7d8dd6"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"List", "[", 
  RowBox[{
   RowBox[{"List", "[", 
    RowBox[{"1", ",", "2", ",", "3"}], "]"}], ",", 
   RowBox[{"List", "[", 
    RowBox[{"4", ",", "5", ",", "6"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769012734847322*^9, 3.769012742124954*^9}, {
   3.769012845012398*^9, 3.76901287556308*^9}, 3.7690129066572857`*^9},
 CellLabel->"In[86]:=",
 CellID->152859042,ExpressionUUID->"f56e8d6d-b869-449c-b4c2-b329437fc8d7"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "5", ",", "6"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7690757702875233`*^9, 3.769100641687705*^9, 
  3.7697726752605257`*^9, 3.769975530035309*^9, 3.771923578090904*^9, 
  3.771929509774514*^9, 3.881416742829805*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[86]=",
 CellID->422790878,ExpressionUUID->"5971dc72-abbc-401f-b43d-5920a4dc6949"]
}, Open  ]],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s what happens if we ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "da4e880b-57de-42fb-af18-20d2f064a7a5"],
 " over this structure."
}], "Text",
 CellChangeTimes->{{3.769012758140192*^9, 3.769012781296782*^9}, {
  3.7747838900720053`*^9, 3.774783891048005*^9}, {3.7753977731294603`*^9, 
  3.7753977762074604`*^9}},
 CellTags->"p: 34",
 CellID->2123458214,ExpressionUUID->"7eb1ae1f-b3dc-45e0-8d03-1305f41f45be"],

Cell[TextData[{
 "A canonical use of ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.774782457986826*^9, 3.7748757240046325`*^9, 
  3.7753977811174603`*^9},
 CellID->456570819,ExpressionUUID->"88e9d883-596a-4217-bcf0-999516619fae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"f", ",", 
   RowBox[{"List", "[", 
    RowBox[{
     RowBox[{"List", "[", 
      RowBox[{"1", ",", "2", ",", "3"}], "]"}], ",", 
     RowBox[{"List", "[", 
      RowBox[{"4", ",", "5", ",", "6"}], "]"}]}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690127833693132`*^9, 3.769012791761579*^9}, {
  3.76901283694613*^9, 3.769012868039654*^9}},
 CellLabel->"In[87]:=",
 CellID->1975564201,ExpressionUUID->"c9aa241c-04ea-488a-9783-d9e3d8161c28"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "5"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "6"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690128631601753`*^9, 3.769012868737459*^9}, 
   3.769012926674103*^9, 3.769075770296867*^9, 3.769100641696114*^9, 
   3.769772675301712*^9, 3.769975530078216*^9, 3.771923578103507*^9, 
   3.77192950980678*^9, 3.881416750501004*^9},
 CellLabel->"Out[87]=",
 CellID->1271978155,ExpressionUUID->"0903a580-8289-4d12-a54b-c79f16896bec"]
}, Open  ]],

Cell["\<\
The same operation but using syntactic sugar to represent the Lists:\
\>", "CodeCaption",
 CellChangeTimes->{{3.85626252817605*^9, 3.856262564871909*^9}, 
   3.885470224456938*^9},
 CellID->1797302397,ExpressionUUID->"6f6ea88e-0827-45ee-8af0-a3c45bd17dec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"1", ",", "2", ",", "3"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "6"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{3.856262571681835*^9},
 CellLabel->"In[88]:=",
 CellID->523442690,ExpressionUUID->"70ce5e5b-de76-48a0-a73d-7e1a6428f2e3"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"1", ",", "4"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"2", ",", "5"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"3", ",", "6"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.85626257297961*^9, 3.881416756791744*^9},
 CellLabel->"Out[88]=",
 CellID->1361115754,ExpressionUUID->"9ff14368-30d6-4784-a330-3e192cbc2a84"]
}, Open  ]],

Cell[TextData[{
 "The first argument of the first ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " pairs with the first argument of the second ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "60578211-ea55-42a9-b678-807f4ffd1b5b"],
 " is applied to it, the second argument of the first ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " pairs with the second argument of the second ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "3341c399-4555-4e78-b268-ba7b36202bc2"],
 " is applied to it, and the third argument of the first ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " pairs with the third argument of the second ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and the function ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "7799243f-0a79-442e-abdb-d06c4f973561"],
 " is applied to it. "
}], "Text",
 CellChangeTimes->{{3.769012928243082*^9, 3.7690129631283197`*^9}, {
  3.769013044305764*^9, 3.7690131242543287`*^9}, {3.7753977960354605`*^9, 
  3.7753978264284606`*^9}, {3.7753978621224604`*^9, 3.775397868609461*^9}, {
  3.875785376749967*^9, 3.875785392441317*^9}},
 CellID->513607383,ExpressionUUID->"c3b1e2d3-ec29-4a75-9c62-bccf16c09da5"],

Cell[TextData[{
 "In data analysis, you\[CloseCurlyQuote]re going to find that ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " is very useful in trying to build a new column out of two or more existing \
columns. Consider, for example, data in which one column has the heights of \
various rectangles and another has the widths. Here\[CloseCurlyQuote]s what \
one might do to compute the areas of the rectangles and make them a new \
column."
}], "Text",
 CellID->775575769,ExpressionUUID->"d3ce843b-58fd-4cf3-986f-3b7320c1f1e4"],

Cell[TextData[{
 "Use ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " to create a new column using multiple existing columns in matrix-like data:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747824706600933`*^9, {3.7748757303476324`*^9, 3.7748757330436325`*^9}, {
   3.775397954557461*^9, 3.7753979587734604`*^9}},
 CellID->9740974,ExpressionUUID->"4fd2ccc7-d412-4b84-b531-ae65136ca358"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"#1", ",", "#2", ",", 
      RowBox[{"Times", "[", 
       RowBox[{"#1", ",", "#2"}], "]"}]}], "}"}], "&"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "7", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "5", ",", "9"}], "}"}]}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769013203727913*^9, 3.769013250051198*^9}},
 CellLabel->"In[89]:=",
 CellID->1471861292,ExpressionUUID->"f416f68a-33ae-42ec-9724-5f6e6637f35e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "4", ",", "12"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"7", ",", "5", ",", "35"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", "9", ",", "18"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769013218976304*^9, 3.7690132506461782`*^9, 
  3.769075770321658*^9, 3.7691006417335777`*^9, 3.769772675315753*^9, 
  3.769975530090912*^9, 3.771923578139656*^9, 3.771929509815905*^9, 
  3.881416765337294*^9},
 CellLabel->"Out[89]=",
 CellID->1816568413,ExpressionUUID->"8de9b473-0ebe-44d1-b5ca-0b544856fede"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["MapIndexed",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 FontColor->GrayLevel[0.45]]], "Subsubsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->777347503,ExpressionUUID->"007effd3-52ef-4e0a-bf3a-8fd0503f8e04"],

Cell[TextData[{
 "With ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " we saw how one can take two expressions and apply a function to \
corresponding parts of each expression. Sometimes, however, the second \
expression to which the function is applied can be readily inferred from the \
first expression. The ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " function provides a way of generating that second expression without \
having to actually write it down. It\[CloseCurlyQuote]s for a special case \
but an extremely common one. The second expression ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " implicitly generates is the position numbers of each ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " of the first expression. The position numbers are wrapped in ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". So ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["MapIndexed",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
    "[", 
   RowBox[{"f", ",", 
    RowBox[{"{", 
     RowBox[{"a", ",", "b"}], "}"}]}], "]"}]], "InlineCodeText",
  ExpressionUUID->"6e54cab5-430c-432c-99df-9c13e4b21594"],
 " creates ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"a", ",", 
      RowBox[{"{", "1", "}"}]}], "]"}], ",", 
    RowBox[{"f", "[", 
     RowBox[{"a", ",", 
      RowBox[{"{", "2", "}"}]}], "]"}]}], "}"}]], "InlineCodeText",
  ExpressionUUID->"56e4f3c6-f48e-4915-83a1-3f124b027899"],
 " not ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"f", "[", 
     RowBox[{"a", ",", "1"}], "]"}], ",", 
    RowBox[{"f", "[", 
     RowBox[{"a", ",", "2"}], "]"}]}], "}"}]], "InlineCodeText",
  ExpressionUUID->"d6b9d541-3c52-46af-9a22-3927c4d1d9d6"],
 "."
}], "Text",
 CellChangeTimes->{{3.769013290378026*^9, 3.769013349456833*^9}, {
  3.769013456246932*^9, 3.769013495180561*^9}, {3.769119896249584*^9, 
  3.76911989904248*^9}, {3.7747836724760056`*^9, 3.774783675444005*^9}, {
  3.7753979935304604`*^9, 3.775398019491461*^9}, {3.8562630648115463`*^9, 
  3.856263396804699*^9}, {3.8565309805634613`*^9, 3.85653103925771*^9}, {
  3.8655392969848747`*^9, 3.865539297376154*^9}, {3.875785415624317*^9, 
  3.875785510522952*^9}, {3.8776931559585047`*^9, 3.877693229362571*^9}, {
  3.885562409589102*^9, 3.885562429927122*^9}, {3.885562809494196*^9, 
  3.8855628535055337`*^9}, {3.885562942274953*^9, 3.8855630255146036`*^9}, {
  3.8855630695984416`*^9, 3.885563077567655*^9}},
 CellTags->"i:52",
 CellID->184130491,ExpressionUUID->"a8e2127c-ddce-45e4-b8e2-0560a7a2f71b"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s get concrete. Suppose, for example, that the first \
chunk of data was a two-dimensional matrix and the second chunk of data one \
wanted was simply the index of each row. If one lived in a world without ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 ", one could write the following code. Remember that ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Prepend",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Prepend.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Prepend.html"], 
   "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "d"}], "]"}]], 
  "InlineCodeText",ExpressionUUID->"aff5a0ad-e468-4272-b204-e5caa4f25ac8"],
 " yields ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"d", ",", "a", ",", "b", ",", "c"}], "}"}]], "InlineCodeText",
  ExpressionUUID->"a495c56e-7c93-4f1e-b3bb-3f1b59b12a4a"],
 ". The ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " function gets the part numbers of the first argument matching the pattern \
in the second argument but looks only at the level specified in the third \
argument. "
}], "Text",
 CellChangeTimes->{{3.769013290378026*^9, 3.769013349456833*^9}, {
  3.769013456246932*^9, 3.769013495180561*^9}, {3.769119896249584*^9, 
  3.76911989904248*^9}, {3.7747836724760056`*^9, 3.774783675444005*^9}, {
  3.7753979935304604`*^9, 3.775398019491461*^9}, {3.8562630648115463`*^9, 
  3.856263444059331*^9}, {3.856263750623721*^9, 3.856263794780903*^9}, {
  3.85653112114469*^9, 3.856531179117094*^9}, {3.880557162229813*^9, 
  3.880557162503583*^9}, {3.880557192940493*^9, 3.8805571939369497`*^9}, {
  3.8855631950366373`*^9, 3.8855632355162363`*^9}, {3.889693227797001*^9, 
  3.889693228453247*^9}},
 CellTags->"LastCellOfAPage",
 CellID->606608944,ExpressionUUID->"39590882-a79d-418f-885c-eb6aa32fad5d"],

Cell[TextData[{
 "A view of what goes on inside ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 "; ",
 ButtonBox["Echo",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Echo.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Echo.html"],
 " is used to print out the positions of ",
 Cell[BoxData[
 "nestedList"], "InlineCode",ExpressionUUID->
  "949e27f4-8181-42bb-ae7d-a684621663e1"],
 " that match ",
 ButtonBox["_",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Blank.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Blank.html"],
 " at the first level:"
}], "CodeCaption",
 CellTags->"p: 35",
 CellID->914741257,ExpressionUUID->"e72f9de7-367d-4245-bddb-05e3e3bb57eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Module", "[", 
  RowBox[{
   RowBox[{"{", "positionsAtLevel", "}"}], ",", "\[IndentingNewLine]", 
   RowBox[{
    RowBox[{"positionsAtLevel", "=", 
     RowBox[{"Position", "[", 
      RowBox[{"nestedList", ",", "_", ",", 
       RowBox[{"{", "1", "}"}], ",", 
       RowBox[{"Heads", "\[Rule]", "False"}]}], "]"}]}], ";", 
    "\[IndentingNewLine]", 
    RowBox[{"Echo", "[", "positionsAtLevel", "]"}], ";", 
    RowBox[{"MapThread", "[", 
     RowBox[{
      RowBox[{
       RowBox[{"Prepend", "[", 
        RowBox[{"#1", ",", 
         RowBox[{"#2", "[", 
          RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", 
      RowBox[{"{", 
       RowBox[{"nestedList", ",", "positionsAtLevel"}], "}"}]}], "]"}]}]}], 
  "\[IndentingNewLine]", "]"}]], "Input",
 CellChangeTimes->{{3.769014079521421*^9, 3.769014103954376*^9}, {
  3.769015877944606*^9, 3.7690159148924427`*^9}, {3.769120068898377*^9, 
  3.769120127950235*^9}, {3.8562629107847767`*^9, 3.856262918546681*^9}, {
  3.856263724817614*^9, 3.856263732917018*^9}},
 CellLabel->"In[90]:=",
 CellID->220877526,ExpressionUUID->"737b0ab2-d260-45bc-82cd-8fff0fce8766"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", "1", "}"}], ",", 
   RowBox[{"{", "2", "}"}], ",", 
   RowBox[{"{", "3", "}"}], ",", 
   RowBox[{"{", "4", "}"}], ",", 
   RowBox[{"{", "5", "}"}]}], "}"}]], "Echo",
 CellChangeTimes->{3.881416775924251*^9},
 CellID->2134996429,ExpressionUUID->"674ba09a-029d-4b16-9ded-1318c8d44b80"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690140967499*^9, 3.769014104555985*^9}, 
   3.769015879866116*^9, 3.769015916148447*^9, 3.76907577037844*^9, 
   3.76908231989163*^9, 3.769083387319396*^9, 3.7691006418099957`*^9, 
   3.769120128919702*^9, 3.769772675433486*^9, 3.769975530213122*^9, 
   3.7719235782511253`*^9, 3.771929509909048*^9, 3.856262927026504*^9, 
   3.8562629762187023`*^9, 3.856263733996086*^9, 3.881416776195344*^9},
 CellLabel->"Out[90]=",
 CellID->580724480,ExpressionUUID->"17f704f2-072a-4d1d-aeca-4414a4504321"]
}, Open  ]],

Cell[TextData[{
 "The built-in ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " function provides a different and generally shorter method of achieving \
this output. Let\[CloseCurlyQuote]s first see it in action."
}], "Text",
 CellChangeTimes->{{3.7690135024242363`*^9, 3.769013533357176*^9}, {
  3.769013979894783*^9, 3.769014067380896*^9}, {3.7753984256506824`*^9, 
  3.7753984296730847`*^9}},
 CellID->1315068279,ExpressionUUID->"14d48c18-6b49-4fd5-b9e0-831c9f08d563"],

Cell[TextData[{
 "A canonical use of ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.7747824933283596`*^9, 3.7748757460986323`*^9, 
  3.775398439095027*^9},
 CellID->409133792,ExpressionUUID->"07b18725-7d88-49a9-9a13-6dd3dcd33488"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Prepend", "[", 
     RowBox[{"#1", ",", 
      RowBox[{"#2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", "nestedList", ",", 
   RowBox[{"{", "1", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690133680031424`*^9, 3.769013410605309*^9}, {
  3.769013535847621*^9, 3.7690135690717697`*^9}, {3.8562638564402733`*^9, 
  3.856263860266029*^9}},
 CellLabel->"In[91]:=",
 CellID->1296074320,ExpressionUUID->"32c55b19-4b16-46fa-a30a-cd347f054a10"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.7690135695034027`*^9, 3.7690757703633327`*^9, 
  3.769082317010168*^9, 3.7690833845659847`*^9, 3.7691006417915916`*^9, 
  3.76977267538229*^9, 3.7699755301591387`*^9, 3.771923578203444*^9, 
  3.7719295098695097`*^9, 3.8562638606821413`*^9, 3.881416782428422*^9},
 CellLabel->"Out[91]=",
 CellID->1754372011,ExpressionUUID->"5b466b52-8be3-47c0-9936-4fd8898f9a5a"]
}, Open  ]],

Cell[TextData[{
 "The ",
 Cell[BoxData[
  RowBox[{"{", "1", "}"}]], "InlineCodeText",ExpressionUUID->
  "62721871-25ec-479b-b5f9-14c02774433f"],
 " in the third argument basically instructs the Wolfram Language kernel to \
construct the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " numbers of ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "67cb3d34-d6b7-4ecf-b9ed-025bceb45c5a"],
 " (excluding heads) that lie at the first level. As shown next, if the third \
argument is omitted, the level specification defaults to ",
 Cell[BoxData[
  RowBox[{"{", "1", "}"}]], "InlineCodeText",ExpressionUUID->
  "5d9668cb-6382-481a-b845-7f6d148c9dbc"],
 "."
}], "Text",
 CellChangeTimes->{{3.7690140689454947`*^9, 3.769014077504815*^9}, {
  3.769015867828268*^9, 3.769015870241782*^9}, {3.7690159214043503`*^9, 
  3.769015930644576*^9}, {3.769015966600176*^9, 3.7690160652675734`*^9}, {
  3.769119960051759*^9, 3.769120048278131*^9}, {3.7747836783720055`*^9, 
  3.774783681548005*^9}, {3.7753984431024275`*^9, 3.77539847552967*^9}, {
  3.7753995574314575`*^9, 3.775399600484457*^9}, {3.856262764205935*^9, 
  3.85626277375666*^9}, {3.856262855749773*^9, 3.8562628570866213`*^9}, {
  3.856263873822015*^9, 3.856263951859579*^9}, {3.856531784562459*^9, 
  3.856531841903244*^9}, {3.865539350703088*^9, 3.865539363113175*^9}, {
  3.865592533083975*^9, 3.865592553795486*^9}, {3.877693370152811*^9, 
  3.8776933769870977`*^9}, {3.88547015506308*^9, 3.885470156733655*^9}, {
  3.8856523376830635`*^9, 3.885652338204662*^9}, {3.8963404405739403`*^9, 
  3.8963404413159523`*^9}},
 CellID->365064426,ExpressionUUID->"801d6257-b237-461b-a5e0-5dbc327ec3aa"],

Cell[TextData[{
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " without a third argument uses ",
 Cell[BoxData[
  RowBox[{"{", "1", "}"}]], "InlineCode",ExpressionUUID->
  "182f0113-a50f-4e1b-92a5-13f30fb38382"],
 " as the default level specification:"
}], "CodeCaption",
 CellChangeTimes->{{3.856263964441935*^9, 3.856263982945866*^9}, 
   3.877693396285701*^9, {3.88556392009011*^9, 3.8855639276323233`*^9}, 
   3.897574156039904*^9},
 CellID->1734301627,ExpressionUUID->"ade4547f-d5bc-4407-8b13-e1b599b63843"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{
   RowBox[{
    RowBox[{"Prepend", "[", 
     RowBox[{"#1", ",", 
      RowBox[{"#2", "[", 
       RowBox[{"[", "1", "]"}], "]"}]}], "]"}], "&"}], ",", "nestedList"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.856263958996172*^9, 3.856263959512682*^9}},
 CellLabel->"In[92]:=",
 CellID->1852243537,ExpressionUUID->"ba131732-13b0-4e63-bb9e-c3ff7ddf9e7c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"1", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.8562639600660667`*^9, 3.881416787757639*^9},
 CellLabel->"Out[92]=",
 CellID->1334883087,ExpressionUUID->"74e4ba7d-e147-4aeb-913b-b1914cc91f89"]
}, Open  ]],

Cell[TextData[{
 "One can use ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " with different level specifications."
}], "Text",
 CellChangeTimes->{{3.8562639934657393`*^9, 3.856264002740044*^9}, {
   3.856264035010047*^9, 3.856264035590794*^9}, 3.877693410900814*^9},
 CellID->145195687,ExpressionUUID->"1ddcab83-8e7e-4951-b9aa-35ea06905f48"],

Cell[TextData[{
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " in which one matches Parts at only the second level:"
}], "CodeCaption",
 CellChangeTimes->{{3.85626404140107*^9, 3.856264070899352*^9}, {
  3.877693415591161*^9, 3.877693421552096*^9}},
 CellID->1627334601,ExpressionUUID->"2faadd64-6341-4e23-b77e-83bbd2e6a01f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"h", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"d", ",", "e", ",", "f", ",", "g"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.8562640052220716`*^9, 3.856264026517716*^9}},
 CellLabel->"In[93]:=",
 CellID->512026645,ExpressionUUID->"591cc3c2-d0cf-4ce2-8068-a7845cee1d8f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"a", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{"b", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{"c", ",", 
       RowBox[{"{", 
        RowBox[{"1", ",", "3"}], "}"}]}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"h", "[", 
      RowBox[{"d", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{"e", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "]"}], ",", 
     RowBox[{"h", "[", 
      RowBox[{"g", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "4"}], "}"}]}], "]"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.856264027037528*^9, 3.881416792700725*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[93]=",
 CellID->97357396,ExpressionUUID->"73ca8356-28d5-4fad-9bfb-334a13602a28"]
}, Open  ]],

Cell[TextData[{
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " generalizes to many operations and can save a lot of typing\[LongDash]and \
prevent the mistakes that accompany such efforts."
}], "Text",
 CellChangeTimes->{{3.769016041107811*^9, 3.769016114824654*^9}, 
   3.769016930994482*^9, {3.774783684948005*^9, 3.7747836851080055`*^9}, {
   3.775399043502457*^9, 3.7753990483654575`*^9}, {3.8562640852293053`*^9, 
   3.856264127495677*^9}, {3.8855639671178145`*^9, 3.885563969375353*^9}},
 CellTags->"p: 36",
 CellID->1582731546,ExpressionUUID->"4d887762-65a9-41da-a694-45bd7e33dc6b"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["MapAt",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 FontColor->GrayLevel[0.45]]], "Subsubsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->1743256220,ExpressionUUID->"940af334-193c-428d-9c8d-876f91aa6668"],

Cell[TextData[{
 "Sometimes, one just wants to apply a function to selected positions in \
data. Suppose, for example, that I wanted to apply the ",
 ButtonBox["Reverse",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Reverse.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Reverse.html"],
 " function just to the second and fourth rows of ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "ac659589-7ff3-45cc-b32f-b1379541c4de"],
 ". Here\[CloseCurlyQuote]s how I could do it. I wrap the result in ",
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " so it is easier to see."
}], "Text",
 CellChangeTimes->{{3.769081523971409*^9, 3.769081640876568*^9}, {
   3.76912018300165*^9, 3.7691201919221907`*^9}, 3.7747836875630054`*^9, {
   3.7753990605724573`*^9, 3.775399079094457*^9}},
 CellTags->"i:53",
 CellID->2123712673,ExpressionUUID->"67077beb-ebdd-44d5-92e6-8c5826cd9e5f"],

Cell[TextData[{
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " lets one apply functions at only certain positions:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747825167587023`*^9, 3.774875754370632*^9, 3.775399154260457*^9, {
   3.8855640216112523`*^9, 3.8855640229626665`*^9}},
 CellID->71967055,ExpressionUUID->"36bfd1f3-c251-4d05-9b50-2004e2e4618e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"MapAt", "[", 
    RowBox[{"Reverse", ",", "nestedList", ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", "2", "}"}], ",", 
       RowBox[{"{", "4", "}"}]}], "}"}]}], "]"}], ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690815943073997`*^9, 3.769081602779518*^9}, {
  3.769120194350595*^9, 3.7691202041626*^9}},
 CellLabel->"In[94]:=",
 CellID->1395622584,ExpressionUUID->"4adc83dc-2d6c-4f14-b0a5-c4a57dce716a"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], "5", "0.08`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], 
      "]"}], "\<\"Thurgood Marshall\"\>"},
    {"\<\"Elena Kagan\"\>", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], "0.83`", "2", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], "4", "0.07`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], "\<\"Oliver Ellsworth\"\>"},
    {"\<\"William Rehnquist\"\>", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], "0.35`", "4", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], "9", "0.87`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], 
      "]"}], "\<\"Oliver Wendell Holmes, Jr.\"\>"}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{
  3.769081603981738*^9, 3.769082322316098*^9, 3.7690833904883327`*^9, 
   3.769100641851987*^9, {3.769120197837946*^9, 3.769120204739797*^9}, 
   3.769772675455799*^9, 3.769975530235799*^9, 3.771923578296829*^9, 
   3.771929509926859*^9, 3.881416806104517*^9},
 CellLabel->"Out[94]=",
 CellID->1229755306,ExpressionUUID->"b2233bbc-9403-4b85-8796-5be79425d525"]
}, Open  ]],

Cell[TextData[{
 "Notice that I had to encapsulate the position information in Lists. \
Although this may seem to be a nuisance, it permits code like this to be \
unambiguous. If I weren\[CloseCurlyQuote]t required to stick the position \
information in Lists, the Wolfram Language would not know if, in the \
following code, I intended to try to apply ",
 ButtonBox["Framed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Framed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Framed.html"],
 " to both the second and first rows of the data or whether I intended to \
apply it only to the first column of the second row."
}], "Text",
 CellChangeTimes->{{3.769081641809724*^9, 3.769081664158032*^9}, {
   3.769081696171111*^9, 3.769081737531577*^9}, {3.769120238501422*^9, 
   3.769120263176633*^9}, {3.769180686157547*^9, 3.7691806870959167`*^9}, 
   3.7753991778234572`*^9, {3.8854701634107585`*^9, 3.8854701668585863`*^9}, {
   3.8896935683030443`*^9, 3.8896935734961405`*^9}},
 CellID->138589008,ExpressionUUID->"ba111c1c-01a7-4f17-90f4-9c9e402f3cbd"],

Cell[TextData[{
 "Position specifications in ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " can be very detailed:"
}], "CodeCaption",
 CellChangeTimes->{{3.777352625451466*^9, 3.777352650855356*^9}},
 CellID->861981625,ExpressionUUID->"90091b1f-4960-4797-ba4c-dd60a2a5c2b2"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"MapAt", "[", 
    RowBox[{"Framed", ",", "nestedList", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"2", ",", "1"}], "}"}], "}"}]}], "]"}], ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690815943073997`*^9, 3.769081602779518*^9}, {
  3.769081669470108*^9, 3.7690816897332573`*^9}, {3.769120269556916*^9, 
  3.769120275459592*^9}, {3.7691806513236*^9, 3.769180662329288*^9}},
 CellLabel->"In[95]:=",
 CellID->344223888,ExpressionUUID->"347571ec-cb7b-4520-a2bc-de86ba389bb5"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], "5", "0.08`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], 
      "]"}], "\<\"Thurgood Marshall\"\>"},
    {
     FrameBox[
      TemplateBox[<|
       "color" -> RGBColor[
         0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
       "RGBColorSwatchTemplate"],
      StripOnInput->False], "2", "0.83`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], "\<\"Elena Kagan\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], "4", "0.07`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], "\<\"Oliver Ellsworth\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], "4", "0.35`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], "\<\"William Rehnquist\"\>"},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], "9", "0.87`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], 
      "]"}], "\<\"Oliver Wendell Holmes, Jr.\"\>"}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.769081691144601*^9, 3.769082324543799*^9, 
  3.769083393283578*^9, 3.76910064187187*^9, 3.769120275877953*^9, 
  3.76918065271699*^9, 3.7697726755150948`*^9, 3.769975530297557*^9, 
  3.771923578326132*^9, 3.7719295099733887`*^9, 3.881416812366753*^9},
 CellLabel->"Out[95]=",
 CellID->453509200,ExpressionUUID->"6ede1dcc-b3f6-48f9-b701-3b0e974e6a89"]
}, Open  ]],

Cell[TextData[{
 "I can use more complex position specifications in ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 ". "
}], "Text",
 CellChangeTimes->{{3.7690817608944197`*^9, 3.769081822381536*^9}, {
   3.769180694434389*^9, 3.7691807120657*^9}, 3.775399849594457*^9, 
   3.7754000642094574`*^9},
 CellTags->"LastCellOfAPage",
 CellID->1260116051,ExpressionUUID->"eeda2d21-6b06-4f43-978d-f0509742ff16"],

Cell[TextData[{
 "Apply the ",
 ButtonBox["Framed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Framed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Framed.html"],
 " function to the fifth position of elements in ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " rows: "
}], "CodeCaption",
 CellChangeTimes->{{3.775400045633457*^9, 3.7754000680464573`*^9}, 
   3.877693506179989*^9},
 CellTags->"p: 37",
 CellID->87742728,ExpressionUUID->"38955627-95f7-449c-beb8-73b1be55ed12"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"MapAt", "[", 
    RowBox[{"Framed", ",", "nestedList", ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{"All", ",", "5"}], "}"}], "}"}]}], "]"}], ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690817712635117`*^9, 3.769081781656419*^9}, {
  3.769120286843768*^9, 3.7691202929132767`*^9}, {3.769180697889573*^9, 
  3.769180704975893*^9}},
 CellLabel->"In[96]:=",
 CellID->2038438949,ExpressionUUID->"baa424a8-483b-4a9a-b8c7-7610707170d4"],

Cell[BoxData[
 TagBox[GridBox[{
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], "5", "0.08`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
     FrameBox["\<\"Thurgood Marshall\"\>",
      StripOnInput->False]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], "2", "0.83`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], 
     FrameBox["\<\"Elena Kagan\"\>",
      StripOnInput->False]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], "4", "0.07`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], 
     FrameBox["\<\"Oliver Ellsworth\"\>",
      StripOnInput->False]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], "4", "0.35`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     FrameBox["\<\"William Rehnquist\"\>",
      StripOnInput->False]},
    {
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], "9", "0.87`", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     FrameBox["\<\"Oliver Wendell Holmes, Jr.\"\>",
      StripOnInput->False]}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.769081782300476*^9, 3.769082326577731*^9, 
  3.7690833956729527`*^9, 3.7691006419158983`*^9, 3.7691202932347803`*^9, 
  3.7691807058978243`*^9, 3.769772675584383*^9, 3.7699755303691053`*^9, 
  3.7719235784317513`*^9, 3.771929510027076*^9, 3.881416816934382*^9},
 CellLabel->"Out[96]=",
 CellID->396021245,ExpressionUUID->"5c95dfd9-7214-4829-9835-063b201d3704"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Apply",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 FontColor->GrayLevel[0.45]]], "Subsubsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->257251033,ExpressionUUID->"eb8101d9-2ef6-4aca-bb9b-ef183d858ca0"],

Cell[TextData[{
 "The ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " function causes the function to insert itself into the expression tree. It \
basically adds\[LongDash]at least temporarily\[LongDash]a new level to the \
expression, although sometimes this new level disappears after the inserted \
function evaluates its arguments. Often, that\[CloseCurlyQuote]s exactly what \
one wants, but sometimes instead of adding a level, one wants to replace \
heads of the expression at some level of the expression. ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " is the Wolfram Language function to do this. There\[CloseCurlyQuote]s a \
standard example that shows how it works."
}], "Text",
 CellChangeTimes->{{3.769163072286376*^9, 3.7691632545276127`*^9}, 
   3.7754000771784573`*^9, {3.7754002711796026`*^9, 3.775400307863938*^9}, 
   3.7773527038092937`*^9, {3.8855643427394733`*^9, 3.885564351631683*^9}},
 CellTags->"i:54",
 CellID->111233947,ExpressionUUID->"8bb7c308-48e4-4d5b-bf7a-7a1450b3141e"],

Cell[TextData[{
 "A canonical example of ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.77478253183821*^9, 3.7748757603386326`*^9, 
  3.7754003160435734`*^9},
 CellID->12392933,ExpressionUUID->"da04b07a-8530-4160-8ae5-a5d59afa8b76"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"Plus", ",", 
   RowBox[{"List", "[", 
    RowBox[{"2", ",", "2"}], "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769163256565889*^9, 3.769163272024089*^9}, {
  3.7691633049773893`*^9, 3.769163305068622*^9}},
 CellLabel->"In[97]:=",
 CellID->74760028,ExpressionUUID->"7f876aaa-b410-4487-a324-97aa85544b72"],

Cell[BoxData["4"], "Output",
 CellChangeTimes->{3.769163262296941*^9, 3.769163305643446*^9, 
  3.7697726756106443`*^9, 3.7699755303953047`*^9, 3.7719235785077963`*^9, 
  3.7719295100477324`*^9, 3.881416822910911*^9},
 CellLabel->"Out[97]=",
 CellID->911184165,ExpressionUUID->"e115e32b-074f-4f77-85c9-3c220b8e054d"]
}, Open  ]],

Cell[TextData[{
 "In the example, the ",
 ButtonBox["Plus",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Plus.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Plus.html"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " has replaced the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 ", but while ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["List",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/List.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/List.html"], "[", 
   RowBox[{"2", ",", "3"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "184c2253-eabc-4caa-9572-164f2a0f9a3e"],
 " cannot be evaluated further, the Wolfram Language knows that ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Plus",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Plus.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Plus.html"], "[", 
   RowBox[{"2", ",", "2"}], "]"}]], "InlineCodeText",ExpressionUUID->
  "d9f5771f-f0d9-49cd-bc81-4236b0638467"],
 " is 4. "
}], "Text",
 CellChangeTimes->{{3.7691632741465473`*^9, 3.7691633101697817`*^9}, {
   3.7691633838305883`*^9, 3.7691633865969973`*^9}, {3.77540158638745*^9, 
   3.7754016054774504`*^9}, {3.856264574784027*^9, 3.856264576947657*^9}, {
   3.877693549319394*^9, 3.877693554063837*^9}, {3.885468013609772*^9, 
   3.8854680168760643`*^9}, {3.8855644022067227`*^9, 3.885564402394191*^9}, 
   3.8963405668206453`*^9},
 CellID->293600159,ExpressionUUID->"03875d53-2d1b-4b70-a644-625ccd34b7ef"],

Cell[TextData[{
 "I can also show what ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " does using ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 ". Notice how the ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "9e141b6d-ca74-41b5-87b6-a416d444cbaa"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " replaces the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 " in the expression."
}], "Text",
 CellChangeTimes->{{3.769163317916*^9, 3.769163390744611*^9}, {
   3.7754017046034503`*^9, 3.77540171971045*^9}, 3.7773527515846653`*^9, {
   3.8776935724823227`*^9, 3.8776935764698143`*^9}},
 CellID->847495178,ExpressionUUID->"6f1b256d-ad11-4a94-9915-4796ffbcb58f"],

Cell[TextData[{
 "Visualize how ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " works with ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 "; notice the use of the operator form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " and postfix notation:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747825424322696`*^9, 3.7748757629136324`*^9, {3.7754017271424503`*^9, 
   3.77540173057845*^9}, {3.856272123894183*^9, 3.856272135121063*^9}, 
   3.877693584573865*^9, {3.8855645079326224`*^9, 3.8855645081619844`*^9}},
 CellID->219345899,ExpressionUUID->"c0f3fdfd-52a5-4c8f-a0c9-ac55cf86ea92"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{" ", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"2", ",", "2"}], "}"}], ",", 
     RowBox[{"Apply", "[", 
      RowBox[{"f", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}]}], "]"}]}], "}"}], "//", 
   RowBox[{
    RowBox[{"Map", "[", "TreeForm", "]"}], "/*", "Framed"}]}]}]], "Input",
 CellChangeTimes->{{3.76916333067837*^9, 3.769163346575172*^9}, {
  3.7719236651856213`*^9, 3.771923666289796*^9}, {3.8562644948342543`*^9, 
  3.856264554121273*^9}},
 CellLabel->"In[98]:=",
 CellID->1961728579,ExpressionUUID->"b43962e3-5de1-4e6c-90ec-4c7968010e99"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4472135954999579, 0.8944271909999159}, {0., 
        0.}, {0.8944271909999159, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], LineBox[{{1, 2}, {1, 3}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["List", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"{", 
               RowBox[{"2", ",", "2"}], "}"}], HoldForm]],
           Annotation[#, 
            HoldForm[{2, 2}], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4472135954999579, 0.8944271909999159}, {
         0., 0.}, {0.8944271909999159, 0.}}]& ],
      AspectRatio->1,
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{190.17584228515625`, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[{2, 2}],
     Editable->False], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4472135954999579, 0.8944271909999159}, {0., 
        0.}, {0.8944271909999159, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], LineBox[{{1, 2}, {1, 3}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"f", "[", 
               RowBox[{"2", ",", "2"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[2, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4472135954999579, 0.8944271909999159}, {
         0., 0.}, {0.8944271909999159, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{190.592041015625, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`f[2, 2]],
     Editable->False]}], "}"}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{3.856264554441821*^9, 3.881416828166026*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[98]=",
 CellID->1232306257,ExpressionUUID->"b29e7876-7953-4758-b14e-192ebe6ae75e"]
}, Open  ]],

Cell[TextData[{
 "By default, ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " works at level 0 of the expression, right on the top-level ",
 ButtonBox["Head",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Head.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Head.html"],
 ". As with ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 ", one can ask ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " to work at different levels. Here I take the more complicated expression \
and ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "ca6cb574-ccc0-4c70-a88d-93b80ac13fc7"],
 " at level 1. I\[CloseCurlyQuote]ll show the results using ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.7691633971434793`*^9, 3.769163454862873*^9}, {
   3.7691634922660027`*^9, 3.769163507786723*^9}, {3.7754017355224504`*^9, 
   3.7754017832344503`*^9}, {3.87769359907073*^9, 3.877693610687813*^9}, 
   3.885555118542545*^9, {3.8855646792285843`*^9, 3.8855647278292437`*^9}, {
   3.885654196260107*^9, 3.885654203757722*^9}, {3.889693632134776*^9, 
   3.8896936323790855`*^9}},
 CellTags->"p: 38",
 CellID->1082026607,ExpressionUUID->"61de52c5-56a4-441b-bc9b-9814c1cc9841"],

Cell[TextData[{
 "Use ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " at deeper levels:"
}], "CodeCaption",
 CellChangeTimes->{3.774782555192546*^9, 3.7748757656176324`*^9, 
  3.7754017875364504`*^9, 3.7754018770504503`*^9, 3.8776936169683867`*^9},
 CellID->420475458,ExpressionUUID->"acd4cd96-e464-452f-8a10-68732f8849de"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"TreeForm", "[", 
     RowBox[{"g", "[", 
      RowBox[{"8", ",", 
       RowBox[{"h", "[", 
        RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "]"}], ",", 
    RowBox[{"TreeForm", "[", 
     RowBox[{"Apply", "[", 
      RowBox[{"f", ",", 
       RowBox[{"g", "[", 
        RowBox[{"8", ",", 
         RowBox[{"h", "[", 
          RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
       RowBox[{"{", "1", "}"}]}], "]"}], "]"}]}], "}"}], "//", 
  "Framed"}]], "Input",
 CellChangeTimes->{{3.7691634565394783`*^9, 3.769163523728591*^9}, {
  3.7691635854502583`*^9, 3.769163592157295*^9}, {3.771923669777059*^9, 
  3.7719236708268337`*^9}},
 CellLabel->"In[99]:=",
 CellID->911727825,ExpressionUUID->"ac509e22-36c1-44fd-8951-60c6391d775b"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4082482904638631, 1.6329931618554523`}, {0., 
        0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
        0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 5}, {3, 6}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"8", ",", 
                 RowBox[{"h", "[", 
                   RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "]"}], 
             HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[8, 
              $CellContext`h[7, $CellContext`y, 9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["h", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"h", "[", 
               RowBox[{"7", ",", "y", ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`h[7, $CellContext`y, 9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["7",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["7", HoldForm]],
           Annotation[#, 
            HoldForm[7], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4082482904638631, 1.6329931618554523`}, {
         0., 0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {
         0., 0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{191.998779296875, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[8, 
       $CellContext`h[7, $CellContext`y, 9]]],
     Editable->False], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[
       GraphicsComplexBox[{{0.4082482904638631, 1.6329931618554523`}, {0., 
        0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {0., 
        0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}, {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 3}, {3, 4}, {3, 5}, {3, 6}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["g", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"g", "[", 
               RowBox[{"8", ",", 
                 RowBox[{"f", "[", 
                   RowBox[{"7", ",", "y", ",", "9"}], "]"}]}], "]"}], 
             HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`g[8, 
              $CellContext`f[7, $CellContext`y, 9]]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["8",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox["8", HoldForm]],
           Annotation[#, 
            HoldForm[8], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["f", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"f", "[", 
               RowBox[{"7", ",", "y", ",", "9"}], "]"}], HoldForm]],
           Annotation[#, 
            HoldForm[
             $CellContext`f[7, $CellContext`y, 9]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["7",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["7", HoldForm]],
           Annotation[#, 
            HoldForm[7], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["y",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox["y", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`y], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["9",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.05],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox["9", HoldForm]],
           Annotation[#, 
            HoldForm[9], "Tooltip"]& ]}}],
       Annotation[#, 
        VertexCoordinateRules -> {{0.4082482904638631, 1.6329931618554523`}, {
         0., 0.8164965809277261}, {0.8164965809277261, 0.8164965809277261}, {
         0., 0.}, {0.8164965809277261, 0.}, {1.6329931618554523`, 0.}}]& ],
      AspectRatio->NCache[2^Rational[1, 2], 1.4142135623730951`],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->{200.70025634765625`, Automatic},
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[
      $CellContext`g[8, 
       $CellContext`f[7, $CellContext`y, 9]]],
     Editable->False]}], "}"}],
  StripOnInput->False]], "Output",
 CellChangeTimes->{
  3.76916348592946*^9, 3.7691635241774406`*^9, {3.7691635873066797`*^9, 
   3.769163592861721*^9}, 3.769772675729416*^9, 3.769975530488607*^9, 
   3.771923578594153*^9, 3.771923671222682*^9, 3.771929510157608*^9, 
   3.8814168380403833`*^9},
 CellLabel->"Out[99]=",
 CellID->780482359,ExpressionUUID->"8883a571-a7a4-48d1-a3db-5420ff44be9f"]
}, Open  ]],

Cell[TextData[{
 "As of Version 13.1, there is also ",
 ButtonBox["MapApply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapApply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapApply.html"],
 ", which works at level 1 of the expression."
}], "Text",
 CellChangeTimes->{{3.8757885559925137`*^9, 3.875788572740486*^9}, 
   3.875788617396529*^9, {3.8855652182327194`*^9, 3.885565225902121*^9}, {
   3.8896937291962194`*^9, 3.8896937321473837`*^9}},
 CellID->170762455,ExpressionUUID->"e5a19467-26a2-4347-9449-39f4dc85b690"],

Cell[TextData[{
 ButtonBox["MapApply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapApply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapApply.html"],
 " is equivalent to ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " at level 1:"
}], "CodeText",
 CellChangeTimes->{{3.87578858732339*^9, 3.875788621694283*^9}, {
  3.885565236050694*^9, 3.885565245230299*^9}, {3.8896937384985075`*^9, 
  3.8896937401975403`*^9}},
 CellID->2103618955,ExpressionUUID->"0a38401f-9d92-41a8-845d-9dbbc2d20745"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"VerificationTest", "[", 
   RowBox[{
    RowBox[{"MapApply", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "a", "}"}], ",", 
        RowBox[{"{", "b", "}"}]}], "}"}]}], "]"}], ",", 
    RowBox[{"Apply", "[", 
     RowBox[{"f", ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", "a", "}"}], ",", 
        RowBox[{"{", "b", "}"}]}], "}"}], ",", 
      RowBox[{"{", "1", "}"}]}], "]"}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"\"\<ExpectedOutput\>\"", ",", "\"\<VerificationTest\>\""}], "}"}],
   "]"}]], "Input",
 CellChangeTimes->{{3.8757885002851353`*^9, 3.875788508325078*^9}, {
  3.87578863500062*^9, 3.875788636719635*^9}, {3.8757886803477488`*^9, 
  3.875788744004238*^9}},
 CellLabel->"In[100]:=",
 CellID->1098759784,ExpressionUUID->"ee6eb42e-32b7-4030-9b35-a55adc4f698e"],

Cell[BoxData[
 RowBox[{"\[LeftAssociation]", 
  RowBox[{
   RowBox[{"\<\"ExpectedOutput\"\>", "\[Rule]", 
    TagBox[
     RowBox[{"{", 
      RowBox[{
       RowBox[{"f", "[", "a", "]"}], ",", 
       RowBox[{"f", "[", "b", "]"}]}], "}"}],
     HoldForm]}], ",", 
   RowBox[{"\<\"VerificationTest\"\>", "\[Rule]", 
    TagBox[
     RowBox[{"VerificationTest", "[", 
      RowBox[{
       RowBox[{"f", "@@@", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"{", "a", "}"}], ",", 
          RowBox[{"{", "b", "}"}]}], "}"}]}], ",", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"f", "[", "a", "]"}], ",", 
         RowBox[{"f", "[", "b", "]"}]}], "}"}], ",", 
       RowBox[{"{", "}"}], ",", 
       RowBox[{"TestID", "\[Rule]", "None"}], ",", 
       RowBox[{"SameTest", "\[Rule]", "SameQ"}], ",", 
       RowBox[{"TimeConstraint", "\[Rule]", "\[Infinity]"}], ",", 
       RowBox[{"MemoryConstraint", "\[Rule]", "\[Infinity]"}]}], "]"}],
     HoldForm]}]}], "\[RightAssociation]"}]], "Output",
 CellChangeTimes->{
  3.875788509331016*^9, 3.875788583678774*^9, {3.875788691521428*^9, 
   3.875788702098921*^9}, {3.875788735098319*^9, 3.87578874427997*^9}, 
   3.8814168433609657`*^9},
 CellLabel->"Out[100]=",
 CellID->729574479,ExpressionUUID->"64d47c2a-474a-45eb-8366-59c0050a04bb"]
}, Open  ]],

Cell[TextData[{
 "Just as there is an operator form for ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " built into the Wolfram Language and a ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " that permits use of the operator form at deeper levels, so too with ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.856272158273978*^9, 3.8562721994363003`*^9}, {
   3.856532271025036*^9, 3.856532286466003*^9}, 3.877694211028431*^9, {
   3.885565268962493*^9, 3.8855652691490154`*^9}},
 CellID->1674011242,ExpressionUUID->"e72d4152-091a-40c6-abb5-5d50a4fc05e3"],

Cell[TextData[{
 "Use an operator form of ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.856272242309927*^9, 3.856272260251058*^9}, 
   3.877694232446733*^9},
 CellID->461651975,ExpressionUUID->"ac2d480c-c2a4-4833-979d-5f91ef21681f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Apply", "[", "Plus", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{"2", ",", "3"}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.856272205544804*^9, 3.8562722099443197`*^9}},
 CellLabel->"In[101]:=",
 CellID->140397775,ExpressionUUID->"10e6d758-9013-4525-95e7-5076661a6610"],

Cell[BoxData["5"], "Output",
 CellChangeTimes->{3.8562722107206573`*^9, 3.88141684784575*^9},
 CellLabel->"Out[101]=",
 CellID->579967694,ExpressionUUID->"6cea534c-1dfc-450b-ac92-6eea3235c7c5"]
}, Open  ]],

Cell[TextData[{
 "Use the ",
 ButtonBox["ApplyLevel",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
ApplyLevel"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
ApplyLevel"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " to apply the function at a deeper level of the expression:"
}], "CodeCaption",
 CellChangeTimes->{{3.856272242309927*^9, 3.856272260251058*^9}, {
  3.856537742715773*^9, 3.85653783955429*^9}, {3.877694239985466*^9, 
  3.877694256084393*^9}},
 CellTags->"i:55",
 CellID->2111128489,ExpressionUUID->"11b2b7a2-b60f-42a8-9687-94f3ae4bfd9e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   InterpretationBox[
    TagBox[
     TagBox[
      DynamicModuleBox[{Typeset`open = False}, 
       FrameBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[GridBox[{
               {
                StyleBox[
                 StyleBox[
                  AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                   BoxBaselineShift->-0.25,
                   BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                  
                  FontColor->RGBColor[
                   0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                 ShowStringCharacters->False,
                 FontFamily->"Source Sans Pro Black",
                 FontSize->0.6538461538461539 Inherited,
                 FontWeight->"Heavy",
                 PrivateFontOptions->{"OperatorSubstitution"->False}], 
                StyleBox[
                 RowBox[{
                  StyleBox["ApplyLevel", "ResourceFunctionLabel"], " "}],
                 ShowAutoStyles->False,
                 ShowStringCharacters->False,
                 FontSize->Rational[12, 13] Inherited,
                 FontColor->GrayLevel[0.1]]}
              },
              GridBoxSpacings->{"Columns" -> {{0.25}}}],
             Alignment->Left,
             BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
             BaselinePosition->Baseline,
             FrameMargins->{{3, 0}, {0, 0}}], 
            ItemBox[
             PaneBox[
              TogglerBox[Dynamic[Typeset`open], {True->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeCloser"],
                ImageSizeCache->{11., {2., 9.}}], False->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeOpener"],
                ImageSizeCache->{11., {2., 9.}}]},
               Appearance->None,
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{1, 1}, {0, 0}}],
             Frame->{{
                RGBColor[
                0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                 0.5], False}, {False, False}}]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
         GridBox[{
           {GridBox[{
              {
               PaneBox[GridBox[{
                  {
                   StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                   StyleBox[
                    RowBox[{
                    StyleBox["ApplyLevel", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                 },
                 GridBoxSpacings->{"Columns" -> {{0.25}}}],
                Alignment->Left,
                BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                BaselinePosition->Baseline,
                FrameMargins->{{3, 0}, {0, 0}}], 
               ItemBox[
                PaneBox[
                 TogglerBox[Dynamic[Typeset`open], {True->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeCloser"]], False->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeOpener"]]},
                  Appearance->None,
                  BaselinePosition->Baseline,
                  ContentPadding->False,
                  FrameMargins->0],
                 Alignment->Left,
                 BaselinePosition->Baseline,
                 FrameMargins->{{1, 1}, {0, 0}}],
                Frame->{{
                   RGBColor[
                   0.8313725490196079, 0.8470588235294118, 0.8509803921568627,
                     0.5], False}, {False, False}}]}
             },
             BaselinePosition->{1, 1},
             GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
           {
            StyleBox[
             PaneBox[GridBox[{
                {
                 RowBox[{
                  TagBox["\<\"Version (latest): \"\>",
                   "IconizedLabel"], " ", 
                  TagBox["\<\"1.0.0\"\>",
                   "IconizedItem"]}]},
                {
                 TagBox[
                  
                  TemplateBox[{
                   "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/94444d3b-d884-4aef-971d-ee99d84b6c1e/"},
                   "HyperlinkURL"],
                  "IconizedItem"]}
               },
               DefaultBaseStyle->"Column",
               GridBoxAlignment->{"Columns" -> {{Left}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
             FontFamily->"Roboto",
             FontSize->11]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
               GrayLevel[0.8]}, False}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open],
         BaselinePosition->Baseline,
         ImageSize->Automatic],
        Background->RGBColor[
         0.9686274509803922, 0.9764705882352941, 0.984313725490196],
        BaselinePosition->Baseline,
        DefaultBaseStyle->{},
        FrameMargins->{{0, 0}, {1, 0}},
        FrameStyle->RGBColor[
         0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
        RoundingRadius->4]],
      #& ,
      TagBoxNote->" "],
     {"FunctionResourceBox", 
      RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
      "ApplyLevel"},
     TagBoxNote->"FunctionResourceBox"],
    ResourceFunction[
     ResourceObject[<|
      "Name" -> "ApplyLevel", "ShortName" -> "ApplyLevel", "UUID" -> 
       "94444d3b-d884-4aef-971d-ee99d84b6c1e", "ResourceType" -> "Function", 
       "Version" -> "1.0.0", "Description" -> 
       "Create an operator that applies a function over data at a specified \
level", "RepositoryLocation" -> 
       URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
       "SymbolName" -> 
       "FunctionRepository`$748067e3e59c480b93f5429ea81244af`ApplyLevel", 
       "FunctionLocation" -> 
       CloudObject[
        "https://www.wolframcloud.com/obj/2eeea0ed-57f4-4b26-ba16-\
c8ce0e3fad3e"]|>, {
      ResourceSystemBase -> 
       "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}]],
    Selectable->False], "[", 
   RowBox[{"Plus", ",", 
    RowBox[{"{", "1", "}"}]}], "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"2", ",", "3"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"4", ",", "5"}], "}"}]}], "}"}], "]"}]], "Input",
 CellChangeTimes->{{3.856272218076421*^9, 3.85627223661664*^9}, {
  3.8814168571976433`*^9, 3.881416883128294*^9}},
 CellLabel->"In[104]:=",
 CellID->1516278644,ExpressionUUID->"1c33371b-74e9-4823-b149-5e6f69c0f161"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "9"}], "}"}]], "Output",
 CellChangeTimes->{3.856272237270418*^9, 3.881416853708899*^9, 
  3.881416888058243*^9},
 CellLabel->"Out[104]=",
 CellID->1975872469,ExpressionUUID->"5118fc69-3355-42f6-a69c-f253929e31cc"]
}, Open  ]],

Cell[TextData[{
 "There are two forms of syntactic sugar for ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 ". The double \[OpenCurlyDoubleQuote]at\[CloseCurlyDoubleQuote] in ",
 Cell[BoxData[
  RowBox[{"f", 
   ButtonBox["@@",
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"], 
   "x"}]], "InlineCodeText",ExpressionUUID->
  "0b3d8478-16ff-4233-8f83-0640a05bcda2"],
 " means to ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "d4e0e99f-3b95-42e4-be5c-7285b118a65a"],
 " to ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "2c0be865-6755-4c75-b941-4ad0313abf03"],
 " at level 0. The triple \[OpenCurlyDoubleQuote]at\[CloseCurlyDoubleQuote] \
in ",
 Cell[BoxData[
  RowBox[{"f", 
   ButtonBox["@@@",
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"], 
   "x"}]], "InlineCodeText",ExpressionUUID->
  "3c98b2df-3170-4039-b327-1919da447bc8"],
 " means to ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " ",
 Cell[BoxData[
 "f"], "InlineCodeText",ExpressionUUID->
  "54e64acf-a5df-45ce-af04-272dac77ada5"],
 " to ",
 Cell[BoxData[
 "x"], "InlineCodeText",ExpressionUUID->
  "c692fce3-49ba-426a-b359-1b27472acb86"],
 " at level 1."
}], "Text",
 CellChangeTimes->{{3.769163495687622*^9, 3.769163500179082*^9}, {
   3.769163533050495*^9, 3.769163606028872*^9}, {3.77540190179545*^9, 
   3.7754019224924507`*^9}, 3.77540217442745*^9, {3.885565304641209*^9, 
   3.8855653593808393`*^9}, {3.8856543481038947`*^9, 3.885654357734206*^9}},
 CellTags->"LastCellOfAPage",
 CellID->684075409,ExpressionUUID->"ca19dbc3-1bc9-42ba-9b78-e908f873596c"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Thread",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 FontColor->GrayLevel[0.45]]], "Subsubsubsection",
 PageBreakAbove->True,
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellTags->"p: 39",
 CellID->956965639,ExpressionUUID->"2a155ad8-5784-4770-bc7d-694d0f608a81"],

Cell[TextData[{
 "This book uses the ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " command a lot. It\[CloseCurlyQuote]s a little bit like ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 ". Here\[CloseCurlyQuote]s an example."
}], "Text",
 CellChangeTimes->{{3.769016147876321*^9, 3.769016163323534*^9}, {
  3.769016940055121*^9, 3.769016945947277*^9}, {3.7754022237544503`*^9, 
  3.7754022272134504`*^9}},
 CellTags->"i:56",
 CellID->1222765007,ExpressionUUID->"8cfb8c49-3427-4687-9b44-860f0324783f"],

Cell[TextData[{
 "A canonical example of ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.7747825650195284`*^9, 3.774875768865632*^9, 
  3.7754022324034505`*^9},
 CellID->42688470,ExpressionUUID->"7d7571a5-4a97-42e0-932c-8e8348d4581a"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", 
    RowBox[{"{", 
     RowBox[{"d", ",", "e", ",", "f"}], "}"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769016948055211*^9, 3.769017066352129*^9}},
 CellLabel->"In[105]:=",
 CellID->1365141791,ExpressionUUID->"23dfdbde-ef3c-44a6-9922-f3678e171744"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "d"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"b", ",", "e"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"c", ",", "f"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769017001894191*^9, 3.769017066808239*^9, 
  3.769075770407917*^9, 3.769100641932268*^9, 3.769772675744535*^9, 
  3.769975530503271*^9, 3.7719235786086407`*^9, 3.7719295101673613`*^9, 
  3.881416892722331*^9},
 CellLabel->"Out[105]=",
 CellID->1191941046,ExpressionUUID->"526b58f4-0c24-4ad4-8fb9-2f3b38572d7d"]
}, Open  ]],

Cell[TextData[{
 "As with ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 ", each element in each of the inner structures (like ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"a", ",", "b", ",", "c"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "654b88d1-b97c-4072-ae3c-af6e87ed951a"],
 " or ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"d", ",", "e", ",", "f"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "97535ee9-e48e-4a5a-ad18-512fe5f0d2ca"],
 ") pairs up with an element of the other inner structures in the same \
position within that structure. "
}], "Text",
 CellChangeTimes->{{3.76901707305238*^9, 3.7690171566609898`*^9}, {
  3.769120322022318*^9, 3.769120331042923*^9}, {3.77540223723645*^9, 
  3.7754022461344504`*^9}},
 CellTags->"i:57",
 CellID->1491901077,ExpressionUUID->"835870e3-a8c9-4bbb-9cdc-236ec51e9d9d"],

Cell[TextData[{
 "There\[CloseCurlyQuote]s also a very handy special case of ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 ". Remember that ",
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " only works if the inner data structures have the same length. Thus, this \
fails to do anything."
}], "Text",
 CellChangeTimes->{{3.769017419287703*^9, 3.769017478984146*^9}, 
   3.7747836908750052`*^9, {3.774783893744005*^9, 3.774783896680005*^9}, {
   3.7754022542984505`*^9, 3.77540225761345*^9}},
 CellID->847319374,ExpressionUUID->"7f48a898-5480-4ff2-905a-d6886e967289"],

Cell[TextData[{
 ButtonBox["MapThread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapThread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapThread.html"],
 " generally fails if the second argument is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " with differing structures:"
}], "CodeCaption",
 CellChangeTimes->{3.774782575457572*^9, 3.7748757721456327`*^9, 
  3.7754022645624504`*^9, 3.877694320016715*^9},
 CellID->145983669,ExpressionUUID->"552fb5a2-9da7-40e0-97d3-4378c0c43371"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "d"}], "}"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769017464701619*^9, 3.7690174729666777`*^9}},
 CellLabel->"In[106]:=",
 CellID->2136244131,ExpressionUUID->"aae865bd-c9c3-44f7-96b3-1dbc97887bb4"],

Cell[BoxData[
 TemplateBox[{
  "MapThread", "mptd", 
   "\"Object \\!\\(\\*RowBox[{\\\"d\\\"}]\\) at position {2, \
\\!\\(\\*RowBox[{\\\"2\\\"}]\\)} in \\!\\(\\*RowBox[{\\\"MapThread\\\", \\\"[\
\\\", RowBox[{\\\"f\\\", \\\",\\\", RowBox[{\\\"{\\\", \
RowBox[{RowBox[{\\\"{\\\", RowBox[{\\\"a\\\", \\\",\\\", \\\"b\\\", \
\\\",\\\", \\\"c\\\"}], \\\"}\\\"}], \\\",\\\", \\\"d\\\"}], \\\"}\\\"}]}], \
\\\"]\\\"}]\\) has only \\!\\(\\*RowBox[{\\\"0\\\"}]\\) of required \
\\!\\(\\*RowBox[{\\\"1\\\"}]\\) dimensions.\"", 2, 96, 2, 
   27285885561973558937, "Local"},
  "MessageTemplate"]], "Message", "MSG",
 CellChangeTimes->{3.7690757704521627`*^9, 3.769100641967958*^9, 
  3.769772675786471*^9, 3.769975530547619*^9, 3.771923578644259*^9, 
  3.771929510201805*^9},
 CellLabel->"During evaluation of In[96]:=",
 CellID->72059448,ExpressionUUID->"ce66d673-fb4b-4489-8489-644bccde87b3"],

Cell[BoxData[
 RowBox[{"MapThread", "[", 
  RowBox[{"f", ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "d"}], "}"}]}], 
  "]"}]], "Output",
 CellChangeTimes->{3.769017473295281*^9, 3.769075770466587*^9, 
  3.76910064197407*^9, 3.769772675883917*^9, 3.7699755305588617`*^9, 
  3.771923578656818*^9, 3.7719295102134523`*^9, 3.881416900229661*^9},
 CellLabel->"Out[106]=",
 CellID->215424652,ExpressionUUID->"4cbd093e-d21b-4320-bfa9-acf0cec1f051"]
}, Open  ]],

Cell[TextData[{
 "However, ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " takes any atomic value and assumes it is essentially the same thing as an \
array of the same length as the other structures on which ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " is operating and whose values are all equal to that one atomic value."
}], "Text",
 CellChangeTimes->{{3.769017482119652*^9, 3.76901752726607*^9}, {
  3.769120353286338*^9, 3.769120362824625*^9}, {3.7691606342753973`*^9, 
  3.769160673516119*^9}, {3.7754022802014503`*^9, 3.7754023061644506`*^9}},
 CellID->191890356,ExpressionUUID->"06468bfd-350a-4586-8b1d-24cafe4b3dc1"],

Cell[TextData[{
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " can work where some of the elements of the second argument are atoms:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747825860356293`*^9, 3.7748757751376324`*^9, 3.7754023143174505`*^9, {
   3.856272370016395*^9, 3.856272370746586*^9}},
 CellID->866140152,ExpressionUUID->"b79a4811-b04b-4017-aae6-4324f024cf29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"f", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"a", ",", "b", ",", "c"}], "}"}], ",", "d"}], "]"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769017713629099*^9, 3.769017742897073*^9}},
 CellLabel->"In[107]:=",
 CellID->1376850713,ExpressionUUID->"3cbefbf6-d4e5-4ca0-87b0-88ea473b7110"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", 
    RowBox[{"a", ",", "d"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"b", ",", "d"}], "]"}], ",", 
   RowBox[{"f", "[", 
    RowBox[{"c", ",", "d"}], "]"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769017723174086*^9, 3.7690177437007513`*^9}, 
   3.7690757704903107`*^9, 3.769100641982992*^9, 3.7697726758935537`*^9, 
   3.769975530568321*^9, 3.7719235786899757`*^9, 3.771929510244602*^9, 
   3.881416922780242*^9},
 CellLabel->"Out[107]=",
 CellID->1252440185,ExpressionUUID->"5c4a0071-6638-4919-b65e-e26fd2276998"]
}, Open  ]],

Cell[TextData[{
 "By the way, if there\[CloseCurlyQuote]s only one inner data structure, ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " works a lot like ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.7690172009216633`*^9, 3.769017220589231*^9}, 
   3.769075826308289*^9, {3.774783899415005*^9, 3.7747839003910055`*^9}, {
   3.77540232611845*^9, 3.7754023287084503`*^9}},
 CellID->916129082,ExpressionUUID->"b2573d3f-6040-4c08-8af1-aad3e8bb58bb"],

Cell[TextData[{
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " disguised as ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782594273453*^9, 3.774875778712632*^9, {3.7754023313954506`*^9, 
   3.7754023353434505`*^9}},
 CellID->428972552,ExpressionUUID->"426cd13a-cea6-4caa-b680-155c1bab6c3d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Thread", "[", 
  RowBox[{"f", "[", 
   RowBox[{"{", 
    RowBox[{"a", ",", "b", ",", "c"}], "}"}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7690171862280684`*^9, 3.769017190792454*^9}},
 CellLabel->"In[108]:=",
 CellID->148211364,ExpressionUUID->"f2863c78-19ad-4d18-a035-31a986f25e67"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"f", "[", "a", "]"}], ",", 
   RowBox[{"f", "[", "b", "]"}], ",", 
   RowBox[{"f", "[", "c", "]"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769017191226944*^9, 3.769075770499206*^9, 
  3.769100642020406*^9, 3.769772675934219*^9, 3.7699755306114073`*^9, 
  3.7719235787023373`*^9, 3.771929510252536*^9, 3.881416925931388*^9},
 CellLabel->"Out[108]=",
 CellID->1110103062,ExpressionUUID->"c6f07bf6-7b34-40bb-b217-4bd13bd2dcea"]
}, Open  ]],

Cell[TextData[{
 "Indeed, if one gives a ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " a ",
 ButtonBox["Listable",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Listable.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Listable.html"],
 " attribute, it automatically threads over Lists without having to write ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " explicitly. Here is one way of making a ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " ",
 ButtonBox["Listable",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Listable.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Listable.html"],
 ": just include that word as a third argument to ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 ". (You can\[CloseCurlyQuote]t use this method if you use the ampersand \
notation or if you use the function arrow (",
 ButtonBox["\[Function]",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 ") notation to create the function; it only works if you write out ",
 ButtonBox["Function",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
 " literally.)"
}], "Text",
 CellChangeTimes->{{3.769017232300212*^9, 3.769017273892581*^9}, {
   3.769017320781074*^9, 3.769017384216735*^9}, {3.769120403837447*^9, 
   3.769120406145741*^9}, 3.7747836935320053`*^9, {3.77540233923845*^9, 
   3.7754023406094503`*^9}, {3.7754023974994507`*^9, 
   3.7754024569964504`*^9}, {3.7773528756944323`*^9, 
   3.7773528927205267`*^9}, {3.880557249241334*^9, 3.880557255429734*^9}, 
   3.885566158438437*^9, 3.8855662034237833`*^9, 3.896340662007757*^9},
 CellTags->{"LastCellOfAPage", "i:58"},
 CellID->382985419,ExpressionUUID->"dfdbdc8d-f178-4703-8a31-feed756d9a21"],

Cell[TextData[{
 "Make a function ",
 ButtonBox["Listable",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Listable.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Listable.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782603002326*^9, 3.7748757808726325`*^9, {3.7754024608954506`*^9, 
   3.7754024671754503`*^9}, 3.777352935860875*^9},
 CellTags->"p: 40",
 CellID->143558437,ExpressionUUID->"90dc00c9-4961-4b3f-b42a-097fd355d8b1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "=", 
  RowBox[{"Function", "[", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"x", ",", "y"}], "}"}], ",", 
    RowBox[{"x", "-", "y"}], ",", "Listable"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.769017277992382*^9, 3.769017295332006*^9}},
 CellLabel->"In[109]:=",
 CellID->1483139215,ExpressionUUID->"ac8b6c41-8d07-43f7-94d6-885c0eb6c187"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", "y"}], "}"}], ",", 
   RowBox[{"x", "-", "y"}], ",", "Listable"}], "]"}]], "Output",
 CellChangeTimes->{3.7690172966188107`*^9, 3.769075770524486*^9, 
  3.7691006420796337`*^9, 3.7697726759474916`*^9, 3.769975530676252*^9, 
  3.771923578737124*^9, 3.771929510286031*^9, 3.881416931984829*^9},
 CellLabel->"Out[109]=",
 CellID->1787142219,ExpressionUUID->"06a19753-6083-4938-a3f8-70b900d16a45"]
}, Open  ]],

Cell[TextData[{
 "Now ",
 Cell[BoxData[
 "q"], "InlineCodeText",ExpressionUUID->
  "ddf197f6-dd18-4c7b-8cbf-cedcb601e387"],
 " will ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " over the arguments. I don\[CloseCurlyQuote]t have to write ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.769017390692134*^9, 3.769017405044691*^9}, {
   3.769075862201337*^9, 3.7690758628092957`*^9}, {3.7754025564724503`*^9, 
   3.7754025681204505`*^9}, 3.877694584963457*^9, {3.89634065339607*^9, 
   3.896340653555727*^9}},
 CellID->1941302877,ExpressionUUID->"d1e021c8-7092-49f9-bc6c-5be56b5eea3d"],

Cell[TextData[{
 ButtonBox["Listable",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Listable.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Listable.html"],
 " functions thread without the need for ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.774782620595085*^9, 3.774875784457632*^9, 
  3.7754029801854506`*^9, 3.885566227598649*^9},
 CellID->92874239,ExpressionUUID->"77f0467f-b4aa-447b-928a-80f8ba0707cb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "7", ",", "8"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1", ",", "0", ",", "13"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769017297749127*^9, 3.769017315004571*^9}},
 CellLabel->"In[110]:=",
 CellID->1482873745,ExpressionUUID->"577b0789-a0b6-4741-b366-e13617d71480"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5", ",", "7", ",", 
   RowBox[{"-", "5"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690173092832413`*^9, 3.769017316068404*^9}, 
   3.769075770532044*^9, 3.7691006420905237`*^9, 3.76977267598839*^9, 
   3.7699755306882772`*^9, 3.771923578747209*^9, 3.7719295103482924`*^9, 
   3.8814169402216053`*^9},
 CellLabel->"Out[110]=",
 CellID->420566703,ExpressionUUID->"ff440f4e-daa0-49be-a584-f4b4bced6e47"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"q", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"6", ",", "7", ",", "8"}], "}"}], ",", "5"}], "]"}]], "Input",
 CellChangeTimes->{{3.769017407091166*^9, 3.769017410905789*^9}},
 CellLabel->"In[111]:=",
 CellID->993332672,ExpressionUUID->"65c7af6a-7ead-4f5a-bd90-05a96106fc30"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"1", ",", "2", ",", "3"}], "}"}]], "Output",
 CellChangeTimes->{3.7690174116324673`*^9, 3.7690757705583878`*^9, 
  3.769100642125942*^9, 3.769772676000765*^9, 3.769975530731065*^9, 
  3.771923578782874*^9, 3.7719295103641644`*^9, 3.881416944061648*^9},
 CellLabel->"Out[111]=",
 CellID->268044286,ExpressionUUID->"9443cb37-0a5e-45c6-a945-3fa704931da7"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Common Operations on Lists", "Subsection",
 CellChangeTimes->{{3.76901122109624*^9, 3.7690112268594437`*^9}},
 CellID->699787974,ExpressionUUID->"4a03c6df-3bd1-416d-95f4-65fd5871b173"],

Cell["\<\
The Wolfram Language has a large number of operations that work on Lists (and \
other data containers that we have not yet examined). Many of these \
operations make use of functions as arguments. I present a few here that are \
most commonly used in this book.\
\>", "Text",
 CellChangeTimes->{{3.769011230184404*^9, 3.769011287124918*^9}, {
  3.769076657356642*^9, 3.7690766643759193`*^9}, {3.8562726599477053`*^9, 
  3.856272735591351*^9}, {3.880557282258101*^9, 3.880557287141006*^9}},
 CellID->1250616598,ExpressionUUID->"52fe420d-441a-468e-a37f-653971a88c6d"],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Length",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Length.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Length.html"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->1649917466,ExpressionUUID->"3fedcc64-fc7c-459f-b88d-856d3c47fb88"],

Cell[TextData[{
 "The ",
 ButtonBox["Length",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Length.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Length.html"],
 " function computes how many elements are in the top level of an expression."
}], "Text",
 CellChangeTimes->{{3.7691754404384727`*^9, 3.7691754706564913`*^9}, 
   3.7754030243364506`*^9},
 CellTags->"i:59",
 CellID->1235558941,ExpressionUUID->"992eb565-a951-4c7c-b977-3e450739ba49"],

Cell[TextData[{
 "Use ",
 ButtonBox["Length",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Length.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Length.html"],
 " to count elements:"
}], "CodeCaption",
 CellChangeTimes->{3.774782633962422*^9, 3.7748757877606325`*^9, 
  3.7754030320684505`*^9},
 CellID->555924890,ExpressionUUID->"5e6b12ab-6cf8-4003-99ce-e4ccf74e8847"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", "Length", "]"}], "[", 
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"4", ",", "5", ",", "6"}], "}"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{"3", ",", "4", ",", "5", ",", "6", ",", "7"}], "]"}], ",", 
    RowBox[{"g", "[", 
     RowBox[{"8", ",", 
      RowBox[{"h", "[", 
       RowBox[{"q", ",", "8", ",", "y", ",", "9"}], "]"}]}], "]"}]}], "}"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.856272760129724*^9, 3.856272812113351*^9}, 
   3.856272843624485*^9},
 CellLabel->"In[112]:=",
 CellID->1271558542,ExpressionUUID->"64a7c8af-541a-4d96-b6fc-e31045fae371"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"3", ",", "5", ",", "2"}], "}"}]], "Output",
 CellChangeTimes->{3.856272843873019*^9, 3.88141695160903*^9},
 CellLabel->"Out[112]=",
 CellID->183755095,ExpressionUUID->"30363631-c1f5-489a-881f-32d08e69a405"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["SortBy",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/SortBy.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/SortBy.html"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->1736504741,ExpressionUUID->"9687753a-f409-4210-ae95-b9044789eda1"],

Cell[TextData[{
 "One can use ",
 ButtonBox["SortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/SortBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/SortBy.html"],
 " to sort a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " (or another data structure) according to the value of some function \
applied to each element of the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". Here I use ",
 ButtonBox["SortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/SortBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/SortBy.html"],
 " to sort a bunch of strings according to the number of characters they \
contain."
}], "Text",
 CellChangeTimes->{{3.769017856610683*^9, 3.769017874650722*^9}, {
   3.7691204308645763`*^9, 3.769120445410413*^9}, {3.7754030408064504`*^9, 
   3.7754030408934507`*^9}, {3.856272861960346*^9, 3.8562728683066797`*^9}, {
   3.8776948346359367`*^9, 3.877694844790205*^9}, 3.8855551325766363`*^9, {
   3.888933258828233*^9, 3.8889332964439077`*^9}},
 CellTags->"i:60",
 CellID->1695096994,ExpressionUUID->"e22260e3-7db1-413e-aa3f-df0d36a62cf9"],

Cell["Sort strings by their number of characters:", "CodeCaption",
 CellChangeTimes->{3.774782644252451*^9, 3.7748757901526327`*^9},
 CellID->203368130,ExpressionUUID->"3daf0467-c7d1-47db-9180-04764855b5ef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<zebra\>\"", ",", "\"\<yak\>\"", ",", "\"\<wombat\>\"", ",", 
     "\"\<stegosaurus\>\""}], "}"}], ",", "StringLength"}], "]"}]], "Input",
 CellChangeTimes->{{3.769017877815374*^9, 3.7690179326971607`*^9}},
 CellLabel->"In[113]:=",
 CellID->1318898366,ExpressionUUID->"ea2818b7-a212-416d-bfa0-0f6f5bed9ac8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"yak\"\>", ",", "\<\"zebra\"\>", ",", "\<\"wombat\"\>", 
   ",", "\<\"stegosaurus\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.769017933179076*^9, 3.7690757705660152`*^9, 
  3.769100642164836*^9, 3.769772676054023*^9, 3.769975530787342*^9, 
  3.7719235788299713`*^9, 3.771929510427987*^9, 3.881416958172123*^9},
 CellLabel->"Out[113]=",
 CellID->1637357366,ExpressionUUID->"62577255-4259-49a8-8362-c63e39a5affd"]
}, Open  ]],

Cell[TextData[{
 "Here I sort a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists according to the value of its last element."
}], "Text",
 CellChangeTimes->{{3.769120450397784*^9, 3.769120476398912*^9}, 
   3.87769485756643*^9, 3.8855551387700915`*^9},
 CellTags->"LastCellOfAPage",
 CellID->1274898801,ExpressionUUID->"1c3bfab2-eb9a-4d15-9f5f-1bb440065010"],

Cell[TextData[{
 "Sort Lists of numbers by their ",
 ButtonBox["Last",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Last.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Last.html"],
 " value:"
}], "CodeCaption",
 CellChangeTimes->{3.774782653708396*^9, 3.7748757935036325`*^9, 
  3.877694872082563*^9},
 CellTags->"p: 41",
 CellID->399629588,ExpressionUUID->"00402900-fdd9-48db-af26-59351debf13d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"SortBy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"3", ",", "1"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"4", ",", "6"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"5", ",", "2"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"11", ",", "3", ",", "4"}], "}"}]}], "}"}], ",", "Last"}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769017944217712*^9, 3.7690179738768787`*^9}, {
  3.769120461643128*^9, 3.769120465336152*^9}},
 CellLabel->"In[114]:=",
 CellID->750290687,ExpressionUUID->"6eb295fd-5c27-4eeb-95b3-21466928cbcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"3", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"11", ",", "3", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4", ",", "6"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769017974319249*^9, 3.7690757705934267`*^9, 
  3.769100642173616*^9, 3.769120478780992*^9, 3.7697726760947657`*^9, 
  3.769975530800536*^9, 3.7719235788433523`*^9, 3.771929510435998*^9, 
  3.8814169697524967`*^9},
 CellLabel->"Out[114]=",
 CellID->182194538,ExpressionUUID->"809e6703-1c9c-4d94-9bc5-9c33fafbd522"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s a cousin function, ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 ", which does exactly what you think it does."
}], "Text",
 CellChangeTimes->{{3.769017982034348*^9, 3.769017999297718*^9}, {
  3.7747839030230055`*^9, 3.774783903824005*^9}, {3.7754030926194506`*^9, 
  3.7754030997254505`*^9}},
 CellID->725389429,ExpressionUUID->"81f2e740-45b7-4e99-a8ae-603a6b4bca23"],

Cell[TextData[{
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " is ",
 ButtonBox["SortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/SortBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/SortBy.html"],
 " and then ",
 ButtonBox["Reverse",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Reverse.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Reverse.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747826734163666`*^9, 3.774875796231632*^9, {3.7754031063694506`*^9, 
   3.7754031122224503`*^9}},
 CellTags->"i:61",
 CellID->175348173,ExpressionUUID->"f9b9a923-565b-4906-9fb3-040a9f718ba5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ReverseSortBy", "[", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
    "\"\<zebra\>\"", ",", "\"\<yak\>\"", ",", "\"\<wombat\>\"", ",", 
     "\"\<stegosaurus\>\""}], "}"}], ",", "StringLength"}], "]"}]], "Input",
 CellChangeTimes->{{3.769018003531993*^9, 3.7690180115729027`*^9}},
 CellLabel->"In[115]:=",
 CellID->343496413,ExpressionUUID->"c907ed33-ada9-464d-8e13-b8a742be1d5e"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"stegosaurus\"\>", ",", "\<\"wombat\"\>", ",", "\<\"zebra\"\>", 
   ",", "\<\"yak\"\>"}], "}"}]], "Output",
 CellChangeTimes->{3.769018011990924*^9, 3.769075770601057*^9, 
  3.769100642212799*^9, 3.7691204849692907`*^9, 3.769772676107047*^9, 
  3.769975530843368*^9, 3.771923578877267*^9, 3.771929510469676*^9, 
  3.8814169756830997`*^9},
 CellLabel->"Out[115]=",
 CellID->1262001460,ExpressionUUID->"8273e1a4-408f-4b0f-a7cc-c0e2b634313c"]
}, Open  ]],

Cell["Both of these functions have frequently used operator forms.", "Text",
 CellChangeTimes->{{3.7690759325454273`*^9, 3.76907594178428*^9}},
 CellID->2135673558,ExpressionUUID->"5602ae1e-08d6-4ee5-97fc-00317fca5a8b"],

Cell[TextData[{
 "Operator forms of ",
 ButtonBox["SortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/SortBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/SortBy.html"],
 " and ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782683188344*^9, 3.7748757995206327`*^9, {3.7754031189234505`*^9, 
   3.77540312180245*^9}, {3.880557336968501*^9, 3.8805573489010897`*^9}},
 CellID->583362609,ExpressionUUID->"76153ad4-ce27-4d12-9cd1-80c9a02b3821"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"SortBy", "[", "StringLength", "]"}], "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<zebra\>\"", ",", "\"\<yak\>\"", ",", "\"\<wombat\>\"", ",", 
      "\"\<stegosaurus\>\""}], "}"}], "]"}], ",", 
   RowBox[{
    RowBox[{"ReverseSortBy", "[", "StringLength", "]"}], "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<zebra\>\"", ",", "\"\<yak\>\"", ",", "\"\<wombat\>\"", ",", 
      "\"\<stegosaurus\>\""}], "}"}], "]"}]}], "}"}]], "Input",
 CellChangeTimes->{{3.769075944129149*^9, 3.76907598049793*^9}},
 CellLabel->"In[116]:=",
 CellID->1226091640,ExpressionUUID->"8bd6e81a-dd45-4147-93fb-e87187a46288"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"\<\"yak\"\>", ",", "\<\"zebra\"\>", ",", "\<\"wombat\"\>", 
     ",", "\<\"stegosaurus\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"stegosaurus\"\>", ",", "\<\"wombat\"\>", 
     ",", "\<\"zebra\"\>", ",", "\<\"yak\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769075980771226*^9, 3.7691006422241907`*^9, 
  3.769120496413105*^9, 3.7697726761482067`*^9, 3.7699755308558617`*^9, 
  3.771923578890049*^9, 3.771929510479232*^9, 3.881416981916485*^9},
 CellLabel->"Out[116]=",
 CellID->1704892287,ExpressionUUID->"c6ced6ec-c707-4481-ac30-44f510c02c01"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["GatherBy",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/GatherBy.html?"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html?"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->437998704,ExpressionUUID->"1cb981e4-1b76-4f2b-9b50-3ad7e7bd5726"],

Cell[TextData[{
 "Another common operation is to collect elements of the data in different \
Lists depending on specific aspects of the data. Here\[CloseCurlyQuote]s an \
example that uses many features of the Wolfram Language described in this \
chapter. I write a function ",
 Cell[BoxData[
 "northernHemisphereQ"], "InlineCodeText",ExpressionUUID->
  "121f398d-9c0c-49dc-8791-1e6d8f2d0387"],
 " that yields ",
 ButtonBox["True",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/True.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/True.html"],
 " if the ",
 ButtonBox["Latitude",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Latitude.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Latitude.html"],
 " of its fourth element is greater than the ",
 ButtonBox["Latitude",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Latitude.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Latitude.html"],
 " of the equator. I then use ",
 Cell[BoxData[
  StyleBox["northernHemisphereQ", "InlineCode"]], "InlineCodeText",
  ExpressionUUID->"98a8f56a-906a-4919-90fe-021003deab74"],
 " to group the rows in ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "51a409f0-6eb7-40f8-809f-ba4c07c328a0"],
 "."
}], "Text",
 CellChangeTimes->{{3.76907598909383*^9, 3.769076052542626*^9}, {
   3.769076212946899*^9, 3.7690762471557693`*^9}, {3.769076342679532*^9, 
   3.769076377828761*^9}, {3.769076415578186*^9, 3.7690764736729393`*^9}, {
   3.769083413489135*^9, 3.7690834143938713`*^9}, 3.7747836962590055`*^9, {
   3.7754033151214504`*^9, 3.7754033382784505`*^9}, 3.7773530190790653`*^9, {
   3.856273036425679*^9, 3.8562730409344177`*^9}, {3.877695671628337*^9, 
   3.877695676569829*^9}, {3.888933357948516*^9, 3.888933370107565*^9}, {
   3.889693965849543*^9, 3.889693981854667*^9}},
 CellTags->"i:62",
 CellID->1563893249,ExpressionUUID->"ce2b1d0e-b312-4310-aa52-6ae6ad541d57"],

Cell["\<\
A function to figure out if a location is north of the equator:\
\>", "CodeCaption",
 CellChangeTimes->{3.7747826915341787`*^9, 3.774875802943632*^9},
 CellID->174040160,ExpressionUUID->"371127de-3786-4740-a323-e68eeaaf44a5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"northernHemisphereQ", "=", 
  RowBox[{"row", "\[Function]", 
   RowBox[{
    RowBox[{"Latitude", "[", 
     RowBox[{"row", "[", 
      RowBox[{"[", "4", "]"}], "]"}], "]"}], ">", 
    RowBox[{"Quantity", "[", 
     RowBox[{"0", ",", "\"\<AngularDegrees\>\""}], "]"}]}]}]}]], "Input",
 CellChangeTimes->{{3.769076386856485*^9, 3.769076405061565*^9}, {
  3.7690834169747477`*^9, 3.7690834174021273`*^9}},
 CellLabel->"In[117]:=",
 CellID->537849349,ExpressionUUID->"8ebe2038-0e26-4fcd-8251-4d619b34a6bc"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{"row", ",", 
   RowBox[{
    RowBox[{"Latitude", "[", 
     RowBox[{"row", "\[LeftDoubleBracket]", "4", "\[RightDoubleBracket]"}], 
     "]"}], ">", 
    TemplateBox[{"0", 
      RowBox[{"\[InvisibleSpace]", "\"\[Degree]\""}], "degrees", 
      "\"AngularDegrees\""},
     "QuantityPostfix"]}]}], "]"}]], "Output",
 CellChangeTimes->{3.769076485573505*^9, 3.769083418040559*^9, 
  3.769100642259508*^9, 3.769772676161943*^9, 3.769975530898507*^9, 
  3.7719235789251623`*^9, 3.77192951051694*^9, 3.8814169868380747`*^9},
 CellLabel->"Out[117]=",
 CellID->1774813756,ExpressionUUID->"95caad6a-e1c4-424a-ad17-80e478d53b24"]
}, Open  ]],

Cell[TextData[{
 "Use ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " to encapsulate data in Lists depending on the value of a function applied \
to that data:"
}], "CodeCaption",
 CellChangeTimes->{{3.769180985054384*^9, 3.769180998037962*^9}, 
   3.7747827040084257`*^9, 3.7748758054796324`*^9, 3.7754034845644503`*^9},
 CellID->1771601541,ExpressionUUID->"268f58ee-af94-4cae-b664-b95b069b576e"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gathered", "=", 
  RowBox[{"GatherBy", "[", 
   RowBox[{"nestedList", ",", "northernHemisphereQ"}], "]"}]}]], "Input",
 CellChangeTimes->{{3.769076054457592*^9, 3.769076073825307*^9}, {
   3.76907616821768*^9, 3.769076194674614*^9}, {3.769076249929976*^9, 
   3.769076333253064*^9}, 3.76907641171461*^9, {3.769076477499072*^9, 
   3.769076497601734*^9}},
 CellLabel->"In[118]:=",
 CellID->1406754689,ExpressionUUID->"40b85976-74d4-4ce7-989d-79036d5e7beb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
        "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
       ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
        "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "43"}], ",", 
          RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
        "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "22"}], ",", 
          RowBox[{"-", "40"}]}], "}"}], "]"}], 
       ",", "\<\"Oliver Ellsworth\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
        "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"17", ",", "78"}], "}"}], "]"}], 
       ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
        "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{"14", ",", "64"}], "}"}], "]"}], 
       ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.769076195138978*^9, {3.769076250333447*^9, 3.769076270014121*^9}, {
   3.769076302439139*^9, 3.769076324685343*^9}, 3.769076493499564*^9, 
   3.769076534207285*^9, 3.7690823350659237`*^9, {3.769083403951373*^9, 
   3.76908341968569*^9}, 3.76910064227663*^9, 3.7697726762116756`*^9, 
   3.7699755309191217`*^9, 3.771923578950551*^9, 3.771929510533719*^9, 
   3.881416992707369*^9},
 CellLabel->"Out[118]=",
 CellID->2015535995,ExpressionUUID->"f9460b68-8db0-429c-a8c4-a543f2f499e2"]
}, Open  ]],

Cell[TextData[{
 "The symbol ",
 Cell[BoxData[
 "gathered"], "InlineCodeText",ExpressionUUID->
  "71c9e3c8-2d31-48e9-9074-1ff13f09344b"],
 " now holds a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists of Lists. If I now look at the first part of ",
 Cell[BoxData[
 "gathered"], "InlineCodeText",ExpressionUUID->
  "f81be40f-9839-45ef-a4b8-378b51dca6db"],
 " (a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists), I see all the points are in the Southern Hemisphere."
}], "Text",
 CellChangeTimes->{{3.769076506640695*^9, 3.769076555671204*^9}, {
  3.769076965888608*^9, 3.7690769853085947`*^9}, {3.7754038618184505`*^9, 
  3.7754038710914507`*^9}, {3.856273099488278*^9, 3.856273100410843*^9}, {
  3.8776958230265017`*^9, 3.8776958341209517`*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1650910852,ExpressionUUID->"7a8f1bbc-14c3-47b9-ba0b-2145f07bdc4e"],

Cell[TextData[{
 "Look at the first part of ",
 Cell[BoxData[
 "gathered"], "InlineCode",ExpressionUUID->
  "23cab02f-19b1-4bdd-ba3b-307117986a40"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7754038890464506`*^9, 3.7754038990184507`*^9}},
 CellTags->"p: 42",
 CellID->75047153,ExpressionUUID->"cf5bacb6-c1b4-4de9-9408-3059f6fdfd32"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gathered", "[", 
  RowBox[{"[", "1", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769076528158141*^9, 3.769076530115581*^9}},
 CellLabel->"In[119]:=",
 CellID->478816448,ExpressionUUID->"f0e5b446-3a7e-45ef-85f7-3447c90173f9"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
     ",", "\<\"Thurgood Marshall\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
    "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], 
     ",", "\<\"Oliver Ellsworth\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.76907653065865*^9, 3.769076536879983*^9}, 
   3.769082337284748*^9, 3.7690834229158907`*^9, 3.7691006423196917`*^9, 
   3.7697726762323008`*^9, 3.76997553097058*^9, 3.771923578993658*^9, 
   3.771929510575788*^9, 3.881416997687787*^9},
 CellLabel->"Out[119]=",
 CellID->1927714207,ExpressionUUID->"c8cc5417-64e8-4cc4-a180-d2576eed8860"]
}, Open  ]],

Cell[TextData[{
 "The second part of ",
 StyleBox["gathered", "InlineCodeText"],
 " has points in only the Northern Hemisphere."
}], "Text",
 CellChangeTimes->{{3.7690765580832043`*^9, 3.769076579944826*^9}, {
  3.77540390609245*^9, 3.7754039206794505`*^9}},
 CellID->281379911,ExpressionUUID->"2470cdeb-221a-44d3-b670-5bdd387efea8"],

Cell[TextData[{
 "Look at the second part of ",
 Cell[BoxData[
 "gathered"], "InlineCode",ExpressionUUID->
  "d26e0e06-c567-4207-979d-92a66d648889"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7754039251794505`*^9, 3.7754039346554503`*^9}},
 CellID->51868181,ExpressionUUID->"cae44e65-9ee6-4890-8e6d-928d27a743df"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"gathered", "[", 
  RowBox[{"[", "2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769076528158141*^9, 3.769076530115581*^9}, {
  3.76907658196033*^9, 3.769076583882259*^9}},
 CellLabel->"In[120]:=",
 CellID->1416096887,ExpressionUUID->"292a47b0-4f58-4bbe-899c-270cb7cd2dcb"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769076584375681*^9, 3.769082338738943*^9, 
  3.769083425325161*^9, 3.769100642334476*^9, 3.7697726762781887`*^9, 
  3.7699755309882727`*^9, 3.7719235790113173`*^9, 3.771929510589466*^9, 
  3.881417004840165*^9},
 CellLabel->"Out[120]=",
 CellID->1031174353,ExpressionUUID->"869ca331-5dad-479a-b8ad-f45fa36e0541"]
}, Open  ]],

Cell[TextData[{
 "One can ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " recursively. Here I first break down the data by whether the last value in \
the row is in the Northern Hemisphere. Then I break it down by whether the \
second number in the row is even. What we now see is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists of Lists of Lists!"
}], "Text",
 CellChangeTimes->{{3.769089007539452*^9, 3.7690890952586527`*^9}, {
   3.769120561471603*^9, 3.769120603351365*^9}, 3.7754040015114503`*^9, 
   3.777353088569934*^9, {3.856538340399128*^9, 3.856538342840839*^9}, {
   3.877695858076345*^9, 3.877695873941749*^9}, 3.8855551467966695`*^9},
 CellID->1408211335,ExpressionUUID->"978c6016-0fc4-4e04-a882-c36f0637c779"],

Cell[TextData[{
 "Use ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " with a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of functions to recursively break down data:"
}], "CodeCaption",
 CellChangeTimes->{3.7747827243194566`*^9, 3.7748758105666323`*^9, 
  3.7754040187584505`*^9, 3.877695882765592*^9},
 CellID->78898118,ExpressionUUID->"8c1268b5-61e1-46a2-9835-4a2e49ebdd73"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"evenQ2", "=", 
  RowBox[{"Function", "[", 
   RowBox[{"row", ",", 
    RowBox[{"EvenQ", "[", 
     RowBox[{"row", "[", 
      RowBox[{"[", "2", "]"}], "]"}], "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.769174748775984*^9, 3.769174761921308*^9}},
 CellLabel->"In[121]:=",
 CellID->447096387,ExpressionUUID->"a4a77e58-ff87-4b5e-b7f2-43a90e24978e"],

Cell[BoxData[
 RowBox[{"Function", "[", 
  RowBox[{"row", ",", 
   RowBox[{"EvenQ", "[", 
    RowBox[{"row", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}], 
    "]"}]}], "]"}]], "Output",
 CellChangeTimes->{3.7691747624148273`*^9, 3.769772676294541*^9, 
  3.7699755310337887`*^9, 3.771923579047955*^9, 3.7719295106005573`*^9, 
  3.8814170096902533`*^9},
 CellLabel->"Out[121]=",
 CellID->510714406,ExpressionUUID->"54eb72af-ccc5-4f3d-8947-6732c7704d23"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GatherBy", "[", 
  RowBox[{"nestedList", ",", 
   RowBox[{"{", 
    RowBox[{"northernHemisphereQ", ",", "evenQ2"}], "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769089059055801*^9, 3.769089071809554*^9}, {
  3.769174764335206*^9, 3.769174767964044*^9}, {3.769174866389717*^9, 
  3.769174873490604*^9}},
 CellLabel->"In[122]:=",
 CellID->1188914369,ExpressionUUID->"34977c1a-0824-40b2-849d-3fa4f6005460"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TemplateBox[<|
         "color" -> RGBColor[
           0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
         "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
        ",", "\<\"Thurgood Marshall\"\>"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         TemplateBox[<|
          "color" -> RGBColor[
            0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
          "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
         RowBox[{"GeoPosition", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "43"}], ",", 
            RowBox[{"-", "113"}]}], "}"}], "]"}], 
         ",", "\<\"Elena Kagan\"\>"}], "}"}], ",", 
       RowBox[{"{", 
        RowBox[{
         TemplateBox[<|
          "color" -> RGBColor[
            0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
          "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
         RowBox[{"GeoPosition", "[", 
          RowBox[{"{", 
           RowBox[{
            RowBox[{"-", "22"}], ",", 
            RowBox[{"-", "40"}]}], "}"}], "]"}], 
         ",", "\<\"Oliver Ellsworth\"\>"}], "}"}]}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TemplateBox[<|
         "color" -> RGBColor[
           0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
         "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{"17", ",", "78"}], "}"}], "]"}], 
        ",", "\<\"William Rehnquist\"\>"}], "}"}], "}"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", 
       RowBox[{
        TemplateBox[<|
         "color" -> RGBColor[
           0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
         "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{"14", ",", "64"}], "}"}], "]"}], 
        ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}], "}"}]}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.7690890721375628`*^9, 3.769100642376967*^9, 3.769174768634845*^9, {
   3.769174869989196*^9, 3.769174873954238*^9}, 3.769772676337297*^9, 
   3.769975531048554*^9, 3.771923579063891*^9, 3.7719295106355963`*^9, 
   3.881417013408429*^9},
 CellLabel->"Out[122]=",
 CellID->634098257,ExpressionUUID->"75097af5-8da5-46a1-b346-92e95438262e"]
}, Open  ]],

Cell[TextData[{
 "Notice that this is different than a ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " in which I compute the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     RowBox[{"northernHemisphereQ", "[", 
      ButtonBox[
       StyleBox["#",
        FontColor->GrayLevel[0]],
       BaseStyle->"Hyperlink",
       ButtonData->{
         URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
       ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"], 
      "]"}], ",", 
     RowBox[{
      ButtonBox[
       StyleBox["EvenQ",
        FontColor->GrayLevel[0]],
       BaseStyle->"Hyperlink",
       ButtonData->{
         URL["https://reference.wolfram.com/language/ref/EvenQ.html"], None},
       ButtonNote->"https://reference.wolfram.com/language/ref/EvenQ.html"], 
      "[", 
      ButtonBox[
       StyleBox["#",
        FontColor->GrayLevel[0]],
       BaseStyle->"Hyperlink",
       ButtonData->{
         URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
       ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"], 
      "]"}]}], "}"}], 
   ButtonBox[
    StyleBox["&",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Function.html"], None},
    ButtonNote->
     "https://reference.wolfram.com/language/ref/Function.html"]}]], 
  "InlineCodeText",ExpressionUUID->"544aece2-f847-4910-87c1-bdfb2a1340d5"],
 " for each row. In this latter case, I separate the data into categories \
based on the value of a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " whose first value determines whether the row\[CloseCurlyQuote]s fourth \
element represents a location in the Northern Hemisphere and whose second \
value determines whether the row\[CloseCurlyQuote]s second element is even. \
There are thus four possibilities."
}], "Text",
 CellChangeTimes->{{3.7691745985519133`*^9, 3.7691747267123947`*^9}, {
   3.7691747981263037`*^9, 3.769174890686453*^9}, {3.7754041157554502`*^9, 
   3.7754041260574503`*^9}, 3.877695905181119*^9, {3.877695946133765*^9, 
   3.877695960659724*^9}, 3.877696131797935*^9},
 CellID->1789701143,ExpressionUUID->"7ca927c0-888a-4717-b4fd-6c82a98f3491"],

Cell[TextData[{
 "Use a function that generates a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " to do more complex breakdowns of data:"
}], "CodeCaption",
 CellChangeTimes->{3.7747827339194164`*^9, 3.7748758133506327`*^9, 
  3.7754041572144504`*^9, 3.8776961503500443`*^9},
 CellID->21305542,ExpressionUUID->"728d5006-15c3-4e00-b889-d68af00b75b8"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"GatherBy", "[", 
  RowBox[{"nestedList", ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"northernHemisphereQ", "[", "#", "]"}], ",", 
      RowBox[{"evenQ2", "[", "#", "]"}]}], "}"}], "&"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769089059055801*^9, 3.769089071809554*^9}, {
  3.769174619971282*^9, 3.769174635359621*^9}, {3.76917480519799*^9, 
  3.7691748069109*^9}, {3.7691748611219893`*^9, 3.769174877323587*^9}},
 CellLabel->"In[123]:=",
 CellID->483942409,ExpressionUUID->"fe1b1122-744c-42b7-afb7-810737133a5d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      TemplateBox[<|
       "color" -> RGBColor[
         0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
       "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{
         RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], 
      ",", "\<\"Thurgood Marshall\"\>"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
        "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "43"}], ",", 
          RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\<\"Elena Kagan\"\>"}], 
      "}"}], ",", 
     RowBox[{"{", 
      RowBox[{
       TemplateBox[<|
        "color" -> RGBColor[
          0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
        "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
       RowBox[{"GeoPosition", "[", 
        RowBox[{"{", 
         RowBox[{
          RowBox[{"-", "22"}], ",", 
          RowBox[{"-", "40"}]}], "}"}], "]"}], 
       ",", "\<\"Oliver Ellsworth\"\>"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      TemplateBox[<|
       "color" -> RGBColor[
         0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
       "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{"17", ",", "78"}], "}"}], "]"}], 
      ",", "\<\"William Rehnquist\"\>"}], "}"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"{", 
     RowBox[{
      TemplateBox[<|
       "color" -> RGBColor[
         0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
       "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
      RowBox[{"GeoPosition", "[", 
       RowBox[{"{", 
        RowBox[{"14", ",", "64"}], "}"}], "]"}], 
      ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}], "}"}]}], 
  "}"}]], "Output",
 CellChangeTimes->{
  3.769174636375136*^9, 3.7691748075331993`*^9, {3.769174863500305*^9, 
   3.76917487785883*^9}, 3.769772676359231*^9, 3.769975531101759*^9, 
   3.77192357910951*^9, 3.771929510677026*^9, 3.881417020578259*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[123]=",
 CellID->1683184762,ExpressionUUID->"325b814e-35be-4212-b9f9-c9d3e1f43e72"]
}, Open  ]],

Cell[TextData[{
 "There are two matters to keep in mind with respect to ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 ". First, as of Version 13, there\[CloseCurlyQuote]s no operator form of ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 ". Second, ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " has a powerful cousin, ",
 ButtonBox["GroupBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GroupBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GroupBy.html"],
 ", that you will meet in a subsequent chapter after I have introduced ",
 ButtonBox["Association",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Association.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Association.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.7690766694147463`*^9, 3.769076763562354*^9}, {
   3.769120636447509*^9, 3.769120647457728*^9}, 3.769160738788726*^9, {
   3.7747839067280054`*^9, 3.774783907568005*^9}, {3.7754042264609585`*^9, 
   3.7754042477343388`*^9}, {3.777353135566923*^9, 3.777353140106476*^9}, {
   3.865544686428843*^9, 3.865544686498426*^9}, {3.8855698005001326`*^9, 
   3.8855698119124207`*^9}},
 CellTags->"p: 43",
 CellID->988630503,ExpressionUUID->"ea50a8e1-1e14-4182-b104-8626a1da9b94"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Select",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Select.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->803122163,ExpressionUUID->"3e69a535-ebf6-46de-9130-a55e10fd991f"],

Cell[TextData[{
 "Often, one wants to just filter data: some one wants to keep and some one \
wants to discard. There are several functions to accomplish this in the \
Wolfram Language. Here I will present the ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " function. It\[CloseCurlyQuote]s another functional construct. One writes \
the data to be filtered as the first argument and a function that yields a ",
 ButtonBox["True",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/True.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/True.html"],
 " or ",
 ButtonBox["False",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/False.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/False.html"],
 " (Boolean) value as the second argument. Here I select just those rows in ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "72125a76-37fa-46df-8792-20e4474b478b"],
 " that are in the Northern Hemisphere."
}], "Text",
 CellChangeTimes->{{3.769076860612967*^9, 3.769076950021936*^9}, {
   3.769076996181817*^9, 3.769077036664645*^9}, {3.769120672065901*^9, 
   3.769120684290082*^9}, 3.769160749562455*^9, {3.7754048355928507`*^9, 
   3.775404842775569*^9}, {3.7754048824455357`*^9, 3.7754048930385947`*^9}, {
   3.8562731164991827`*^9, 3.856273121482161*^9}, {3.877696218577611*^9, 
   3.8776962225986*^9}, {3.8855551520237203`*^9, 3.8855551583720846`*^9}, {
   3.8855699589908295`*^9, 3.885569972767503*^9}},
 CellTags->"i:63",
 CellID->874784024,ExpressionUUID->"9955ac2c-82ce-4bde-b456-88e5165afda7"],

Cell[TextData[{
 "A canonical example of ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " to filter data:"
}], "CodeCaption",
 CellChangeTimes->{3.774782743415366*^9, 3.7748758159026327`*^9, 
  3.7754049182551165`*^9},
 CellID->191784724,ExpressionUUID->"fb9b0e52-11bc-47d1-9dcf-2bf7a15e274b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Select", "[", 
  RowBox[{"nestedList", ",", "northernHemisphereQ"}], "]"}]], "Input",
 CellChangeTimes->{{3.76907739616387*^9, 3.769077410134212*^9}},
 CellLabel->"In[124]:=",
 CellID->1207445190,ExpressionUUID->"414bb4d5-9f7f-4140-82dc-f8a3ab0f9ec1"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769077410560191*^9, 3.769082341777141*^9, 
  3.769083428776188*^9, 3.769100642395029*^9, 3.769772676407895*^9, 
  3.7699755311225243`*^9, 3.771923579129759*^9, 3.77192951069398*^9, 
  3.881417028290669*^9},
 CellLabel->"Out[124]=",
 CellID->869259118,ExpressionUUID->"2a7506dc-3416-4ced-b597-f618d949fc34"]
}, Open  ]],

Cell[TextData[{
 "There\[CloseCurlyQuote]s an operator form of ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " that takes the selection function as its only argument."
}], "Text",
 CellChangeTimes->{{3.769077413886714*^9, 3.76907744764316*^9}, {
   3.774783910502005*^9, 3.7747839112470055`*^9}, 3.775404925560847*^9},
 CellID->1719925492,ExpressionUUID->"5b51faf6-7507-4c49-b0ee-4a4d73f4e50d"],

Cell[TextData[{
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " has an operator form:"
}], "CodeCaption",
 CellChangeTimes->{3.774782752927317*^9, 3.774875818422632*^9, 
  3.775404942460537*^9},
 CellID->264107795,ExpressionUUID->"1579c861-f514-4681-bf71-7459dee3e2f4"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Select", "[", "northernHemisphereQ", "]"}], "[", "nestedList", 
  "]"}]], "Input",
 CellChangeTimes->{{3.769077449399468*^9, 3.769077458588985*^9}},
 CellLabel->"In[125]:=",
 CellID->689310341,ExpressionUUID->"5a0dd856-8e05-48c0-a515-e10d43811138"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], 
     ",", "\<\"William Rehnquist\"\>"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690774552796164`*^9, 3.769077459340124*^9}, 
   3.769082343183325*^9, 3.769083431468377*^9, 3.7691006424361258`*^9, 
   3.769772676423938*^9, 3.769975531169668*^9, 3.7719235791697273`*^9, 
   3.7719295107304068`*^9, 3.8814170356654367`*^9},
 CellLabel->"Out[125]=",
 CellID->1991491309,ExpressionUUID->"53e27708-1d7d-47a2-9384-4c89c7e24db7"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[StyleBox[ButtonBox["Transpose",
 BaseStyle->"Hyperlink",
 ButtonData->{
   URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
 ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 FontColor->RGBColor[
  0.9019607843137255, 0.4117647058823529, 
   0.027450980392156862`]]], "Subsubsection",
 CellChangeTimes->{{3.7690111280081053`*^9, 3.769011131277317*^9}, 
   3.8896930692433825`*^9, {3.893768096544052*^9, 3.893768123256897*^9}},
 CellID->888505878,ExpressionUUID->"5e21b9c3-aea2-46e2-b807-1ee39b995ae4"],

Cell[TextData[{
 "All of the functions in this section can be used on Lists of Lists or even \
more deeply nested constructs. There is one function, however, that I find \
particularly salient in data analysis, ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 ". The idea is to take a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists data structure in which each inner ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " has the same number of elements (the ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "192ee7ec-6cd2-4e74-805e-3374120dc4ae"],
 " I\[CloseCurlyQuote]ve been using here is an example) and then \
\[OpenCurlyDoubleQuote]flip\[CloseCurlyDoubleQuote] the data so that the rows \
become columns and the columns become rows."
}], "Text",
 CellChangeTimes->{{3.769077548405484*^9, 3.769077670133374*^9}, {
   3.7754049570709977`*^9, 3.775404961167407*^9}, {3.775405048813171*^9, 
   3.775405067678057*^9}, 3.8805574044935217`*^9, {3.885468023238064*^9, 
   3.885468025807787*^9}, {3.8896940055004835`*^9, 3.889694010560895*^9}},
 CellTags->"i:64",
 CellID->647260802,ExpressionUUID->"06583cdc-b3b4-421a-a0c5-a149cc37a160"],

Cell[TextData[{
 "Use ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 " to flip rows and columns of matrix-like data:"
}], "CodeCaption",
 CellChangeTimes->{3.7747827628243065`*^9, 3.7748758217746325`*^9, 
  3.7754050871240015`*^9},
 CellID->90032010,ExpressionUUID->"8a05cfe5-9a49-4fdf-b055-c1575907aff9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Transpose", "[", "nestedList", "]"}]], "Input",
 CellChangeTimes->{{3.769077672395094*^9, 3.769077678268066*^9}},
 CellLabel->"In[126]:=",
 CellID->446525748,ExpressionUUID->"352607ca-5e8d-45b2-94d9-4b8693cd6bde"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", 
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2", ",", "4", ",", "4", ",", "9"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"0.08`", ",", "0.83`", ",", "0.07`", ",", "0.35`", ",", "0.87`"}],
     "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"\<\"Thurgood Marshall\"\>", ",", "\<\"Elena Kagan\"\>", 
     ",", "\<\"Oliver Ellsworth\"\>", ",", "\<\"William Rehnquist\"\>", 
     ",", "\<\"Oliver Wendell Holmes, Jr.\"\>"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769077678768961*^9, 3.769082345910643*^9, 
  3.769083435441058*^9, 3.769100642451832*^9, 3.7697726764694223`*^9, 
  3.769975531187355*^9, 3.771923579189918*^9, 3.7719295107450857`*^9, 
  3.88141704129186*^9},
 CellLabel->"Out[126]=",
 CellID->398473053,ExpressionUUID->"8a9d53c0-cadb-4a93-af00-901d79ef71a9"]
}, Open  ]],

Cell[TextData[{
 "Now instead of the first column being a bunch of colors, the first row is a \
",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of colors, and instead of the fifth column being a bunch of United States \
Supreme Court justices, now the fifth row is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of those justices."
}], "Text",
 CellChangeTimes->{{3.769120718728614*^9, 3.769120790647831*^9}, {
  3.7754051192782164`*^9, 3.7754051276390524`*^9}, {3.8776966111419086`*^9, 
  3.8776966247710543`*^9}},
 CellID->2042694667,ExpressionUUID->"11c8cac4-571f-4069-b989-90a990d93123"],

Cell[TextData[{
 "Transposing is useful for many reasons, but exploitation of implicit \
Listability is the one on which I want to focus here. Code often runs faster \
if, instead of Mapping a function over some ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of values element by element, one instead calls a ",
 ButtonBox["Listable",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Listable.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Listable.html"],
 " function once, then executes it on a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of values. This is particularly important where the function in question \
has to make calls to internet resources, such as the ",
 ButtonBox["Wolfram Cloud",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://www.wolframcloud.com/"], None},
  ButtonNote->"https://www.wolframcloud.com/"],
 ", or where it would otherwise take time to load. Here\[CloseCurlyQuote]s an \
example in which I generate 20 random dates and represent them as strings. I \
postfix the ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " ",
 ButtonBox["Terse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
Terse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/Terse"],
 " after the assignment to spare us needless detail (and save paper). ",
 ButtonBox["Terse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
Terse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/Terse"],
 " is essentially an operator form of ",
 ButtonBox["Short",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Short.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Short.html"],
 ". The number and structure of elided elements when using functions like ",
 ButtonBox["Short",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Short.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Short.html"],
 " and ResourceFunctions like ",
 ButtonBox["Terse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
Terse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/Terse"],
 " and ",
 ButtonBox["AugmentedTerse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"],
 " will depend on the operating system and details of the Wolfram Language \
front end you are using. Do not be troubled if your output when using these \
functions varies slightly from what is shown in the book."
}], "Text",
 CellTags->{"LastCellOfAPage", "i:65", "p: 44"},
 CellID->1190543782,ExpressionUUID->"d3da8d07-5627-4657-a338-310452796ea8"],

Cell[TextData[{
 "After using ",
 ButtonBox["SeedRandom",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/SeedRandom.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/SeedRandom.html"],
 ", use ",
 ButtonBox["RandomDate",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RandomDate.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/RandomDate.html"],
 " to create 20 dates from 1999 and convert them to strings using ",
 ButtonBox["DateString",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateString.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateString.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782777169741*^9, 3.7748758256636324`*^9, {3.881406168687331*^9, 
   3.881406193045494*^9}, {3.881407555238449*^9, 3.881407591038671*^9}, {
   3.885395368981901*^9, 3.8853953693918147`*^9}, 3.885572014723482*^9},
 CellID->491201136,ExpressionUUID->"5c07beb4-435d-4cec-9c41-0ac4377b73b3"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"randomDates", "=", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"SeedRandom", "[", "20221230", "]"}], ";", 
      RowBox[{"Map", "[", 
       RowBox[{
        RowBox[{
         RowBox[{"DateString", "[", 
          RowBox[{"#", ",", 
           RowBox[{"{", 
            RowBox[{
            "\"\<Year\>\"", ",", "\"\</\>\"", ",", "\"\<Month\>\"", ",", 
             "\"\</\>\"", ",", "\"\<Day\>\""}], "}"}]}], "]"}], "&"}], ",", 
        RowBox[{"RandomDate", "[", 
         RowBox[{
          RowBox[{"DateObject", "[", 
           RowBox[{
            RowBox[{"{", "1999", "}"}], ",", "\"\<Year\>\""}], "]"}], ",", 
          "20"}], "]"}]}], "]"}]}], ")"}]}], ")"}], "//", 
  RowBox[{
   InterpretationBox[
    TagBox[
     TagBox[
      DynamicModuleBox[{Typeset`open = False}, 
       FrameBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[GridBox[{
               {
                StyleBox[
                 StyleBox[
                  AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                   BoxBaselineShift->-0.25,
                   BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                  
                  FontColor->RGBColor[
                   0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                 ShowStringCharacters->False,
                 FontFamily->"Source Sans Pro Black",
                 FontSize->0.6538461538461539 Inherited,
                 FontWeight->"Heavy",
                 PrivateFontOptions->{"OperatorSubstitution"->False}], 
                StyleBox[
                 RowBox[{
                  StyleBox["Terse", "ResourceFunctionLabel"], " "}],
                 ShowAutoStyles->False,
                 ShowStringCharacters->False,
                 FontSize->Rational[12, 13] Inherited,
                 FontColor->GrayLevel[0.1]]}
              },
              GridBoxSpacings->{"Columns" -> {{0.25}}}],
             Alignment->Left,
             BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
             BaselinePosition->Baseline,
             FrameMargins->{{3, 0}, {0, 0}}], 
            ItemBox[
             PaneBox[
              TogglerBox[Dynamic[Typeset`open], {True->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeCloser"],
                ImageSizeCache->{11., {2., 9.}}], False->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeOpener"],
                ImageSizeCache->{11., {2., 9.}}]},
               Appearance->None,
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{1, 1}, {0, 0}}],
             Frame->{{
                RGBColor[
                0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                 0.5], False}, {False, False}}]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
         GridBox[{
           {GridBox[{
              {
               PaneBox[GridBox[{
                  {
                   StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                   StyleBox[
                    RowBox[{
                    StyleBox["Terse", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                 },
                 GridBoxSpacings->{"Columns" -> {{0.25}}}],
                Alignment->Left,
                BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                BaselinePosition->Baseline,
                FrameMargins->{{3, 0}, {0, 0}}], 
               ItemBox[
                PaneBox[
                 TogglerBox[Dynamic[Typeset`open], {True->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeCloser"]], False->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeOpener"]]},
                  Appearance->None,
                  BaselinePosition->Baseline,
                  ContentPadding->False,
                  FrameMargins->0],
                 Alignment->Left,
                 BaselinePosition->Baseline,
                 FrameMargins->{{1, 1}, {0, 0}}],
                Frame->{{
                   RGBColor[
                   0.8313725490196079, 0.8470588235294118, 0.8509803921568627,
                     0.5], False}, {False, False}}]}
             },
             BaselinePosition->{1, 1},
             GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
           {
            StyleBox[
             PaneBox[GridBox[{
                {
                 RowBox[{
                  TagBox["\<\"Version (latest): \"\>",
                   "IconizedLabel"], " ", 
                  TagBox["\<\"1.0.0\"\>",
                   "IconizedItem"]}]},
                {
                 TagBox[
                  
                  TemplateBox[{
                   "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/6809487c-44ed-4a55-a610-ab706ebb8661/"},
                   "HyperlinkURL"],
                  "IconizedItem"]}
               },
               DefaultBaseStyle->"Column",
               GridBoxAlignment->{"Columns" -> {{Left}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
             FontFamily->"Roboto",
             FontSize->11]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
               GrayLevel[0.8]}, False}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open],
         BaselinePosition->Baseline,
         ImageSize->Automatic],
        Background->RGBColor[
         0.9686274509803922, 0.9764705882352941, 0.984313725490196],
        BaselinePosition->Baseline,
        DefaultBaseStyle->{},
        FrameMargins->{{0, 0}, {1, 0}},
        FrameStyle->RGBColor[
         0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
        RoundingRadius->4]],
      #& ,
      TagBoxNote->" "],
     {"FunctionResourceBox", 
      RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
      "Terse"},
     TagBoxNote->"FunctionResourceBox"],
    ResourceFunction[
     ResourceObject[<|
      "Name" -> "Terse", "ShortName" -> "Terse", "UUID" -> 
       "6809487c-44ed-4a55-a610-ab706ebb8661", "ResourceType" -> "Function", 
       "Version" -> "1.0.0", "Description" -> "An operator form of Short", 
       "RepositoryLocation" -> 
       URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
       "SymbolName" -> 
       "FunctionRepository`$369a78f89aa2413eb5b19a962ce89cd7`Terse", 
       "FunctionLocation" -> 
       CloudObject[
        "https://www.wolframcloud.com/obj/c1820918-b759-4685-b9b8-\
c971a81216b5"]|>, ResourceSystemBase -> Automatic]],
    Selectable->False], "[", "3", "]"}]}]], "Input",
 CellChangeTimes->{{3.881405753102029*^9, 3.881405780243174*^9}, {
  3.881406073940282*^9, 3.881406075482891*^9}, {3.8814061076640053`*^9, 
  3.881406110577074*^9}, {3.881407593951606*^9, 3.881407606066937*^9}},
 CellLabel->"In[127]:=",
 CellID->8373282,ExpressionUUID->"622e66e1-da85-4154-b0fc-43b198e8fc38"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{"\<\"1999/10/24\"\>", ",", "\<\"1999/07/03\"\>", 
    ",", "\<\"1999/11/25\"\>", ",", "\<\"1999/01/25\"\>", ",", 
    RowBox[{"\[LeftSkeleton]", "12", "\[RightSkeleton]"}], 
    ",", "\<\"1999/07/24\"\>", ",", "\<\"1999/04/16\"\>", 
    ",", "\<\"1999/12/29\"\>", ",", "\<\"1999/03/17\"\>"}], "}"}],
  Short[#, 3]& ]], "Output",
 CellChangeTimes->{{3.881406054504631*^9, 3.881406076231001*^9}, 
   3.881406116966045*^9, 3.8814076102098427`*^9, 3.881417047722466*^9},
 CellLabel->"Out[127]//Short=",
 CellID->1284417596,ExpressionUUID->"44b1705d-8130-4ad1-901f-27ffd5712e34"]
}, Open  ]],

Cell[TextData[{
 "Now I ask the Wolfram Language interpreter, which through Version 13 makes \
use of Wolfram servers to do its work, to convert each of these dates to a ",
 ButtonBox["DateObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateObject.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateObject.html"],
 " on which computation can be easily done. I apply ",
 ButtonBox["EchoTiming",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/EchoTiming.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/EchoTiming.html"],
 " to get information on how long it takes; I use the ",
 ButtonBox["//",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Postfix.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Postfix.html"],
 " postfix \[OpenCurlyDoubleQuote]afterthought\[CloseCurlyDoubleQuote] \
operator to do so."
}], "Text",
 CellChangeTimes->{3.9025001287129774`*^9},
 CellTags->"i:66",
 CellID->232582819,ExpressionUUID->"75826578-da33-406c-bf0f-39507bbe0c9e"],

Cell[TextData[{
 "Mapping ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " over data can take a long time in ",
 "Version 13.2:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782786777702*^9, 3.7748758279416323`*^9, 3.7754073743894405`*^9, 
   3.877696796453154*^9, {3.881406132786504*^9, 3.881406133177807*^9}},
 CellID->416203485,ExpressionUUID->"d11895cd-876c-4181-9230-aeef0ebb2786"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Map", "[", 
   RowBox[{
    RowBox[{"Interpreter", "[", "\"\<Date\>\"", "]"}], ",", "randomDates"}], 
   "]"}], "//", "EchoTiming"}]], "Input",
 CellChangeTimes->{{3.769078171543002*^9, 3.769078182637906*^9}, {
  3.7690782192191343`*^9, 3.7690782234864693`*^9}, {3.769078289593169*^9, 
  3.769078291129629*^9}, {3.769081404810358*^9, 3.769081409854679*^9}, {
  3.769769031187224*^9, 3.769769038291222*^9}, {3.877696805465056*^9, 
  3.877696830579179*^9}, {3.898869054475355*^9, 3.8988690607464542`*^9}},
 CellLabel->"In[4]:=",
 CellID->412705545,ExpressionUUID->"089a2230-a213-49b2-b476-b1660dab470e"],

Cell[BoxData["7.478259`"], "EchoTiming",
 CellChangeTimes->{3.898869094078703*^9},
 CellID->2010412335,ExpressionUUID->"1c084def-5997-4669-9181-2b357b7b6a4f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{
     RowBox[{"\"Sun 24 Oct 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "10", ",", "24"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 3 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 25 Nov 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "11", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 25 Jan 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "1", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 9 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "9"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 3 May 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "5", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Tue 21 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "21"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 25 Feb 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "2", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 12 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "12"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 3 May 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "5", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Fri 17 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "17"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 6 Feb 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "2", ",", "6"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 10 Mar 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "3", ",", "10"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Tue 7 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "7"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 18 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "18"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 3 Jun 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "6", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 24 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "24"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Fri 16 Apr 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "4", ",", "16"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 29 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "29"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 17 Mar 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "3", ",", "17"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{{3.769078216975979*^9, 3.769078225032584*^9}, 
   3.769078298596465*^9, 3.769081454566571*^9, 3.7691006499179487`*^9, 
   3.769772682455649*^9, 3.769975538282745*^9, 3.771923588505928*^9, 
   3.771929519586173*^9, 3.880627072883603*^9, {3.881406068250834*^9, 
   3.8814060806565123`*^9}, 3.8814061266608458`*^9, 3.8814076208942223`*^9, 
   3.881417067205765*^9, {3.898869076924259*^9, 3.898869094105686*^9}},
 CellLabel->"Out[4]=",
 CellID->492412447,ExpressionUUID->"7297c1ac-798d-4c11-8b7f-89ccbf006ad0"]
}, Open  ]],

Cell[TextData[{
 "Now I take advantage of the implicit Listability of ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " and instead call the function once, applying it to the entire ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of dates."
}], "Text",
 CellChangeTimes->{{3.7690782284652348`*^9, 3.769078257286005*^9}, 
   3.769078395907193*^9, {3.769160897020002*^9, 3.769160903599997*^9}, 
   3.7754076465754404`*^9, {3.856279516644582*^9, 3.856279517758659*^9}, 
   3.877696856199154*^9, 3.885634833504317*^9},
 CellTags->{"LastCellOfAPage", "i:67"},
 CellID->747614211,ExpressionUUID->"5570ec7e-3c57-4fab-9531-43f4cd37460f"],

Cell[TextData[{
 "Exploit Listability to speed up ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " and other functions:"
}], "CodeCaption",
 CellChangeTimes->{3.7747827983548594`*^9, 3.774875830877632*^9, 
  3.7754076906164403`*^9},
 CellTags->"p: 45",
 CellID->48558757,ExpressionUUID->"b24ab022-8cb3-49cb-9223-11afd2920737"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"Interpreter", "[", "\"\<Date\>\"", "]"}], "[", "randomDates", 
   "]"}], "//", "EchoTiming"}]], "Input",
 CellChangeTimes->{{3.769078260901979*^9, 3.7690782686837473`*^9}, {
   3.7690783684614983`*^9, 3.7690783844737577`*^9}, {3.769772609080954*^9, 
   3.769772615330275*^9}, 3.769772752667922*^9, 3.877696841342198*^9, {
   3.898869109081657*^9, 3.898869112697328*^9}},
 CellLabel->"In[6]:=",
 CellID->1030202654,ExpressionUUID->"343b483f-7145-4249-bebb-2746b9ccc365"],

Cell[BoxData["1.075785`"], "EchoTiming",
 CellChangeTimes->{3.8988691474266233`*^9},
 CellID->601469678,ExpressionUUID->"e809cddc-a760-44b3-9357-1f520e898ad5"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TemplateBox[{
     RowBox[{"\"Sun 24 Oct 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "10", ",", "24"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 3 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 25 Nov 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "11", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 25 Jan 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "1", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 9 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "9"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 3 May 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "5", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Tue 21 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "21"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 25 Feb 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "2", ",", "25"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 12 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "12"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Mon 3 May 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "5", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Fri 17 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "17"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 6 Feb 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "2", ",", "6"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 10 Mar 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "3", ",", "10"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Tue 7 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "7"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 18 Sep 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "9", ",", "18"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Thu 3 Jun 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "6", ",", "3"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Sat 24 Jul 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "7", ",", "24"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Fri 16 Apr 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "4", ",", "16"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 29 Dec 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "12", ",", "29"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False], ",", 
   TemplateBox[{
     RowBox[{"\"Wed 17 Mar 1999\""}], 
     RowBox[{"DateObject", "[", 
       RowBox[{
         RowBox[{"{", 
           RowBox[{"1999", ",", "3", ",", "17"}], "}"}], ",", "\"Day\""}], 
       "]"}]},
    "DateObject",
    Editable->False]}], "}"}]], "Output",
 CellChangeTimes->{
  3.769078269484211*^9, {3.769078376695002*^9, 3.7690784006322603`*^9}, 
   3.769081441941175*^9, 3.769100651180497*^9, 3.769772682601716*^9, 
   3.769772754191033*^9, 3.769975539431609*^9, 3.771923590022068*^9, 
   3.7719295208269043`*^9, 3.8814076283125343`*^9, 3.8814170842371483`*^9, {
   3.8988691293491077`*^9, 3.8988691474507837`*^9}},
 CellLabel->"Out[6]=",
 CellID->695351717,ExpressionUUID->"d791ab06-fb3c-4c5c-9013-25d36f15d951"]
}, Open  ]],

Cell["\<\
Even with a short list, using the non-threaded version takes much longer.\
\>", "Text",
 CellChangeTimes->{{3.769081462535191*^9, 3.769081482082203*^9}, {
  3.7754077392854404`*^9, 3.77540774001344*^9}},
 CellID->956976611,ExpressionUUID->"7affba0d-178e-4b9f-b639-47e01ec0f124"],

Cell[TextData[{
 "Now notice that with ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 ", I can take separated elements of a nested ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and collect them into a cohesive ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " to take advantage of implicit listability and then use ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 " again to restore the original structure of the data. Suppose, for example, \
I want to get the ",
 ButtonBox["Entity",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Entity.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Entity.html"],
 " corresponding to each of the persons in the last element of the rows of ",
 Cell[BoxData[
 "nestedList"], "InlineCodeText",ExpressionUUID->
  "4c2a5109-e180-45e4-beef-99fbc2c5ec03"],
 ". I could do this using ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " with a ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " specification of ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    ButtonBox[
     StyleBox["All",
      FontColor->GrayLevel[0]],
     BaseStyle->"Hyperlink",
     ButtonData->{
       URL["https://reference.wolfram.com/language/ref/All.html"], None},
     ButtonNote->"https://reference.wolfram.com/language/ref/All.html"], ",", 
    "5"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "15f089a5-d28e-4eb6-85ce-4e03bb354a05"],
 ", which says to take all the rows and apply ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " to each of the fifth Parts. "
}], "Text",
 CellChangeTimes->{{3.7690818470734367`*^9, 3.76908194499264*^9}, {
   3.769082367369904*^9, 3.7690823752207212`*^9}, {3.769083447445698*^9, 
   3.769083486223322*^9}, {3.769083696830398*^9, 3.769083707594849*^9}, {
   3.7691609229018717`*^9, 3.76916097878918*^9}, 3.7747837047140055`*^9, {
   3.7754078138144403`*^9, 3.7754078319504404`*^9}, {3.7754078643374405`*^9, 
   3.77540787369644*^9}, {3.77540804386444*^9, 3.7754080640704403`*^9}, {
   3.856279551090756*^9, 3.856279556156067*^9}, {3.8565387964421177`*^9, 
   3.85653883517686*^9}, {3.877696871436295*^9, 3.877696932429817*^9}, {
   3.8855724418865457`*^9, 3.8855724605377507`*^9}, 3.885634838822695*^9},
 CellTags->"i:68",
 CellID->1928899909,ExpressionUUID->"b9e999f7-83a3-4a04-8a65-728e495c42be"],

Cell[TextData[{
 "Running ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " on the values in a column of data is relatively slow:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747828093449583`*^9, 3.7747837094340053`*^9, {3.7748758355896325`*^9, 
   3.774875837429632*^9}, {3.77540787946844*^9, 3.77540788567044*^9}, {
   3.77540806825344*^9, 3.77540807145944*^9}},
 CellID->49643145,ExpressionUUID->"37b708f8-8ed7-4a36-9394-652ed71408ee"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"MapAt", "[", 
   RowBox[{
    RowBox[{"Interpreter", "[", "\"\<Person\>\"", "]"}], ",", "nestedList", 
    ",", 
    RowBox[{"{", 
     RowBox[{"{", 
      RowBox[{"All", ",", "5"}], "}"}], "}"}]}], "]"}], "//", 
  "EchoTiming"}]], "Input",
 CellChangeTimes->{{3.7690819024855957`*^9, 3.769081916515911*^9}, {
   3.769081966063682*^9, 3.7690819668586073`*^9}, {3.7690820467270412`*^9, 
   3.769082088520341*^9}, {3.769082244456757*^9, 3.76908224454454*^9}, {
   3.769082390967639*^9, 3.7690824130184393`*^9}, {3.769083554355299*^9, 
   3.769083560710702*^9}, {3.769083722191866*^9, 3.769083728057028*^9}, {
   3.7697726236723013`*^9, 3.7697726294642153`*^9}, 3.8776969373411207`*^9, {
   3.8988692112472553`*^9, 3.898869212810795*^9}},
 CellLabel->"In[8]:=",
 CellID->815520100,ExpressionUUID->"fb096d58-cba6-46e2-852f-240612f43d4b"],

Cell[BoxData["2.41613`"], "EchoTiming",
 CellChangeTimes->{3.898869217705295*^9},
 CellID->790355281,ExpressionUUID->"434f5578-3e2f-498e-956a-02253703ad13"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Thurgood Marshall\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"ThurgoodMarshall::jh347\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"ThurgoodMarshall::jh347\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Elena Kagan\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"ElenaKagan::9ynw2\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"ElenaKagan::9ynw2\\\"]\"", "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Oliver Ellsworth\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"OliverEllsworth::7b79z\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"OliverEllsworth::7b79z\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"William Rehnquist\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"WilliamRehnquist::5xqqp\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"WilliamRehnquist::5xqqp\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Oliver Wendell Holmes, Jr.\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"OliverWendellHolmesJr::7tzh8\""}], 
         "]"}], "\"Entity[\\\"Person\\\", \
\\\"OliverWendellHolmesJr::7tzh8\\\"]\"", "\"person\""},
      "Entity"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769081911897132*^9, 3.7690819178048897`*^9}, {
   3.769082063589909*^9, 3.7690820927099257`*^9}, 3.7690822530954437`*^9, 
   3.7690823547033463`*^9, {3.769082403810802*^9, 3.769082415856904*^9}, 
   3.769083564990765*^9, 3.7690837301267853`*^9, 3.769100652296039*^9, 
   3.76977268617354*^9, 3.769975543696239*^9, 3.77192359445277*^9, 
   3.771929522662888*^9, {3.881417092089038*^9, 3.88141712452256*^9}, 
   3.89886921773133*^9},
 CellLabel->"Out[8]=",
 CellID->1314851072,ExpressionUUID->"385839eb-715d-4a39-834c-fb47ce6fdd68"]
}, Open  ]],

Cell[TextData[{
 "Or I could try this alternative version in which I first ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 " the data and then use ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " with a ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " specification of 5, telling Mathematica to find the fifth ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " (now a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of justices) and make a single call to ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " that gets ",
 ButtonBox["Entity",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Entity.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Entity.html"],
 " specifications for all of the elements in the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.769082409307497*^9, 3.7690824266540956`*^9}, {
   3.769160986010051*^9, 3.769161051726022*^9}, 3.77540789184544*^9, 
   3.7754080201104403`*^9, 3.77540807729044*^9, {3.7754081960234404`*^9, 
   3.7754082112024403`*^9}, {3.877696949045418*^9, 3.8776969822337523`*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1350776468,ExpressionUUID->"bed66ccf-688d-4262-8778-024328c09e39"],

Cell[TextData[{
 "Running ",
 ButtonBox["Interpreter",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Interpreter.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Interpreter.html"],
 " in a listable way over a row in a transposed matrix is faster:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782820156039*^9, {3.774875841613632*^9, 3.774875842389632*^9}, {
   3.7754083420750484`*^9, 3.7754083641566706`*^9}, 3.777354451211152*^9, 
   3.877696989466845*^9, {3.8963411306757107`*^9, 3.8963411320525084`*^9}},
 CellTags->"p: 46",
 CellID->340339881,ExpressionUUID->"f6112bb9-9afe-4eff-8674-0a7bfedab5a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Transpose", "[", 
   RowBox[{"MapAt", "[", 
    RowBox[{
     RowBox[{"Interpreter", "[", "\"\<Person\>\"", "]"}], ",", 
     RowBox[{"Transpose", "[", "nestedList", "]"}], ",", 
     RowBox[{"{", 
      RowBox[{"{", "5", "}"}], "}"}]}], "]"}], "]"}], "//", 
  "EchoTiming"}]], "Input",
 CellChangeTimes->{{3.76908242837921*^9, 3.769082450469029*^9}, {
   3.7690835724816303`*^9, 3.769083593772194*^9}, {3.769083734207654*^9, 
   3.769083745463455*^9}, {3.7697726348886423`*^9, 3.769772641944758*^9}, 
   3.877696941438423*^9, {3.898869229591495*^9, 3.898869231597128*^9}},
 CellLabel->"In[9]:=",
 CellID->1768262311,ExpressionUUID->"abf96da3-9ff6-4d3e-ab52-6d3e2d2da4d6"],

Cell[BoxData["0.007426`"], "EchoTiming",
 CellChangeTimes->{3.898869232038279*^9},
 CellID->320333128,ExpressionUUID->"b914bdb5-e22a-47e2-97a6-3b1730006a58"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7101881771505834, 0.7989108398643558, 0.8028079784985009]|>,
      "RGBColorSwatchTemplate"], ",", "5", ",", "0.08`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Thurgood Marshall\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"ThurgoodMarshall::jh347\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"ThurgoodMarshall::jh347\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`]|>,
      "RGBColorSwatchTemplate"], ",", "2", ",", "0.83`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "43"}], ",", 
        RowBox[{"-", "113"}]}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Elena Kagan\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"ElenaKagan::9ynw2\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"ElenaKagan::9ynw2\\\"]\"", "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.07`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"-", "22"}], ",", 
        RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Oliver Ellsworth\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"OliverEllsworth::7b79z\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"OliverEllsworth::7b79z\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.71799307373688, 0.8971633609144036, 0.09594209586818336]|>,
      "RGBColorSwatchTemplate"], ",", "4", ",", "0.35`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"William Rehnquist\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"WilliamRehnquist::5xqqp\""}], "]"}], 
       "\"Entity[\\\"Person\\\", \\\"WilliamRehnquist::5xqqp\\\"]\"", 
       "\"person\""},
      "Entity"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[<|
      "color" -> RGBColor[
        0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]|>,
      "RGBColorSwatchTemplate"], ",", "9", ",", "0.87`", ",", 
     RowBox[{"GeoPosition", "[", 
      RowBox[{"{", 
       RowBox[{"14", ",", "64"}], "}"}], "]"}], ",", 
     TemplateBox[{"\"Oliver Wendell Holmes, Jr.\"", 
       RowBox[{"Entity", "[", 
         RowBox[{"\"Person\"", ",", "\"OliverWendellHolmesJr::7tzh8\""}], 
         "]"}], "\"Entity[\\\"Person\\\", \
\\\"OliverWendellHolmesJr::7tzh8\\\"]\"", "\"person\""},
      "Entity"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690824316724977`*^9, 3.7690824521776133`*^9}, {
   3.769083588974777*^9, 3.7690835959588614`*^9}, 3.769083747179695*^9, 
   3.769100653383922*^9, 3.769772686289152*^9, 3.769975543807274*^9, 
   3.771923595901021*^9, 3.771929522799334*^9, 3.881417128729127*^9, 
   3.89886923207977*^9},
 CellLabel->"Out[9]=",
 CellID->97379267,ExpressionUUID->"588a2ba9-34e4-43c0-b3c9-c2e79b8a72ba"]
}, Open  ]],

Cell["\<\
As you can see, the second method works a lot faster. By the way, you will \
notice I Transposed the data, performed an operation on what became a row of \
that Transposed data, and then Transposed the results back to the original \
orientation. I will do this a lot in this book. I call this technique the \
\[OpenCurlyDoubleQuote]Double Transpose Trick.\[CloseCurlyDoubleQuote] Real \
mathematicians, I am advised, sometimes call a similar technique \
\[OpenCurlyDoubleQuote]conjugation.\[CloseCurlyDoubleQuote]\
\>", "Text",
 CellChangeTimes->{{3.769083606125105*^9, 3.769083651313265*^9}, 
   3.769083688649085*^9, {3.769083754903494*^9, 3.7690838141588383`*^9}, {
   3.8562795753848667`*^9, 3.856279597521934*^9}, {3.8776970120238028`*^9, 
   3.877697012204867*^9}, {3.885572648956542*^9, 3.8855726499678016`*^9}},
 CellID->276686938,ExpressionUUID->"fbaf5206-6e60-4acb-bd52-8ba56372f986"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["A Sample Problem Using \[OpenCurlyDoubleQuote]Old-School\
\[CloseCurlyDoubleQuote] Wolfram Language Methods", "Subsection",
 CellChangeTimes->{{3.7748806933264203`*^9, 3.7748807015414205`*^9}, {
  3.7754099369544287`*^9, 3.7754099371634283`*^9}},
 CellID->604870805,ExpressionUUID->"7d129b6a-1d53-45a3-9a51-33d871768838"],

Cell[CellGroupData[{

Cell["Data Retrieval", "Subsubsection",
 CellChangeTimes->{{3.771854126877327*^9, 3.771854130302215*^9}},
 CellID->161362593,ExpressionUUID->"1abd6f24-b3dd-45a5-9540-7172b3c7e814"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s analyze some sports data using these old-school \
functions. I start by retrieving a ",
 ButtonBox["ResourceObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceObject.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceObject.html"],
 " created for this book containing salary information from 2007\[Dash]2017 \
for soccer (a.k.a. football) players in Major League Soccer (MLS) in the \
United States. "
}], "Text",
 CellChangeTimes->{{3.769088638525607*^9, 3.769088713767046*^9}, {
  3.7690887575274973`*^9, 3.7690887714287*^9}, {3.7747839212140055`*^9, 
  3.774783921910005*^9}, {3.7754099400574284`*^9, 3.7754099403224287`*^9}, {
  3.7754101160624285`*^9, 3.7754101317624283`*^9}, {3.7754102062034283`*^9, 
  3.7754102170104284`*^9}, {3.775472285317399*^9, 3.775472286895399*^9}, {
  3.8562798357988367`*^9, 3.8562798828808203`*^9}, {3.856279944294129*^9, 
  3.856279986717724*^9}, {3.856280026388709*^9, 3.856280029671155*^9}, {
  3.8562800742210712`*^9, 3.856280076196025*^9}, {3.881406351068535*^9, 
  3.8814063517232723`*^9}, {3.8855726958669415`*^9, 3.885572697197401*^9}},
 CellID->1069548003,ExpressionUUID->"b661e44f-045d-4bf3-a105-fb10d8b213e0"],

Cell[TextData[{
 "Acquire the ",
 ButtonBox["ResourceObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceObject.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceObject.html"],
 " from the Wolfram Data Repository:"
}], "CodeCaption",
 CellChangeTimes->{{3.77549691973217*^9, 3.775496924283777*^9}, {
   3.888932934911173*^9, 3.888932972321426*^9}, 3.897745527580264*^9},
 CellID->1255197607,ExpressionUUID->"426259f7-291e-4b68-a212-e7d7d8623fef"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ro", "=", 
  RowBox[{
  "ResourceObject", "[", "\"\<Sample Data for Query Book\>\"", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.888932859088291*^9, 3.8889328965549097`*^9}},
 CellLabel->"In[3]:=",
 CellID->834729015,ExpressionUUID->"f54f8216-3ad5-402e-ae1f-d53ac2a9e898"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["ResourceObject",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"], 
               ImageSizeCache -> {12., {0., 12.}}], Appearance -> None, 
              BaseStyle -> {}, ButtonFunction :> (Typeset`open$$ = True), 
              Evaluator -> Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            StyleBox[
             GraphicsBox[
              RasterBox[CompressedData["
1:eJztnMeOHUUUhi1gwZJX4C3YskFia8QD2MJYbIxkIyFehp1ztsc55+xxzjnn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               "], {{0, 0}, {180., 180.}}, {0, 255}, ColorFunction -> 
               RGBColor], AspectRatio -> 1, Axes -> False, Background -> None,
               Frame -> None, FrameTicks -> None, ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], PlotRange -> {{0, 180.}, {0, 180.}}], 
             StripOnInput -> False, CacheGraphics -> False], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Sample Data for Query Book\"", "\" \"", 
                    
                    TemplateBox[{
                    "\"\[RightGuillemet]\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"]}, "RowDefault"], 
                  "SummaryItem"]}], 
               TagBox["\"\"", "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"DataResource\"", "SummaryItem"]}], 
               "\[SpanFromLeft]"}, {
               TagBox[
                DynamicModuleBox[{ResourceSystemClient`Private`len$$ = 1}, 
                 RowBox[{
                   TagBox["\"Description: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    ButtonBox[
                    DynamicBox[
                    ToBoxes[
                    Replace[
                    ResourceSystemClient`Private`snipDots[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], Except[
                    Blank[String]] -> 
                    Snippet[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], {0}], StandardForm], 
                    ImageSizeCache -> {466., {2.2265625, 8.94140625}}], 
                    Appearance -> None, BaseStyle -> {}, 
                    ButtonFunction :> (ResourceSystemClient`Private`len$$ = 
                    Ceiling[ResourceSystemClient`Private`len$$ 1.5]), 
                    Evaluator -> Automatic, Method -> "Preemptive"], 
                    "SummaryItem"]}], DynamicModuleValues :> {}], 
                "SummaryItem"], "\[SpanFromLeft]"}}, AutoDelete -> False, 
             BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True -> 
        GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              Appearance -> None, BaseStyle -> {}, 
              ButtonFunction :> (Typeset`open$$ = False), Evaluator -> 
              Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            StyleBox[
             GraphicsBox[
              RasterBox[CompressedData["
1:eJztnMeOHUUUhi1gwZJX4C3YskFia8QD2MJYbIxkIyFehp1ztsc55+xxzjnn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               "], {{0, 0}, {180., 180.}}, {0, 255}, ColorFunction -> 
               RGBColor], AspectRatio -> 1, Axes -> False, Background -> None,
               Frame -> None, FrameTicks -> None, ImageSize -> 
              Dynamic[{
                Automatic, 
                 3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                  Magnification])}], PlotRange -> {{0, 180.}, {0, 180.}}], 
             StripOnInput -> False, CacheGraphics -> False], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Name: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TemplateBox[{"\"Sample Data for Query Book\"", "\" \"", 
                    
                    TemplateBox[{
                    "\"\[RightGuillemet]\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"]}, "RowDefault"], 
                  "SummaryItem"]}], 
               TagBox["\"\"", "SummaryItem"]}, {
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"DataResource\"", "SummaryItem"]}], 
               "\[SpanFromLeft]"}, {
               TagBox[
                DynamicModuleBox[{ResourceSystemClient`Private`len$$ = 1}, 
                 RowBox[{
                   TagBox["\"Description: \"", "SummaryItemAnnotation"], 
                   "\[InvisibleSpace]", 
                   TagBox[
                    ButtonBox[
                    DynamicBox[
                    ToBoxes[
                    Replace[
                    ResourceSystemClient`Private`snipDots[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], Except[
                    Blank[String]] -> 
                    Snippet[
                    "Data to support the Wolfram Media book Query: Getting \
Information from Data with the Wolfram Language", 
                    ResourceSystemClient`Private`len$$], {0}], StandardForm]],
                     Appearance -> None, BaseStyle -> {}, 
                    ButtonFunction :> (ResourceSystemClient`Private`len$$ = 
                    Ceiling[ResourceSystemClient`Private`len$$ 1.5]), 
                    Evaluator -> Automatic, Method -> "Preemptive"], 
                    "SummaryItem"]}], DynamicModuleValues :> {}], 
                "SummaryItem"], "\[SpanFromLeft]"}, {
               RowBox[{
                 TagBox["\"Categories: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{
                    ",", "\",\"", "\"Astronomy\"", "\"History\"", 
                    "\"Human Activities\""}, "RowWithSeparators"], Short], 
                  "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"ContentTypes: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{
                    ",", "\",\"", "\"Text\"", "\"Numerical Data\""}, 
                    "RowWithSeparators"], Short], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Keywords: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   
                   TemplateBox[{",", "\",\"", "\"Dataset\"", "\"Query\""}, 
                    "RowWithSeparators"], Short], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Documentation: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  TemplateBox[{
                   "\"https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/\"", 
                    "https://datarepository.wolframcloud.com/resources/\
bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7/"}, "HyperlinkURL"], "SummaryItem"]}], 
               ""}, {
               RowBox[{
                 TagBox["\"Data Location: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  DynamicModuleBox[{
                   ResourceSystemClient`Private`typesetstorage$$ = 
                    ResourceSystemClient`Private`typesetstorageLocation, 
                    ResourceSystemClient`Private`info$$}, 
                   DynamicBox[
                    ToBoxes[
                    ResourceSystemClient`Private`info$$ = 
                    ResourceSystemClient`Private`resourceInfo[
                    "bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7"]; If[
                    AssociationQ[ResourceSystemClient`Private`info$$], 
                    ResourceSystemClient`Private`typesetstorage$$[
                    Lookup[
                    ResourceSystemClient`Private`info$$, 
                    "ContentElementLocations", None]], 
                    Missing["NotAvailable"]], StandardForm]], 
                   DynamicModuleValues :> {}], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"UUID: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                 "\"bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7\"", "SummaryItem"]}],
                ""}, {
               RowBox[{
                 TagBox["\"Version: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"1.0.1\"", "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Size: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  TemplateBox[{
                   "918.7280000000001`", "\"kB\"", "kilobytes", 
                    "\"Kilobytes\""}, "Quantity"], "SummaryItem"]}], ""}, {
               RowBox[{
                 TagBox["\"Elements: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  TagBox[
                   RowBox[{"\"aAssociation\"", ",", "\"Content\"", ",", 
                    RowBox[{"\[LeftSkeleton]", "20", "\[RightSkeleton]"}], 
                    ",", "\"Titanic List of Associations\"", ",", 
                    "\"Titanic List of Associations Dataset\""}], 
                   Short[#, 2]& ], "SummaryItem"]}], ""}}, AutoDelete -> 
             False, BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  ResourceObject[<|
   "Name" -> "Sample Data for Query Book", "UUID" -> 
    "bd67dc14-bd67-4f1a-acaa-ddb12a7a79e7", "ResourceType" -> "DataResource", 
    "Version" -> "1.0.1", "Description" -> 
    "Data to support the Wolfram Media book Query: Getting Information from \
Data with the Wolfram Language", "RepositoryLocation" -> 
    URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
    "ContentSize" -> Quantity[918.7280000000001, "Kilobytes"], 
    "ContentElements" -> {
     "aAssociation", "Content", "Dinghy Association of Associations", 
      "Dinghy Association of Associations Dataset", 
      "Dinghy List of Associations", "Dinghy List of Associations Dataset", 
      "Eastern Cities List", "IDWeight List of Associations", 
      "Lifeboat List of Associations", 
      "Lifeboat List of Associations Dataset", "Mars Association", 
      "MLS List of Associations", "MLS List of Associations Dataset", 
      "MLS List of Lists", "MLS List of Lists Dataset", 
      "Planets Deeply Nested Structure", 
      "Planets Deeply Nested Structure Dataset", "Pops List", 
      "Titanic Cabins 2 List of Associations", 
      "Titanic Cabins 2 List of Associations Dataset", 
      "Titanic Cabins List of Associations", 
      "Titanic Cabins List of Associations Dataset", 
      "Titanic List of Associations", 
      "Titanic List of Associations Dataset"}|>, {
   ResourceSystemBase -> 
    "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "Output",
 CellChangeTimes->{
  3.888932908054226*^9, 3.888933667462413*^9, 3.89946053551606*^9, 
   3.899480149933816*^9, {3.899544850701754*^9, 3.8995448729630527`*^9}},
 CellLabel->"Out[3]=",
 CellID->1927372901,ExpressionUUID->"641d84d5-9b8e-4690-817f-e7500f80af17"]
}, Open  ]],

Cell[TextData[{
 "The symbol ",
 Cell[BoxData[
 "ro"], "InlineCodeText",ExpressionUUID->
  "e1571f2b-4bbc-4f85-a26b-1f6c6eb71fea"],
 " now refers to a ",
 ButtonBox["ResourceObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceObject.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceObject.html"],
 " containing various forms of data. The \[OpenCurlyDoubleQuote]MLS List of \
Lists\[CloseCurlyDoubleQuote] element of that ",
 ButtonBox["ResourceObject",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceObject.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceObject.html"],
 " contains a matrix with 5553 rows and seven columns. I can assign that \
element to the symbol ",
 Cell[BoxData[
 "mls"], "InlineCodeText",ExpressionUUID->
  "3b0e7087-5c79-4713-82af-d89d24c33d60"],
 StyleBox[". ", "InlineCodeText"],
 "By postfixing the ",
 ButtonBox["AugmentedTerse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " after the assignment, I show the output as a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Lists (a matrix) but also show the structure of data."
}], "Text",
 CellChangeTimes->{{3.769088638525607*^9, 3.769088713767046*^9}, {
   3.7690887575274973`*^9, 3.7690887714287*^9}, {3.7747839212140055`*^9, 
   3.774783921910005*^9}, {3.7754099400574284`*^9, 3.7754099403224287`*^9}, {
   3.7754101160624285`*^9, 3.7754101317624283`*^9}, {3.7754102062034283`*^9, 
   3.7754102170104284`*^9}, {3.775472285317399*^9, 3.775472286895399*^9}, {
   3.8562798357988367`*^9, 3.8562798828808203`*^9}, {3.856279944294129*^9, 
   3.856279986717724*^9}, {3.856280026388709*^9, 3.856280029671155*^9}, {
   3.856280086799259*^9, 3.856280136378028*^9}, {3.856539049923788*^9, 
   3.856539091530662*^9}, {3.87769755348419*^9, 3.877697574599028*^9}, 
   3.8853957764702253`*^9, {3.885572725683177*^9, 3.885572733261756*^9}, {
   3.8855727765606937`*^9, 3.8855727862082715`*^9}, {3.890316753390809*^9, 
   3.890316758816168*^9}, 3.896341202550578*^9, 3.897573824228756*^9},
 CellTags->{"LastCellOfAPage", "i:69"},
 CellID->121026861,ExpressionUUID->"87f2ba43-969f-4ff7-bf1c-c5cb0bd09bf3"],

Cell[TextData[{
 "Retrieve data on soccer salaries and use the ",
 ButtonBox["AugmentedTerse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " to provide information on the structure of the data:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747828338354073`*^9, 3.7748758460456324`*^9, {3.777354542026363*^9, 
   3.777354542905897*^9}, {3.8562798864003468`*^9, 3.8562799140755444`*^9}, {
   3.856539138089486*^9, 3.856539146189513*^9}, 3.8565391826293983`*^9, {
   3.87769759117854*^9, 3.87769759675669*^9}},
 CellTags->{"i:70", "p: 47"},
 CellID->137313122,ExpressionUUID->"e46768c6-f8a3-4ddc-bce8-ea293a0ac50f"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mls", "=", 
    RowBox[{"ResourceData", "[", 
     RowBox[{"ro", ",", "\"\<MLS List of Lists\>\""}], "]"}]}], ")"}], "//", 
  RowBox[{
   InterpretationBox[
    TagBox[
     TagBox[
      DynamicModuleBox[{Typeset`open = False}, 
       FrameBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[GridBox[{
               {
                StyleBox[
                 StyleBox[
                  AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                   BoxBaselineShift->-0.25,
                   BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                  
                  FontColor->RGBColor[
                   0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                 ShowStringCharacters->False,
                 FontFamily->"Source Sans Pro Black",
                 FontSize->0.6538461538461539 Inherited,
                 FontWeight->"Heavy",
                 PrivateFontOptions->{"OperatorSubstitution"->False}], 
                StyleBox[
                 RowBox[{
                  StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                 ShowAutoStyles->False,
                 ShowStringCharacters->False,
                 FontSize->Rational[12, 13] Inherited,
                 FontColor->GrayLevel[0.1]]}
              },
              GridBoxSpacings->{"Columns" -> {{0.25}}}],
             Alignment->Left,
             BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
             BaselinePosition->Baseline,
             FrameMargins->{{3, 0}, {0, 0}}], 
            ItemBox[
             PaneBox[
              TogglerBox[Dynamic[Typeset`open], {True->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeCloser"],
                ImageSizeCache->{11., {2., 9.}}], False->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeOpener"],
                ImageSizeCache->{11., {2., 9.}}]},
               Appearance->None,
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{1, 1}, {0, 0}}],
             Frame->{{
                RGBColor[
                0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                 0.5], False}, {False, False}}]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
         GridBox[{
           {GridBox[{
              {
               PaneBox[GridBox[{
                  {
                   StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                   StyleBox[
                    RowBox[{
                    StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                 },
                 GridBoxSpacings->{"Columns" -> {{0.25}}}],
                Alignment->Left,
                BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                BaselinePosition->Baseline,
                FrameMargins->{{3, 0}, {0, 0}}], 
               ItemBox[
                PaneBox[
                 TogglerBox[Dynamic[Typeset`open], {True->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeCloser"]], False->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeOpener"]]},
                  Appearance->None,
                  BaselinePosition->Baseline,
                  ContentPadding->False,
                  FrameMargins->0],
                 Alignment->Left,
                 BaselinePosition->Baseline,
                 FrameMargins->{{1, 1}, {0, 0}}],
                Frame->{{
                   RGBColor[
                   0.8313725490196079, 0.8470588235294118, 0.8509803921568627,
                     0.5], False}, {False, False}}]}
             },
             BaselinePosition->{1, 1},
             GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
           {
            StyleBox[
             PaneBox[GridBox[{
                {
                 RowBox[{
                  TagBox["\<\"Version (latest): \"\>",
                   "IconizedLabel"], " ", 
                  TagBox["\<\"1.0.0\"\>",
                   "IconizedItem"]}]},
                {
                 TagBox[
                  
                  TemplateBox[{
                   "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/55ad4cc5-e284-40ca-a3cb-8a4166c38701/"},
                   "HyperlinkURL"],
                  "IconizedItem"]}
               },
               DefaultBaseStyle->"Column",
               GridBoxAlignment->{"Columns" -> {{Left}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
             FontFamily->"Roboto",
             FontSize->11]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
               GrayLevel[0.8]}, False}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open],
         BaselinePosition->Baseline,
         ImageSize->Automatic],
        Background->RGBColor[
         0.9686274509803922, 0.9764705882352941, 0.984313725490196],
        BaselinePosition->Baseline,
        DefaultBaseStyle->{},
        FrameMargins->{{0, 0}, {1, 0}},
        FrameStyle->RGBColor[
         0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
        RoundingRadius->4]],
      #& ,
      TagBoxNote->" "],
     {"FunctionResourceBox", 
      RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
      "AugmentedTerse"},
     TagBoxNote->"FunctionResourceBox"],
    ResourceFunction[
     ResourceObject[<|
      "Name" -> "AugmentedTerse", "ShortName" -> "AugmentedTerse", "UUID" -> 
       "55ad4cc5-e284-40ca-a3cb-8a4166c38701", "ResourceType" -> "Function", 
       "Version" -> "1.0.0", "Description" -> 
       "An operator form of Short with an alternative compressed \
representation of the output", "RepositoryLocation" -> 
       URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
       "SymbolName" -> 
       "FunctionRepository`$779c3314c408433eb6df4354526edb23`AugmentedTerse", 
       "FunctionLocation" -> 
       CloudObject[
        "https://www.wolframcloud.com/obj/5aa416ea-2adb-41c1-9102-\
ddaa33f49612"]|>, {
      ResourceSystemBase -> 
       "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}]],
    Selectable->False], "[", "10", "]"}]}]], "Input",
 CellChangeTimes->{{3.769097209819282*^9, 3.769097223841763*^9}, {
  3.769952963669487*^9, 3.7699529731237097`*^9}, {3.771928909089356*^9, 
  3.771928912065578*^9}, {3.856279803814508*^9, 3.856279846700019*^9}, {
  3.881417190307534*^9, 3.881417218758772*^9}},
 CellLabel->"In[7]:=",
 CellID->1943618907,ExpressionUUID->"3c978a01-b63b-4130-8725-6c5c2880105d"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   TagBox[
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{"\<\"CHI\"\>", ",", "\<\"Armas\"\>", ",", "\<\"Chris\"\>", 
        ",", "\<\"M\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"225\[ThinSpace]000.00\"", 225000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"225\[ThinSpace]000.00\"", 225000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"CHI\"\>", ",", "\<\"Banner\"\>", ",", "\<\"Michael\"\>", 
        ",", "\<\"M\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"CHI\"\>", ",", "\<\"Barrett\"\>", ",", "\<\"Chad\"\>", 
        ",", "\<\"F\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"41\[ThinSpace]212.50\"", 41212.5, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"48\[ThinSpace]712.50\"", 48712.5, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"CHI\"\>", ",", "\<\"Blanco\"\>", 
        ",", "\<\"Cuauhtemoc\"\>", ",", "\<\"F\"\>", ",", 
        TemplateBox[{
          InterpretationBox["2.492316`*^6", 2.492316*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["2.666778`*^6", 2.666778*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"\[LeftSkeleton]", "5546", "\[RightSkeleton]"}], ",", 
      RowBox[{"{", 
       RowBox[{"\<\"VAN\"\>", ",", "\<\"Williams\"\>", ",", "\<\"Sheanon\"\>",
         ",", "\<\"D\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"175\[ThinSpace]000.00\"", 175000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"184\[ThinSpace]000.00\"", 184000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Missing", "[", "]"}], ",", "\<\"Babouli\"\>", 
        ",", "\<\"Mo\"\>", ",", "\<\"F\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"54\[ThinSpace]075.00\"", 54075., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"54\[ThinSpace]075.00\"", 54075., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"Missing", "[", "]"}], ",", "\<\"Ramajo\"\>", 
        ",", "\<\"David Mateos\"\>", ",", "\<\"D\"\>", ",", 
        TemplateBox[{
          InterpretationBox[
          "\"420\[ThinSpace]000.00\"", 420000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"453\[ThinSpace]333.33\"", 453333.33, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          RowBox[{
            StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
          RowBox[{"DateObject", "[", 
            RowBox[{
              RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
         "DateObject",
         Editable->False]}], "}"}]}], "}"}],
    Short[#, 10]& ], ",", 
   RowBox[{"{", 
    RowBox[{"5553", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.856279826420743*^9, 3.856279848196539*^9}, 
   3.8655449084108458`*^9, 3.880627102227727*^9, 3.880628668799554*^9, 
   3.8806312264299183`*^9, 3.881417184453017*^9, 3.881417224464457*^9, 
   3.882283962209427*^9},
 CellLabel->"Out[7]=",
 CellID->127527510,ExpressionUUID->"6b6ca072-e38e-425d-978e-74bb537f3234"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Exploration", "Subsubsection",
 CellChangeTimes->{{3.771854144920896*^9, 3.771854147626142*^9}},
 CellID->121986215,ExpressionUUID->"fea58898-51f5-472c-a643-371e7541db27"],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s a sample of the first five rows. \
I\[CloseCurlyQuote]ll put it in a ",
 ButtonBox["Grid",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Grid.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Grid.html"],
 " with dividers to make it easier to see. The first column is the club for \
which the person played, the second and third columns are the last and first \
names of the player, the fourth column contains an abbreviation for the \
position (or positions) of the player, the fifth column contains a base \
salary, the sixth column contains any guaranteed compensation (defined as \
base plus annualized bonuses), and the seventh column contains the year to \
which the data is applicable."
}], "Text",
 CellChangeTimes->{{3.76908877647218*^9, 3.7690888225295486`*^9}, {
  3.769088853295117*^9, 3.769088936957456*^9}, {3.769089983297311*^9, 
  3.76909001563925*^9}, {3.769097616045133*^9, 3.769097626533554*^9}, {
  3.7747839282210054`*^9, 3.7747839292300053`*^9}, {3.7754104949234285`*^9, 
  3.7754105044984283`*^9}, {3.856280179679592*^9, 3.856280181018003*^9}, {
  3.865544962188805*^9, 3.8655449622424507`*^9}, {3.877697609050024*^9, 
  3.877697616763091*^9}},
 CellTags->"i:71",
 CellID->688375747,ExpressionUUID->"6aa010c3-7341-4059-9446-67d8fe1ff483"],

Cell["Show the first five rows of the data:", "CodeCaption",
 CellChangeTimes->{
  3.774782844923516*^9, 3.7748758485816326`*^9, {3.775410540559428*^9, 
   3.775410541335428*^9}},
 CellID->265353070,ExpressionUUID->"4d2fba34-3a53-48b6-8727-e4c2179ba53d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"mls", "[", 
    RowBox[{"[", 
     RowBox[{"Range", "[", "5", "]"}], "]"}], "]"}], ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769089222512781*^9, 3.769089227637974*^9}, {
  3.7690976288466587`*^9, 3.7690976338004704`*^9}},
 CellLabel->"In[8]:=",
 CellID->459511348,ExpressionUUID->"b5c8b40f-a037-49d7-a971-55044ff37a2d"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"CHI\"\>", "\<\"Armas\"\>", "\<\"Chris\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"225\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          225000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 225000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"225\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          225000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 225000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"CHI\"\>", "\<\"Banner\"\>", "\<\"Michael\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"12\[ThinSpace]900.00\"", ShowStringCharacters -> False],
           12900., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 12900., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"12\[ThinSpace]900.00\"", ShowStringCharacters -> False],
           12900., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 12900., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"CHI\"\>", "\<\"Barrett\"\>", "\<\"Chad\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"41\[ThinSpace]212.50\"", ShowStringCharacters -> False],
           41212.5, AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 41212.5, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"48\[ThinSpace]712.50\"", ShowStringCharacters -> False],
           48712.5, AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 48712.5, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"CHI\"\>", "\<\"Blanco\"\>", "\<\"Cuauhtemoc\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox["2.492316`*^6", 2.492316*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox["2.666778`*^6", 2.666778*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"CHI\"\>", "\<\"Brown\"\>", "\<\"C.J.\"\>", "\<\"D\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"106\[ThinSpace]391.00\"", ShowStringCharacters -> False], 
          106391., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 106391., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"106\[ThinSpace]391.00\"", ShowStringCharacters -> False], 
          106391., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 106391., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.769089228059637*^9, 3.769097634119646*^9, 
  3.769100654314164*^9, 3.76977268728128*^9, 3.769975544638124*^9, 
  3.7719235960141582`*^9, 3.771928936291888*^9, 3.7719295244658947`*^9, 
  3.8562801615156517`*^9, 3.880627106985921*^9, 3.8806286784456797`*^9, 
  3.881417247396299*^9, 3.882283969801681*^9},
 CellLabel->"Out[8]=",
 CellID->606192375,ExpressionUUID->"49b0807e-4e54-48ec-92fd-420144e63603"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s look to see if there are any missing values in the \
data. To do this, we\[CloseCurlyQuote]ll use ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 ". I have to look at level 2, because all the rows have at least some data."
}], "Text",
 CellChangeTimes->{{3.769089233697777*^9, 3.769089294323153*^9}, {
   3.774783932189005*^9, 3.7747839377820053`*^9}, 3.775410577363428*^9, {
   3.865544998998877*^9, 3.865544999671714*^9}, {3.8855735772582045`*^9, 
   3.8855735834457192`*^9}},
 CellTags->{"LastCellOfAPage", "i:72"},
 CellID->1536241901,ExpressionUUID->"3e68f07e-3f08-417e-aff9-ba694376b8ee"],

Cell[TextData[{
 "Use ",
 ButtonBox["Position",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Position.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Position.html"],
 " to find ",
 ButtonBox["Missing",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Missing.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Missing.html"],
 " values in the data:"
}], "CodeCaption",
 CellChangeTimes->{3.774782856492673*^9, 3.7748758505406322`*^9, 
  3.775410586811428*^9, 3.777354608499999*^9},
 CellTags->"p: 48",
 CellID->246038905,ExpressionUUID->"6a7f5811-f62a-4c4b-ac1e-34043d081d63"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Position", "[", 
  RowBox[{"mls", ",", "_Missing", ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769089251017724*^9, 3.769089282566104*^9}},
 CellLabel->"In[140]:=",
 CellID->817164804,ExpressionUUID->"ce267a53-84de-411c-af72-9760b363fdb8"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"560", ",", "5"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"560", ",", "6"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"1818", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2113", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2357", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2549", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2641", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2670", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2684", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2812", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"2929", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3025", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3244", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3303", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3397", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3429", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3500", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3505", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3577", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3820", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"3939", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4043", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4064", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4067", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4106", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4205", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4294", ",", "4"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4334", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4723", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4750", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4932", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4933", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4934", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4935", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4936", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4937", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"4984", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5203", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5339", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5367", ",", "3"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5552", ",", "1"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"5553", ",", "1"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769089263462859*^9, 3.7690892828544807`*^9}, 
   3.7691006544175377`*^9, 3.7697726874053926`*^9, 3.769975544750762*^9, 
   3.7719235960255747`*^9, 3.771928938660495*^9, 3.771929524558075*^9, 
   3.880627111530725*^9, 3.8806286851770678`*^9, 3.880632088428087*^9, 
   3.88141725268445*^9},
 CellLabel->"Out[140]=",
 CellID->329301839,ExpressionUUID->"87f5bfbe-45d5-435d-887e-86b9f451b2a3"]
}, Open  ]],

Cell[TextData[{
 "We can get the columns in which the data is missing by mapping ",
 ButtonBox["Last",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Last.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Last.html"],
 " over these positions."
}], "Text",
 CellChangeTimes->{{3.88063205702256*^9, 3.880632075941731*^9}, {
  3.8855736506568747`*^9, 3.8855736574733105`*^9}},
 CellTags->"i:73",
 CellID->1826551503,ExpressionUUID->"3766d413-3a2b-4bbb-8deb-43416cc63c4c"],

Cell[TextData[{
 "Use ",
 ButtonBox["%",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Out.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Out.html"],
 " to capture the last output; ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " ",
 ButtonBox["Last",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Last.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Last.html"],
 " to get the second element of each ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ":"
}], "CodeText",
 CellChangeTimes->{{3.880632096162326*^9, 3.880632149225933*^9}},
 CellID->2145942334,ExpressionUUID->"f2b4f03e-7d1a-4803-9e42-de96979036ec"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Last", ",", "%"}], "]"}]], "Input",
 CellChangeTimes->{{3.880632078585432*^9, 3.880632091253598*^9}},
 CellLabel->"In[141]:=",
 CellID->26858423,ExpressionUUID->"2ed04ef9-9a06-4858-992a-9678e83c29ee"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
  "5", ",", "6", ",", "3", ",", "3", ",", "3", ",", "1", ",", "1", ",", "3", 
   ",", "1", ",", "1", ",", "3", ",", "1", ",", "3", ",", "1", ",", "3", ",", 
   "1", ",", "3", ",", "3", ",", "1", ",", "3", ",", "1", ",", "1", ",", "3", 
   ",", "3", ",", "1", ",", "3", ",", "4", ",", "1", ",", "3", ",", "3", ",", 
   "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "1", ",", "3", ",", "3", 
   ",", "3", ",", "3", ",", "1", ",", "1"}], "}"}]], "Output",
 CellChangeTimes->{3.880632091911915*^9, 3.8814172589562807`*^9},
 CellLabel->"Out[141]=",
 CellID->337180613,ExpressionUUID->"7489fe4e-31f0-45cb-a796-44bde3171a59"]
}, Open  ]],

Cell["\<\
If we now look at the columns in which the Missings occur, it turns out that \
some of them are in 3, which is the first name of the player. This is not due \
to a failing of the dataset originators but due to the fact that many \
Brazilian players choose to play under a single name such \
\[OpenCurlyDoubleQuote]Pele\[CloseCurlyDoubleQuote] or \
\[OpenCurlyDoubleQuote]Kaka\[CloseCurlyDoubleQuote] rather than the \
conventional first name\[Dash]last name system. I want to preserve those \
often important players in our analysis. On the other hand, some of the \
columns for which I have missing data involve club name (column 1) or salary \
(column 5) or guaranteed compensation (column 6). If that information is \
missing, I do want to exclude the rows from my analysis. \
\>", "Text",
 CellChangeTimes->{{3.8806316219588947`*^9, 3.880631625830801*^9}, {
   3.880631691440929*^9, 3.880631851256894*^9}, {3.880631888170938*^9, 
   3.880631907608679*^9}, {3.880632156684169*^9, 3.880632171005986*^9}, 
   3.8853957810085945`*^9, {3.8855737513641725`*^9, 3.885573789053749*^9}},
 CellID->304759050,ExpressionUUID->"d54c1ccd-cffd-41b6-b2b9-d68f1d9dea68"],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s how I can use ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " to filter out the rows that contain crucial missing data."
}], "Text",
 CellChangeTimes->{{3.880631922462661*^9, 3.880631952543201*^9}, {
  3.880734487009157*^9, 3.880734488025971*^9}, {3.8855737918826914`*^9, 
  3.8855737922746534`*^9}},
 CellID->1198000130,ExpressionUUID->"0c90ac82-79c6-4dc1-86c9-d4c87a3c28f5"],

Cell[TextData[{
 "Combine ",
 ButtonBox["Or",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Or.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Or.html"],
 ", ",
 ButtonBox["Not",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Not.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Not.html"],
 ", and ",
 ButtonBox["MissingQ",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MissingQ.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MissingQ.html"],
 " to create a function that lets ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " preserve those rows in which the needed information is present:"
}], "CodeText",
 CellChangeTimes->{{3.8806322097656937`*^9, 3.880632255920855*^9}, {
   3.8806323075010138`*^9, 3.8806323948317204`*^9}, 3.885573808701597*^9},
 CellID->882612603,ExpressionUUID->"5502f81a-85c6-46c5-a81a-dd2e7b35c185"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"mls2", "=", 
    RowBox[{"Select", "[", 
     RowBox[{"mls", ",", 
      RowBox[{
       RowBox[{"Not", "[", 
        RowBox[{"Or", "[", 
         RowBox[{
          RowBox[{"MissingQ", "[", 
           RowBox[{"#", "[", 
            RowBox[{"[", "1", "]"}], "]"}], "]"}], ",", 
          RowBox[{"MissingQ", "[", 
           RowBox[{"#", "[", 
            RowBox[{"[", "5", "]"}], "]"}], "]"}], ",", 
          RowBox[{"MissingQ", "[", 
           RowBox[{"#", "[", 
            RowBox[{"[", "6", "]"}], "]"}], "]"}]}], "]"}], "]"}], "&"}]}], 
     "]"}]}], ")"}], "//", "Dimensions"}]], "Input",
 CellChangeTimes->{{3.880631958665175*^9, 3.880632031616207*^9}, {
  3.880632186453553*^9, 3.8806322050463543`*^9}},
 CellLabel->"In[10]:=",
 CellID->565657255,ExpressionUUID->"ebbf4be7-d644-4214-a5c6-2561b7238160"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"5532", ",", "7"}], "}"}]], "Output",
 CellChangeTimes->{{3.880632007054624*^9, 3.880632032030978*^9}, 
   3.8806322056649513`*^9, 3.881417266169786*^9, 3.882284060472444*^9},
 CellLabel->"Out[10]=",
 CellID->238026837,ExpressionUUID->"26cd36da-7ecd-41bd-80a8-86738a632b45"]
}, Open  ]],

Cell[TextData[{
 "The result, assigned to variable ",
 Cell[BoxData[
 "mls2"], "InlineCodeText",ExpressionUUID->
  "90a88648-dd97-4d71-af82-f0f9f39b8484"],
 ", has fewer rows than the original data because some of the rows \
\[OpenCurlyDoubleQuote]contaminated\[CloseCurlyDoubleQuote] with Missings \
have been deleted."
}], "Text",
 CellChangeTimes->{{3.769089297010152*^9, 3.769089426088163*^9}, {
   3.7690894680999804`*^9, 3.769089529523835*^9}, {3.76916111246236*^9, 
   3.769161145577916*^9}, {3.769161177687677*^9, 3.769161214260597*^9}, {
   3.7754106035824285`*^9, 3.7754106919924283`*^9}, {3.856280195553885*^9, 
   3.8562801965546103`*^9}, {3.865548846998844*^9, 3.865548906609082*^9}, 
   3.880632410732501*^9},
 CellID->1090138224,ExpressionUUID->"f201becc-1b66-408b-b009-9b2121eb0e50"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Data Transformations", "Subsubsection",
 CellChangeTimes->{{3.7718541609638987`*^9, 3.771854191606594*^9}},
 CellID->135643774,ExpressionUUID->"228e3bcf-a4ea-4d9c-a47d-c2b17b76eb0b"],

Cell[CellGroupData[{

Cell["Sorting", "Subsubsubsection",
 CellChangeTimes->{{3.771854210228755*^9, 3.7718542138602962`*^9}},
 CellID->1694358496,ExpressionUUID->"44b5e2d7-6fca-483d-8639-f8f05bb85e79"],

Cell["\<\
Let\[CloseCurlyQuote]s first do something simple: who have been the highest \
paid players in MLS?\
\>", "Text",
 CellChangeTimes->{{3.769097273966511*^9, 3.769097287598446*^9}, {
   3.769161221966975*^9, 3.769161228898493*^9}, {3.774783940949005*^9, 
   3.774783941661005*^9}, 3.775411443811428*^9},
 CellTags->{"LastCellOfAPage", "i:74"},
 CellID->1847183370,ExpressionUUID->"656c0d9f-7c7f-46d0-982f-3b3209acac89"],

Cell[TextData[{
 "Use ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " and a function to find the highest paid players:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782876609684*^9, 3.7748758565646324`*^9, 3.7754115532204285`*^9, {
   3.856280259925338*^9, 3.8562802621014557`*^9}, {3.880628833745373*^9, 
   3.880628841980362*^9}, {3.885574547393356*^9, 3.8855745605265512`*^9}},
 CellTags->"p: 49",
 CellID->1908282140,ExpressionUUID->"97af765f-2160-4aac-9dcf-243ce2868133"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Take", "[", 
    RowBox[{
     RowBox[{"ReverseSortBy", "[", 
      RowBox[{"mls2", ",", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "&"}]}], "]"}], ",", "10"}], "]"}], 
   ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690972905843983`*^9, 3.7690973326489143`*^9}, {
  3.7690976401729393`*^9, 3.7690976431180773`*^9}},
 CellLabel->"In[12]:=",
 CellID->501925993,ExpressionUUID->"a67d9964-4173-4c5d-8240-102d827f0b3d"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"ORL\"\>", "\<\"Kaka\"\>", 
     RowBox[{"Missing", "[", "]"}], "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox["6.66`*^6", 6.66*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox["7.1675`*^6", 7.1675*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"ORL\"\>", "\<\"Kaka\"\>", 
     RowBox[{"Missing", "[", "]"}], "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox["6.66`*^6", 6.66*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox["7.1675`*^6", 7.1675*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"ORL\"\>", "\<\"Kaka\"\>", 
     RowBox[{"Missing", "[", "]"}], "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox["6.66`*^6", 6.66*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox["7.1675`*^6", 7.1675*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"ORL\"\>", "\<\"Kaka\"\>", 
     RowBox[{"Missing", "[", "]"}], "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox["6.66`*^6", 6.66*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox["7.1675`*^6", 7.1675*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TOR\"\>", "\<\"Giovinco\"\>", "\<\"Sebastian\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox["5.6`*^6", 5.6*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "7.11555567`*^6", 7.11555567*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TOR\"\>", "\<\"Giovinco\"\>", "\<\"Sebastian\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox["5.6`*^6", 5.6*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "7.11555567`*^6", 7.11555567*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TOR\"\>", "\<\"Giovinco\"\>", "\<\"Sebastian\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox["5.6`*^6", 5.6*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "7.11555567`*^6", 7.11555567*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"SEA\"\>", "\<\"Dempsey\"\>", "\<\"Clint\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox["4.913004`*^6", 4.913004*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "6.69518875`*^6", 6.69518875*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"LA\"\>", "\<\"Beckham\"\>", "\<\"David\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
       "5.50000008`*^6", 5.50000008*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "6.50000004`*^6", 6.50000004*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2011\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2011", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"LA\"\>", "\<\"Beckham\"\>", "\<\"David\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
       "5.50000008`*^6", 5.50000008*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
       "6.50000004`*^6", 6.50000004*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2010\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2010", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.882284202172534*^9},
 CellLabel->"Out[12]=",
 CellID->277777813,ExpressionUUID->"7c6e3cc4-cb8d-49a7-8b91-af144ac9a8d8"]
}, Open  ]],

Cell["\<\
It turns out that Brazil\[CloseCurlyQuote]s Kaka, Italy\[CloseCurlyQuote]s \
Sebastian Giovinco, England\[CloseCurlyQuote]s David Beckham and America\
\[CloseCurlyQuote]s Clint Dempsey top the list.\
\>", "Text",
 CellChangeTimes->{{3.769161243825836*^9, 3.76916127443408*^9}, {
   3.76916130543286*^9, 3.769161328941997*^9}, {3.7691614530652113`*^9, 
   3.769161512628194*^9}, 3.769161917961008*^9, {3.8806288632439747`*^9, 
   3.8806289005693808`*^9}, {3.8806324346262407`*^9, 3.8806324451323757`*^9}, 
   3.896341305467767*^9},
 CellID->1414820192,ExpressionUUID->"df50a99b-6ada-43d0-b3f0-e7bfbda5e4a3"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Plotting", "Subsubsubsection",
 CellChangeTimes->{{3.771854223468622*^9, 3.771854229455421*^9}},
 CellID->1418350088,ExpressionUUID->"b62cae03-7860-4cf8-a8c0-c22550783f9f"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s create a scatter plot of the base salary versus the \
guaranteed compensation. I can do this using the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " function and then wrapping the results in ",
 ButtonBox["ListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ListPlot.html"],
 ". Notice the use of ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 " in the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " specification, which gets me all rows of the data. The ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"6", ",", "7"}], "}"}]], "InlineCodeText",ExpressionUUID->
  "7ec16476-7287-438e-ac17-367e94d9394b"],
 " gets me the fifth (base salary) and sixth (guaranteed compensation) column \
of each row. I\[CloseCurlyQuote]ve iconized the ",
 ButtonBox["ListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ListPlot.html"],
 " options as they are inessential to what I am trying to show here."
}], "Text",
 CellChangeTimes->{{3.7690895460898952`*^9, 3.769089570689013*^9}, {
   3.769089638179619*^9, 3.769089687985847*^9}, {3.769089719860806*^9, 
   3.769089722330472*^9}, {3.769089772017991*^9, 3.7690897868844767`*^9}, 
   3.7691613448422117`*^9, {3.774783944213005*^9, 3.774783944878005*^9}, {
   3.7754116828464284`*^9, 3.775411765653428*^9}, {3.880627220506463*^9, 
   3.880627222116499*^9}},
 CellTags->"i:75",
 CellID->51966467,ExpressionUUID->"3d8e0c22-db41-44f2-80fc-5a215eb981d3"],

Cell[TextData[{
 "Get two columns from the data and make a scatter plot with ",
 ButtonBox["ListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ListPlot.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782888181841*^9, 3.7748758604116325`*^9, {3.7754117723764286`*^9, 
   3.7754117769284286`*^9}},
 CellID->64051613,ExpressionUUID->"4822b8e4-c05c-4a22-99d2-1ad8699ff002"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ListPlot", "[", 
  RowBox[{
   RowBox[{"mls2", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", 
      RowBox[{"{", 
       RowBox[{"5", ",", "6"}], "}"}]}], "]"}], "]"}], ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["5", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["520", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[
    ImageSize -> 500, Axes -> False, Frame -> True, 
     FrameLabel -> {"base salary", "guaranteed compensation"}, PlotRange -> 
     All],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.7690895768854313`*^9, 3.7690895993208942`*^9}, {
   3.769089693071534*^9, 3.769089767801755*^9}, 3.880627137659216*^9, {
   3.880627211973288*^9, 3.880627213546316*^9}, {3.8806289300027113`*^9, 
   3.880628932150008*^9}, {3.880632476276129*^9, 3.88063253296801*^9}},
 CellLabel->"In[14]:=",
 CellID->87773158,ExpressionUUID->"6c1ff94f-828b-4287-9e87-51c0bd31bcdc"],

Cell[BoxData[
 GraphicsBox[{{}, 
   {RGBColor[0.368417, 0.506779, 0.709798], PointSize[0.003666666666666667], 
    AbsoluteThickness[1.6], PointBox[CompressedData["
1:eJylfXm81XP+/2m5ddt02y8VB6lUuFmT7VxCCFcLDc04jCWhuQxqsh2ENIZr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     "]]}, {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{0, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"guaranteed compensation\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"base salary\"", HoldForm], TraditionalForm], None}},
  FrameTicks->{{Automatic, Automatic}, {Automatic, Automatic}},
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "AxisPadding" -> Scaled[0.02], "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "OptimizePlotMarkers" -> True, "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{0, 6.66*^6}, {0, 7.1675*^6}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{Automatic, Automatic}]], "Output",
 CellChangeTimes->{{3.7690895899747047`*^9, 3.769089601316724*^9}, {
   3.7690897059316683`*^9, 3.769089759083831*^9}, 3.769100656295145*^9, 
   3.769772689956085*^9, 3.7699755470919943`*^9, 3.7719235964084806`*^9, 
   3.7719289482249537`*^9, 3.771929526418715*^9, 3.880627131899722*^9, 
   3.8806272149232073`*^9, 3.8806289341618357`*^9, {3.8806324540312643`*^9, 
   3.880632535427966*^9}, 3.881417339303055*^9, 3.882284248557638*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[14]=",
 CellID->990161061,ExpressionUUID->"e597848a-580f-4d3e-9eaf-c427e79ac277"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Sorting with Selection", "Subsubsubsection",
 CellChangeTimes->{{3.7690995533972797`*^9, 3.7690995629595337`*^9}, {
  3.771854241208891*^9, 3.7718542469910307`*^9}},
 CellTags->"p: 50",
 CellID->548822030,ExpressionUUID->"860f23f7-281b-44f1-ab40-c85f10c6b08a"],

Cell[TextData[{
 "It seems as if, for many players, the base compensation is the same as the \
guaranteed amount, but for others, the guaranteed amount is higher. I\
\[CloseCurlyQuote]d like to know the identity of players for whom the ratio \
between guaranteed amount and base amount is greatest. Here I use ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " and ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " to accomplish the job. "
}], "Text",
 CellChangeTimes->{{3.769089808365446*^9, 3.769089866144796*^9}, {
   3.7690899062546864`*^9, 3.769089937048991*^9}, {3.769162013090867*^9, 
   3.769162024604827*^9}, {3.7691620710100327`*^9, 3.769162114396327*^9}, {
   3.7754117840084286`*^9, 3.7754118015424285`*^9}, 3.777354791762307*^9, {
   3.856280290582573*^9, 3.856280328079397*^9}, {3.8565396449458017`*^9, 
   3.85653966214614*^9}, 3.880627267413506*^9},
 CellTags->"i:76",
 CellID->710098879,ExpressionUUID->"b397d02c-8b3a-4f6e-9c18-15da11facee9"],

Cell[TextData[{
 "Combine ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " and ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " operators:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747828970857315`*^9, 3.774875864108632*^9, {3.777354775292178*^9, 
   3.777354780408042*^9}, {3.856280352367937*^9, 3.8562803559462214`*^9}, {
   3.8855748640815325`*^9, 3.8855748762066827`*^9}},
 CellID->1134921,ExpressionUUID->"a6d5774c-0fa4-4622-9a9f-c930d31e07a9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Grid", "[", 
  RowBox[{
   RowBox[{"Part", "[", 
    RowBox[{
     RowBox[{"ReverseSortBy", "[", 
      RowBox[{"mls2", ",", 
       RowBox[{
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "6", "]"}], "]"}], "/", 
         RowBox[{"#", "[", 
          RowBox[{"[", "5", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
     RowBox[{"Range", "[", "10", "]"}]}], "]"}], ",", 
   RowBox[{"Dividers", "\[Rule]", "All"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.76908986951547*^9, 3.769089894494091*^9}, {
  3.769097648524687*^9, 3.769097654141163*^9}, {3.769162028653892*^9, 
  3.76916202937739*^9}, {3.880627239874194*^9, 3.88062724577913*^9}, {
  3.880628939315803*^9, 3.880628941770832*^9}},
 CellLabel->"In[15]:=",
 CellID->552175843,ExpressionUUID->"06d41cb5-af6e-4126-8ab3-e974ffb028a1"],

Cell[BoxData[
 TagBox[GridBox[{
    {"\<\"CHV\"\>", "\<\"Courtois\"\>", "\<\"Laurent\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"60\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           60000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 60000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"206\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          206000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 206000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2011\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2011", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TFC\"\>", "\<\"Wynne\"\>", "\<\"Marvell\"\>", "\<\"D\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"47\[ThinSpace]500.00\"", ShowStringCharacters -> False],
           47500., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 47500., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"150\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          150000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 150000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2008\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2008", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TFC\"\>", "\<\"Wynne\"\>", "\<\"Marvell\"\>", "\<\"D\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"47\[ThinSpace]500.00\"", ShowStringCharacters -> False],
           47500., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 47500., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"150\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          150000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 150000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TFC\"\>", "\<\"White\"\>", "\<\"O'Brian\"\>", "\<\"F\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"36\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           36000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 36000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"113\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          113000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 113000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2009\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2009", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"POR\"\>", "\<\"Nagbe\"\>", "\<\"Darlington\"\>", "\<\"M/F\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"65\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           65000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 65000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"201\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          201000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 201000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2011\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2011", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"POR\"\>", "\<\"Okugo\"\>", "\<\"Amobi\"\>", "\<\"D-M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"65\[ThinSpace]004.00\"", ShowStringCharacters -> False],
           65004., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 65004., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"187\[ThinSpace]941.50\"", ShowStringCharacters -> False], 
          187941.5, AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 187941.5, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TFC\"\>", "\<\"Wynne\"\>", "\<\"Marvell\"\>", "\<\"D\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"57\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           57000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 57000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"159\[ThinSpace]500.00\"", ShowStringCharacters -> False], 
          159500., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 159500., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2009\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2009", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"PHI\"\>", "\<\"Stahl\"\>", "\<\"Toni\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"40\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           40000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 40000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"110\[ThinSpace]300.00\"", ShowStringCharacters -> False], 
          110300., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 110300., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2010\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2010", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"CLB\"\>", "\<\"Duka\"\>", "\<\"Dilaver\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"80\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           80000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 80000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"213\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          213000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 213000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2010\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2010", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]},
    {"\<\"TFC\"\>", "\<\"Edu\"\>", "\<\"Maurice\"\>", "\<\"M\"\>", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"50\[ThinSpace]000.00\"", ShowStringCharacters -> False],
           50000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 50000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"132\[ThinSpace]500.00\"", ShowStringCharacters -> False], 
          132500., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 132500., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"], 
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False]}
   },
   AutoDelete->False,
   GridBoxDividers->{"Columns" -> {{True}}, "Rows" -> {{True}}},
   GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
  "Grid"]], "Output",
 CellChangeTimes->{3.769089895441594*^9, 3.7690976550619183`*^9, 
  3.769100656894287*^9, 3.769162031596878*^9, 3.769772691930862*^9, 
  3.769975548858254*^9, 3.7719235964517937`*^9, 3.771928952093549*^9, 
  3.771929527935815*^9, 3.880627246876554*^9, 3.8806289427655773`*^9, 
  3.880632553435671*^9, 3.881417385741599*^9, 3.882284256095674*^9},
 CellLabel->"Out[15]=",
 CellID->1120730804,ExpressionUUID->"be44958f-0c9b-4954-b48f-3986d123685c"]
}, Open  ]],

Cell[TextData[{
 "By the way, where the desired Parts of an expression are adjacent to each \
other, I can use the ",
 ButtonBox["Take",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Take.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Take.html"],
 " function rather than ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.7690900308500767`*^9, 3.769090105849659*^9}, {
   3.7754118654794283`*^9, 3.775411869271428*^9}, 3.777354837058084*^9},
 CellTags->"i:77",
 CellID->1297442800,ExpressionUUID->"e858c192-b04f-41db-ae20-8c5237b01211"],

Cell[TextData[{
 "Use ",
 ButtonBox["Take",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Take.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Take.html"],
 " when the Parts you want are adjacent:"
}], "CodeCaption",
 CellChangeTimes->{3.774782910119035*^9, 3.7748758669726324`*^9, 
  3.7754119006194286`*^9, 3.777354820178101*^9},
 CellID->15260860,ExpressionUUID->"98d45cb8-a940-442d-9e8e-866b16b82645"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"Take", "[", 
   RowBox[{
    RowBox[{"ReverseSortBy", "[", 
     RowBox[{"mls2", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"#", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "&"}]}], "]"}], ",", "10"}], "]"}],
   "===", 
  RowBox[{"Part", "[", 
   RowBox[{
    RowBox[{"ReverseSortBy", "[", 
     RowBox[{"mls2", ",", 
      RowBox[{
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "6", "]"}], "]"}], "/", 
        RowBox[{"#", "[", 
         RowBox[{"[", "5", "]"}], "]"}]}], "&"}]}], "]"}], ",", 
    RowBox[{"Range", "[", "10", "]"}]}], "]"}]}]], "Input",
 CellChangeTimes->{{3.76908986951547*^9, 3.769089894494091*^9}, {
  3.769090061269087*^9, 3.769090063719924*^9}, {3.7691621205314083`*^9, 
  3.769162156780081*^9}, {3.880627275334887*^9, 3.880627284087471*^9}, {
  3.880628949713122*^9, 3.880628956683161*^9}},
 CellLabel->"In[16]:=",
 CellID->1628499304,ExpressionUUID->"e2d44eee-a791-45e2-9b28-7f20e6f7c575"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{
  3.769100657515176*^9, {3.76916212269305*^9, 3.769162160048802*^9}, 
   3.769772695542207*^9, 3.769975552387631*^9, 3.771923596527149*^9, 
   3.771928957960041*^9, 3.771929530918787*^9, 3.880627285422365*^9, 
   3.8806289579151287`*^9, 3.88063256846399*^9, 3.881417399822967*^9, 
   3.882284266610528*^9},
 CellLabel->"Out[16]=",
 CellID->537555172,ExpressionUUID->"54662d09-9778-4c20-91c7-e0de546c64af"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Gathering and Aggregating", "Subsubsubsection",
 CellChangeTimes->{{3.769097249358554*^9, 3.769097258276696*^9}, {
  3.7718542689856052`*^9, 3.771854283081349*^9}},
 CellID->205602557,ExpressionUUID->"b478f179-b329-4fc6-bfb6-2f763d0417e3"],

Cell["\<\
Let\[CloseCurlyQuote]s also see how total league payroll has varied over \
time. First, I gather the data together by year, which is in column seven. \
The result is a number of matrices, one for each year of the data, and each \
one of which has seven columns, just like the original matrix. \
\>", "Text",
 CellChangeTimes->{{3.7690959414445477`*^9, 3.7690959567658243`*^9}, {
  3.7690989598359823`*^9, 3.769099036278433*^9}, {3.7690995711662188`*^9, 
  3.769099579150588*^9}, {3.774783950349005*^9, 3.774783951054005*^9}, {
  3.7754120744874287`*^9, 3.775412084087428*^9}, {3.856280523853554*^9, 
  3.856280531886381*^9}, {3.880629103451231*^9, 3.880629105406598*^9}},
 CellTags->"i:78",
 CellID->629872765,ExpressionUUID->"21e936b0-84ad-4cec-8cc7-fd2468614943"],

Cell[TextData[{
 "Use ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " to break up the data by year:"
}], "CodeCaption",
 CellChangeTimes->{3.7747829212711496`*^9, 3.774875870139632*^9, 
  3.775412089896428*^9},
 CellID->140116007,ExpressionUUID->"5e26ff0f-3630-4cb0-8b39-128899b81ace"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Dimensions", ",", 
   RowBox[{"mlsByYear", "=", 
    RowBox[{"GatherBy", "[", 
     RowBox[{"mls2", ",", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "7", "]"}], "]"}], "&"}]}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769099001620687*^9, 3.7690990112966633`*^9}, {
  3.7690990579811907`*^9, 3.7690990594691353`*^9}, {3.880627322402883*^9, 
  3.880627322534913*^9}, {3.8806289637271137`*^9, 3.880628963815361*^9}},
 CellLabel->"In[17]:=",
 CellID->1159000034,ExpressionUUID->"1e293fc6-11da-4dfb-ac87-7f204208ca99"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"371", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"388", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"411", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"552", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"573", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"569", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"549", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"614", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769099011571574*^9, 3.769099059992247*^9, 
  3.76910065767209*^9, 3.769772695596246*^9, 3.769975552448855*^9, 
  3.7719235965636168`*^9, 3.77192896173505*^9, 3.771929531007683*^9, 
  3.8806273232047863`*^9, 3.880628964330051*^9, 3.88063257165388*^9, 
  3.88141740406181*^9, 3.882284234471674*^9, 3.882284268217647*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[17]=",
 CellID->2011476000,ExpressionUUID->"68cc9deb-2f39-4e5e-8467-1ba32ce2baec"]
}, Open  ]],

Cell[TextData[{
 "Now I get compensation and year information for each person in each year. \
The result is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of matrices that have the same number of rows as the corresponding \
matrices in the input data but in which there are only two columns."
}], "Text",
 CellChangeTimes->{{3.769099079580755*^9, 3.769099110032043*^9}, {
   3.7690991466262417`*^9, 3.769099183428298*^9}, {3.7690995851655703`*^9, 
   3.7690995895104733`*^9}, {3.7754121000304284`*^9, 
   3.7754121011264286`*^9}, {3.8562805486365557`*^9, 
   3.8562805498842497`*^9}, {3.8806291124492598`*^9, 3.880629117706646*^9}, 
   3.885575201120085*^9},
 CellTags->"p: 51",
 CellID->246154164,ExpressionUUID->"a46ba477-f1db-410c-9cde-276de4d047da"],

Cell["\<\
Grab the year and guaranteed compensation information for each year:\
\>", "CodeCaption",
 CellChangeTimes->{
  3.7747829312951517`*^9, 3.7748758720206327`*^9, {3.880629673851083*^9, 
   3.8806296787449493`*^9}},
 CellID->856564760,ExpressionUUID->"2da01586-a13d-418e-bf7d-43ee65c36763"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Dimensions", ",", 
   RowBox[{"mlsYearCompensation", "=", 
    RowBox[{"mlsByYear", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "6"}], "}"}]}], "]"}], "]"}]}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769099112039833*^9, 3.7690991437556353`*^9}, {
  3.769099189020838*^9, 3.769099198439282*^9}, {3.880627339508341*^9, 
  3.880627339612598*^9}, {3.880628974057004*^9, 3.880628995890813*^9}, {
  3.880629120664587*^9, 3.880629120744213*^9}, {3.880629684102549*^9, 
  3.8806296883644257`*^9}},
 CellLabel->"In[18]:=",
 CellID->1701035479,ExpressionUUID->"57bda192-9206-4083-861f-35c5dcc601ea"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"371", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"388", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"411", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"552", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"573", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"569", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"549", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"614", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769099126960079*^9, 3.769099144415853*^9}, 
   3.76909919984757*^9, 3.769100657712595*^9, 3.76977269563369*^9, 
   3.769975552461988*^9, 3.771923596581993*^9, 3.7719289642325163`*^9, 
   3.7719295310472603`*^9, 3.880627350028371*^9, {3.8806289749069967`*^9, 
   3.8806289964139214`*^9}, 3.8806291211882353`*^9, 3.880629689496711*^9, 
   3.880632574301064*^9, 3.881417435092119*^9, 3.8822842808621483`*^9},
 CellLabel->"Out[18]=",
 CellID->1376280383,ExpressionUUID->"339d72d6-fca9-4777-9036-7c7f11a9f82c"]
}, Open  ]],

Cell["Let\[CloseCurlyQuote]s focus on one of these matrices.", "Text",
 CellChangeTimes->{{3.769099237392634*^9, 3.769099278920083*^9}, {
  3.769099600936778*^9, 3.7690996055259037`*^9}, {3.774783954116005*^9, 
  3.774783958501005*^9}, {3.7754708938831472`*^9, 3.7754708946032195`*^9}},
 CellID->349930657,ExpressionUUID->"2d6de410-c054-49f8-9cf5-82b5bcd766a9"],

Cell["Look at the first five rows of the first matrix:", "CodeCaption",
 CellChangeTimes->{{3.7754708524350033`*^9, 3.7754708581625757`*^9}},
 CellID->32079444,ExpressionUUID->"09bdd8a6-d9a4-4c60-8de8-982612ce484c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mlsYearCompensation", "[", 
  RowBox[{"[", 
   RowBox[{"1", ",", 
    RowBox[{"Range", "[", "5", "]"}]}], "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.769099256760113*^9, 3.769099275826295*^9}, {
  3.880629694228784*^9, 3.8806296972185383`*^9}},
 CellLabel->"In[19]:=",
 CellID->1904637586,ExpressionUUID->"edbe4e2a-2f9a-4b9c-b5da-7fcb8d7a9d36"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"225\[ThinSpace]000.00\"", ShowStringCharacters -> False], 
          225000., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 225000., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"12\[ThinSpace]900.00\"", ShowStringCharacters -> False],
           12900., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 12900., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox["\"48\[ThinSpace]712.50\"", ShowStringCharacters -> False],
           48712.5, AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 48712.5, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox["2.666778`*^6", 2.666778*^6, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
        TagBox[
         InterpretationBox[
          StyleBox[
          "\"106\[ThinSpace]391.00\"", ShowStringCharacters -> False], 
          106391., AutoDelete -> True], 
         NumberForm[#, {Infinity, 2}, DigitBlock -> 3, NumberSeparator -> 
          "\[ThinSpace]"]& ], 106391., Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.7690992640820093`*^9, 3.769099280707986*^9}, 
   3.769100657754484*^9, 3.7697726956488256`*^9, 3.769975552506556*^9, 
   3.7719235966195917`*^9, 3.771928966487722*^9, 3.7719295310561657`*^9, 
   3.880627355192368*^9, {3.880628978147409*^9, 3.880629001481574*^9}, 
   3.8806291244679832`*^9, 3.880629697632937*^9, 3.880632579643489*^9, 
   3.881417448763142*^9, 3.8822842981852913`*^9},
 CellLabel->"Out[19]=",
 CellID->1192867431,ExpressionUUID->"213b209b-a7b2-4808-8176-d932837cc9fb"]
}, Open  ]],

Cell[TextData[{
 "What I see is the year information is the same. This result is expected; \
the first matrix was created by gathering all the data from the \
first-confronted year together, so to create a relationship between year and \
total compensation, I just need the first column of the first row to get the \
year for the entire matrix. And I need the ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " of the second column of each matrix to get the total compensation for that \
year. I use the ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " function to do this for all the matrices."
}], "Text",
 CellChangeTimes->{{3.7690992822585487`*^9, 3.7690993847240963`*^9}, {
   3.769162415854838*^9, 3.769162418612007*^9}, {3.775470915276286*^9, 
   3.775470935540313*^9}, 3.7754710104198*^9, 3.777354968945436*^9, {
   3.8806291315777273`*^9, 3.8806291340193644`*^9}},
 CellID->1791646266,ExpressionUUID->"51a81055-744e-4ebe-9ab2-ed1fdb9c4dc1"],

Cell["\<\
I first define the function to be used to create the data structure.\
\>", "Text",
 CellChangeTimes->{{3.769162421025311*^9, 3.769162438827026*^9}, {
  3.7754710217059283`*^9, 3.775471022271985*^9}},
 CellID->1530152877,ExpressionUUID->"fef39cfe-39f7-4ba6-ad8a-e32d6a403900"],

Cell[TextData[{
 "Write a function to take a two-column matrix and get the top-left element \
and the ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " of all the second-column elements:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747829450005226`*^9, {3.7748758755156326`*^9, 3.7748758777876325`*^9}, {
   3.775471028289587*^9, 3.7754710285296106`*^9}, {3.7773549857774687`*^9, 
   3.777354988489565*^9}, {3.8855752709998245`*^9, 3.88557527134296*^9}},
 CellID->284599811,ExpressionUUID->"ae55b62b-d449-4eb9-9ce4-c038e360d6bc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"yearTotal", "=", 
   RowBox[{"matrix", "\[Function]", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"matrix", "[", 
       RowBox[{"[", 
        RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
      RowBox[{"Total", "[", 
       RowBox[{"matrix", "[", 
        RowBox[{"[", 
         RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "}"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769162440869521*^9, 3.7691624528575783`*^9}, {
  3.8806297685447073`*^9, 3.8806297696251097`*^9}},
 CellLabel->"In[20]:=",
 CellID->172782680,ExpressionUUID->"904a39f8-7b25-4cfc-8ea8-c72c52863eb3"],

Cell[TextData[{
 "Now use the operator form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " to evaluate ",
 Cell[BoxData[
 "yearTotalCompensation"], "InlineCode",ExpressionUUID->
  "b2cf301c-4bb7-4487-8f1a-00b45274a98a"],
 " over all the years:"
}], "CodeCaption",
 CellChangeTimes->{{3.775471518049399*^9, 3.775471538421399*^9}, {
   3.775471628904399*^9, 3.7754716415003986`*^9}, {3.8806297119583893`*^9, 
   3.8806297165168123`*^9}, 3.8855752804339285`*^9},
 CellID->1269423376,ExpressionUUID->"304d4d0b-ebb7-4c65-ad8d-64de43f2df29"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mlsYearTotalCompensation", "=", 
  RowBox[{
   RowBox[{"Map", "[", "yearTotal", "]"}], "[", "mlsYearCompensation", 
   "]"}]}]], "Input",
 CellChangeTimes->{{3.769099388087661*^9, 3.7690994512065697`*^9}, {
  3.769162386418289*^9, 3.769162389625312*^9}, {3.769162455854075*^9, 
  3.7691624620075407`*^9}, {3.880629719135434*^9, 3.8806297309798517`*^9}, {
  3.880629772730197*^9, 3.8806297744852753`*^9}},
 CellLabel->"In[21]:=",
 CellID->52370275,ExpressionUUID->"97580554-b511-4f1e-9bd8-5bb74a13b59a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "4.222366007`*^7", 4.222366007*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2008\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2008", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "4.729250920999999`*^7", 4.729250920999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2009\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2009", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "5.187805049`*^7", 5.187805049*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2010\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2010", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "7.130497269999999`*^7", 7.130497269999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2011\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2011", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "8.507947580999999`*^7", 8.507947580999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "9.913085228`*^7", 9.913085228*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2013\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2013", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "9.48496423`*^7", 9.48496423*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.2933452645`*^8", 1.2933452645*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.6701798003`*^8", 1.6701798003*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.7512715915`*^8", 1.7512715915*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "2.0039435593`*^8", 2.0039435593*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.769099417714246*^9, 3.7690994516183558`*^9, 3.769100657926992*^9, 
   3.769162391202332*^9, 3.76977269588104*^9, 3.769975552709906*^9, 
   3.771923596695853*^9, 3.77192897186614*^9, 3.771929531217815*^9, 
   3.8806273696164227`*^9, 3.880629026191929*^9, {3.880629723078312*^9, 
   3.88062973137633*^9}, 3.8806297751534843`*^9, 3.880632585918812*^9, 
   3.88141750654012*^9, 3.8822843178501673`*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[21]=",
 CellID->1745520635,ExpressionUUID->"9a0f9848-20d8-4a89-8314-eefe242056d5"]
}, Open  ]],

Cell[TextData[{
 "Now if I just wrap a ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 " around the result, I get an attractive graphic. Again, I iconize out the \
details."
}], "Text",
 CellChangeTimes->{{3.769099421619944*^9, 3.769099433888154*^9}, {
  3.769162276431139*^9, 3.76916233642794*^9}, {3.7754716882293987`*^9, 
  3.7754716930853987`*^9}, {3.880629058677951*^9, 3.880629060886574*^9}},
 CellTags->{"i:79", "p: 52"},
 CellID->1105562149,ExpressionUUID->"459cf7d2-c2ef-4ec6-a788-f8275d1b50a7"],

Cell[TextData[{
 "Make a ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 " of total guaranteed compensation paid by year in MLS:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774782956809703*^9, 3.7748758801386323`*^9, {3.880629658878626*^9, 
   3.880629662252563*^9}, {3.8855753018905*^9, 3.885575319674657*^9}},
 CellID->1721805856,ExpressionUUID->"75898072-3e0f-47a0-8415-f0b7dcfddc52"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"DateListPlot", "[", 
  RowBox[{"mlsYearTotalCompensation", ",", 
   InterpretationBox[
    DynamicModuleBox[{Typeset`open = False}, 
     TemplateBox[{"Expression", "SequenceIcon", 
       GridBox[{{
          RowBox[{
            TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["Sequence", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["5", "IconizedItem"]}]}, {
          RowBox[{
            TagBox["\"Byte count: \"", "IconizedLabel"], "\[InvisibleSpace]", 
            TagBox["512", "IconizedItem"]}]}}, 
        GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
        "Column", 
        GridBoxItemSize -> {
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
       Dynamic[Typeset`open]},
      "IconizedObject"]],
    Sequence[
    ImageSize -> 500, Frame -> True, 
     FrameLabel -> {"Year", "Total MLS Compensation"}, Joined -> False, 
     Filling -> Bottom],
    SelectWithContents->True,
    Selectable->False]}], "]"}]], "Input",
 CellChangeTimes->{{3.769099436489541*^9, 3.769099491639867*^9}, {
   3.769162204268146*^9, 3.769162238992786*^9}, 3.7691622726821537`*^9, {
   3.8806273796852417`*^9, 3.880627394150714*^9}, {3.880629734459195*^9, 
   3.8806297374369907`*^9}},
 CellLabel->"In[22]:=",
 CellID->1245916292,ExpressionUUID->"7fc00ab4-b4e4-41cc-884a-d682ec972cfb"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQQbIjVeOmrG9Cc4KrU4AvkKDSkvHatE1r1k6m0D
8Q9cWPDSUb71tfDRPR0gvsH3Oy8dz5w5YyTDMBHEXyAr+cpxcYHt+WseU0B8
AZfQV45BO+Qmli+aDuJvmDLxlaOxsfFKzbnTwObvPvvK8eyZMz8/X50H4k94
yPkaaD//j98vFoP4DBxur4HyPu9KHiwBmx/R9Nrxm8ad5z2PlzvC3MuAAGD3
IvHB7kXig92LxAe7F4kPdi8SH+xeZPNB7kXig92LxAe7F9l8kHuRzRtK4QsA
iC6txQ==
    "], {{{}, {}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{12, 1}],
        LineBox[{13, 2}], LineBox[{14, 3}], LineBox[{15, 4}], 
       LineBox[{16, 5}], LineBox[{17, 6}], LineBox[{18, 7}], LineBox[{19, 8}],
        LineBox[{20, 9}], LineBox[{21, 10}], LineBox[{22, 11}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.3765984*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Total MLS Compensation\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Year\"", HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {
      Charting`DateTicksFunction[Automatic, DateTicksFormat -> {Automatic}], 
      Charting`DateTicksFunction[
      Automatic, DateTicksFormat -> {Automatic}, "TickLabels" -> None]}}, {{
     Automatic, Automatic}, {{{3.3450624*^9, 
        FormBox[
         StyleBox["\"2006\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         StyleBox["\"2008\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         StyleBox["\"2010\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         StyleBox["\"2012\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         StyleBox["\"2014\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         StyleBox["\"2016\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         StyleBox["\"2018\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}, {{3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "NoShowPlotTheme" -> Automatic, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "AllowMicroRanges" -> {True, False}, "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{3.3765984*^9, 3.6922176*^9}, {0, 2.0039435593*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{{}, Automatic}]], "Output",
 CellChangeTimes->{
  3.769099491977737*^9, 3.7691006580651493`*^9, {3.769162219469822*^9, 
   3.769162239849196*^9}, 3.769772696070386*^9, 3.769975552899044*^9, 
   3.771923596756895*^9, 3.7719289746367893`*^9, 3.771929531374092*^9, 
   3.880627396157176*^9, 3.8806290303638678`*^9, 3.880629737857327*^9, 
   3.8806325892389383`*^9, 3.881417521804268*^9, 3.882284331739737*^9},
 CellLabel->"Out[22]=",
 CellID->1191607268,ExpressionUUID->"74dc01b9-19e4-46e3-b884-acedd237cb03"]
}, Open  ]],

Cell["\<\
I\[CloseCurlyQuote]d also like to see if the same pattern holds for base \
salary, but now I\[CloseCurlyQuote]d like to put all the code together and do \
it in one step. Indeed, I\[CloseCurlyQuote]d like to do it using operator \
forms.\
\>", "Text",
 CellChangeTimes->{{3.769162184067679*^9, 3.769162194889374*^9}, {
  3.769162284062365*^9, 3.769162293682304*^9}, {3.76916258137211*^9, 
  3.7691625881692333`*^9}, {3.7747839610920053`*^9, 3.774783961461005*^9}, {
  3.7754717218113985`*^9, 3.7754717225873985`*^9}},
 CellID->1553562708,ExpressionUUID->"25292037-276f-426b-8995-c9c11130aaac"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s graph using a ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{{3.7773550381153727`*^9, 3.77735504133678*^9}},
 CellID->1452548128,ExpressionUUID->"7010edff-26a9-4b29-9e1c-f7524fdb3bb1"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{
      RowBox[{"#", "[", 
       RowBox[{"[", 
        RowBox[{"All", ",", "All", ",", 
         RowBox[{"{", 
          RowBox[{"7", ",", "5"}], "}"}]}], "]"}], "]"}], "&"}], ")"}], "/*", 
    RowBox[{"Map", "[", "yearTotal", "]"}], "/*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"DateListPlot", "[", 
       RowBox[{"#", ",", 
        InterpretationBox[
         DynamicModuleBox[{Typeset`open = False}, 
          TemplateBox[{"Expression", "SequenceIcon", 
            GridBox[{{
               RowBox[{
                 TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
                 TagBox["Sequence", "IconizedItem"]}]}, {
               RowBox[{
                 TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
                 TagBox["5", "IconizedItem"]}]}, {
               RowBox[{
                 TagBox["\"Byte count: \"", "IconizedLabel"], 
                 "\[InvisibleSpace]", 
                 TagBox["512", "IconizedItem"]}]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
             "Column", 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
            Dynamic[Typeset`open]},
           "IconizedObject"]],
         Sequence[
         ImageSize -> 500, Frame -> True, 
          FrameLabel -> {"Year", "Base MLS Compensation"}, Joined -> False, 
          Filling -> Bottom],
         SelectWithContents->True,
         Selectable->False]}], "]"}], "&"}], ")"}]}], ")"}], "[", "mlsByYear",
   "]"}]], "Input",
 CellChangeTimes->{{3.769162592626906*^9, 3.769162652829419*^9}, {
  3.880629779571671*^9, 3.880629780788166*^9}},
 CellLabel->"In[23]:=",
 CellID->525491609,ExpressionUUID->"530a9059-d389-4673-9aa0-5b4bfcf3b5e7"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQQbIjVeOt5YXPCYP7LJEchXaEh56Vgtsu50VkUL
iH/gwoKXjksKbN/8j2kD8Q2+33npaGxsPPnMxD4Qf4Gs5CvHHXKtfeIPJ4L4
Ai6hrxxF1rmfqJg+BcTfMGXiK8eZM2euadEC8xV2n33l2Po68MPMY7NB/AkP
OV87yre+DmXgWATiM3C4vXbkuq78fbLiYrD5EU2vgeovLo09sNQR5l4GBAC7
F4kPdi8SH+xeJD7YvUh8sHuR+GD3IpsPci8SH+xeJD7Yvcjmg9yLbN5QCl8A
moGqOQ==
    "], {{{}, {}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{12, 1}],
        LineBox[{13, 2}], LineBox[{14, 3}], LineBox[{15, 4}], 
       LineBox[{16, 5}], LineBox[{17, 6}], LineBox[{18, 7}], LineBox[{19, 8}],
        LineBox[{20, 9}], LineBox[{21, 10}], LineBox[{22, 11}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.3765984*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Base MLS Compensation\"", HoldForm], TraditionalForm], None}, {
     FormBox[
      TagBox["\"Year\"", HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {
      Charting`DateTicksFunction[Automatic, DateTicksFormat -> {Automatic}], 
      Charting`DateTicksFunction[
      Automatic, DateTicksFormat -> {Automatic}, "TickLabels" -> None]}}, {{
     Automatic, Automatic}, {{{3.3450624*^9, 
        FormBox[
         StyleBox["\"2006\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         StyleBox["\"2008\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         StyleBox["\"2010\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         StyleBox["\"2012\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         StyleBox["\"2014\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         StyleBox["\"2016\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         StyleBox["\"2018\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}, {{3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "NoShowPlotTheme" -> Automatic, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "AllowMicroRanges" -> {True, False}, "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{3.3765984*^9, 3.6922176*^9}, {0, 1.8246421091*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{{}, Automatic}]], "Output",
 CellChangeTimes->{3.76916265375213*^9, 3.769772696281273*^9, 
  3.7699755531036587`*^9, 3.7719235976281567`*^9, 3.771928977223433*^9, 
  3.771929531539855*^9, 3.8806297939360657`*^9, 3.880632607632617*^9, 
  3.881417531107704*^9, 3.882284338391378*^9},
 CellLabel->"Out[23]=",
 CellID->1432550493,ExpressionUUID->"3d6642cb-0a5a-474d-b57b-b6dbdc119ab1"]
}, Open  ]],

Cell["The pattern is indeed very similar.", "Text",
 CellChangeTimes->{{3.769162694120187*^9, 3.769162715927141*^9}, {
  3.8562806351904707`*^9, 3.8562806437743483`*^9}, {3.880629820092856*^9, 
  3.880629824648089*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1136515825,ExpressionUUID->"0bd6a873-645e-4b2d-bde4-e97fe67d64bb"]
}, Open  ]],

Cell[CellGroupData[{

Cell["From Gathering to Aggregating to Sorting", "Subsubsubsection",
 CellChangeTimes->{{3.769099617755953*^9, 3.7690996278947983`*^9}, {
  3.771854322996808*^9, 3.771854345159197*^9}},
 CellTags->"p: 53",
 CellID->562117424,ExpressionUUID->"84036eed-4393-4dd2-9889-e87496cbf72d"],

Cell[TextData[{
 "I wonder what teams had the highest payroll. Let\[CloseCurlyQuote]s ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " team and year then total up the guaranteed compensation. I\
\[CloseCurlyQuote]ll proceed in multiple steps though this could be written \
as a one-liner."
}], "Text",
 CellChangeTimes->{{3.76909012240377*^9, 3.7690901719204693`*^9}, 
   3.7754720591533985`*^9, 3.877707616867611*^9},
 CellTags->"i:80",
 CellID->1301156318,ExpressionUUID->"50be217a-b749-4b07-8096-8be4e862acb0"],

Cell["\<\
First, let\[CloseCurlyQuote]s break down the number of players by year and by \
team. There ends up being 213 combinations.\
\>", "Text",
 CellID->1486998922,ExpressionUUID->"a988711b-5517-4ccd-b5eb-f2f72f95111a"],

Cell["Break down the MLS data by a combination of team and year:", \
"CodeCaption",
 CellChangeTimes->{3.7747829704730697`*^9, 3.7748758875226326`*^9},
 CellID->64004257,ExpressionUUID->"f329c0db-680e-40a2-85a9-59941b30b42c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{"mlsByTeamYear", "=", 
   RowBox[{"GatherBy", "[", 
    RowBox[{"mls2", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#", "[", 
         RowBox[{"[", "1", "]"}], "]"}], ",", 
        RowBox[{"#", "[", 
         RowBox[{"[", "7", "]"}], "]"}]}], "}"}], "&"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769088967005892*^9, 3.7690889841824827`*^9}, {
  3.769089109740693*^9, 3.769089130786137*^9}, {3.7690938826020927`*^9, 
  3.769093902609733*^9}, {3.769093937239168*^9, 3.769093944551646*^9}, {
  3.7690940479879417`*^9, 3.7690940615195227`*^9}},
 CellLabel->"In[24]:=",
 CellID->276765543,ExpressionUUID->"0f831a6d-103e-4651-b889-71d7a863dff6"],

Cell[BoxData[
 RowBox[{"{", "213", "}"}]], "Output",
 CellChangeTimes->{{3.769094051889615*^9, 3.769094062090975*^9}, 
   3.76910065811091*^9, 3.769772696331476*^9, 3.769975553161186*^9, 
   3.771923597763612*^9, 3.771928980469318*^9, 3.77192953158633*^9, 
   3.880629842763733*^9, 3.880632612132242*^9, 3.881417555489832*^9, 
   3.8822843452778883`*^9},
 CellLabel->"Out[24]=",
 CellID->1769351917,ExpressionUUID->"cdf777cb-4ed6-418f-9f05-84fbab2633ae"]
}, Open  ]],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s get the ",
 ButtonBox["Dimensions",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dimensions.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dimensions.html"],
 " of each of these and see if, as I predict, they are all ",
 Cell[BoxData[
  FormBox["n", TraditionalForm]], "InlineMath",ExpressionUUID->
  "c23bb701-7a4e-4869-9e45-3bb5752c9218"],
 " rows by seven columns. To do this, I compute the ",
 ButtonBox["Dimensions",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dimensions.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dimensions.html"],
 " of each matrix and then ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " a ",
 ButtonBox["MatchQ",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MatchQ.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MatchQ.html"],
 " operator over the results. The ",
 ButtonBox["MatchQ",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MatchQ.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MatchQ.html"],
 " operator in this example yields ",
 ButtonBox["True",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/True.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/True.html"],
 " if the expression it confronts is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " whose first element is some positive integer and whose last element is the \
number 7. I then ",
 ButtonBox["Apply",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Apply.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Apply.html"],
 " the ",
 ButtonBox["And",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/And.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/And.html"],
 " function to the resulting ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of Boolean values to see if all the values are ",
 ButtonBox["True",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/True.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/True.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.769094082526793*^9, 3.76909412231463*^9}, {
   3.7691628040282917`*^9, 3.769162814205903*^9}, {3.7691628483852367`*^9, 
   3.769162861935073*^9}, {3.769162931751252*^9, 3.769162932143879*^9}, {
   3.769163628915811*^9, 3.769163749599105*^9}, 3.769166040990487*^9, {
   3.774783967028005*^9, 3.774783967613005*^9}, {3.775472616516036*^9, 
   3.7754726821575994`*^9}, {3.856280573721897*^9, 3.856280575387061*^9}, {
   3.8565399736622133`*^9, 3.856540026863695*^9}, {3.877707688169175*^9, 
   3.877707723326024*^9}, 3.8963414056004353`*^9, 3.896341437634256*^9},
 CellTags->"i:81",
 CellID->1286503873,ExpressionUUID->"3a4fed04-ab78-47c2-9c9d-2504eeaa31ee"],

Cell[TextData[{
 "Find out if the groups resulting from ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 " have the same number of columns:"
}], "CodeCaption",
 CellChangeTimes->{3.7747829816171837`*^9, 3.7748758899146323`*^9, 
  3.7754726990462885`*^9},
 CellID->70676224,ExpressionUUID->"6e32d9f8-070e-4bfc-b56a-b46ae87e6510"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Apply", "[", 
  RowBox[{"And", ",", 
   RowBox[{"Map", "[", 
    RowBox[{
     RowBox[{"MatchQ", "[", 
      RowBox[{"{", 
       RowBox[{
        RowBox[{"_Integer", "?", "Positive"}], ",", "7"}], "}"}], "]"}], ",", 
     RowBox[{"Map", "[", 
      RowBox[{"Dimensions", ",", "mlsByTeamYear"}], "]"}]}], "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769094090678788*^9, 3.7690941459765368`*^9}, {
  3.76916277908922*^9, 3.7691630419483843`*^9}, {3.7691636798005667`*^9, 
  3.7691636939476767`*^9}},
 CellLabel->"In[25]:=",
 CellID->624914140,ExpressionUUID->"5d828a93-ccfd-482b-93bf-0e7e47862d89"],

Cell[BoxData["True"], "Output",
 CellChangeTimes->{{3.7691630204491043`*^9, 3.7691630426099*^9}, 
   3.769163707608036*^9, 3.769772696344892*^9, 3.769975553173291*^9, 
   3.771923597777213*^9, 3.771928983519184*^9, 3.7719295316269283`*^9, 
   3.8806298503332863`*^9, 3.880632616024638*^9, 3.881417559859879*^9, 
   3.882284349646995*^9},
 CellLabel->"Out[25]=",
 CellID->689738866,ExpressionUUID->"a6ed801a-6eae-4e1e-89d0-d82aacda1cc7"]
}, Open  ]],

Cell[TextData[{
 "Indeed, everything is an ",
 Cell[BoxData[
  FormBox[
   RowBox[{"n", "\[Times]", "7"}], TraditionalForm]], "InlineMath",
  ExpressionUUID->"75f8b0d2-e93e-4e30-9d77-7b5b3105e931"],
 " matrix of data. This finding suggests that if we took the sixth part of \
each row in each of these matrices and then totaled up the values, we\
\[CloseCurlyQuote]d get the desired result. Here\[CloseCurlyQuote]s the sixth \
item in each row in each of the gathered rows."
}], "Text",
 CellID->1852832392,ExpressionUUID->"271a833f-3932-46fa-ba48-0cf1367ab9a7"],

Cell[TextData[{
 "Use a sequence of arguments to ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " to retrieve data that has been subjected to ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747829911141334`*^9, 3.7748758924756327`*^9, {3.7754729279481764`*^9, 
   3.775472934906872*^9}, {3.8805584842474413`*^9, 3.880558485469922*^9}},
 CellID->212455070,ExpressionUUID->"02d0a5a6-188b-4cc6-8d77-61be39c9dbd0"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"compensationsByTeamYear", "=", 
    RowBox[{"Part", "[", 
     RowBox[{"mlsByTeamYear", ",", "All", ",", "All", ",", "6"}], "]"}]}], 
   ")"}], "//", 
  RowBox[{
   InterpretationBox[
    TagBox[
     TagBox[
      DynamicModuleBox[{Typeset`open = False}, 
       FrameBox[
        PaneSelectorBox[{False->GridBox[{
           {
            PaneBox[GridBox[{
               {
                StyleBox[
                 StyleBox[
                  AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                   BoxBaselineShift->-0.25,
                   BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                  
                  FontColor->RGBColor[
                   0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                 ShowStringCharacters->False,
                 FontFamily->"Source Sans Pro Black",
                 FontSize->0.6538461538461539 Inherited,
                 FontWeight->"Heavy",
                 PrivateFontOptions->{"OperatorSubstitution"->False}], 
                StyleBox[
                 RowBox[{
                  StyleBox["Terse", "ResourceFunctionLabel"], " "}],
                 ShowAutoStyles->False,
                 ShowStringCharacters->False,
                 FontSize->Rational[12, 13] Inherited,
                 FontColor->GrayLevel[0.1]]}
              },
              GridBoxSpacings->{"Columns" -> {{0.25}}}],
             Alignment->Left,
             BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
             BaselinePosition->Baseline,
             FrameMargins->{{3, 0}, {0, 0}}], 
            ItemBox[
             PaneBox[
              TogglerBox[Dynamic[Typeset`open], {True->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeCloser"],
                ImageSizeCache->{11., {2., 9.}}], False->
               
               DynamicBox[FEPrivate`FrontEndResource[
                "FEBitmaps", "IconizeOpener"],
                ImageSizeCache->{11., {2., 9.}}]},
               Appearance->None,
               BaselinePosition->Baseline,
               ContentPadding->False,
               FrameMargins->0],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{1, 1}, {0, 0}}],
             Frame->{{
                RGBColor[
                0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                 0.5], False}, {False, False}}]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
          GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
         GridBox[{
           {GridBox[{
              {
               PaneBox[GridBox[{
                  {
                   StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                   StyleBox[
                    RowBox[{
                    StyleBox["Terse", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                 },
                 GridBoxSpacings->{"Columns" -> {{0.25}}}],
                Alignment->Left,
                BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                BaselinePosition->Baseline,
                FrameMargins->{{3, 0}, {0, 0}}], 
               ItemBox[
                PaneBox[
                 TogglerBox[Dynamic[Typeset`open], {True->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeCloser"]], False->
                  
                  DynamicBox[FEPrivate`FrontEndResource[
                   "FEBitmaps", "IconizeOpener"]]},
                  Appearance->None,
                  BaselinePosition->Baseline,
                  ContentPadding->False,
                  FrameMargins->0],
                 Alignment->Left,
                 BaselinePosition->Baseline,
                 FrameMargins->{{1, 1}, {0, 0}}],
                Frame->{{
                   RGBColor[
                   0.8313725490196079, 0.8470588235294118, 0.8509803921568627,
                     0.5], False}, {False, False}}]}
             },
             BaselinePosition->{1, 1},
             GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
             GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
           {
            StyleBox[
             PaneBox[GridBox[{
                {
                 RowBox[{
                  TagBox["\<\"Version (latest): \"\>",
                   "IconizedLabel"], " ", 
                  TagBox["\<\"1.0.0\"\>",
                   "IconizedItem"]}]},
                {
                 TagBox[
                  
                  TemplateBox[{
                   "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/6809487c-44ed-4a55-a610-ab706ebb8661/"},
                   "HyperlinkURL"],
                  "IconizedItem"]}
               },
               DefaultBaseStyle->"Column",
               GridBoxAlignment->{"Columns" -> {{Left}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
              Alignment->Left,
              BaselinePosition->Baseline,
              FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
             FontFamily->"Roboto",
             FontSize->11]}
          },
          BaselinePosition->{1, 1},
          GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
          GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
               GrayLevel[0.8]}, False}},
          
          GridBoxItemSize->{
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
         Typeset`open],
         BaselinePosition->Baseline,
         ImageSize->Automatic],
        Background->RGBColor[
         0.9686274509803922, 0.9764705882352941, 0.984313725490196],
        BaselinePosition->Baseline,
        DefaultBaseStyle->{},
        FrameMargins->{{0, 0}, {1, 0}},
        FrameStyle->RGBColor[
         0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
        RoundingRadius->4]],
      #& ,
      TagBoxNote->" "],
     {"FunctionResourceBox", 
      RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
      "Terse"},
     TagBoxNote->"FunctionResourceBox"],
    ResourceFunction[
     ResourceObject[<|
      "Name" -> "Terse", "ShortName" -> "Terse", "UUID" -> 
       "6809487c-44ed-4a55-a610-ab706ebb8661", "ResourceType" -> "Function", 
       "Version" -> "1.0.0", "Description" -> "An operator form of Short", 
       "RepositoryLocation" -> 
       URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
       "SymbolName" -> 
       "FunctionRepository`$369a78f89aa2413eb5b19a962ce89cd7`Terse", 
       "FunctionLocation" -> 
       CloudObject[
        "https://www.wolframcloud.com/obj/c1820918-b759-4685-b9b8-\
c971a81216b5"]|>, ResourceSystemBase -> Automatic]],
    Selectable->False], "[", "2", "]"}]}]], "Input",
 CellChangeTimes->{{3.769094268593685*^9, 3.769094275634227*^9}, {
  3.771929000000018*^9, 3.771929041204261*^9}, {3.880629862116247*^9, 
  3.880629868076458*^9}},
 CellLabel->"In[26]:=",
 CellID->1542127400,ExpressionUUID->"9e3d99c7-a71f-4fd6-91d5-ac5d0b6a9c2a"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      TemplateBox[{
        InterpretationBox[
        "\"225\[ThinSpace]000.00\"", 225000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"48\[ThinSpace]712.50\"", 48712.5, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox["2.666778`*^6", 2.666778*^6, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"106\[ThinSpace]391.00\"", 106391., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"58\[ThinSpace]008.00\"", 58008., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"50\[ThinSpace]500.00\"", 50500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"151\[ThinSpace]500.00\"", 151500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"44\[ThinSpace]100.00\"", 44100., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"120\[ThinSpace]750.00\"", 120750., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"17\[ThinSpace]700.00\"", 17700., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"187\[ThinSpace]500.00\"", 187500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"126\[ThinSpace]500.00\"", 126500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"136\[ThinSpace]000.00\"", 136000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"17\[ThinSpace]700.00\"", 17700., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"69\[ThinSpace]300.00\"", 69300., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"32\[ThinSpace]340.00\"", 32340., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"30\[ThinSpace]000.00\"", 30000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"42\[ThinSpace]500.00\"", 42500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"74\[ThinSpace]700.00\"", 74700., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"50\[ThinSpace]800.00\"", 50800., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"78\[ThinSpace]000.00\"", 78000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"36\[ThinSpace]625.00\"", 36625., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"267\[ThinSpace]500.00\"", 267500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"]}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "211", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{
      TemplateBox[{
        InterpretationBox[
        "\"85\[ThinSpace]000.00\"", 85000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"253\[ThinSpace]500.00\"", 253500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"70\[ThinSpace]475.00\"", 70475., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"65\[ThinSpace]000.00\"", 65000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"140\[ThinSpace]000.00\"", 140000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"202\[ThinSpace]000.00\"", 202000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"183\[ThinSpace]833.33\"", 183833.33, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"71\[ThinSpace]885.00\"", 71885., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"73\[ThinSpace]800.00\"", 73800., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"66\[ThinSpace]849.00\"", 66849., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"180\[ThinSpace]000.00\"", 180000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"131\[ThinSpace]250.00\"", 131250., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"175\[ThinSpace]000.00\"", 175000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"885\[ThinSpace]500.00\"", 885500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"67\[ThinSpace]500.00\"", 67500., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"65\[ThinSpace]000.00\"", 65000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"120\[ThinSpace]000.00\"", 120000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "1.80000004`*^6", 1.80000004*^6, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"378\[ThinSpace]933.33\"", 378933.33, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"99\[ThinSpace]600.00\"", 99600., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"533\[ThinSpace]700.04\"", 533700.04, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"54\[ThinSpace]075.00\"", 54075., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"670\[ThinSpace]000.00\"", 670000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"308\[ThinSpace]333.33\"", 308333.33, Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"377\[ThinSpace]000.00\"", 377000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"194\[ThinSpace]000.00\"", 194000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"80\[ThinSpace]000.00\"", 80000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"368\[ThinSpace]125.00\"", 368125., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"], ",", 
      TemplateBox[{
        InterpretationBox[
        "\"184\[ThinSpace]000.00\"", 184000., Selectable -> False], 
        RowBox[{
          FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
        "US dollars", "\"USDollars\""},
       "QuantityPrefix"]}], "}"}]}], "}"}],
  Short[#, 2]& ]], "Output",
 CellChangeTimes->{
  3.769094276315467*^9, 3.769100658829311*^9, 3.769772696689937*^9, 
   3.769975553517755*^9, 3.7719235978325567`*^9, {3.771928985975869*^9, 
   3.771929041851685*^9}, 3.771929531844924*^9, 3.880629871197138*^9, 
   3.8806326187739077`*^9, 3.880633181003003*^9, 3.8814175687697687`*^9, 
   3.882284354439528*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[26]//Short=",
 CellID->159701592,ExpressionUUID->"1f5eec67-fafe-4b51-acb1-0ce615928afa"]
}, Open  ]],

Cell[TextData[{
 "Now I just ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " the ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " function over this:"
}], "CodeCaption",
 CellChangeTimes->{{3.7754733323866158`*^9, 3.775473350363414*^9}, 
   3.777355150404859*^9},
 CellTags->"p: 54",
 CellID->586624606,ExpressionUUID->"d8e86c9c-b94a-4567-9ecf-af6505112c76"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"totalCompensationsByTeamYear", "=", 
    RowBox[{"Map", "[", 
     RowBox[{"Total", ",", "compensationsByTeamYear"}], "]"}]}], ")"}], "//", 
  "Short"}]], "Input",
 CellChangeTimes->{{3.769093914200686*^9, 3.769093925765195*^9}, {
  3.769093962458823*^9, 3.76909399059156*^9}, {3.769094293935079*^9, 
  3.769094317796402*^9}, {3.769094958740654*^9, 3.769094961432372*^9}, {
  3.880629886875874*^9, 3.880629893342266*^9}},
 CellLabel->"In[27]:=",
 CellID->2024623710,ExpressionUUID->"2cec139e-aca6-43dc-aa60-be069891fb2b"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    TemplateBox[{
      InterpretationBox["4.7163045`*^6", 4.7163045*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.7896457000000002`*^6", 1.7896457000000002`*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.10822606`*^6", 2.10822606*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.281303`*^6", 2.281303*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["3.07276475`*^6", 3.07276475*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.27639`*^6", 2.27639*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.43414709`*^6", 2.43414709*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.63755`*^6", 2.63755*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["9.32205439`*^6", 9.32205439*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["1.945848`*^6", 1.945848*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["4.92808933`*^6", 4.92808933*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "\"83\[ThinSpace]100.00\"", 83100., Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["1.97424975`*^6", 1.97424975*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.6539875`*^6", 2.6539875*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["9.1776656`*^6", 9.1776656*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.2152955`*^6", 2.2152955*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.45709446`*^6", 2.45709446*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.50338238`*^6", 2.50338238*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["3.3675892`*^6", 3.3675892*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "\"127\[ThinSpace]200.00\"", 127200., Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.551054`*^6", 2.551054*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["2.7264788`*^6", 2.7264788*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    RowBox[{"\[LeftSkeleton]", "169", "\[RightSkeleton]"}], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.295227817`*^7", 1.295227817*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["6.74754499`*^6", 6.74754499*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["8.04061975`*^6", 8.04061975*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["6.82576094`*^6", 6.82576094*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "5.2724479399999995`*^6", 5.2724479399999995`*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["5.09121665`*^6", 5.09121665*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "6.588350779999999`*^6", 6.588350779999999*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.218289611`*^7", 1.218289611*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "\"118\[ThinSpace]008.00\"", 118008., Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "5.322864550000001`*^6", 5.322864550000001*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["5.29460589`*^6", 5.29460589*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["5.80011833`*^6", 5.80011833*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["6.89518617`*^6", 6.89518617*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["1.32191997`*^7", 1.32191997*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["7.1170101`*^6", 7.1170101*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.082414454`*^7", 1.082414454*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "7.4193554399999995`*^6", 7.4193554399999995`*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "1.030615048`*^7", 1.030615048*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["6.95928711`*^6", 6.95928711*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox[
      "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"], ",", 
    TemplateBox[{
      InterpretationBox["8.07937107`*^6", 8.07937107*^6, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.769093917772211*^9, 3.769093946894261*^9}, {
   3.7690939780633287`*^9, 3.7690939910905848`*^9}, {3.7690942978524313`*^9, 
   3.769094318360198*^9}, 3.7690949628189783`*^9, 3.769100659458419*^9, 
   3.769772697798723*^9, 3.769975554649518*^9, 3.77192359784715*^9, 
   3.7719289899931993`*^9, {3.771929033309022*^9, 3.771929044823242*^9}, 
   3.771929532446515*^9, {3.880629882484864*^9, 3.880629893820509*^9}, 
   3.880632621471971*^9, 3.880633181165065*^9, 3.881417579427822*^9, 
   3.882284361449494*^9},
 CellLabel->"Out[27]//Short=",
 CellID->1885962532,ExpressionUUID->"339c0c5e-c36f-4054-9671-ff913f813ccf"]
}, Open  ]],

Cell["\<\
In some sense, I\[CloseCurlyQuote]m done, but the results aren\
\[CloseCurlyQuote]t very meaningful because I don\[CloseCurlyQuote]t know \
what team and years these values correspond to. Here\[CloseCurlyQuote]s how I \
get that. I realize that the first and seventh part of each of the gathered \
rows has to be the same for each row: that\[CloseCurlyQuote]s how the \
gathered rows were created, so if I look at just the first row of each \
grouping and take the first and seventh parts, I get the needed information. \
\>", "Text",
 CellChangeTimes->{{3.769094324042164*^9, 3.7690944419166193`*^9}, {
   3.769094474299974*^9, 3.769094533086034*^9}, 3.774783712843005*^9, {
   3.7754735492592163`*^9, 3.775473565202216*^9}},
 CellID->673357807,ExpressionUUID->"5a25a487-d0e8-43ca-9dc7-9e98cc1e3c44"],

Cell[TextData[{
 "Use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " to get the team and year associated with each payroll value:"
}], "CodeCaption",
 CellChangeTimes->{{3.77735520176309*^9, 3.777355208567333*^9}, {
  3.8805587484968023`*^9, 3.880558770993948*^9}},
 CellID->1542437680,ExpressionUUID->"0cad255c-0284-4893-b8d0-0dd53f6ae597"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"teamYears", "=", 
    RowBox[{"Part", "[", 
     RowBox[{"mlsByTeamYear", ",", "All", ",", "1", ",", 
      RowBox[{"{", 
       RowBox[{"1", ",", "7"}], "}"}]}], "]"}]}], ")"}], "//", 
  "Short"}]], "Input",
 CellChangeTimes->{{3.769094378151085*^9, 3.769094398738289*^9}, {
  3.769094445333354*^9, 3.7690945015024137`*^9}, {3.8805588394831343`*^9, 
  3.8805588492919207`*^9}, {3.880629913200267*^9, 3.880629916551875*^9}},
 CellLabel->"In[28]:=",
 CellID->1404530533,ExpressionUUID->"425efa83-52f3-4c90-ac08-eb95d3cace46"],

Cell[BoxData[
 TagBox[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"CHI\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], ",", 
    RowBox[{"\[LeftSkeleton]", "211", "\[RightSkeleton]"}], ",", 
    RowBox[{"{", 
     RowBox[{"\<\"VAN\"\>", ",", 
      FrameBox[
       StyleBox[
        RowBox[{
         StyleBox[
          RowBox[{"\<\"\"\>", "\[Ellipsis]", "\<\"\"\>"}], 
          "DateObjectLabel"], "\<\"2017\"\>"}], "Text",
        ShowStringCharacters->False,
        FontFamily->"Source Sans Pro",
        FontSize->13,
        FontWeight->"Plain",
        FontColor->RGBColor[
         0.12941176470588237`, 0.34509803921568627`, 0.43529411764705883`]],
       Background->Hue[0.11, 0, 0.97],
       BaseStyle->{FontFamily -> "Courier"},
       BaselinePosition->Baseline,
       FrameMargins->{{5, 5}, {2, 2}},
       FrameStyle->Hue[0.57, 0, 0.82],
       RoundingRadius->2]}], "}"}]}], "}"}],
  Short]], "Output",
 CellChangeTimes->{{3.769094470025923*^9, 3.769094501960629*^9}, 
   3.769100659678481*^9, 3.769772698119681*^9, 3.769975554985044*^9, 
   3.771923597861188*^9, 3.771929048170148*^9, 3.771929532691935*^9, 
   3.880558850843562*^9, {3.880629905098954*^9, 3.8806299169674187`*^9}, 
   3.8806326250876904`*^9, 3.88063318121904*^9, 3.881417586180043*^9, 
   3.882284366614337*^9},
 CellLabel->"Out[28]//Short=",
 CellID->1373574914,ExpressionUUID->"6efc886c-a92e-413e-a86f-1bfad865f578"]
}, Open  ]],

Cell[TextData[{
 "By using ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 ", I can get the relationship I need. I\[CloseCurlyQuote]ll ",
 ButtonBox["ReverseSort",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSort.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSort.html"],
 " the results based on total compensation so that the team with the biggest \
payroll comes first, and I\[CloseCurlyQuote]m done. Toronto, which had the \
highly compensated Sebastian Giovinco, Michael Bradley, and Jozy Altidore \
during the period 2015\[Dash]2017, tops the list."
}], "Text",
 CellChangeTimes->{{3.7690945065971413`*^9, 3.769094656543565*^9}, {
   3.7754738695612164`*^9, 3.775473894791216*^9}, {3.880629968302767*^9, 
   3.880630022056828*^9}, {3.880633390651762*^9, 3.8806334317370577`*^9}, {
   3.885634525005107*^9, 3.8856345616005363`*^9}, 3.896341616867938*^9},
 CellID->1976171894,ExpressionUUID->"9aae9d7f-f39d-4911-a008-6afab02db28c"],

Cell[TextData[{
 "Use ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " and ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " to put team-year data together with the total compensation such that the \
big payroll teams come up first:"
}], "CodeCaption",
 CellChangeTimes->{{3.777355252155047*^9, 3.777355281432767*^9}, {
  3.777355336105736*^9, 3.7773553376569843`*^9}},
 CellID->1994189223,ExpressionUUID->"858be087-aed6-4459-973e-882cdc64397b"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Take", "[", 
  RowBox[{
   RowBox[{"ReverseSortBy", "[", 
    RowBox[{
     RowBox[{"Thread", "[", 
      RowBox[{"Rule", "[", 
       RowBox[{"teamYears", ",", "totalCompensationsByTeamYear"}], "]"}], 
      "]"}], ",", "Last"}], "]"}], ",", "10"}], "]"}]], "Input",
 CellChangeTimes->{{3.769094550015572*^9, 3.769094556848837*^9}, {
  3.769094594423579*^9, 3.769094600004877*^9}, {3.769094662521296*^9, 
  3.7690946721117373`*^9}, {3.8806331870728188`*^9, 3.880633195440933*^9}},
 CellLabel->"In[29]:=",
 CellID->1457366262,ExpressionUUID->"720753ea-7fff-4137-903e-02c624d5280c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.2136512029999997`*^7", 2.2136512029999997`*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.179850857`*^7", 2.179850857*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.126757475`*^7", 2.126757475*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.112777663`*^7", 2.112777663*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.810573604`*^7", 1.810573604*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.741426789`*^7", 1.741426789*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NY\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox["1.67281078`*^7", 1.67281078*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.671260318`*^7", 1.671260318*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.76909455727627*^9, 3.769094600518833*^9, 3.769094672613256*^9, 
   3.769100659729*^9, 3.769772698151359*^9, 3.769975555019404*^9, 
   3.771923597908813*^9, 3.771929051002692*^9, 3.771929532744007*^9, 
   3.880629920291546*^9, 3.8806326277730017`*^9, {3.880633181232973*^9, 
   3.880633195883925*^9}, 3.880633237063342*^9, 3.8814175948081837`*^9, 
   3.8822843708197947`*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[29]=",
 CellID->970630517,ExpressionUUID->"f3931303-cda1-4eb7-a13d-6641f78dacad"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["An Operator Approach to the Same Computations", "Subsubsection",
 CellChangeTimes->{{3.769095880172391*^9, 3.769095887828785*^9}, 
   3.7690996393493347`*^9, {3.7748808084234204`*^9, 3.7748808172214203`*^9}},
 CellTags->"p: 55",
 CellID->2115950892,ExpressionUUID->"74dcfbb8-dc7b-49a8-ac27-4bfcec0318cc"],

Cell[TextData[{
 "Let\[CloseCurlyQuote]s try these two latter computations again using \
operators. First, I\[CloseCurlyQuote]ll recreate the graphic showing the \
total compensation time series. I start by writing a function that takes data \
and gathers elements together that share the same seventh element. The \
gathered rows are wrapped in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 "."
}], "Text",
 CellChangeTimes->{{3.769094689474552*^9, 3.769094697996648*^9}, {
   3.769094749378948*^9, 3.7690947641535597`*^9}, {3.769095072731061*^9, 
   3.7690950954837313`*^9}, {3.769099641178164*^9, 3.769099721730772*^9}, 
   3.774783715257005*^9, {3.774783970300005*^9, 3.7747839706830053`*^9}, {
   3.7754741102592163`*^9, 3.775474118671216*^9}},
 CellTags->"i:82",
 CellID->1995702086,ExpressionUUID->"d6552f14-8e3a-43c6-a6b8-863b521979f9"],

Cell[TextData[{
 "Create an operator form for a specific application of ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.7747830121962414`*^9, 3.7748759025456324`*^9, 
  3.775474126555216*^9},
 CellID->625649664,ExpressionUUID->"70683553-7e32-4bcf-bdef-54874f44c92f"],

Cell[BoxData[
 RowBox[{
  RowBox[{"league1", "=", 
   RowBox[{"data", "\[Function]", 
    RowBox[{"GatherBy", "[", 
     RowBox[{"data", ",", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "7", "]"}], "]"}], "&"}]}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769094689474552*^9, 3.769094697996648*^9}, {
   3.769094749378948*^9, 3.7690947641535597`*^9}, {3.769095072731061*^9, 
   3.7690950954837313`*^9}, {3.769099641178164*^9, 3.769099648737183*^9}, 
   3.7690996888684607`*^9, {3.7690997256719027`*^9, 3.769099750070784*^9}, {
   3.769099788245907*^9, 3.769099789017777*^9}},
 CellLabel->"In[30]:=",
 CellID->1950636151,ExpressionUUID->"9166924e-70f6-4fe8-ae24-4a3488df7c51"],

Cell["Here\[CloseCurlyQuote]s how it works:", "CodeCaption",
 CellChangeTimes->{{3.775474134426216*^9, 3.7754741377852163`*^9}},
 CellID->457990957,ExpressionUUID->"f5eeebc8-dbb9-40ab-a9a0-b65ab49f23fd"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Dimensions", ",", 
   RowBox[{"league1", "[", "mls2", "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769099759957365*^9, 3.769099795125518*^9}},
 CellLabel->"In[37]:=",
 CellID->2050162285,ExpressionUUID->"9cea0f51-bd33-4876-9801-5a52ad1ccf5a"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"371", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"388", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"411", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"552", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"573", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"569", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"549", ",", "7"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"614", ",", "7"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769099768595211*^9, 3.7690997957689*^9}, 
   3.7691006598403*^9, 3.7697726982817707`*^9, 3.76997555516339*^9, 
   3.771923597967705*^9, 3.7719290559706917`*^9, 3.771929532848784*^9, 
   3.8806300360074053`*^9, 3.88141760914986*^9, 3.882284393569775*^9, 
   3.882284790460288*^9},
 CellLabel->"Out[37]=",
 CellID->971179826,ExpressionUUID->"32db56a4-8dc0-4140-b194-c9af1a57515f"]
}, Open  ]],

Cell[TextData[{
 "Next, I create an operator that extracts the seventh and sixth parts of \
every row (second ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 ") of every matrix (first ",
 ButtonBox["All",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/All.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/All.html"],
 ") that it confronts. "
}], "Text",
 CellChangeTimes->{{3.7690997982190933`*^9, 3.769099888304517*^9}, {
  3.775474176815216*^9, 3.775474191529216*^9}},
 CellID->434375078,ExpressionUUID->"fa481d78-7808-40da-9b63-256b20555933"],

Cell["Create an operator form to get certain parts of data:", "CodeCaption",
 CellChangeTimes->{3.774783022109233*^9, 3.7748759058736324`*^9},
 CellID->441478470,ExpressionUUID->"b40724e0-fe1d-445e-bc8d-2dd4ff14a2af"],

Cell[BoxData[
 RowBox[{
  RowBox[{"league2", "=", 
   RowBox[{"data", "\[Function]", 
    RowBox[{"data", "[", 
     RowBox[{"[", 
      RowBox[{"All", ",", "All", ",", 
       RowBox[{"{", 
        RowBox[{"7", ",", "6"}], "}"}]}], "]"}], "]"}]}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769099859774048*^9, 3.769099873987822*^9}},
 CellLabel->"In[38]:=",
 CellID->1173565537,ExpressionUUID->"7a6a0b5e-315c-4f0c-b8fb-58fde897c38c"],

Cell[TextData[{
 "I\[CloseCurlyQuote]ll RightCompose that operator with ",
 Cell[BoxData[
 "league1"], "InlineCodeText",ExpressionUUID->
  "8af3ea7b-e84d-405a-bcde-61279f29090c"],
 ". Now I get matrices of varying lengths but that each have just two columns."
}], "Text",
 CellChangeTimes->{{3.769099889486443*^9, 3.769099926766185*^9}, {
  3.7747839794670053`*^9, 3.774783979819005*^9}, {3.775474215713216*^9, 
  3.7754742231092157`*^9}, {3.8856346602341013`*^9, 3.885634661041944*^9}},
 CellID->82297698,ExpressionUUID->"c5a9dad1-80e4-4e97-bd28-16255041e5be"],

Cell[TextData[{
 "Apply a ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of two functions to the MLS data:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747830319002113`*^9, 3.7748759087616324`*^9, 3.7754742610242157`*^9, {
   3.885634670535081*^9, 3.8856346715264187`*^9}},
 CellID->341298345,ExpressionUUID->"6ac9b483-9d4c-4b85-a826-609229bdf749"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{"Dimensions", ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"league1", "/*", "league2"}], ")"}], "[", "mls2", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769099894607189*^9, 3.7690999085901833`*^9}},
 CellLabel->"In[39]:=",
 CellID->1953201954,ExpressionUUID->"3594b45d-dc94-49f8-aa5b-da27a66b2c8f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{"371", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"410", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"388", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"411", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"525", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"552", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"573", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"569", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"570", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"549", ",", "2"}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{"614", ",", "2"}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{3.769099908846805*^9, 3.769100659882999*^9, 
  3.769163846983035*^9, 3.76977269832629*^9, 3.769975555217525*^9, 
  3.771923598032783*^9, 3.7719290607613277`*^9, 3.771929532897416*^9, 
  3.880630041694491*^9, 3.881417619102805*^9, 3.882284802034233*^9},
 CellLabel->"Out[39]=",
 CellID->1993833756,ExpressionUUID->"f60e1884-89d2-4ead-92fe-5c5214e9121d"]
}, Open  ]],

Cell[TextData[{
 "Now I\[CloseCurlyQuote]ll create an operator that takes a list of matrices, \
and for each one, generates a pair of values in a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". The first element of the output list is the first column of the first row \
of the matrix. The second element is the total of all elements in the second \
column. Note that I use the operator form of ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " to do this."
}], "Text",
 CellChangeTimes->{{3.7690999511128387`*^9, 3.769099996447752*^9}, {
   3.769100053100122*^9, 3.769100085024909*^9}, {3.774783982451005*^9, 
   3.7747839831950054`*^9}, {3.775474283849216*^9, 3.775474284928216*^9}, 
   3.7754749726142144`*^9, {3.777355406176806*^9, 3.777355408208517*^9}, {
   3.856280674821974*^9, 3.85628067928086*^9}, {3.877708014697859*^9, 
   3.87770801786073*^9}, {3.8807353179057293`*^9, 3.880735322124627*^9}, 
   3.8856346777587576`*^9},
 CellID->666163788,ExpressionUUID->"301f0d6f-07b5-4d47-aead-22895bc555dd"],

Cell[TextData[{
 "Create an operator that turns a matrix into a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.774783042493271*^9, 3.7748759115766325`*^9, 
  3.777355428248169*^9},
 CellID->125374504,ExpressionUUID->"c15dd16c-b35e-4657-8e1d-d59f5305d10b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"league3", "=", 
   RowBox[{"Map", "[", 
    RowBox[{"matrix", "\[Function]", 
     RowBox[{"{", 
      RowBox[{
       RowBox[{"matrix", "[", 
        RowBox[{"[", 
         RowBox[{"1", ",", "1"}], "]"}], "]"}], ",", 
       RowBox[{"Total", "[", 
        RowBox[{"matrix", "[", 
         RowBox[{"[", 
          RowBox[{"All", ",", "2"}], "]"}], "]"}], "]"}]}], "}"}]}], "]"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769100000031563*^9, 3.7691000040074053`*^9}, {
   3.769100061214109*^9, 3.7691000635858192`*^9}, 3.769163830835446*^9},
 CellLabel->"In[40]:=",
 CellID->179586518,ExpressionUUID->"329e2f85-5e5d-4259-a7ed-c73885f9db13"],

Cell[TextData[{
 "Again, I add the new operator to our ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " pipeline."
}], "Text",
 CellChangeTimes->{{3.769100006041712*^9, 3.7691000197579107`*^9}, 
   3.7754749808832145`*^9},
 CellTags->"LastCellOfAPage",
 CellID->71094693,ExpressionUUID->"77d52c6b-7dee-4d98-aa25-dea516de28ec"],

Cell[TextData[{
 "Make a three-function pipeline using ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " and apply it to the MLS data:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747830518482065`*^9, 3.774882884265891*^9, {3.7754749836942143`*^9, 
   3.7754749916582146`*^9}, {3.8856347511599474`*^9, 3.885634751313564*^9}},
 CellTags->"p: 56",
 CellID->10482146,ExpressionUUID->"da69efa7-b4f0-4799-9676-5f593db923eb"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"league1", "/*", "league2", "/*", "league3"}], ")"}], "[", "mls2", 
  "]"}]], "Input",
 CellChangeTimes->{{3.7691000212695923`*^9, 3.7691000469969273`*^9}, {
  3.7691657080125628`*^9, 3.769165713531136*^9}},
 CellLabel->"In[41]:=",
 CellID->1574016729,ExpressionUUID->"7420a3af-2f42-4bb3-8ca4-0bca180f3357"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "4.222366007`*^7", 4.222366007*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2008\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2008", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "4.729250920999999`*^7", 4.729250920999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2009\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2009", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "5.187805049`*^7", 5.187805049*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2010\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2010", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "7.130497269999999`*^7", 7.130497269999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2011\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2011", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "8.507947580999999`*^7", 8.507947580999999*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "9.913085228`*^7", 9.913085228*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2013\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2013", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "9.48496423`*^7", 9.48496423*^7, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.2933452645`*^8", 1.2933452645*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.6701798003`*^8", 1.6701798003*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "1.7512715915`*^8", 1.7512715915*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TemplateBox[{
       RowBox[{
         StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
      "DateObject",
      Editable->False], ",", 
     TemplateBox[{
       InterpretationBox[
       "2.0039435593`*^8", 2.0039435593*^8, Selectable -> False], 
       RowBox[{
         FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
       "US dollars", "\"USDollars\""},
      "QuantityPrefix"]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.769100029746502*^9, 3.769100047382107*^9}, 
   3.76910065994737*^9, 3.769163852902811*^9, 3.769165714111164*^9, 
   3.76916625752244*^9, 3.7697726985033693`*^9, 3.7699755554131002`*^9, 
   3.77192359810948*^9, 3.771929064949614*^9, 3.771929533059024*^9, 
   3.880630049582905*^9, 3.8814176361928177`*^9, 3.8822848153124533`*^9},
 CellLabel->"Out[41]=",
 CellID->92876686,ExpressionUUID->"eda1d7c6-b900-4627-9ef3-262273ddcd0d"]
}, Open  ]],

Cell[TextData[{
 "Finally, I add to the pipeline an operator I won\[CloseCurlyQuote]t bother \
naming that makes a ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 ". I\[CloseCurlyQuote]ve iconized some of the inessential options of the ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 " function."
}], "Text",
 CellChangeTimes->{{3.769100108985758*^9, 3.769100143700996*^9}, {
   3.769166266339253*^9, 3.769166288091399*^9}, {3.7747839866900053`*^9, 
   3.774783987060005*^9}, 3.775475069301214*^9, {3.856540313188778*^9, 
   3.856540335082111*^9}, {3.8853957939934635`*^9, 3.8853957959532013`*^9}, {
   3.8856347734985185`*^9, 3.8856347744928675`*^9}},
 CellID->215245591,ExpressionUUID->"e5b69205-6edd-420c-8352-717367f31ef8"],

Cell[TextData[{
 "Add an operator form of ",
 ButtonBox["DateListPlot",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/DateListPlot.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/DateListPlot.html"],
 " to the pipeline to show compensation trends:"
}], "CodeCaption",
 CellChangeTimes->{3.7747830611891403`*^9, 3.7748759146496325`*^9, 
  3.7754750745012145`*^9},
 CellID->136900161,ExpressionUUID->"812a1f07-17de-46d2-9c05-500bb3b53349"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{"league1", "/*", "league2", "/*", "league3", "/*", 
    RowBox[{"(", 
     RowBox[{
      RowBox[{"DateListPlot", "[", 
       RowBox[{"#", ",", 
        InterpretationBox[
         DynamicModuleBox[{Typeset`open = False}, 
          TemplateBox[{"Expression", "SequenceIcon", 
            GridBox[{{
               RowBox[{
                 TagBox["\"Head: \"", "IconizedLabel"], "\[InvisibleSpace]", 
                 TagBox["Sequence", "IconizedItem"]}]}, {
               RowBox[{
                 TagBox["\"Length: \"", "IconizedLabel"], "\[InvisibleSpace]", 
                 TagBox["5", "IconizedItem"]}]}, {
               RowBox[{
                 TagBox["\"Byte count: \"", "IconizedLabel"], 
                 "\[InvisibleSpace]", 
                 TagBox["512", "IconizedItem"]}]}}, 
             GridBoxAlignment -> {"Columns" -> {{Left}}}, DefaultBaseStyle -> 
             "Column", 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
            Dynamic[Typeset`open]},
           "IconizedObject"]],
         Sequence[
         ImageSize -> 500, Frame -> True, 
          FrameLabel -> {"Year", "Total MLS Compensation"}, Joined -> False, 
          Filling -> Bottom],
         SelectWithContents->True,
         Selectable->False]}], "]"}], "&"}], ")"}]}], ")"}], "[", "mls2", 
  "]"}]], "Input",
 CellChangeTimes->{{3.7691001469853573`*^9, 3.769100187311185*^9}, {
  3.769165900929337*^9, 3.769165949445878*^9}},
 CellLabel->"In[42]:=",
 CellID->1409645418,ExpressionUUID->"8b9f1ba6-bbcd-4b3b-a4c7-e6c39e138c21"],

Cell[BoxData[
 GraphicsBox[{{}, GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGBQBGIQDQQbIjVeOmrG9Cc4KrU4AvkKDSkvHatE1r1k6m0D
8Q9cWPDSUb71tfDRPR0gvsH3Oy8dz5w5YyTDMBHEXyAr+cpxcYHt+WseU0B8
AZfQV45BO+Qmli+aDuJvmDLxlaOxsfFKzbnTwObvPvvK8eyZMz8/X50H4k94
yPkaaD//j98vFoP4DBxur4HyPu9KHiwBmx/R9Nrxm8ad5z2PlzvC3MuAAGD3
IvHB7kXig92LxAe7F4kPdi8SH+xeZPNB7kXig92LxAe7F9l8kHuRzRtK4QsA
iC6txQ==
    "], {{{}, {}, {}, {}, 
      {RGBColor[0.368417, 0.506779, 0.709798], Opacity[0.3], LineBox[{12, 1}],
        LineBox[{13, 2}], LineBox[{14, 3}], LineBox[{15, 4}], 
       LineBox[{16, 5}], LineBox[{17, 6}], LineBox[{18, 7}], LineBox[{19, 8}],
        LineBox[{20, 9}], LineBox[{21, 10}], LineBox[{22, 11}]}}, 
     {RGBColor[0.368417, 0.506779, 0.709798], PointSize[
      0.012833333333333334`], AbsoluteThickness[1.6], 
      PointBox[{23, 24, 25, 26, 27, 28, 29, 30, 31, 32, 33}]}}], {{}, {}}},
  AspectRatio->NCache[GoldenRatio^(-1), 0.6180339887498948],
  Axes->{False, False},
  AxesLabel->{None, None},
  AxesOrigin->{3.3765984*^9, 0},
  DisplayFunction->Identity,
  Frame->{{True, True}, {True, True}},
  FrameLabel->{{
     FormBox[
      TagBox["\"Total MLS Compensation\"", HoldForm], TraditionalForm], 
     None}, {
     FormBox[
      TagBox["\"Year\"", HoldForm], TraditionalForm], None}},
  FrameTicks->FrontEndValueCache[{{Automatic, Automatic}, {
      Charting`DateTicksFunction[Automatic, DateTicksFormat -> {Automatic}], 
      Charting`DateTicksFunction[
      Automatic, DateTicksFormat -> {Automatic}, "TickLabels" -> None]}}, {{
     Automatic, Automatic}, {{{3.3450624*^9, 
        FormBox[
         StyleBox["\"2006\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         StyleBox["\"2008\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         StyleBox["\"2010\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         StyleBox["\"2012\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         StyleBox["\"2014\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         StyleBox["\"2016\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         StyleBox["\"2018\"", 
          Directive[], {}, StripOnInput -> False], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}, {{3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
         Rational[1, 72], 0}, 
        Directive[]}, {3.3450624*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.3765984*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4081344*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4397568*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.4712928*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5028288*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5343648*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5659872*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.5975232*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6290592*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6605952*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.6922176*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}, {3.7237536*^9, 
        FormBox[
         TemplateBox[{0, 0}, "Spacer2"], TraditionalForm], {
        0.009722222222222222, 0.}, 
        Directive[]}}}}],
  GridLines->{None, None},
  GridLinesStyle->Directive[
    GrayLevel[0.5, 0.4]],
  ImageSize->500,
  Method->{
   "NoShowPlotTheme" -> Automatic, "AxisPadding" -> Scaled[0.02], 
    "DefaultBoundaryStyle" -> Automatic, 
    "DefaultGraphicsInteraction" -> {
     "Version" -> 1.2, "TrackMousePosition" -> {True, False}, 
      "Effects" -> {
       "Highlight" -> {"ratio" -> 2}, "HighlightPoint" -> {"ratio" -> 2}, 
        "Droplines" -> {
         "freeformCursorMode" -> True, 
          "placement" -> {"x" -> "All", "y" -> "None"}}}}, "DefaultMeshStyle" -> 
    AbsolutePointSize[6], "DefaultPlotStyle" -> {
      Directive[
       RGBColor[0.368417, 0.506779, 0.709798], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.880722, 0.611041, 0.142051], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.560181, 0.691569, 0.194885], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.922526, 0.385626, 0.209179], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.528488, 0.470624, 0.701351], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.772079, 0.431554, 0.102387], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.363898, 0.618501, 0.782349], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[1, 0.75, 0], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.647624, 0.37816, 0.614037], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.571589, 0.586483, 0.], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.915, 0.3325, 0.2125], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.40082222609352647`, 0.5220066643438841, 0.85], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.9728288904374106, 0.621644452187053, 0.07336199581899142], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.736782672705901, 0.358, 0.5030266573755369], 
       AbsoluteThickness[1.6]], 
      Directive[
       RGBColor[0.28026441037696703`, 0.715, 0.4292089322474965], 
       AbsoluteThickness[1.6]]}, "DomainPadding" -> Scaled[0.02], 
    "PointSizeFunction" -> "SmallPointSize", "RangePadding" -> Scaled[0.05], 
    "AllowMicroRanges" -> {True, False}, "OptimizePlotMarkers" -> True, 
    "OptimizePlotMarkers" -> True, 
    "CoordinatesToolOptions" -> {"DisplayFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& ), "CopiedValueFunction" -> ({
        Identity[
         Part[#, 1]], 
        Identity[
         Part[#, 2]]}& )}},
  PlotRange->{{3.3765984*^9, 3.6922176*^9}, {0, 2.0039435593*^8}},
  PlotRangeClipping->True,
  PlotRangePadding->{{
     Scaled[0.02], 
     Scaled[0.02]}, {
     Scaled[0.02], 
     Scaled[0.05]}},
  Ticks->{{}, Automatic}]], "Output",
 CellChangeTimes->{3.769100188075717*^9, 3.769100661682423*^9, 
  3.769165903818405*^9, 3.769165952125917*^9, 3.769772698830299*^9, 
  3.769975555764267*^9, 3.771923599092753*^9, 3.771929067266017*^9, 
  3.7719295333674793`*^9, 3.8806300544992657`*^9, 3.881417645004925*^9, 
  3.8822848461078568`*^9},
 CellLabel->"Out[42]=",
 CellID->535661732,ExpressionUUID->"c462f5d5-adb6-442f-8f52-7362e10f1b24"]
}, Open  ]],

Cell["\<\
Now I recreate the ranking of teams and years with total compensation using \
operators. The first operator this time is one that takes data and gathers it \
according to its first and then seventh parts.\
\>", "Text",
 CellChangeTimes->{{3.769094689474552*^9, 3.769094697996648*^9}, {
   3.769094749378948*^9, 3.7690947641535597`*^9}, {3.769095072731061*^9, 
   3.7690950954837313`*^9}, {3.769099641178164*^9, 3.769099644256507*^9}, {
   3.769100192980527*^9, 3.7691002362310038`*^9}, 3.777355464704565*^9, 
   3.8856348147433586`*^9},
 CellID->856434755,ExpressionUUID->"910498b6-b830-4567-b057-c2df47775466"],

Cell[TextData[{
 "Create another special operator form of ",
 ButtonBox["GatherBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/GatherBy.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/GatherBy.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{3.774783071918213*^9, 3.7748759172166324`*^9, 
  3.7754753355622144`*^9},
 CellID->46614440,ExpressionUUID->"27466176-9d93-4877-947f-8925826da96b"],

Cell[BoxData[
 RowBox[{
  RowBox[{"team1", "=", 
   RowBox[{
    RowBox[{"GatherBy", "[", 
     RowBox[{"#", ",", 
      RowBox[{
       RowBox[{"{", 
        RowBox[{
         RowBox[{"#", "[", 
          RowBox[{"[", "1", "]"}], "]"}], ",", 
         RowBox[{"#", "[", 
          RowBox[{"[", "7", "]"}], "]"}]}], "}"}], "&"}]}], "]"}], "&"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769095103144528*^9, 3.769095106032362*^9}, {
  3.769100237889737*^9, 3.769100238582103*^9}},
 CellLabel->"In[43]:=",
 CellID->1701959274,ExpressionUUID->"3ccb8f7e-bbba-4b30-b01a-bb58bc276062"],

Cell[TextData[{
 "If I apply it, I get that ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of 213 matrices:"
}], "CodeCaption",
 CellChangeTimes->{{3.7754753433062143`*^9, 3.7754753510092144`*^9}, 
   3.877708116639332*^9, {3.882284873907731*^9, 3.882284875254458*^9}},
 CellID->228933502,ExpressionUUID->"4dd95af8-d886-4fad-ab3e-f4c3f6797761"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Dimensions", "[", 
  RowBox[{
   RowBox[{"(", "team1", ")"}], "[", "mls2", "]"}], "]"}]], "Input",
 CellChangeTimes->{{3.7690952816331263`*^9, 3.7690952973159924`*^9}, {
  3.7691002421434813`*^9, 3.769100243541098*^9}},
 CellLabel->"In[44]:=",
 CellID->533955254,ExpressionUUID->"9ad13d5c-3403-491d-87a3-9003c23059ca"],

Cell[BoxData[
 RowBox[{"{", "213", "}"}]], "Output",
 CellChangeTimes->{3.769095297560403*^9, 3.7691002440421047`*^9, 
  3.769100344673107*^9, 3.769100661780274*^9, 3.769772698913957*^9, 
  3.769975555835424*^9, 3.7719235991972637`*^9, 3.7719290714120007`*^9, 
  3.7719295334151983`*^9, 3.88063006057577*^9, 3.881417656788238*^9, 
  3.882284855799445*^9},
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[44]=",
 CellID->311509173,ExpressionUUID->"4745ea4e-49e3-4b7d-80a9-7f6572f37fc7"]
}, Open  ]],

Cell[TextData[{
 "The second operator creates a pair of values as a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ". The first element is the first (team) and seventh (year) elements of the \
first row of the data. The second element is the sixth (guaranteed \
compensation) element of each row of each grouping within the data. "
}], "Text",
 CellChangeTimes->{{3.769095108068863*^9, 3.76909517738912*^9}, {
   3.7691663037937098`*^9, 3.769166329018841*^9}, {3.856280973355991*^9, 
   3.856280977326675*^9}, 3.877708203955368*^9, 3.8856350308793993`*^9},
 CellTags->"p: 57",
 CellID->404930289,ExpressionUUID->"21675a59-815f-4fd9-a7da-35e9763b4f35"],

Cell[TextData[{
 "Write an operator that takes a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of matrices and produces a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ":"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747830823342543`*^9, 3.7748759204966326`*^9, {3.877708238611806*^9, 
   3.8777082441458673`*^9}, 3.885634988557432*^9},
 CellID->206325492,ExpressionUUID->"22440d01-069d-4cba-b089-38af7bd80bf1"],

Cell[BoxData[
 RowBox[{
  RowBox[{"team2", "=", 
   RowBox[{"(", 
    RowBox[{
     RowBox[{"{", 
      RowBox[{
       RowBox[{"Part", "[", 
        RowBox[{"#", ",", "All", ",", "1", ",", 
         RowBox[{"{", 
          RowBox[{"1", ",", "7"}], "}"}]}], "]"}], ",", 
       RowBox[{"Part", "[", 
        RowBox[{"#", ",", "All", ",", "All", ",", "6"}], "]"}]}], "}"}], 
     "&"}], ")"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769095327246163*^9, 3.769095362775929*^9}, {
  3.769100247346713*^9, 3.769100247963101*^9}},
 CellLabel->"In[45]:=",
 CellID->905771872,ExpressionUUID->"9b8402fa-7dd5-45ed-8906-f7ff5dc6b7b8"],

Cell[TextData[{
 "I now create a ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of ",
 Cell[BoxData[
 "team1"], "InlineCodeText",ExpressionUUID->
  "56b19c73-1c6e-4f2e-b16e-585e21f2a02a"],
 " and ",
 Cell[BoxData[
 "team2"], "InlineCodeText",ExpressionUUID->
  "0840d63b-91f3-4ecb-b2c1-4472655b115c"],
 " and apply it to the data. The first element of the created ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " has the dimensions of 213 rows by two columns (the team and the year). The \
second element contains salary data for all the players on the team that \
year. "
}], "Text",
 CellChangeTimes->{{3.7690953650704803`*^9, 3.769095380997281*^9}, {
   3.769095436293851*^9, 3.7690954717841*^9}, {3.76909553004465*^9, 
   3.769095530708447*^9}, {3.769100251589211*^9, 3.769100256368382*^9}, {
   3.7754753931732144`*^9, 3.775475427710346*^9}, 3.877708316941598*^9, {
   3.8822848965229053`*^9, 3.8822848982112494`*^9}, {3.885635894437873*^9, 
   3.885635894635296*^9}},
 CellID->1802164790,ExpressionUUID->"7655e20c-499e-4f8d-a20f-205df635af87"],

Cell[TextData[{
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of ",
 StyleBox["team1", "InlineCode"],
 " and ",
 StyleBox["team2", "InlineCode"],
 "; use the ",
 ButtonBox["AugmentedTerse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " to compress the output and show its dimensionality: "
}], "CodeCaption",
 CellChangeTimes->{{3.77735567990672*^9, 3.777355683691413*^9}, {
  3.8856359303652835`*^9, 3.88563595659937*^9}, {3.8890919690775137`*^9, 
  3.889092040032795*^9}, {3.896341881251872*^9, 3.896341887642358*^9}},
 CellID->918421238,ExpressionUUID->"d5354dd2-8386-4f35-b689-770af9d28657"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     TagBox[
      TagBox[
       DynamicModuleBox[{Typeset`open = False}, 
        FrameBox[
         PaneSelectorBox[{False->GridBox[{
            {
             PaneBox[GridBox[{
                {
                 StyleBox[
                  StyleBox[
                   AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                   
                   FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                  ShowStringCharacters->False,
                  FontFamily->"Source Sans Pro Black",
                  FontSize->0.6538461538461539 Inherited,
                  FontWeight->"Heavy",
                  PrivateFontOptions->{"OperatorSubstitution"->False}], 
                 StyleBox[
                  RowBox[{
                   StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                  ShowAutoStyles->False,
                  ShowStringCharacters->False,
                  FontSize->Rational[12, 13] Inherited,
                  FontColor->GrayLevel[0.1]]}
               },
               GridBoxSpacings->{"Columns" -> {{0.25}}}],
              Alignment->Left,
              BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
              BaselinePosition->Baseline,
              FrameMargins->{{3, 0}, {0, 0}}], 
             ItemBox[
              PaneBox[
               TogglerBox[Dynamic[Typeset`open], {True->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeCloser"],
                 ImageSizeCache->{11., {2., 9.}}], False->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeOpener"],
                 ImageSizeCache->{11., {2., 9.}}]},
                Appearance->None,
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{1, 1}, {0, 0}}],
              Frame->{{
                 RGBColor[
                 0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                  0.5], False}, {False, False}}]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
           GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
          GridBox[{
            {GridBox[{
               {
                PaneBox[GridBox[{
                   {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                  },
                  GridBoxSpacings->{"Columns" -> {{0.25}}}],
                 Alignment->Left,
                 BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                 BaselinePosition->Baseline,
                 FrameMargins->{{3, 0}, {0, 0}}], 
                ItemBox[
                 PaneBox[
                  TogglerBox[Dynamic[Typeset`open], {True->
                   
                   DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                   
                   DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                   Appearance->None,
                   BaselinePosition->Baseline,
                   ContentPadding->False,
                   FrameMargins->0],
                  Alignment->Left,
                  BaselinePosition->Baseline,
                  FrameMargins->{{1, 1}, {0, 0}}],
                 Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
              },
              BaselinePosition->{1, 1},
              
              GridBoxAlignment->{
               "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
            {
             StyleBox[
              PaneBox[GridBox[{
                 {
                  RowBox[{
                   TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                   TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                 {
                  TagBox[
                   
                   TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/55ad4cc5-e284-40ca-a3cb-8a4166c38701/"},
                    "HyperlinkURL"],
                   "IconizedItem"]}
                },
                DefaultBaseStyle->"Column",
                GridBoxAlignment->{"Columns" -> {{Left}}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
              FontFamily->"Roboto",
              FontSize->11]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                GrayLevel[0.8]}, False}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
          Typeset`open],
          BaselinePosition->Baseline,
          ImageSize->Automatic],
         Background->RGBColor[
          0.9686274509803922, 0.9764705882352941, 0.984313725490196],
         BaselinePosition->Baseline,
         DefaultBaseStyle->{},
         FrameMargins->{{0, 0}, {1, 0}},
         FrameStyle->RGBColor[
          0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
         RoundingRadius->4]],
       #& ,
       TagBoxNote->" "],
      {"FunctionResourceBox", 
       RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
       "AugmentedTerse"},
      TagBoxNote->"FunctionResourceBox"],
     ResourceFunction[
      ResourceObject[<|
       "Name" -> "AugmentedTerse", "ShortName" -> "AugmentedTerse", "UUID" -> 
        "55ad4cc5-e284-40ca-a3cb-8a4166c38701", "ResourceType" -> "Function", 
        "Version" -> "1.0.0", "Description" -> 
        "An operator form of Short with an alternative compressed \
representation of the output", "RepositoryLocation" -> 
        URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
        "SymbolName" -> 
        "FunctionRepository`$779c3314c408433eb6df4354526edb23`AugmentedTerse",
         "FunctionLocation" -> 
        CloudObject[
         "https://www.wolframcloud.com/obj/5aa416ea-2adb-41c1-9102-\
ddaa33f49612"]|>, ResourceSystemBase -> Automatic]],
     Selectable->False], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"team1", "/*", "team2"}], ")"}], "[", "mls2", "]"}]}], 
  "]"}]], "Input",
 CellChangeTimes->{{3.769166544505126*^9, 3.769166573709393*^9}, {
  3.769166918324441*^9, 3.7691669239113626`*^9}, {3.889091424282078*^9, 
  3.889091470002132*^9}, {3.889091530184723*^9, 3.889091550684802*^9}, {
  3.889091581169751*^9, 3.889091581663601*^9}, {3.88909192815779*^9, 
  3.889091953546274*^9}},
 CellID->16957113,ExpressionUUID->"c572902e-5efc-4629-af54-583b50278923"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TagBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"CHI\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"CHV\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}], ",", 
        RowBox[{"\[LeftSkeleton]", "210", "\[RightSkeleton]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"VAN\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}]}], "}"}],
      Short[#, 1]& ], ",", 
     RowBox[{"{", 
      RowBox[{"213", ",", "2"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{
          TemplateBox[{
            InterpretationBox[
            "\"225\[ThinSpace]000.00\"", 225000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"48\[ThinSpace]712.50\"", 48712.5, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "2.666778`*^6", 2.666778*^6, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"106\[ThinSpace]391.00\"", 106391., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"58\[ThinSpace]008.00\"", 58008., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"50\[ThinSpace]500.00\"", 50500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"151\[ThinSpace]500.00\"", 151500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"44\[ThinSpace]100.00\"", 44100., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"120\[ThinSpace]750.00\"", 120750., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"17\[ThinSpace]700.00\"", 17700., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"187\[ThinSpace]500.00\"", 187500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"126\[ThinSpace]500.00\"", 126500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"136\[ThinSpace]000.00\"", 136000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"17\[ThinSpace]700.00\"", 17700., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"69\[ThinSpace]300.00\"", 69300., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"32\[ThinSpace]340.00\"", 32340., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"30\[ThinSpace]000.00\"", 30000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"42\[ThinSpace]500.00\"", 42500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"74\[ThinSpace]700.00\"", 74700., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"50\[ThinSpace]800.00\"", 50800., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"78\[ThinSpace]000.00\"", 78000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"36\[ThinSpace]625.00\"", 36625., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"267\[ThinSpace]500.00\"", 267500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"12\[ThinSpace]900.00\"", 12900., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"]}], "}"}], ",", 
        RowBox[{"\[LeftSkeleton]", "211", "\[RightSkeleton]"}], ",", 
        RowBox[{"{", 
         RowBox[{
          TemplateBox[{
            InterpretationBox[
            "\"85\[ThinSpace]000.00\"", 85000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"253\[ThinSpace]500.00\"", 253500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"70\[ThinSpace]475.00\"", 70475., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"65\[ThinSpace]000.00\"", 65000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"140\[ThinSpace]000.00\"", 140000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"202\[ThinSpace]000.00\"", 202000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"183\[ThinSpace]833.33\"", 183833.33, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"71\[ThinSpace]885.00\"", 71885., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"73\[ThinSpace]800.00\"", 73800., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"66\[ThinSpace]849.00\"", 66849., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"180\[ThinSpace]000.00\"", 180000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"131\[ThinSpace]250.00\"", 131250., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"175\[ThinSpace]000.00\"", 175000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"885\[ThinSpace]500.00\"", 885500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"67\[ThinSpace]500.00\"", 67500., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"65\[ThinSpace]000.00\"", 65000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"120\[ThinSpace]000.00\"", 120000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "1.80000004`*^6", 1.80000004*^6, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"378\[ThinSpace]933.33\"", 378933.33, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"99\[ThinSpace]600.00\"", 99600., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"533\[ThinSpace]700.04\"", 533700.04, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"65\[ThinSpace]004.00\"", 65004., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"54\[ThinSpace]075.00\"", 54075., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"670\[ThinSpace]000.00\"", 670000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"308\[ThinSpace]333.33\"", 308333.33, Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"377\[ThinSpace]000.00\"", 377000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"194\[ThinSpace]000.00\"", 194000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"80\[ThinSpace]000.00\"", 80000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"368\[ThinSpace]125.00\"", 368125., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"], ",", 
          TemplateBox[{
            InterpretationBox[
            "\"184\[ThinSpace]000.00\"", 184000., Selectable -> False], 
            RowBox[{
              FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
            "US dollars", "\"USDollars\""},
           "QuantityPrefix"]}], "}"}]}], "}"}],
      Short[#, 1]& ], ",", 
     RowBox[{"{", "213", "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.8889337853026857`*^9, 3.8889339438921003`*^9, 3.889091473188489*^9, {
   3.889091537190015*^9, 3.889091552333723*^9}, 3.889091583195672*^9, 
   3.889091934581739*^9},
 CellLabel->"Out[7]=",
 CellID->1530356787,ExpressionUUID->"4d810cb6-8143-4e69-a695-65903988715a"]
}, Open  ]],

Cell[TextData[{
 "The third operator does nothing to the first part of its data but computes \
the ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " of the second part. I can use ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " to perform this task. The ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " specification says to take the second element of the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " and to ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " all elements of it."
}], "Text",
 CellChangeTimes->{{3.769095476257635*^9, 3.769095552762123*^9}, {
   3.769166470144148*^9, 3.7691664779992943`*^9}, {3.7691668227988977`*^9, 
   3.769166847602488*^9}, 3.775475468735448*^9, {3.8565404272004766`*^9, 
   3.856540443514984*^9}, {3.877708352045813*^9, 3.877708381161635*^9}, {
   3.8896946945287747`*^9, 3.8896946993770685`*^9}},
 CellID->1268362144,ExpressionUUID->"dde24822-446b-4192-beae-bb139fdd238f"],

Cell[TextData[{
 "Use ",
 ButtonBox["MapAt",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapAt.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapAt.html"],
 " to apply a function only to all parts of the second part of an expression:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774783097757797*^9, 3.7748759235776324`*^9, 3.7754754789724717`*^9, {
   3.877708411639964*^9, 3.877708414505525*^9}},
 CellID->24700960,ExpressionUUID->"101cfdf2-9640-4aa3-8ff8-d5f5571b3d59"],

Cell[BoxData[
 RowBox[{
  RowBox[{"team3", "=", 
   RowBox[{"MapAt", "[", 
    RowBox[{"Total", ",", 
     RowBox[{"{", 
      RowBox[{"2", ",", "All"}], "}"}]}], "]"}]}], ";"}]], "Input",
 CellChangeTimes->{{3.769095505112705*^9, 3.769095525046022*^9}, {
   3.769100267072323*^9, 3.7691002685069447`*^9}, {3.7691663636065474`*^9, 
   3.769166404141769*^9}, 3.7691664441623383`*^9, {3.769166499575691*^9, 
   3.7691665240003653`*^9}, {3.769166561078539*^9, 3.769166561715931*^9}, {
   3.769166658496398*^9, 3.769166660964287*^9}, {3.769166740165737*^9, 
   3.7691667555636463`*^9}, {3.769166817357733*^9, 3.769166818984734*^9}},
 CellLabel->"In[48]:=",
 CellID->1688975429,ExpressionUUID->"f70a20b0-0ed8-4788-a332-f5c285ca8735"],

Cell[TextData[{
 "I now create a ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of ",
 Cell[BoxData[
 "team1"], "InlineCodeText",ExpressionUUID->
  "7a506424-b9e5-42e5-a2cb-f12a84612b31"],
 ", ",
 Cell[BoxData[
 "team2"], "InlineCodeText",ExpressionUUID->
  "00c38efa-48cb-43af-b062-8f6760b63a43"],
 ", and ",
 Cell[BoxData[
 "team3"], "InlineCodeText",ExpressionUUID->
  "10405c2d-f5f8-4d4f-8830-f8b1a1d06a7d"],
 ". The result is a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " in which the first element is again the ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " of team-years and the second element is the total salaries for that \
team-year."
}], "Text",
 CellChangeTimes->{{3.7690955537837477`*^9, 3.769095556534296*^9}, {
   3.769095595631147*^9, 3.769095623273614*^9}, {3.769100272013568*^9, 
   3.769100278243704*^9}, {3.769166902111083*^9, 3.769166907188651*^9}, 
   3.774783717810005*^9, {3.7754754894795227`*^9, 3.7754755013907137`*^9}, 
   3.7773557603789177`*^9, {3.87770842447294*^9, 3.8777084366623583`*^9}, 
   3.885636142050398*^9, {3.8890923575365887`*^9, 3.889092359333892*^9}, 
   3.896341894036619*^9},
 CellTags->"LastCellOfAPage",
 CellID->948824146,ExpressionUUID->"66544aab-47db-48e7-9f8b-7765f6051e18"],

Cell[TextData[{
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of ",
 StyleBox["team1", "InlineCode"],
 ", ",
 StyleBox["team2", "InlineCode"],
 ", and ",
 StyleBox["team3", "InlineCode"],
 "; use the ",
 ButtonBox["AugmentedTerse",
  BaseStyle->"ResourceFunctionlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"], None},
  ButtonNote->
   "https://resources.wolframcloud.com/FunctionRepository/resources/\
AugmentedTerse"],
 " ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " to compress the output and show its dimensionality: "
}], "CodeCaption",
 CellChangeTimes->{{3.77735567990672*^9, 3.777355683691413*^9}, {
  3.8856359303652835`*^9, 3.88563595659937*^9}, {3.8890919690775137`*^9, 
  3.889092040032795*^9}, {3.889092477580451*^9, 3.889092502195368*^9}, {
  3.896341906531558*^9, 3.896341914274283*^9}},
 CellTags->"p: 58",
 CellID->466694603,ExpressionUUID->"cb0b135a-4067-4c81-bb6a-3f7ec27c1a06"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"Map", "[", 
  RowBox[{
   RowBox[{
    InterpretationBox[
     TagBox[
      TagBox[
       DynamicModuleBox[{Typeset`open = False}, 
        FrameBox[
         PaneSelectorBox[{False->GridBox[{
            {
             PaneBox[GridBox[{
                {
                 StyleBox[
                  StyleBox[
                   AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                   
                   FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                  ShowStringCharacters->False,
                  FontFamily->"Source Sans Pro Black",
                  FontSize->0.6538461538461539 Inherited,
                  FontWeight->"Heavy",
                  PrivateFontOptions->{"OperatorSubstitution"->False}], 
                 StyleBox[
                  RowBox[{
                   StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                  ShowAutoStyles->False,
                  ShowStringCharacters->False,
                  FontSize->Rational[12, 13] Inherited,
                  FontColor->GrayLevel[0.1]]}
               },
               GridBoxSpacings->{"Columns" -> {{0.25}}}],
              Alignment->Left,
              BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
              BaselinePosition->Baseline,
              FrameMargins->{{3, 0}, {0, 0}}], 
             ItemBox[
              PaneBox[
               TogglerBox[Dynamic[Typeset`open], {True->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeCloser"],
                 ImageSizeCache->{11., {2., 9.}}], False->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeOpener"],
                 ImageSizeCache->{11., {2., 9.}}]},
                Appearance->None,
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{1, 1}, {0, 0}}],
              Frame->{{
                 RGBColor[
                 0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                  0.5], False}, {False, False}}]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
           GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
          GridBox[{
            {GridBox[{
               {
                PaneBox[GridBox[{
                   {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["AugmentedTerse", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                  },
                  GridBoxSpacings->{"Columns" -> {{0.25}}}],
                 Alignment->Left,
                 BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                 BaselinePosition->Baseline,
                 FrameMargins->{{3, 0}, {0, 0}}], 
                ItemBox[
                 PaneBox[
                  TogglerBox[Dynamic[Typeset`open], {True->
                   
                   DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                   
                   DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                   Appearance->None,
                   BaselinePosition->Baseline,
                   ContentPadding->False,
                   FrameMargins->0],
                  Alignment->Left,
                  BaselinePosition->Baseline,
                  FrameMargins->{{1, 1}, {0, 0}}],
                 Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
              },
              BaselinePosition->{1, 1},
              
              GridBoxAlignment->{
               "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
              
              GridBoxItemSize->{
               "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
              GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
            {
             StyleBox[
              PaneBox[GridBox[{
                 {
                  RowBox[{
                   TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                   TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                 {
                  TagBox[
                   
                   TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/55ad4cc5-e284-40ca-a3cb-8a4166c38701/"},
                    "HyperlinkURL"],
                   "IconizedItem"]}
                },
                DefaultBaseStyle->"Column",
                GridBoxAlignment->{"Columns" -> {{Left}}},
                
                GridBoxItemSize->{
                 "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
              FontFamily->"Roboto",
              FontSize->11]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                GrayLevel[0.8]}, False}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
          Typeset`open],
          BaselinePosition->Baseline,
          ImageSize->Automatic],
         Background->RGBColor[
          0.9686274509803922, 0.9764705882352941, 0.984313725490196],
         BaselinePosition->Baseline,
         DefaultBaseStyle->{},
         FrameMargins->{{0, 0}, {1, 0}},
         FrameStyle->RGBColor[
          0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
         RoundingRadius->4]],
       #& ,
       TagBoxNote->" "],
      {"FunctionResourceBox", 
       RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
       "AugmentedTerse"},
      TagBoxNote->"FunctionResourceBox"],
     ResourceFunction[
      ResourceObject[<|
       "Name" -> "AugmentedTerse", "ShortName" -> "AugmentedTerse", "UUID" -> 
        "55ad4cc5-e284-40ca-a3cb-8a4166c38701", "ResourceType" -> "Function", 
        "Version" -> "1.0.0", "Description" -> 
        "An operator form of Short with an alternative compressed \
representation of the output", "RepositoryLocation" -> 
        URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
        "SymbolName" -> 
        "FunctionRepository`$779c3314c408433eb6df4354526edb23`AugmentedTerse",
         "FunctionLocation" -> 
        CloudObject[
         "https://www.wolframcloud.com/obj/5aa416ea-2adb-41c1-9102-\
ddaa33f49612"]|>, ResourceSystemBase -> Automatic]],
     Selectable->False], "[", "1", "]"}], ",", 
   RowBox[{
    RowBox[{"(", 
     RowBox[{"team1", "/*", "team2", "/*", "team3"}], ")"}], "[", "mls2", 
    "]"}]}], "]"}]], "Input",
 CellChangeTimes->{{3.769166544505126*^9, 3.769166573709393*^9}, {
  3.769166918324441*^9, 3.7691669239113626`*^9}, {3.889092389064567*^9, 
  3.8890924462250013`*^9}},
 CellID->1868670835,ExpressionUUID->"a9c0149a-5fb8-4ba9-8586-a656ce36b74f"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{"{", 
    RowBox[{
     TagBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"\<\"CHI\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"CHV\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2007\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2007", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}], ",", 
        RowBox[{"\[LeftSkeleton]", "210", "\[RightSkeleton]"}], ",", 
        RowBox[{"{", 
         RowBox[{"\<\"VAN\"\>", ",", 
          TemplateBox[{
            RowBox[{
              StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
            RowBox[{"DateObject", "[", 
              RowBox[{
                RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
           "DateObject",
           Editable->False]}], "}"}]}], "}"}],
      Short[#, 1]& ], ",", 
     RowBox[{"{", 
      RowBox[{"213", ",", "2"}], "}"}]}], "}"}], ",", 
   RowBox[{"{", 
    RowBox[{
     TagBox[
      RowBox[{"{", 
       RowBox[{
        TemplateBox[{
          InterpretationBox[
          "4.7163045`*^6", 4.7163045*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.7896457000000002`*^6", 1.7896457000000002`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.10822606`*^6", 2.10822606*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["2.281303`*^6", 2.281303*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "3.07276475`*^6", 3.07276475*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["2.27639`*^6", 2.27639*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.43414709`*^6", 2.43414709*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["2.63755`*^6", 2.63755*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "9.32205439`*^6", 9.32205439*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["1.945848`*^6", 1.945848*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "4.92808933`*^6", 4.92808933*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"83\[ThinSpace]100.00\"", 83100., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.97424975`*^6", 1.97424975*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.6539875`*^6", 2.6539875*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "9.1776656`*^6", 9.1776656*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.2152955`*^6", 2.2152955*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.45709446`*^6", 2.45709446*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.50338238`*^6", 2.50338238*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "3.3675892`*^6", 3.3675892*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"127\[ThinSpace]200.00\"", 127200., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["2.551054`*^6", 2.551054*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.7264788`*^6", 2.7264788*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.55306031`*^6", 2.55306031*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.51594954`*^6", 2.51594954*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "4.80816725`*^6", 4.80816725*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.4183763200000003`*^6", 2.4183763200000003`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.48784619`*^6", 2.48784619*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "4.88166885`*^6", 4.88166885*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.37268081`*^6", 2.37268081*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"129\[ThinSpace]000.00\"", 129000., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.77800375`*^6", 2.77800375*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.20004158`*^6", 2.20004158*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "3.2788653`*^6", 3.2788653*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox["3.407212`*^6", 3.407212*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.11620375`*^6", 2.11620375*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "3.54933837`*^6", 3.54933837*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.24654838`*^6", 2.24654838*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.61414255`*^6", 2.61414255*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "4.15216705`*^6", 4.15216705*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.6958273200000003`*^6", 2.6958273200000003`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.4301197`*^6", 2.4301197*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        RowBox[{"\[LeftSkeleton]", "132", "\[RightSkeleton]"}], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.20566176`*^6", 5.20566176*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.67416108`*^6", 5.67416108*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.7524504399999995`*^6", 6.7524504399999995`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.810573604`*^7", 1.810573604*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.74100884`*^6", 6.74100884*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.98083758`*^6", 5.98083758*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.112777663`*^7", 2.112777663*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.82985032`*^6", 5.82985032*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.155442083`*^7", 1.155442083*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.67432396`*^6", 5.67432396*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"62\[ThinSpace]500.00\"", 62500., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.83354397`*^6", 6.83354397*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.9568995`*^6", 5.9568995*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.072881109`*^7", 1.072881109*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.40940025`*^6", 6.40940025*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.179850857`*^7", 2.179850857*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.56560291`*^6", 6.56560291*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "9.00775826`*^6", 9.00775826*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.295227817`*^7", 1.295227817*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.74754499`*^6", 6.74754499*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "8.04061975`*^6", 8.04061975*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.82576094`*^6", 6.82576094*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.2724479399999995`*^6", 5.2724479399999995`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.09121665`*^6", 5.09121665*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.588350779999999`*^6", 6.588350779999999*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.218289611`*^7", 1.218289611*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "\"118\[ThinSpace]008.00\"", 118008., Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.322864550000001`*^6", 5.322864550000001*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.29460589`*^6", 5.29460589*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "5.80011833`*^6", 5.80011833*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.89518617`*^6", 6.89518617*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.32191997`*^7", 1.32191997*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "7.1170101`*^6", 7.1170101*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.082414454`*^7", 1.082414454*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "7.4193554399999995`*^6", 7.4193554399999995`*^6, Selectable -> 
           False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "1.030615048`*^7", 1.030615048*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "6.95928711`*^6", 6.95928711*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"], ",", 
        TemplateBox[{
          InterpretationBox[
          "8.07937107`*^6", 8.07937107*^6, Selectable -> False], 
          RowBox[{
            FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], 
          "US dollars", "\"USDollars\""},
         "QuantityPrefix"]}], "}"}],
      Short[#, 1]& ], ",", 
     RowBox[{"{", "213", "}"}]}], "}"}]}], "}"}]], "Output",
 CellChangeTimes->{{3.889092412119156*^9, 3.8890924369082613`*^9}},
 CellLabel->"Out[13]=",
 CellID->657239823,ExpressionUUID->"1ceb56fe-66af-4b4e-96e3-c3bffccb8d4e"]
}, Open  ]],

Cell[TextData[{
 "Our fourth operator Threads the first element of a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " over the second element of a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 " using ",
 ButtonBox["Rule",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Rule.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Rule.html"],
 ". "
}], "Text",
 CellChangeTimes->{{3.769095627012103*^9, 3.7690956802881203`*^9}, 
   3.769100298274871*^9, 3.7754757755752125`*^9, {3.877708450153306*^9, 
   3.877708456169146*^9}},
 CellID->1623631799,ExpressionUUID->"249d27af-e2db-466c-9b66-31da2e90d9bb"],

Cell[TextData[{
 "Use ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " to create an operator form:"
}], "CodeCaption",
 CellChangeTimes->{
  3.774783108998921*^9, 3.7748763166026325`*^9, {3.7754757795422125`*^9, 
   3.7754757847612123`*^9}},
 CellID->88412202,ExpressionUUID->"ef12db14-4670-4d3b-b042-47cff5400419"],

Cell[BoxData[
 RowBox[{
  RowBox[{"team4", "=", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{"Rule", "[", 
      RowBox[{
       RowBox[{"#", "[", 
        RowBox[{"[", "1", "]"}], "]"}], ",", 
       RowBox[{"#", "[", 
        RowBox[{"[", "2", "]"}], "]"}]}], "]"}], "]"}], "&"}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.769095658988648*^9, 3.7690956734463263`*^9}, {
  3.769100291352612*^9, 3.769100292159637*^9}, {3.76918213258034*^9, 
  3.769182134753523*^9}, {3.7691821884801817`*^9, 3.769182224343998*^9}, {
  3.769182256044476*^9, 3.769182285733053*^9}, {3.896342025986801*^9, 
  3.896342028978305*^9}},
 CellLabel->"In[50]:=",
 CellID->1866250991,ExpressionUUID->"b47b76b4-19ec-4b18-bb8e-c122778e9237"],

Cell[TextData[{
 "Our fifth operator performs ",
 ButtonBox["ReverseSortBy",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ReverseSortBy.html"], 
    None},
  ButtonNote->"https://reference.wolfram.com/language/ref/ReverseSortBy.html"],
 " using the ",
 ButtonBox["Last",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Last.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Last.html"],
 " element and then takes the first 10 values."
}], "Text",
 CellChangeTimes->{{3.769095699532324*^9, 3.769095740914728*^9}, {
   3.769182110503045*^9, 3.769182111227294*^9}, {3.7754757882622128`*^9, 
   3.7754757960462127`*^9}, 3.87770847005908*^9},
 CellID->886172334,ExpressionUUID->"a9bd87cc-7bca-4d7b-8ef8-580b851c2abc"],

Cell[TextData[{
 "Create an operator that takes the 10 rows of data with the highest ",
 ButtonBox["Last",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Last.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Last.html"],
 " values:"
}], "CodeCaption",
 CellChangeTimes->{3.774783118383859*^9, 3.774876319233632*^9, 
  3.775475810373213*^9, 3.885636290459502*^9},
 CellID->272293802,ExpressionUUID->"cce11058-4cbe-4a9f-b5e1-5e2e3176d6fc"],

Cell[BoxData[
 RowBox[{
  RowBox[{"team5", "=", 
   RowBox[{"data", "\[Function]", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"ReverseSortBy", "[", 
       RowBox[{"data", ",", "Last"}], "]"}], ",", "10"}], "]"}]}]}], 
  ";"}]], "Input",
 CellChangeTimes->{{3.7690957198021812`*^9, 3.7690957612466927`*^9}, {
  3.76910030140823*^9, 3.769100302334902*^9}},
 CellLabel->"In[51]:=",
 CellID->1000588128,ExpressionUUID->"19c1b48a-1686-4b4e-91dc-b9115d229644"],

Cell[TextData[{
 "And I make a big ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " and get exactly the result I want."
}], "Text",
 CellChangeTimes->{{3.769095769557056*^9, 3.769095786362541*^9}, 
   3.775475825814213*^9, {3.885636301414579*^9, 3.8856363020249443`*^9}},
 CellTags->{"LastCellOfAPage", "i:83"},
 CellID->38294597,ExpressionUUID->"021f1402-90ca-430e-b65f-c081f816739c"],

Cell["\<\
Create a five-operator pipeline and get the teams with the highest payrolls:\
\>", "CodeCaption",
 CellChangeTimes->{
  3.7747831281778383`*^9, 3.774876321674632*^9, {3.7754758282842126`*^9, 
   3.7754758298842125`*^9}},
 CellTags->"p: 59",
 CellID->409418610,ExpressionUUID->"4de3fb1a-ea03-47e8-98d5-eb344671247d"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"(", 
   RowBox[{
   "team1", "/*", "team2", "/*", "team3", "/*", "team4", "/*", "team5"}], 
   ")"}], "[", "mls2", "]"}]], "Input",
 CellChangeTimes->{{3.769095683631816*^9, 3.769095691861974*^9}, {
  3.7690957638657618`*^9, 3.7690957654373913`*^9}, {3.7691003063462267`*^9, 
  3.769100318389339*^9}},
 CellLabel->"In[52]:=",
 CellID->1975202494,ExpressionUUID->"82793ebe-27fc-42de-ad1d-492ca69f9224"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.2136512029999997`*^7", 2.2136512029999997`*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.179850857`*^7", 2.179850857*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.126757475`*^7", 2.126757475*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.112777663`*^7", 2.112777663*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.810573604`*^7", 1.810573604*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.741426789`*^7", 1.741426789*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NY\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox["1.67281078`*^7", 1.67281078*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.671260318`*^7", 1.671260318*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}]}], "}"}]], "Output",
 CellChangeTimes->{
  3.769095692391951*^9, 3.7690957661748047`*^9, {3.7691003194379263`*^9, 
   3.7691003451410437`*^9}, 3.7691006621362677`*^9, 3.769166438774949*^9, 
   3.769166591904509*^9, 3.7691669669045677`*^9, {3.769182210894753*^9, 
   3.7691822277713633`*^9}, {3.7691822759153013`*^9, 3.7691822876162453`*^9}, 
   3.76977269937883*^9, 3.769975556336731*^9, 3.771923599392632*^9, 
   3.7719290871237707`*^9, 3.771929533813404*^9, 3.880630077959442*^9, 
   3.881417778082843*^9, 3.88228493541814*^9},
 CellLabel->"Out[52]=",
 CellID->884589934,ExpressionUUID->"a1735097-4274-4ec1-be63-f6a2d84a5dee"]
}, Open  ]],

Cell[TextData[{
 "Alternatively, I could give the ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " a name and apply it."
}], "Text",
 CellChangeTimes->{{3.7690958175975857`*^9, 3.7690958343478317`*^9}, 
   3.7754758401972127`*^9},
 CellID->452835264,ExpressionUUID->"5b718345-99d7-4c3e-a50b-ecefa35775d4"],

Cell[TextData[{
 "Name a ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " of functions:"
}], "CodeCaption",
 CellChangeTimes->{
  3.7747831376097813`*^9, 3.7748763415046325`*^9, 3.775475844208213*^9, {
   3.8814064955115843`*^9, 3.881406520743827*^9}},
 CellID->404998412,ExpressionUUID->"ed0885c2-2393-4fa0-9686-b4ce9e9297b5"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"biggestPayrolls", "=", 
  RowBox[{"(", 
   RowBox[{
   "team1", "/*", "team2", "/*", "team3", "/*", "team4", "/*", "team5"}], 
   ")"}]}]], "Input",
 CellChangeTimes->{{3.769095838920573*^9, 3.7690958482889967`*^9}, {
  3.769100350765307*^9, 3.76910036296285*^9}},
 CellLabel->"In[53]:=",
 CellID->1888289210,ExpressionUUID->"979c862d-2243-4415-b753-3a03e45aeb19"],

Cell[BoxData[
 RowBox[{
  RowBox[{
   RowBox[{"GatherBy", "[", 
    RowBox[{"#1", ",", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        RowBox[{"#1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
        ",", 
        RowBox[{
        "#1", "\[LeftDoubleBracket]", "7", "\[RightDoubleBracket]"}]}], "}"}],
       "&"}]}], "]"}], "&"}], "/*", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{
      RowBox[{"#1", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "1", ",", 
        RowBox[{"{", 
         RowBox[{"1", ",", "7"}], "}"}]}], "\[RightDoubleBracket]"}], ",", 
      RowBox[{"#1", "\[LeftDoubleBracket]", 
       RowBox[{"All", ",", "All", ",", "6"}], "\[RightDoubleBracket]"}]}], 
     "}"}], "&"}], ")"}], "/*", 
  RowBox[{"MapAt", "[", 
   RowBox[{"Total", ",", 
    RowBox[{"{", 
     RowBox[{"2", ",", "All"}], "}"}]}], "]"}], "/*", 
  RowBox[{"(", 
   RowBox[{
    RowBox[{"Thread", "[", 
     RowBox[{
      RowBox[{"#1", "\[LeftDoubleBracket]", "1", "\[RightDoubleBracket]"}], 
      "\[Rule]", 
      RowBox[{"#1", "\[LeftDoubleBracket]", "2", "\[RightDoubleBracket]"}]}], 
     "]"}], "&"}], ")"}], "/*", 
  RowBox[{"Function", "[", 
   RowBox[{"data", ",", 
    RowBox[{"Take", "[", 
     RowBox[{
      RowBox[{"ReverseSortBy", "[", 
       RowBox[{"data", ",", "Last"}], "]"}], ",", "10"}], "]"}]}], 
   "]"}]}]], "Output",
 CellChangeTimes->{3.7690958487850437`*^9, 3.7691003637697287`*^9, 
  3.7691006622184477`*^9, 3.769166485937523*^9, 3.7691669733147373`*^9, 
  3.769772699473029*^9, 3.7699755564367247`*^9, 3.771923599423259*^9, 
  3.77192908988859*^9, 3.7719295338837843`*^9, 3.880630086585455*^9, 
  3.881417783300702*^9, 3.882284950942966*^9},
 CellLabel->"Out[53]=",
 CellID->194461468,ExpressionUUID->"0674c530-4c31-4726-b500-cb00b1fc66ac"]
}, Open  ]],

Cell[TextData[{
 "Apply a named ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 " to the data:"
}], "CodeCaption",
 CellChangeTimes->{{3.769182367293805*^9, 3.7691823873275747`*^9}, 
   3.77478315009803*^9, 3.7748763437766323`*^9, {3.7754758505532126`*^9, 
   3.7754758539242125`*^9}},
 CellID->2049498201,ExpressionUUID->"59542eb7-b366-4c96-851b-9d52569efe54"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"biggestPayrolls", "[", "mls2", "]"}]], "Input",
 CellChangeTimes->{{3.7690958625945873`*^9, 3.769095865909301*^9}, 
   3.7691003664415827`*^9},
 CellLabel->"In[54]:=",
 CellID->1974514058,ExpressionUUID->"f1c0b62e-486c-4e03-8d50-e2a4cedc44d2"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.2136512029999997`*^7", 2.2136512029999997`*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.179850857`*^7", 2.179850857*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.126757475`*^7", 2.126757475*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.112777663`*^7", 2.112777663*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.810573604`*^7", 1.810573604*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.741426789`*^7", 1.741426789*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NY\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox["1.67281078`*^7", 1.67281078*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.671260318`*^7", 1.671260318*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}]}], "}"}]], "Output",
 CellChangeTimes->{3.769095866516718*^9, 3.769100366980482*^9, 
  3.76910066238575*^9, 3.769166977520846*^9, 3.769772699669142*^9, 
  3.769975556639304*^9, 3.77192359946113*^9, 3.771929092717141*^9, 
  3.771929534028426*^9, 3.880630089193446*^9, 3.881417788312055*^9, 
  3.88228495579298*^9},
 CellLabel->"Out[54]=",
 CellID->392257524,ExpressionUUID->"f41d3d9f-8eb6-4270-b280-b15b28baee3b"]
}, Open  ]]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Conclusion", "Subsection",
 CellChangeTimes->{{3.769095911637074*^9, 3.769095915383519*^9}},
 CellID->1863754633,ExpressionUUID->"d4a76011-6a74-455c-a8a1-8a2b4ded091c"],

Cell[TextData[{
 "There\[CloseCurlyQuote]s obviously a lot more I could do with our data, but \
this isn\[CloseCurlyQuote]t a study of Major League Soccer and it isn\
\[CloseCurlyQuote]t the end of our study of data analysis. In fact, as I will \
show in a later chapter, it will prove considerably easier to do these sorts \
of computations once we have features such as ",
 ButtonBox["Association",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Association.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Association.html"],
 ", ",
 ButtonBox["Dataset",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Dataset.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Dataset.html"],
 ", and ",
 ButtonBox["Query",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Query.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Query.html"],
 " available. In the meantime, though, I hope you have appreciated the power \
of even the old-school Wolfram Language in dealing with data and, critically, \
an operator-focused style of programming."
}], "Text",
 CellChangeTimes->{{3.769095916562722*^9, 3.769095930346991*^9}, {
  3.769096116335816*^9, 3.769096205955845*^9}, {3.769166993557734*^9, 
  3.769167033279038*^9}, {3.774783989746005*^9, 3.7747839901250052`*^9}, {
  3.7754758594102125`*^9, 3.7754759090332127`*^9}, {3.8856363649356737`*^9, 
  3.885636382216466*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1458935525,ExpressionUUID->"c182b241-0ebe-46d5-86eb-178c94fe0838"],

Cell[CellGroupData[{

Cell[BoxData[
 InterpretationBox["Exercises",
  $Line = 0; Null]], "ExerciseSection",
 CellTags->"p: 60",
 CellID->2000071317,ExpressionUUID->"89dcba58-2102-40b3-971e-38edb2e73355"],

Cell[TextData[{
 "Here is a list of expressions: ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"-", "46"}], ",", " ", "7", ",", " ", 
    RowBox[{"p", "[", "4", "]"}], ",", " ", 
    RowBox[{"p", "[", 
     RowBox[{"3", ",", " ", "4"}], "]"}], ",", " ", 
    RowBox[{"p", "[", 
     RowBox[{"2", ",", " ", 
      RowBox[{"q", "[", 
       RowBox[{"5", ",", " ", "6"}], "]"}]}], "]"}], ",", " ", 
    RowBox[{"4", "+", 
     RowBox[{"7", " ", "\[ImaginaryI]"}]}], ",", " ", 
    FractionBox["9", "10"]}], "}"}]], "InlineCode",ExpressionUUID->
  "e9c42b04-aba5-47d2-84eb-6b742b5d78d3"],
 ". Which of them can you successfully use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " on and which generate an error message? "
}], "Exercise",
 CellChangeTimes->{{3.769173250136813*^9, 3.769173386447424*^9}, {
   3.775480424865255*^9, 3.7754804765004177`*^9}, 3.7754805167554426`*^9, {
   3.777357240870716*^9, 3.77735725199612*^9}, {3.8562810690823717`*^9, 
   3.856281074234929*^9}, {3.8856375743487062`*^9, 3.8856376238970613`*^9}, {
   3.889694738454611*^9, 3.8896947517601*^9}, {3.88971481604576*^9, 
   3.889714861514896*^9}},
 CellTags->"Exercise",
 CellID->345108167,ExpressionUUID->"667d000f-a65a-40bb-aba3-d4a86b7fdabe"],

Cell[TextData[{
 "Write a function that takes a ",
 ButtonBox["List",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/List.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/List.html"],
 ", such as ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"3", ",", " ", "5"}], "}"}]], "InlineCode",ExpressionUUID->
  "71e3e92c-3f82-4e97-a637-3a17898be881"],
 ", and computes the absolute value of the difference between the two \
numbers. Here the right answer would be 2. Hint 1: The function for computing \
absolute value is ",
 ButtonBox["Abs",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Abs.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Abs.html"],
 ". Hint 2: Your function should use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.7691735806891336`*^9, 3.769173714613014*^9}, {
  3.775480525098277*^9, 3.775480559507273*^9}, {3.7754806289403296`*^9, 
  3.7754806363235908`*^9}, {3.7754807553496866`*^9, 3.775480773177904*^9}, {
  3.777357344631509*^9, 3.777357346956882*^9}, {3.877708785271636*^9, 
  3.8777088181773376`*^9}, {3.8856364186012535`*^9, 3.8856364208283105`*^9}, {
  3.885636488076*^9, 3.8856364965229664`*^9}, {3.8856518621321244`*^9, 
  3.8856518621331167`*^9}, {3.8896947736749067`*^9, 3.889694773675867*^9}},
 CellTags->"Exercise",
 CellID->607597237,ExpressionUUID->"46f9dee9-aef3-44a4-ada0-c61fae050a00"],

Cell[TextData[{
 "Use ",
 ButtonBox["Total",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Total.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Total.html"],
 " and ",
 ButtonBox["Map",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Map.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Map.html"],
 " to compute the sum of the absolute value of the differences between the \
following pairs of numbers ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"3", ",", " ", "5"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"8", ",", " ", "9"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{"6", ",", " ", "6"}], "}"}], ",", " ", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"-", "2"}], ",", " ", "11"}], "}"}]}], "}"}]], "InlineCode",
  ExpressionUUID->"8e2045a4-dd23-4d2b-8537-d52698fe81b1"],
 ". You should get 16."
}], "Exercise",
 CellChangeTimes->{{3.769173739008436*^9, 3.7691738100795593`*^9}, {
   3.775480947874997*^9, 3.775480950614997*^9}, {3.775481156998997*^9, 
   3.775481184676997*^9}, 3.777357383284636*^9, {3.885636612395746*^9, 
   3.885636634560822*^9}, {3.889694776195939*^9, 3.8896947803787737`*^9}, {
   3.889695897544382*^9, 3.8896959020632906`*^9}},
 CellTags->"Exercise",
 CellID->1158908686,ExpressionUUID->"b4e54741-dfb1-4d0a-ab81-88e04d4dec1b"],

Cell[CellGroupData[{

Cell[TextData[{
 "The Manhattan distance between two points is the sum of the absolute value \
of the differences in the ",
 Cell[BoxData[
  FormBox[
   StyleBox["x", "TI"], TraditionalForm]],ExpressionUUID->
  "c743480f-f6d7-401c-90fe-d722f05e3072"],
 " coordinates and ",
 Cell[BoxData[
  FormBox[
   StyleBox["y", "TI"], TraditionalForm]],ExpressionUUID->
  "009950c3-7787-4ed4-8c2a-08dd34de160b"],
 " coordinates. So, if one point is at ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"2", ",", " ", "9"}], "}"}]], "InlineCode",ExpressionUUID->
  "31c9a1f8-8842-493f-a2ee-cec2e89ab779"],
 " and the other point is at ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"5", ",", " ", "1"}], "}"}]], "InlineCode",ExpressionUUID->
  "517e756c-5431-4497-b9b8-e7bb8183cc0c"],
 ", the absolute value of the differences are 3 and 8 and the Manhattan \
distance is 11. Find me the Manhattan distance between the points given \
below. Hint: You should probably use ",
 ButtonBox["Thread",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Thread.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Thread.html"],
 " or ",
 ButtonBox["Transpose",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Transpose.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Transpose.html"],
 ". (There is a built-in ",
 ButtonBox["ManhattanDistance",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ManhattanDistance.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ManhattanDistance.html"],
 " function; it would be clever to use it, but you would lose the educational \
benefits of the exercise.)"
}], "Exercise",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.769173479733371*^9, 3.7691735237943497`*^9}, {
   3.7691735575015383`*^9, 3.769173578752775*^9}, {3.769173839121997*^9, 
   3.769173941016765*^9}, {3.769173987702073*^9, 3.769174042192457*^9}, 
   3.774783722833005*^9, {3.7754812387999973`*^9, 3.7754812543429976`*^9}, {
   3.775481288824997*^9, 3.775481293190997*^9}, 3.775481349282997*^9, {
   3.775481657312997*^9, 3.775481659919997*^9}, {3.775481874683997*^9, 
   3.7754818927879972`*^9}, {3.777357416122353*^9, 3.777357442690671*^9}, {
   3.7773575850533867`*^9, 3.777357597786702*^9}, {3.865585908370825*^9, 
   3.865585933030579*^9}, {3.8777088661473417`*^9, 3.87770888700819*^9}, {
   3.885637672887338*^9, 3.8856377103446403`*^9}, {3.888934637333775*^9, 
   3.888934644518085*^9}, {3.889694785780693*^9, 3.889694787419307*^9}, {
   3.889694848875925*^9, 3.8896948511126337`*^9}},
 CellTags->"Exercise",
 CellID->2069077201,ExpressionUUID->"ed5200ef-0192-4b38-bb35-e05c150b9e66"],

Cell[BoxData[{
 RowBox[{
  RowBox[{"point1", "=", 
   RowBox[{"{", 
    RowBox[{"4", ",", "12"}], "}"}]}], ";"}], "\n", 
 RowBox[{
  RowBox[{"point2", "=", 
   RowBox[{"{", 
    RowBox[{"3", ",", "5"}], "}"}]}], ";"}]}], "ExerciseInput",
 ShowGroupOpener->False,
 CellChangeTimes->{{3.7691735250166616`*^9, 3.769173550997363*^9}, {
   3.76917385224788*^9, 3.769173855248826*^9}, {3.769173949479745*^9, 
   3.769173980518899*^9}, 3.777357578761046*^9},
 CellTags->"Exercise",
 CellLabel->"In[182]:=",
 CellID->1084903328,ExpressionUUID->"470cf254-7c43-4a7a-adea-ab36afc871af"]
}, Open  ]],

Cell[TextData[{
 StyleBox["These next exercises ask you to use the MLS data. I\
\[CloseCurlyQuote]d suggest you evaluate the code that creates the ",
  FontWeight->"Bold"],
 Cell[BoxData[
  StyleBox["mls2",
   FontFamily->"Source Sans Pro",
   FontSize->14,
   FontColor->GrayLevel[0]]], "InlineCodeText",
  FontWeight->"Bold",ExpressionUUID->"d5f92102-1b17-4a05-bf92-a6fde4a7fc2f"],
 StyleBox[" variable and use it.",
  FontWeight->"Bold"]
}], "Exercise",
 CellDingbat->None,
 CellChangeTimes->{{3.769175541634996*^9, 3.76917557845181*^9}, 
   3.7754847516067257`*^9, 3.777357613436099*^9},
 CounterIncrements->None,
 CellTags->"Exercise",
 CellID->332482727,ExpressionUUID->"435df473-d9b5-490f-ba28-5b0f3b1dd9a6"],

Cell[TextData[{
 "Augment the matrix of information contained in ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"60351d79-2886-49cb-a806-9b212d08679c"],
 " by inserting a first column that numbers the players from 1 to 4899."
}], "Exercise",
 CellChangeTimes->{{3.7691825506669493`*^9, 3.769182589760968*^9}, 
   3.775484759097475*^9},
 CounterAssignments->{{$CellContext`Exercise, 4}},
 CellTags->"Exercise",
 CellID->393275140,ExpressionUUID->"c440deaf-04c6-4b7c-b9b8-5a83f565d1a7"],

Cell[TextData[{
 "Find the base salary of the last player in the ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"11619f41-1438-40b4-bb72-8ebfa4c8a583"],
 " data."
}], "Exercise",
 CellChangeTimes->{{3.7691755804050713`*^9, 3.769175615038308*^9}, 
   3.7754847688764524`*^9},
 CellTags->"Exercise",
 CellID->1808053344,ExpressionUUID->"a17d3e2c-28cb-47aa-924e-ffba11ce4381"],

Cell[TextData[{
 "Find the median base salary of all the players in the ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"52155ea5-0b33-4c71-8389-688eeda3af96"],
 " data."
}], "Exercise",
 CellChangeTimes->{{3.7691756331149054`*^9, 3.769175671114662*^9}, {
  3.775484775628128*^9, 3.775484777021267*^9}},
 CellTags->"Exercise",
 CellID->1457862554,ExpressionUUID->"83f09d36-ca48-463d-91f4-d88b14297558"],

Cell[TextData[{
 "Find the ",
 ButtonBox["Mean",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Mean.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Mean.html"],
 " difference between the guaranteed compensation and base salary for all \
players in the ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"057dabb2-d581-44cd-a5ba-79cb2b292d30"],
 " data. Then do the same computation but ",
 ButtonBox["Select",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Select.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"],
 " only players whose last names are not equal to Beckham. The ",
 ButtonBox["Unequal",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Unequal.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Unequal.html"],
 " operator in the Wolfram Language is ",
 ButtonBox["!=",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Unequal.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Unequal.html"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.769175678379962*^9, 3.7691757278138103`*^9}, {
   3.7691757852731647`*^9, 3.769175786486452*^9}, {3.769175825955784*^9, 
   3.769175837987512*^9}, 3.7754851012666883`*^9, {3.775485142961858*^9, 
   3.775485164254987*^9}, {3.777357644780857*^9, 3.777357648048263*^9}, {
   3.856281197636716*^9, 3.856281218932905*^9}, {3.856613073559538*^9, 
   3.856613124858234*^9}, {3.8777090926577253`*^9, 3.8777091018161077`*^9}, {
   3.8856377583864956`*^9, 3.88563777649549*^9}, {3.8856378133067026`*^9, 
   3.885637819769433*^9}},
 CellTags->"Exercise",
 CellID->1596278989,ExpressionUUID->"cceb4aa1-d415-440a-bdec-ea61c420fb4b"],

Cell[TextData[{
 "Here\[CloseCurlyQuote]s some code that would let you find rows of the MLS \
dataset that are from 2009: ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    ButtonBox[
     StyleBox["Select",
      FontColor->GrayLevel[0]],
     BaseStyle->"Hyperlink",
     ButtonData->{
       URL["https://reference.wolfram.com/language/ref/Select.html"], None},
     ButtonNote->"https://reference.wolfram.com/language/ref/Select.html"], 
    "[", 
    RowBox[{
     RowBox[{
      ButtonBox[
       StyleBox["#",
        FontColor->GrayLevel[0]],
       BaseStyle->"Hyperlink",
       ButtonData->{
         URL["https://reference.wolfram.com/language/ref/Slot.html"], None},
       ButtonNote->"https://reference.wolfram.com/language/ref/Slot.html"], 
      "[", 
      RowBox[{"[", "7", "]"}], "]"}], 
     ButtonBox[
      StyleBox["==",
       FontColor->GrayLevel[0]],
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["https://reference.wolfram.com/language/ref/Equal.html"], None},
      ButtonNote->"https://reference.wolfram.com/language/ref/Equal.html"], 
     TemplateBox[{
       RowBox[{
         StyleBox[
         "\"Year: \"", FontColor -> GrayLevel[0.5], FontWeight -> Plain], 
         "\"2009\""}], 
       RowBox[{"DateObject", "[", 
         RowBox[{
           RowBox[{"{", "2009", "}"}], ",", "\"Year\"", ",", "\"Gregorian\"", 
           ",", 
           RowBox[{"-", "5.`"}]}], "]"}]},
      "DateObject",
      Editable->False], " ", 
     ButtonBox[
      StyleBox["&",
       FontColor->GrayLevel[0]],
      BaseStyle->"Hyperlink",
      ButtonData->{
        URL["https://reference.wolfram.com/language/ref/Function.html"], None},
      ButtonNote->
       "https://reference.wolfram.com/language/ref/Function.html"]}], "]"}], 
   "[", "mls2", "]"}]], "InlineCode",ExpressionUUID->
  "dfceee32-02ee-4415-ad79-0c256dbac31d"],
 ". Find me the player on the Houston Dynamo team with the highest guaranteed \
compensation in 2009. Hint: Your answer output should be ",
 Cell[BoxData[
  RowBox[{"{", 
   RowBox[{"Ricardo", ",", " ", "Clark"}], "}"}]], "InlineCode",
  ExpressionUUID->"1a0500f8-45e7-41a0-8941-330f83eabc52"],
 "."
}], "Exercise",
 CellTags->"Exercise",
 CellID->707323200,ExpressionUUID->"d4551e4e-798f-4dfd-9009-4fcc45821567"],

Cell[TextData[{
 "What team-year combination had the highest number of players with base \
salaries over $250,000? Hint: To write $250,000 use ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["Quantity",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Quantity.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Quantity.html"], 
   "[", 
   RowBox[{"250000", ",", " ", "\"\<USDollars\>\""}], "]"}]], "InlineCode",
  ExpressionUUID->"5ac5648d-0104-439f-8b5a-2058d351e6ea"],
 "."
}], "Exercise",
 CellChangeTimes->{{3.769174245262096*^9, 3.769174275426198*^9}, {
  3.769174463967482*^9, 3.769174493521639*^9}, {3.775485267258286*^9, 
  3.7754852907446346`*^9}, {3.8856378774135294`*^9, 3.8856378784926434`*^9}, {
  3.8896947973254037`*^9, 3.8896947973254037`*^9}},
 CellTags->{"Exercise", "LastCellOfAPage"},
 CellID->205547354,ExpressionUUID->"20ac2b81-8b67-44fe-ab01-17ec9e8c0175"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Tech Notes", "TechNoteSection",
 CellTags->"p: 61",
 CellID->2102209134,ExpressionUUID->"c7deca42-6f80-40d1-808f-f89e2f023be7"],

Cell[TextData[{
 "I used ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " to show the structure of a Wolfram Language expression. Another \
alternative is to use ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 ", which is kind of how the kernel thinks about an expression. In ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 ", no syntactic sugar is used and the structure of the expression is made \
explicit. Here I compare how one might represent the solution to a quadratic \
equation in ",
 ButtonBox["InputForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/InputForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/InputForm.html"],
 " (the way a user might type it), in ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 " (the way the kernel thinks about it), and in ",
 ButtonBox["TreeForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/TreeForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/TreeForm.html"],
 " (an easier-to-read variant of ",
 ButtonBox["FullForm",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/FullForm.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/FullForm.html"],
 ")."
}], "TechNote",
 CellChangeTimes->{{3.769178405599049*^9, 3.769178490159418*^9}, {
   3.769178523585074*^9, 3.769178598009892*^9}, {3.7754759235582123`*^9, 
   3.7754759445982127`*^9}, {3.775476865326124*^9, 3.775476894226014*^9}, 
   3.8855551651113434`*^9, {3.89634209559486*^9, 3.896342096226903*^9}},
 CellTags->"i:84",
 CellID->1139233202,ExpressionUUID->"2e208e72-23fd-4281-bf19-fded56c1db83"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{
  RowBox[{"{", 
   RowBox[{
    RowBox[{"InputForm", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["z", "2"]}], "+", " ", 
         RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], "\[Equal]", "0"}], 
       ",", "z"}], "]"}], "]"}], ",", 
    RowBox[{"FullForm", "[", 
     RowBox[{"Solve", "[", 
      RowBox[{
       RowBox[{
        RowBox[{
         RowBox[{"a", " ", 
          SuperscriptBox["z", "2"]}], "+", " ", 
         RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], "\[Equal]", "0"}], 
       ",", "z"}], "]"}], "]"}], ",", 
    RowBox[{"TreeForm", "[", 
     RowBox[{
      RowBox[{"Solve", "[", 
       RowBox[{
        RowBox[{
         RowBox[{
          RowBox[{"a", " ", 
           SuperscriptBox["z", "2"]}], "+", " ", 
          RowBox[{"b", " ", "z"}], " ", "+", " ", "c"}], "\[Equal]", "0"}], 
        ",", "z"}], "]"}], ",", 
      RowBox[{"ImageSize", "\[Rule]", "400"}]}], "]"}]}], "}"}], "//", 
  "Framed"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.76917849175729*^9, 3.769178533630054*^9}, {
  3.771929186255163*^9, 3.771929199530388*^9}, {3.771929605356247*^9, 
  3.771929630908334*^9}},
 CellLabel->"In[193]:=",
 CellID->1598642278,ExpressionUUID->"2d98a5aa-2eca-4bdc-9c17-fc98163f06ee"],

Cell[BoxData[
 FrameBox[
  RowBox[{"{", 
   RowBox[{
    InterpretationBox[
     StyleBox[
      RowBox[{"{", 
       RowBox[{
        RowBox[{"{", 
         RowBox[{"z", " ", "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "b"}], " ", "-", " ", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"b", "^", "2"}], " ", "-", " ", 
               RowBox[{"4", "*", "a", "*", "c"}]}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", "a"}], ")"}]}]}], "}"}], ",", " ", 
        RowBox[{"{", 
         RowBox[{"z", " ", "->", " ", 
          RowBox[{
           RowBox[{"(", 
            RowBox[{
             RowBox[{"-", "b"}], " ", "+", " ", 
             RowBox[{"Sqrt", "[", 
              RowBox[{
               RowBox[{"b", "^", "2"}], " ", "-", " ", 
               RowBox[{"4", "*", "a", "*", "c"}]}], "]"}]}], ")"}], "/", 
           RowBox[{"(", 
            RowBox[{"2", "*", "a"}], ")"}]}]}], "}"}]}], "}"}],
      ShowStringCharacters->True,
      NumberMarks->True],
     InputForm[{{$CellContext`z -> (
          Rational[
           1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - (
            4 $CellContext`a) $CellContext`c)^
          Rational[1, 2])}, {$CellContext`z -> (
          Rational[
           1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - (
             4 $CellContext`a) $CellContext`c)^Rational[1, 2])}}],
     AutoDelete->True,
     Editable->True], ",", 
    TagBox[
     StyleBox[
      RowBox[{"List", "[", 
       RowBox[{
        RowBox[{"List", "[", 
         RowBox[{"Rule", "[", 
          RowBox[{"z", ",", 
           RowBox[{"Times", "[", 
            RowBox[{
             RowBox[{"Rational", "[", 
              RowBox[{"1", ",", "2"}], "]"}], ",", 
             RowBox[{"Power", "[", 
              RowBox[{"a", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"Plus", "[", 
              RowBox[{
               RowBox[{"Times", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "b"}], "]"}], ",", 
               RowBox[{"Times", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", 
                 RowBox[{"Power", "[", 
                  RowBox[{
                   RowBox[{"Plus", "[", 
                    RowBox[{
                    RowBox[{"Power", "[", 
                    RowBox[{"b", ",", "2"}], "]"}], ",", 
                    RowBox[{"Times", "[", 
                    RowBox[{
                    RowBox[{"-", "4"}], ",", "a", ",", "c"}], "]"}]}], "]"}], 
                   ",", 
                   RowBox[{"Rational", "[", 
                    RowBox[{"1", ",", "2"}], "]"}]}], "]"}]}], "]"}]}], 
              "]"}]}], "]"}]}], "]"}], "]"}], ",", 
        RowBox[{"List", "[", 
         RowBox[{"Rule", "[", 
          RowBox[{"z", ",", 
           RowBox[{"Times", "[", 
            RowBox[{
             RowBox[{"Rational", "[", 
              RowBox[{"1", ",", "2"}], "]"}], ",", 
             RowBox[{"Power", "[", 
              RowBox[{"a", ",", 
               RowBox[{"-", "1"}]}], "]"}], ",", 
             RowBox[{"Plus", "[", 
              RowBox[{
               RowBox[{"Times", "[", 
                RowBox[{
                 RowBox[{"-", "1"}], ",", "b"}], "]"}], ",", 
               RowBox[{"Power", "[", 
                RowBox[{
                 RowBox[{"Plus", "[", 
                  RowBox[{
                   RowBox[{"Power", "[", 
                    RowBox[{"b", ",", "2"}], "]"}], ",", 
                   RowBox[{"Times", "[", 
                    RowBox[{
                    RowBox[{"-", "4"}], ",", "a", ",", "c"}], "]"}]}], "]"}], 
                 ",", 
                 RowBox[{"Rational", "[", 
                  RowBox[{"1", ",", "2"}], "]"}]}], "]"}]}], "]"}]}], "]"}]}],
           "]"}], "]"}]}], "]"}],
      ShowSpecialCharacters->False,
      ShowStringCharacters->True,
      NumberMarks->True],
     FullForm], ",", 
    InterpretationBox[
     GraphicsBox[
      TagBox[GraphicsComplexBox[CompressedData["
1:eJxTTMoPSmViYGDQB2IQ7fxjRec6R1aHV5qGS1maJB2iFpglTQ5/Y1+9WftF
6RoxOJ/bVk37+TVhhznHFPIiGB/aQ2hBBx6w+Gc4nwEKIsH6eBwg5jyzh/Gr
wPxrUPPZoOZ9hPMh5jE7wNRD6D9weYj+b1D7GB3QaYg/OB1g6lHtYYSbi66+
BmrulcbFZ+RzmBwqoO4+KWYjr6T73x7mL1h4wfgMmff3ffEWgKtXerqZ+cwb
Lgx5GLfg/pPqZkVhOB9iPj/cfguVJNk92wQdYOEP48PCH2YeLLxh5sH4qOHG
gyEOsw8WLhD/CsH5m/LWudmKS8DVu4D9K+qAGj/C8PCrgroTxof4XwquHpau
YPL3Ql9ZCH0Xhft3xaz0W149IvDwExPMnX4zURzO//a3XPA7jyxcfVt7UUiG
uRSGPIyfUlJ7rvWRPJwPSb8ycPsBe78oLw==
        "], {
         {RGBColor[0.55, 0.45, 0.45], 
          LineBox[{{1, 2}, {1, 26}, {2, 3}, {3, 4}, {3, 5}, {5, 6}, {5, 7}, {
           5, 10}, {7, 8}, {7, 9}, {10, 11}, {10, 14}, {11, 12}, {11, 13}, {
           14, 15}, {14, 16}, {16, 17}, {16, 25}, {17, 18}, {17, 21}, {18, 
           19}, {18, 20}, {21, 22}, {21, 23}, {21, 24}, {26, 27}, {27, 28}, {
           27, 29}, {29, 30}, {29, 31}, {29, 34}, {31, 32}, {31, 33}, {34, 
           35}, {34, 38}, {35, 36}, {35, 37}, {38, 39}, {38, 47}, {39, 40}, {
           39, 43}, {40, 41}, {40, 42}, {43, 44}, {43, 45}, {43, 46}}]}, {
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["List", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 1],
            TagBox[
             RowBox[{"{", 
               RowBox[{
                 RowBox[{"{", 
                   RowBox[{"z", "\[Rule]", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"-", "b"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                    RowBox[{"2", " ", "a"}]]}], "}"}], ",", 
                 RowBox[{"{", 
                   RowBox[{"z", "\[Rule]", 
                    FractionBox[
                    RowBox[{
                    RowBox[{"-", "b"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                    RowBox[{"2", " ", "a"}]]}], "}"}]}], "}"}], HoldForm]],
           Annotation[#, 
            
            HoldForm[{{$CellContext`z -> (
                 Rational[
                  1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - \
(4 $CellContext`a) $CellContext`c)^Rational[1, 2])}, {$CellContext`z -> (
                 Rational[
                  1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - \
(4 $CellContext`a) $CellContext`c)^Rational[1, 2])}}], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["List", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 2],
            TagBox[
             RowBox[{"{", 
               RowBox[{"z", "\[Rule]", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "b"}], "-", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                  RowBox[{"2", " ", "a"}]]}], "}"}], HoldForm]],
           Annotation[#, 
            
            HoldForm[{$CellContext`z -> (
                Rational[
                 1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - \
(4 $CellContext`a) $CellContext`c)^Rational[1, 2])}], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Rule", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 3],
            TagBox[
             RowBox[{"z", "\[Rule]", 
               FractionBox[
                RowBox[{
                  RowBox[{"-", "b"}], "-", 
                  SqrtBox[
                   RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                RowBox[{"2", " ", "a"}]]}], HoldForm]],
           Annotation[#, 
            
            HoldForm[$CellContext`z -> (
               Rational[
                1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - (
                 4 $CellContext`a) $CellContext`c)^Rational[1, 2])], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["z",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 4],
            TagBox["z", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`z], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 5],
            TagBox[
             FractionBox[
              RowBox[{
                RowBox[{"-", "b"}], "-", 
                SqrtBox[
                 RowBox[{
                   SuperscriptBox["b", "2"], "-", 
                   RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
              RowBox[{"2", " ", "a"}]], HoldForm]],
           Annotation[#, 
            
            HoldForm[(
              Rational[
               1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - (
                4 $CellContext`a) $CellContext`c)^Rational[1, 2])], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                FractionBox["1", "2"],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 6],
            TagBox[
             FractionBox["1", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[
             Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 7],
            TagBox[
             FractionBox["1", "a"], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a^(-1)], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["a",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 8],
            TagBox["a", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "1"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 9],
            TagBox[
             RowBox[{"-", "1"}], HoldForm]],
           Annotation[#, 
            HoldForm[-1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Plus", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 10],
            TagBox[
             RowBox[{
               RowBox[{"-", "b"}], "-", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox["b", "2"], "-", 
                  RowBox[{"4", " ", "a", " ", "c"}]}]]}], HoldForm]],
           Annotation[#, 
            
            HoldForm[-$CellContext`b - ($CellContext`b^2 - (
               4 $CellContext`a) $CellContext`c)^Rational[1, 2]], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 11],
            TagBox[
             RowBox[{"-", "b"}], HoldForm]],
           Annotation[#, 
            HoldForm[-$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "1"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 12],
            TagBox[
             RowBox[{"-", "1"}], HoldForm]],
           Annotation[#, 
            HoldForm[-1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["b",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 13],
            TagBox["b", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 14],
            TagBox[
             RowBox[{"-", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox["b", "2"], "-", 
                  RowBox[{"4", " ", "a", " ", "c"}]}]]}], HoldForm]],
           Annotation[#, 
            
            HoldForm[-($CellContext`b^2 - (4 $CellContext`a) $CellContext`c)^
              Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "1"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 15],
            TagBox[
             RowBox[{"-", "1"}], HoldForm]],
           Annotation[#, 
            HoldForm[-1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 16],
            TagBox[
             SqrtBox[
              RowBox[{
                SuperscriptBox["b", "2"], "-", 
                RowBox[{"4", " ", "a", " ", "c"}]}]], HoldForm]],
           Annotation[#, 
            
            HoldForm[($CellContext`b^2 - (4 $CellContext`a) $CellContext`c)^
             Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Plus", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 17],
            TagBox[
             RowBox[{
               SuperscriptBox["b", "2"], "-", 
               RowBox[{"4", " ", "a", " ", "c"}]}], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b^2 - (4 $CellContext`a) $CellContext`c], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 18],
            TagBox[
             SuperscriptBox["b", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b^2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["b",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 19],
            TagBox["b", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 20],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 21],
            TagBox[
             RowBox[{
               RowBox[{"-", "4"}], " ", "a", " ", "c"}], HoldForm]],
           Annotation[#, 
            HoldForm[((-4) $CellContext`a) $CellContext`c], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "4"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 22],
            TagBox[
             RowBox[{"-", "4"}], HoldForm]],
           Annotation[#, 
            HoldForm[-4], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["a",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 23],
            TagBox["a", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["c",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 24],
            TagBox["c", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`c], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                FractionBox["1", "2"],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 25],
            TagBox[
             FractionBox["1", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[
             Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["List", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 26],
            TagBox[
             RowBox[{"{", 
               RowBox[{"z", "\[Rule]", 
                 FractionBox[
                  RowBox[{
                    RowBox[{"-", "b"}], "+", 
                    SqrtBox[
                    RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                  RowBox[{"2", " ", "a"}]]}], "}"}], HoldForm]],
           Annotation[#, 
            
            HoldForm[{$CellContext`z -> (
                Rational[
                 1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - \
(4 $CellContext`a) $CellContext`c)^Rational[1, 2])}], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Rule", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 27],
            TagBox[
             RowBox[{"z", "\[Rule]", 
               FractionBox[
                RowBox[{
                  RowBox[{"-", "b"}], "+", 
                  SqrtBox[
                   RowBox[{
                    SuperscriptBox["b", "2"], "-", 
                    RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
                RowBox[{"2", " ", "a"}]]}], HoldForm]],
           Annotation[#, 
            
            HoldForm[$CellContext`z -> (
               Rational[
                1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - (
                  4 $CellContext`a) $CellContext`c)^Rational[1, 2])], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["z",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 28],
            TagBox["z", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`z], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 29],
            TagBox[
             FractionBox[
              RowBox[{
                RowBox[{"-", "b"}], "+", 
                SqrtBox[
                 RowBox[{
                   SuperscriptBox["b", "2"], "-", 
                   RowBox[{"4", " ", "a", " ", "c"}]}]]}], 
              RowBox[{"2", " ", "a"}]], HoldForm]],
           Annotation[#, 
            
            HoldForm[(
              Rational[
               1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - (
                 4 $CellContext`a) $CellContext`c)^Rational[1, 2])], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                FractionBox["1", "2"],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 30],
            TagBox[
             FractionBox["1", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[
             Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 31],
            TagBox[
             FractionBox["1", "a"], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a^(-1)], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["a",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 32],
            TagBox["a", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "1"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 33],
            TagBox[
             RowBox[{"-", "1"}], HoldForm]],
           Annotation[#, 
            HoldForm[-1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Plus", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 34],
            TagBox[
             RowBox[{
               RowBox[{"-", "b"}], "+", 
               SqrtBox[
                RowBox[{
                  SuperscriptBox["b", "2"], "-", 
                  RowBox[{"4", " ", "a", " ", "c"}]}]]}], HoldForm]],
           Annotation[#, 
            
            HoldForm[-$CellContext`b + ($CellContext`b^2 - (
                4 $CellContext`a) $CellContext`c)^Rational[1, 2]], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 35],
            TagBox[
             RowBox[{"-", "b"}], HoldForm]],
           Annotation[#, 
            HoldForm[-$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "1"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 36],
            TagBox[
             RowBox[{"-", "1"}], HoldForm]],
           Annotation[#, 
            HoldForm[-1], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["b",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 37],
            TagBox["b", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 38],
            TagBox[
             SqrtBox[
              RowBox[{
                SuperscriptBox["b", "2"], "-", 
                RowBox[{"4", " ", "a", " ", "c"}]}]], HoldForm]],
           Annotation[#, 
            
            HoldForm[($CellContext`b^2 - (4 $CellContext`a) $CellContext`c)^
             Rational[1, 2]], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Plus", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 39],
            TagBox[
             RowBox[{
               SuperscriptBox["b", "2"], "-", 
               RowBox[{"4", " ", "a", " ", "c"}]}], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b^2 - (4 $CellContext`a) $CellContext`c], 
            "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Power", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 40],
            TagBox[
             SuperscriptBox["b", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b^2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["b",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 41],
            TagBox["b", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`b], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["2",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 42],
            TagBox["2", HoldForm]],
           Annotation[#, 
            HoldForm[2], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox["Times", "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 43],
            TagBox[
             RowBox[{
               RowBox[{"-", "4"}], " ", "a", " ", "c"}], HoldForm]],
           Annotation[#, 
            HoldForm[((-4) $CellContext`a) $CellContext`c], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                RowBox[{"-", "4"}],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 44],
            TagBox[
             RowBox[{"-", "4"}], HoldForm]],
           Annotation[#, 
            HoldForm[-4], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["a",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 45],
            TagBox["a", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`a], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox["c",
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 46],
            TagBox["c", HoldForm]],
           Annotation[#, 
            HoldForm[$CellContext`c], "Tooltip"]& ], 
          TagBox[
           TooltipBox[InsetBox[
             FrameBox[
              StyleBox[
               TagBox[
                FractionBox["1", "2"],
                HoldForm], "StandardForm", "Output",
               StripOnInput->False,
               LineColor->GrayLevel[0],
               FrontFaceColor->GrayLevel[0],
               GraphicsColor->GrayLevel[0],
               FontSize->Scaled[0.02857142857142857],
               FontColor->GrayLevel[0],
               $CellContext`BackFaceColor -> GrayLevel[0]],
              Background->RGBColor[1., 1., 0.871],
              FrameMargins->1.,
              FrameStyle->GrayLevel[0.5],
              StripOnInput->False], 47],
            TagBox[
             FractionBox["1", "2"], HoldForm]],
           Annotation[#, 
            HoldForm[
             Rational[1, 2]], "Tooltip"]& ]}}],
       Annotation[#, VertexCoordinateRules -> CompressedData["
1:eJxTTMoPSmViYGDQB2IQ7fxjRec6R1aHV5qGS1maJB2iFpglTQ5/Y1+9WftF
6RoxOJ/bVk37+TVhhznHFPIiGB/aQ2hBBx6w+Gc4nwEKIsH6eBwg5jyzh/Gr
wPxrUPPZoOZ9hPMh5jE7wNRD6D9weYj+b1D7GB3QaYg/OB1g6lHtYYSbi66+
BmrulcbFZ+RzmBwqoO4+KWYjr6T73x7mL1h4wfgMmff3ffEWgKtXerqZ+cwb
Lgx5GLfg/pPqZkVhOB9iPj/cfguVJNk92wQdYOEP48PCH2YeLLxh5sH4qOHG
gyEOsw8WLhD/CsH5m/LWudmKS8DVu4D9K+qAGj/C8PCrgroTxof4XwquHpau
YPL3Ql9ZCH0Xhft3xaz0W149IvDwExPMnX4zURzO//a3XPA7jyxcfVt7UUiG
uRSGPIyfUlJ7rvWRPJwPSb8ycPsBe78oLw==
         "]]& ],
      AspectRatio->NCache[Rational[5, 7]^Rational[1, 2], 0.8451542547285166],
      FormatType:>StandardForm,
      FrameTicks->Automatic,
      ImageSize->400,
      PlotRange->All,
      PlotRangePadding->Scaled[0.1]],
     TreeForm[{{$CellContext`z -> (
          Rational[
           1, 2]/$CellContext`a) (-$CellContext`b - ($CellContext`b^2 - (
            4 $CellContext`a) $CellContext`c)^
          Rational[1, 2])}, {$CellContext`z -> (
          Rational[
           1, 2]/$CellContext`a) (-$CellContext`b + ($CellContext`b^2 - (
             4 $CellContext`a) $CellContext`c)^Rational[1, 2])}}, ImageSize -> 
      400],
     Editable->False]}], "}"}],
  StripOnInput->False]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.7691785181040783`*^9, 3.769178534017832*^9}, 
   3.769772699902684*^9, 3.7699531019020557`*^9, 3.769975556913066*^9, 
   3.7719235995778923`*^9, 3.771929096862719*^9, {3.771929190693328*^9, 
   3.771929199992861*^9}, 3.771929534221137*^9, 3.771929631618435*^9, 
   3.881417975669737*^9},
 CellLabel->"Out[193]=",
 CellID->904898394,ExpressionUUID->"e4e6d65a-7d82-4dd8-abf4-6399d8715173"]
}, Open  ]],

Cell[TextData[{
 "At several points in this chapter (and this book), I use glyphs like ",
 StyleBox[ButtonBox["\[Function]",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Function.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Function.html"],
  FontColor->GrayLevel[0]],
 " that may seem impossible to type on a keyboard. There are several ways of \
typing these glyphs. The first is to use the escape code representation for \
the glyph. For example, typing ",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "761d6301-1e35-4a3d-90f4-d0adf9a54e25"],
 "\[ThinSpace]",
 StyleBox["fn", "InlineCode"],
 "\[ThinSpace]",
 Cell[BoxData[
  TemplateBox[{"esc"},
   "Key0"]], "InlineCodeText",ExpressionUUID->
  "52029352-5227-4652-9c86-61dbb12345ea"],
 " produces the function arrow. A second method is to use the ",
 Cell[BoxData["\\["], "InlineCode",ExpressionUUID->
  "10ff22a3-73a7-44be-a9ac-2029bd0f4416"],
 " method. If I type ",
 Cell[BoxData["\\["], "InlineCode",ExpressionUUID->
  "e1efedc7-0961-49b7-9290-2b7e9c3f5d6b"],
 " and then immediately follow it with the characters ",
 Cell[BoxData[
  RowBox[{"Function", "]"}]], "InlineCode",ExpressionUUID->
  "b30a1f29-3745-4e20-91a6-9e442b4844c9"],
 StyleBox[",", "InlineCode"],
 " I get the function arrow."
}], "TechNote",
 CellChangeTimes->{{3.769168215171337*^9, 3.769168553911224*^9}, 
   3.7754773306692095`*^9, {3.7773564224972887`*^9, 3.777356449590876*^9}, {
   3.877709263264923*^9, 3.877709275191761*^9}, {3.889694958905106*^9, 
   3.8896950000174627`*^9}, {3.8977459578441467`*^9, 3.897745979162753*^9}},
 CellID->371344384,ExpressionUUID->"4bb86d37-c9e9-4153-b320-832eea46480f"],

Cell[TextData[{
 "At several points in this chapter (and this book), I make use of \
ResourceFunctions. These are functions stored in the ",
 ButtonBox["Wolfram Function Repository",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://resources.wolframcloud.com/FunctionRepository/"], None},
  ButtonNote->"https://resources.wolframcloud.com/FunctionRepository/"],
 " (",
 ButtonBox["wolfr.am/WFR",
  BaseStyle->"Hyperlink",
  ButtonData->{
    URL["https://wolfr.am/WFR"], None},
  ButtonNote->"https://wolfr.am/WFR"],
 ") that, while not part of the official Wolfram Language, have been \
sufficiently vetted and documented to be deemed worthy of public use. To \
retrieve a known ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 ", you just encapsulate a string representation of the function\
\[CloseCurlyQuote]s name in the ",
 ButtonBox["ResourceFunction",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/ResourceFunction.html"],
 " header. "
}], "TechNote",
 CellTags->"i:85",
 CellID->1440151497,ExpressionUUID->"fffe9658-da63-481e-b72b-aa4af1a77b61"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"ResourceFunction", "[", "\"\<SameAsQ\>\"", "]"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellLabel->"In[194]:=",
 CellID->668326244,ExpressionUUID->"11e60e73-2e6c-45ae-b05c-c499ead96b11"],

Cell[BoxData[
 InterpretationBox[
  TagBox[
   TagBox[
    DynamicModuleBox[{Typeset`open = False}, 
     FrameBox[
      PaneSelectorBox[{False->GridBox[{
         {
          PaneBox[GridBox[{
             {
              StyleBox[
               StyleBox[
                AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                 BoxBaselineShift->-0.25,
                 BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                
                FontColor->RGBColor[
                 0.8745098039215686, 0.2784313725490196, 0.03137254901960784]],
               ShowStringCharacters->False,
               FontFamily->"Source Sans Pro Black",
               FontSize->0.6538461538461539 Inherited,
               FontWeight->"Heavy",
               PrivateFontOptions->{"OperatorSubstitution"->False}], 
              StyleBox[
               RowBox[{
                StyleBox["SameAsQ", "ResourceFunctionLabel"], " "}],
               ShowAutoStyles->False,
               ShowStringCharacters->False,
               FontSize->Rational[12, 13] Inherited,
               FontColor->GrayLevel[0.1]]}
            },
            GridBoxSpacings->{"Columns" -> {{0.25}}}],
           Alignment->Left,
           BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
           BaselinePosition->Baseline,
           FrameMargins->{{3, 0}, {0, 0}}], 
          ItemBox[
           PaneBox[
            TogglerBox[Dynamic[Typeset`open], {True->
             
             DynamicBox[FEPrivate`FrontEndResource[
              "FEBitmaps", "IconizeCloser"],
              ImageSizeCache->{11., {2., 9.}}], False->
             
             DynamicBox[FEPrivate`FrontEndResource[
              "FEBitmaps", "IconizeOpener"],
              ImageSizeCache->{11., {2., 9.}}]},
             Appearance->None,
             BaselinePosition->Baseline,
             ContentPadding->False,
             FrameMargins->0],
            Alignment->Left,
            BaselinePosition->Baseline,
            FrameMargins->{{1, 1}, {0, 0}}],
           Frame->{{
              RGBColor[
              0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
               0.5], False}, {False, False}}]}
        },
        BaselinePosition->{1, 1},
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
        GridBoxItemSize->{"Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
        GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
       GridBox[{
         {GridBox[{
            {
             PaneBox[GridBox[{
                {
                 StyleBox[
                  StyleBox[
                   AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                   
                   FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                  ShowStringCharacters->False,
                  FontFamily->"Source Sans Pro Black",
                  FontSize->0.6538461538461539 Inherited,
                  FontWeight->"Heavy",
                  PrivateFontOptions->{"OperatorSubstitution"->False}], 
                 StyleBox[
                  RowBox[{
                   StyleBox["SameAsQ", "ResourceFunctionLabel"], " "}],
                  ShowAutoStyles->False,
                  ShowStringCharacters->False,
                  FontSize->Rational[12, 13] Inherited,
                  FontColor->GrayLevel[0.1]]}
               },
               GridBoxSpacings->{"Columns" -> {{0.25}}}],
              Alignment->Left,
              BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
              BaselinePosition->Baseline,
              FrameMargins->{{3, 0}, {0, 0}}], 
             ItemBox[
              PaneBox[
               TogglerBox[Dynamic[Typeset`open], {True->
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeCloser"]], False->
                
                DynamicBox[FEPrivate`FrontEndResource[
                 "FEBitmaps", "IconizeOpener"]]},
                Appearance->None,
                BaselinePosition->Baseline,
                ContentPadding->False,
                FrameMargins->0],
               Alignment->Left,
               BaselinePosition->Baseline,
               FrameMargins->{{1, 1}, {0, 0}}],
              Frame->{{
                 RGBColor[
                 0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                  0.5], False}, {False, False}}]}
           },
           BaselinePosition->{1, 1},
           GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
           
           GridBoxItemSize->{
            "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
           GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
         {
          StyleBox[
           PaneBox[GridBox[{
              {
               RowBox[{
                TagBox["\<\"Version (latest): \"\>",
                 "IconizedLabel"], " ", 
                TagBox["\<\"1.0.0\"\>",
                 "IconizedItem"]}]},
              {
               TagBox[
                
                TemplateBox[{
                 "\"Documentation \[RightGuillemet]\"", 
                  "https://resources.wolframcloud.com/FunctionRepository/\
resources/4804c8f1-8480-468d-bf7d-045ec6b795f9/"},
                 "HyperlinkURL"],
                "IconizedItem"]}
             },
             DefaultBaseStyle->"Column",
             GridBoxAlignment->{"Columns" -> {{Left}}},
             
             GridBoxItemSize->{
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
            Alignment->Left,
            BaselinePosition->Baseline,
            FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
           FontFamily->"Roboto",
           FontSize->11]}
        },
        BaselinePosition->{1, 1},
        GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
        GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
             GrayLevel[0.8]}, False}},
        GridBoxItemSize->{
         "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
       Typeset`open],
       BaselinePosition->Baseline,
       ImageSize->Automatic],
      Background->RGBColor[
       0.9686274509803922, 0.9764705882352941, 0.984313725490196],
      BaselinePosition->Baseline,
      DefaultBaseStyle->{},
      FrameMargins->{{0, 0}, {1, 0}},
      FrameStyle->RGBColor[
       0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
      RoundingRadius->4]],
    #& ,
    TagBoxNote->" "],
   {"FunctionResourceBox", 
    RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784], 
    "SameAsQ"},
   TagBoxNote->"FunctionResourceBox"],
  ResourceFunction[
   ResourceObject[<|
    "Name" -> "SameAsQ", "ShortName" -> "SameAsQ", "UUID" -> 
     "4804c8f1-8480-468d-bf7d-045ec6b795f9", "ResourceType" -> "Function", 
     "Version" -> "1.0.0", "Description" -> "An operator form of SameQ", 
     "RepositoryLocation" -> 
     URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
     "SymbolName" -> 
     "FunctionRepository`$bf86de3a38c8476283fa191db7d1931d`SameAsQ", 
     "FunctionLocation" -> 
     CloudObject[
      "https://www.wolframcloud.com/objects/0205d045-4c13-4959-b66a-\
ca41cfb1d54b"]|>, ResourceSystemBase -> Automatic]],
  Selectable->False]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellTags->"LastCellOfAPage",
 CellLabel->"Out[194]=",
 CellID->1686671003,ExpressionUUID->"c4dacfcc-9a02-4a6a-9ab0-2a216a226adf"]
}, Open  ]],

Cell[TextData[{
 "If you have internet access at the time you evaluate this, a search will be \
done of various locations and an icon representing the function will be \
returned. To use the function in the Wolfram Language front end, you can \
either use a mouse to cut the iconized representation of the function and \
paste it where it needs to be used or you can eschew the mouse and just type ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["ResourceFunction",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"],
       None},
    ButtonNote->
     "https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
   "[", "\"\<SameAsQ\>\"", "]"}]], "InlineCode",ExpressionUUID->
  "8d5da577-3077-494c-9ef9-5d74bb7c0869"],
 ", so you could write either of the following. You could also select the \
input ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["ResourceFunction",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"],
       None},
    ButtonNote->
     "https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
   "[", "\"\<SameAsQ\>\"", "]"}]], "InlineCode",ExpressionUUID->
  "dc20e94a-181d-45ec-b81c-c362faff36ce"],
 " and use the ",
 StyleBox["Evaluate in Place",
  FontWeight->"SemiBold"],
 " menu command to get an attractive iconized representation of the function."
}], "TechNote",
 CellChangeTimes->{{3.769168751411179*^9, 3.7691688200535517`*^9}, {
   3.769168863887477*^9, 3.769168908672977*^9}, {3.7691695806359243`*^9, 
   3.769169702342184*^9}, 3.7747837202590055`*^9, {3.7754775067282095`*^9, 
   3.7754775609662094`*^9}, {3.885642997993756*^9, 3.885643003930091*^9}, {
   3.8896306821504555`*^9, 3.889630689149132*^9}},
 CellTags->"p: 62",
 CellID->2064321573,ExpressionUUID->"ca5de65c-ea88-4320-99da-abef09f5daae"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      TagBox[
       TagBox[
        DynamicModuleBox[{Typeset`open = False}, 
         FrameBox[
          PaneSelectorBox[{False->GridBox[{
             {
              PaneBox[GridBox[{
                 {
                  StyleBox[
                   StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                   ShowStringCharacters->False,
                   FontFamily->"Source Sans Pro Black",
                   FontSize->0.6538461538461539 Inherited,
                   FontWeight->"Heavy",
                   PrivateFontOptions->{"OperatorSubstitution"->False}], 
                  StyleBox[
                   RowBox[{
                    StyleBox["SameAsQ", "ResourceFunctionLabel"], " "}],
                   ShowAutoStyles->False,
                   ShowStringCharacters->False,
                   FontSize->Rational[12, 13] Inherited,
                   FontColor->GrayLevel[0.1]]}
                },
                GridBoxSpacings->{"Columns" -> {{0.25}}}],
               Alignment->Left,
               BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
               BaselinePosition->Baseline,
               FrameMargins->{{3, 0}, {0, 0}}], 
              ItemBox[
               PaneBox[
                TogglerBox[Dynamic[Typeset`open], {True->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeCloser"],
                  ImageSizeCache->{11., {2., 9.}}], False->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeOpener"],
                  ImageSizeCache->{11., {2., 9.}}]},
                 Appearance->None,
                 BaselinePosition->Baseline,
                 ContentPadding->False,
                 FrameMargins->0],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{1, 1}, {0, 0}}],
               Frame->{{
                  RGBColor[
                  0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                   0.5], False}, {False, False}}]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
           GridBox[{
             {GridBox[{
                {
                 PaneBox[GridBox[{
                    {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["SameAsQ", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                   },
                   GridBoxSpacings->{"Columns" -> {{0.25}}}],
                  Alignment->Left,
                  BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                  BaselinePosition->Baseline,
                  FrameMargins->{{3, 0}, {0, 0}}], 
                 ItemBox[
                  PaneBox[
                   TogglerBox[Dynamic[Typeset`open], {True->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                    Appearance->None,
                    BaselinePosition->Baseline,
                    ContentPadding->False,
                    FrameMargins->0],
                   Alignment->Left,
                   BaselinePosition->Baseline,
                   FrameMargins->{{1, 1}, {0, 0}}],
                  Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
               },
               BaselinePosition->{1, 1},
               
               GridBoxAlignment->{
                "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
               GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
             {
              StyleBox[
               PaneBox[GridBox[{
                  {
                   RowBox[{
                    TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                    TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                  {
                   TagBox[
                    
                    TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/4804c8f1-8480-468d-bf7d-045ec6b795f9/"},
                    "HyperlinkURL"],
                    "IconizedItem"]}
                 },
                 DefaultBaseStyle->"Column",
                 GridBoxAlignment->{"Columns" -> {{Left}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
               FontFamily->"Roboto",
               FontSize->11]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                 GrayLevel[0.8]}, False}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
           Typeset`open],
           BaselinePosition->Baseline,
           ImageSize->Automatic],
          
          Background->RGBColor[
           0.9686274509803922, 0.9764705882352941, 0.984313725490196],
          BaselinePosition->Baseline,
          DefaultBaseStyle->{},
          FrameMargins->{{0, 0}, {1, 0}},
          
          FrameStyle->RGBColor[
           0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
          RoundingRadius->4]],
        #& ,
        TagBoxNote->" "],
       {"FunctionResourceBox", 
        RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784],
         "SameAsQ"},
       TagBoxNote->"FunctionResourceBox"],
      ResourceFunction[
       ResourceObject[<|
        "Name" -> "SameAsQ", "ShortName" -> "SameAsQ", "UUID" -> 
         "4804c8f1-8480-468d-bf7d-045ec6b795f9", "ResourceType" -> "Function",
          "Version" -> "1.0.0", "Description" -> "An operator form of SameQ", 
         "RepositoryLocation" -> 
         URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
         "SymbolName" -> 
         "FunctionRepository`$bf86de3a38c8476283fa191db7d1931d`SameAsQ", 
         "FunctionLocation" -> 
         CloudObject[
          "https://www.wolframcloud.com/objects/0205d045-4c13-4959-b66a-\
ca41cfb1d54b"]|>, {
        ResourceSystemBase -> 
         "https://www.wolframcloud.com/obj/resourcesystem/api/1.0"}]],
      Selectable->False], "[", "4", "]"}], "[", 
    RowBox[{"2", "+", "2"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     RowBox[{"ResourceFunction", "[", "\"\<SameAsQ\>\"", "]"}], "[", "4", 
     "]"}], "[", 
    RowBox[{"2", "+", "2"}], "]"}]}], "}"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.769168933543817*^9, 3.76916893872624*^9}, {
   3.7691695411133337`*^9, 3.769169558666687*^9}, {3.769169620161693*^9, 
   3.7691696349817753`*^9}, 3.877769640632688*^9},
 CellLabel->"In[195]:=",
 CellID->1681167398,ExpressionUUID->"0eb7ecfc-00a4-4601-825c-805c166e06e4"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"True", ",", "True"}], "}"}]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{
  3.769168936643468*^9, {3.7691695454055*^9, 3.769169559199121*^9}, 
   3.7691696354610167`*^9, 3.769772700242778*^9, 3.769975557232251*^9, 
   3.7719235996516857`*^9, 3.771929110116453*^9, 3.771929534325306*^9, 
   3.881417985415223*^9},
 CellLabel->"Out[195]=",
 CellID->1414837077,ExpressionUUID->"3950ea3c-c4e7-4728-89a8-4ea5bad199ce"]
}, Open  ]],

Cell[TextData[{
 "There is now an operator form for ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 ", although one has to access the Wolfram Function Repository to get it \
easily. It is ",
 Cell[BoxData[
  RowBox[{
   ButtonBox[
    StyleBox["ResourceFunction",
     FontColor->GrayLevel[0]],
    BaseStyle->"Hyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/ResourceFunction.html"],
       None},
    ButtonNote->
     "https://reference.wolfram.com/language/ref/ResourceFunction.html"], 
   "[", "\"\<Slice\>\"", "]"}]], "InlineCode",ExpressionUUID->
  "d20a16a4-1438-49ee-aad2-c2e945794c42"],
 ". Here are examples of the way the function works."
}], "TechNote",
 CellChangeTimes->{{3.7691777112373667`*^9, 3.769177773863587*^9}, {
   3.769177902434914*^9, 3.769177904916079*^9}, {3.7754776307772093`*^9, 
   3.775477637861209*^9}, {3.877769668468288*^9, 3.877769668657998*^9}, {
   3.8896951053432875`*^9, 3.8896951053493056`*^9}, 3.8977460937235003`*^9},
 CellID->1933530066,ExpressionUUID->"87e7095d-2fec-480c-bbac-7ed983c2d507"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{
     InterpretationBox[
      TagBox[
       TagBox[
        DynamicModuleBox[{Typeset`open = False}, 
         FrameBox[
          PaneSelectorBox[{False->GridBox[{
             {
              PaneBox[GridBox[{
                 {
                  StyleBox[
                   StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                   ShowStringCharacters->False,
                   FontFamily->"Source Sans Pro Black",
                   FontSize->0.6538461538461539 Inherited,
                   FontWeight->"Heavy",
                   PrivateFontOptions->{"OperatorSubstitution"->False}], 
                  StyleBox[
                   RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                   ShowAutoStyles->False,
                   ShowStringCharacters->False,
                   FontSize->Rational[12, 13] Inherited,
                   FontColor->GrayLevel[0.1]]}
                },
                GridBoxSpacings->{"Columns" -> {{0.25}}}],
               Alignment->Left,
               BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
               BaselinePosition->Baseline,
               FrameMargins->{{3, 0}, {0, 0}}], 
              ItemBox[
               PaneBox[
                TogglerBox[Dynamic[Typeset`open], {True->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeCloser"],
                  ImageSizeCache->{11., {2., 9.}}], False->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeOpener"],
                  ImageSizeCache->{11., {2., 9.}}]},
                 Appearance->None,
                 BaselinePosition->Baseline,
                 ContentPadding->False,
                 FrameMargins->0],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{1, 1}, {0, 0}}],
               Frame->{{
                  RGBColor[
                  0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                   0.5], False}, {False, False}}]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
           GridBox[{
             {GridBox[{
                {
                 PaneBox[GridBox[{
                    {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                   },
                   GridBoxSpacings->{"Columns" -> {{0.25}}}],
                  Alignment->Left,
                  BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                  BaselinePosition->Baseline,
                  FrameMargins->{{3, 0}, {0, 0}}], 
                 ItemBox[
                  PaneBox[
                   TogglerBox[Dynamic[Typeset`open], {True->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                    Appearance->None,
                    BaselinePosition->Baseline,
                    ContentPadding->False,
                    FrameMargins->0],
                   Alignment->Left,
                   BaselinePosition->Baseline,
                   FrameMargins->{{1, 1}, {0, 0}}],
                  Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
               },
               BaselinePosition->{1, 1},
               
               GridBoxAlignment->{
                "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
               GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
             {
              StyleBox[
               PaneBox[GridBox[{
                  {
                   RowBox[{
                    TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                    TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                  {
                   TagBox[
                    
                    TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/6480efeb-6565-4850-9ed0-e2c00631d9f6/"},
                    "HyperlinkURL"],
                    "IconizedItem"]}
                 },
                 DefaultBaseStyle->"Column",
                 GridBoxAlignment->{"Columns" -> {{Left}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
               FontFamily->"Roboto",
               FontSize->11]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                 GrayLevel[0.8]}, False}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
           Typeset`open],
           BaselinePosition->Baseline,
           ImageSize->Automatic],
          
          Background->RGBColor[
           0.9686274509803922, 0.9764705882352941, 0.984313725490196],
          BaselinePosition->Baseline,
          DefaultBaseStyle->{},
          FrameMargins->{{0, 0}, {1, 0}},
          
          FrameStyle->RGBColor[
           0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
          RoundingRadius->4]],
        #& ,
        TagBoxNote->" "],
       {"FunctionResourceBox", 
        RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784],
         "Slice"},
       TagBoxNote->"FunctionResourceBox"],
      ResourceFunction[
       ResourceObject[<|
        "Name" -> "Slice", "ShortName" -> "Slice", "UUID" -> 
         "6480efeb-6565-4850-9ed0-e2c00631d9f6", "ResourceType" -> "Function",
          "Version" -> "1.0.0", "Description" -> "An operator form of Part", 
         "RepositoryLocation" -> 
         URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
         "SymbolName" -> 
         "FunctionRepository`$1dcc7ca341c64d76bd036187ddf47d79`Slice", 
         "FunctionLocation" -> 
         CloudObject[
          "https://www.wolframcloud.com/objects/ca819436-f7a1-48ec-8b80-\
afd0b05e2067"]|>, ResourceSystemBase -> Automatic]],
      Selectable->False], "[", "3", "]"}], "[", 
    RowBox[{"{", 
     RowBox[{
     "\"\<a\>\"", ",", "\"\<b\>\"", ",", "\"\<c\>\"", ",", "\"\<d\>\""}], 
     "}"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      TagBox[
       TagBox[
        DynamicModuleBox[{Typeset`open = False}, 
         FrameBox[
          PaneSelectorBox[{False->GridBox[{
             {
              PaneBox[GridBox[{
                 {
                  StyleBox[
                   StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                   ShowStringCharacters->False,
                   FontFamily->"Source Sans Pro Black",
                   FontSize->0.6538461538461539 Inherited,
                   FontWeight->"Heavy",
                   PrivateFontOptions->{"OperatorSubstitution"->False}], 
                  StyleBox[
                   RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                   ShowAutoStyles->False,
                   ShowStringCharacters->False,
                   FontSize->Rational[12, 13] Inherited,
                   FontColor->GrayLevel[0.1]]}
                },
                GridBoxSpacings->{"Columns" -> {{0.25}}}],
               Alignment->Left,
               BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
               BaselinePosition->Baseline,
               FrameMargins->{{3, 0}, {0, 0}}], 
              ItemBox[
               PaneBox[
                TogglerBox[Dynamic[Typeset`open], {True->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeCloser"],
                  ImageSizeCache->{11., {2., 9.}}], False->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeOpener"],
                  ImageSizeCache->{11., {2., 9.}}]},
                 Appearance->None,
                 BaselinePosition->Baseline,
                 ContentPadding->False,
                 FrameMargins->0],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{1, 1}, {0, 0}}],
               Frame->{{
                  RGBColor[
                  0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                   0.5], False}, {False, False}}]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
           GridBox[{
             {GridBox[{
                {
                 PaneBox[GridBox[{
                    {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                   },
                   GridBoxSpacings->{"Columns" -> {{0.25}}}],
                  Alignment->Left,
                  BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                  BaselinePosition->Baseline,
                  FrameMargins->{{3, 0}, {0, 0}}], 
                 ItemBox[
                  PaneBox[
                   TogglerBox[Dynamic[Typeset`open], {True->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                    Appearance->None,
                    BaselinePosition->Baseline,
                    ContentPadding->False,
                    FrameMargins->0],
                   Alignment->Left,
                   BaselinePosition->Baseline,
                   FrameMargins->{{1, 1}, {0, 0}}],
                  Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
               },
               BaselinePosition->{1, 1},
               
               GridBoxAlignment->{
                "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
               GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
             {
              StyleBox[
               PaneBox[GridBox[{
                  {
                   RowBox[{
                    TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                    TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                  {
                   TagBox[
                    
                    TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/6480efeb-6565-4850-9ed0-e2c00631d9f6/"},
                    "HyperlinkURL"],
                    "IconizedItem"]}
                 },
                 DefaultBaseStyle->"Column",
                 GridBoxAlignment->{"Columns" -> {{Left}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
               FontFamily->"Roboto",
               FontSize->11]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                 GrayLevel[0.8]}, False}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
           Typeset`open],
           BaselinePosition->Baseline,
           ImageSize->Automatic],
          
          Background->RGBColor[
           0.9686274509803922, 0.9764705882352941, 0.984313725490196],
          BaselinePosition->Baseline,
          DefaultBaseStyle->{},
          FrameMargins->{{0, 0}, {1, 0}},
          
          FrameStyle->RGBColor[
           0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
          RoundingRadius->4]],
        #& ,
        TagBoxNote->" "],
       {"FunctionResourceBox", 
        RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784],
         "Slice"},
       TagBoxNote->"FunctionResourceBox"],
      ResourceFunction[
       ResourceObject[<|
        "Name" -> "Slice", "ShortName" -> "Slice", "UUID" -> 
         "6480efeb-6565-4850-9ed0-e2c00631d9f6", "ResourceType" -> "Function",
          "Version" -> "1.0.0", "Description" -> "An operator form of Part", 
         "RepositoryLocation" -> 
         URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
         "SymbolName" -> 
         "FunctionRepository`$1dcc7ca341c64d76bd036187ddf47d79`Slice", 
         "FunctionLocation" -> 
         CloudObject[
          "https://www.wolframcloud.com/objects/ca819436-f7a1-48ec-8b80-\
afd0b05e2067"]|>, ResourceSystemBase -> Automatic]],
      Selectable->False], "[", 
     RowBox[{"2", ",", "1"}], "]"}], "[", 
    RowBox[{"g", "[", 
     RowBox[{"8", ",", 
      RowBox[{"h", "[", 
       RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], "]"}], ",", 
   RowBox[{
    RowBox[{
     InterpretationBox[
      TagBox[
       TagBox[
        DynamicModuleBox[{Typeset`open = False}, 
         FrameBox[
          PaneSelectorBox[{False->GridBox[{
             {
              PaneBox[GridBox[{
                 {
                  StyleBox[
                   StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                   ShowStringCharacters->False,
                   FontFamily->"Source Sans Pro Black",
                   FontSize->0.6538461538461539 Inherited,
                   FontWeight->"Heavy",
                   PrivateFontOptions->{"OperatorSubstitution"->False}], 
                  StyleBox[
                   RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                   ShowAutoStyles->False,
                   ShowStringCharacters->False,
                   FontSize->Rational[12, 13] Inherited,
                   FontColor->GrayLevel[0.1]]}
                },
                GridBoxSpacings->{"Columns" -> {{0.25}}}],
               Alignment->Left,
               BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
               BaselinePosition->Baseline,
               FrameMargins->{{3, 0}, {0, 0}}], 
              ItemBox[
               PaneBox[
                TogglerBox[Dynamic[Typeset`open], {True->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeCloser"],
                  ImageSizeCache->{11., {2., 9.}}], False->
                 
                 DynamicBox[FEPrivate`FrontEndResource[
                  "FEBitmaps", "IconizeOpener"],
                  ImageSizeCache->{11., {2., 9.}}]},
                 Appearance->None,
                 BaselinePosition->Baseline,
                 ContentPadding->False,
                 FrameMargins->0],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{1, 1}, {0, 0}}],
               Frame->{{
                  RGBColor[
                  0.8313725490196079, 0.8470588235294118, 0.8509803921568627, 
                   0.5], False}, {False, False}}]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
            GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}], True->
           GridBox[{
             {GridBox[{
                {
                 PaneBox[GridBox[{
                    {
                    StyleBox[
                    StyleBox[
                    AdjustmentBox["\<\"[\[FilledSmallSquare]]\"\>",
                    BoxBaselineShift->-0.25,
                    BoxMargins->{{0, 0}, {-1, -1}}], "ResourceFunctionIcon",
                    
                    FontColor->RGBColor[
                    0.8745098039215686, 0.2784313725490196, 
                    0.03137254901960784]],
                    ShowStringCharacters->False,
                    FontFamily->"Source Sans Pro Black",
                    FontSize->0.6538461538461539 Inherited,
                    FontWeight->"Heavy",
                    PrivateFontOptions->{"OperatorSubstitution"->False}], 
                    StyleBox[
                    RowBox[{
                    StyleBox["Slice", "ResourceFunctionLabel"], " "}],
                    ShowAutoStyles->False,
                    ShowStringCharacters->False,
                    FontSize->Rational[12, 13] Inherited,
                    FontColor->GrayLevel[0.1]]}
                   },
                   GridBoxSpacings->{"Columns" -> {{0.25}}}],
                  Alignment->Left,
                  BaseStyle->{LineSpacing -> {0, 0}, LineBreakWithin -> False},
                  BaselinePosition->Baseline,
                  FrameMargins->{{3, 0}, {0, 0}}], 
                 ItemBox[
                  PaneBox[
                   TogglerBox[Dynamic[Typeset`open], {True->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeCloser"]], False->
                    
                    DynamicBox[FEPrivate`FrontEndResource[
                    "FEBitmaps", "IconizeOpener"]]},
                    Appearance->None,
                    BaselinePosition->Baseline,
                    ContentPadding->False,
                    FrameMargins->0],
                   Alignment->Left,
                   BaselinePosition->Baseline,
                   FrameMargins->{{1, 1}, {0, 0}}],
                  Frame->{{
                    RGBColor[
                    0.8313725490196079, 0.8470588235294118, 
                    0.8509803921568627, 0.5], False}, {False, False}}]}
               },
               BaselinePosition->{1, 1},
               
               GridBoxAlignment->{
                "Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
               
               GridBoxItemSize->{
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}},
               GridBoxSpacings->{"Columns" -> {{0}}, "Rows" -> {{0}}}]},
             {
              StyleBox[
               PaneBox[GridBox[{
                  {
                   RowBox[{
                    TagBox["\<\"Version (latest): \"\>",
                    "IconizedLabel"], " ", 
                    TagBox["\<\"1.0.0\"\>",
                    "IconizedItem"]}]},
                  {
                   TagBox[
                    
                    TemplateBox[{
                    "\"Documentation \[RightGuillemet]\"", 
                    "https://resources.wolframcloud.com/FunctionRepository/\
resources/6480efeb-6565-4850-9ed0-e2c00631d9f6/"},
                    "HyperlinkURL"],
                    "IconizedItem"]}
                 },
                 DefaultBaseStyle->"Column",
                 GridBoxAlignment->{"Columns" -> {{Left}}},
                 
                 GridBoxItemSize->{
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}],
                Alignment->Left,
                BaselinePosition->Baseline,
                FrameMargins->{{5, 4}, {0, 4}}], "DialogStyle",
               FontFamily->"Roboto",
               FontSize->11]}
            },
            BaselinePosition->{1, 1},
            GridBoxAlignment->{"Columns" -> {{Left}}, "Rows" -> {{Baseline}}},
            GridBoxDividers->{"Columns" -> {{None}}, "Rows" -> {False, {
                 GrayLevel[0.8]}, False}},
            
            GridBoxItemSize->{
             "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, Dynamic[
           Typeset`open],
           BaselinePosition->Baseline,
           ImageSize->Automatic],
          
          Background->RGBColor[
           0.9686274509803922, 0.9764705882352941, 0.984313725490196],
          BaselinePosition->Baseline,
          DefaultBaseStyle->{},
          FrameMargins->{{0, 0}, {1, 0}},
          
          FrameStyle->RGBColor[
           0.8313725490196079, 0.8470588235294118, 0.8509803921568627],
          RoundingRadius->4]],
        #& ,
        TagBoxNote->" "],
       {"FunctionResourceBox", 
        RGBColor[0.8745098039215686, 0.2784313725490196, 0.03137254901960784],
         "Slice"},
       TagBoxNote->"FunctionResourceBox"],
      ResourceFunction[
       ResourceObject[<|
        "Name" -> "Slice", "ShortName" -> "Slice", "UUID" -> 
         "6480efeb-6565-4850-9ed0-e2c00631d9f6", "ResourceType" -> "Function",
          "Version" -> "1.0.0", "Description" -> "An operator form of Part", 
         "RepositoryLocation" -> 
         URL["https://www.wolframcloud.com/obj/resourcesystem/api/1.0"], 
         "SymbolName" -> 
         "FunctionRepository`$1dcc7ca341c64d76bd036187ddf47d79`Slice", 
         "FunctionLocation" -> 
         CloudObject[
          "https://www.wolframcloud.com/objects/ca819436-f7a1-48ec-8b80-\
afd0b05e2067"]|>, ResourceSystemBase -> Automatic]],
      Selectable->False], "[", 
     RowBox[{"All", ",", "2"}], "]"}], "[", 
    RowBox[{"{", 
     RowBox[{
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
              0.7101881771505834, 0.7989108398643558, 0.8028079784985009], 
              RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            
            FrameStyle->RGBColor[
             0.4734587847670556, 0.5326072265762373, 0.5352053189990007],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              
              RowBox[{"0.7101881771505834`", ",", "0.7989108398643558`", ",", 
                "0.8028079784985009`"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = 
              RGBColor[
               0.7101881771505834, 0.7989108398643558, 0.8028079784985009]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[0.7101881771505834, 0.7989108398643558, 0.8028079784985009],
         Editable->False,
         Selectable->False], ",", "5", ",", "0.08", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "4"}], ",", "86"}], "}"}], "]"}], ",", 
        "\"\<Thurgood Marshall\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
              0.00180317540330166, 0.8926700334391704, 
               0.00014246188160593753`], RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            
            FrameStyle->RGBColor[
             0.00120211693553444, 0.5951133556261137, 0.0000949745877372917],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              
              RowBox[{"0.00180317540330166`", ",", "0.8926700334391704`", ",",
                 "0.00014246188160593753`"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = 
              RGBColor[
               0.00180317540330166, 0.8926700334391704, 
                0.00014246188160593753`]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[
         0.00180317540330166, 0.8926700334391704, 0.00014246188160593753`],
         Editable->False,
         Selectable->False], ",", "2", ",", "0.83", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "43"}], ",", 
           RowBox[{"-", "113"}]}], "}"}], "]"}], ",", "\"\<Elena Kagan\>\""}],
        "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
              0.5202427055382031, 0.33813420051434595`, 0.0495895795536585], 
              RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            
            FrameStyle->RGBColor[
             0.34682847035880204`, 0.2254228003428973, 0.033059719702439004`],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              
              RowBox[{"0.5202427055382031`", ",", "0.33813420051434595`", ",",
                 "0.0495895795536585`"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = 
              RGBColor[
               0.5202427055382031, 0.33813420051434595`, 0.0495895795536585]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[
         0.5202427055382031, 0.33813420051434595`, 0.0495895795536585],
         Editable->False,
         Selectable->False], ",", "4", ",", "0.07", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{
           RowBox[{"-", "22"}], ",", 
           RowBox[{"-", "40"}]}], "}"}], "]"}], ",", 
        "\"\<Oliver Ellsworth\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
              0.71799307373688, 0.8971633609144036, 0.09594209586818336], 
              RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            
            FrameStyle->RGBColor[
             0.47866204915792004`, 0.5981089072762691, 0.06396139724545558],
            FrameTicks->None,
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              
              RowBox[{"0.71799307373688`", ",", "0.8971633609144036`", ",", 
                "0.09594209586818336`"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = 
              RGBColor[
               0.71799307373688, 0.8971633609144036, 0.09594209586818336]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[0.71799307373688, 0.8971633609144036, 0.09594209586818336],
         Editable->False,
         Selectable->False], ",", "4", ",", "0.35", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{"17", ",", "78"}], "}"}], "]"}], ",", 
        "\"\<William Rehnquist\>\""}], "}"}], ",", 
      RowBox[{"{", 
       RowBox[{
        InterpretationBox[
         ButtonBox[
          TooltipBox[
           GraphicsBox[{
             {GrayLevel[0], RectangleBox[{0, 0}]}, 
             {GrayLevel[0], RectangleBox[{1, -1}]}, 
             {RGBColor[
              0.7038241862975507, 0.5975069401834057, 0.11356773283085175`], 
              RectangleBox[{0, -1}, {2, 1}]}},
            AspectRatio->1,
            DefaultBaseStyle->"ColorSwatchGraphics",
            Frame->True,
            
            FrameStyle->RGBColor[
             0.46921612419836717`, 0.39833796012227046`, 0.0757118218872345],
            FrameTicks->None,
            
            ImageSize->
             Dynamic[{
              Automatic, 
               1.35 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                Magnification])}],
            PlotRangePadding->None],
           StyleBox[
            RowBox[{"RGBColor", "[", 
              
              RowBox[{"0.7038241862975507`", ",", "0.5975069401834057`", ",", 
                "0.11356773283085175`"}], "]"}], NumberMarks -> False]],
          Appearance->None,
          BaseStyle->{},
          BaselinePosition->Baseline,
          ButtonFunction:>With[{Typeset`box$ = EvaluationBox[]}, 
            If[
             Not[
              AbsoluteCurrentValue["Deployed"]], 
             SelectionMove[Typeset`box$, All, Expression]; 
             FrontEnd`Private`$ColorSelectorInitialAlpha = 1; 
             FrontEnd`Private`$ColorSelectorInitialColor = 
              RGBColor[
               0.7038241862975507, 0.5975069401834057, 0.11356773283085175`]; 
             FrontEnd`Private`$ColorSelectorUseMakeBoxes = True; 
             MathLink`CallFrontEnd[
               FrontEnd`AttachCell[Typeset`box$, 
                FrontEndResource["RGBColorValueSelector"], {
                0, {Left, Bottom}}, {Left, Top}, 
                "ClosingActions" -> {
                 "SelectionDeparture", "ParentChanged", "EvaluatorQuit"}]]]],
          DefaultBaseStyle->{},
          Evaluator->Automatic,
          Method->"Preemptive"],
         RGBColor[
         0.7038241862975507, 0.5975069401834057, 0.11356773283085175`],
         Editable->False,
         Selectable->False], ",", "9", ",", "0.87", ",", 
        RowBox[{"GeoPosition", "[", 
         RowBox[{"{", 
          RowBox[{"14", ",", "64"}], "}"}], "]"}], ",", 
        "\"\<Oliver Wendell Holmes, Jr.\>\""}], "}"}]}], "}"}], " ", "]"}]}], 
  "}"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.769177775991351*^9, 3.769177896234359*^9}, {
   3.7719291259144278`*^9, 3.771929137779016*^9}, {3.771929229638698*^9, 
   3.771929234792997*^9}, 3.877769674606493*^9, {3.877769709276177*^9, 
   3.87776971462243*^9}, {3.881417995238946*^9, 3.881418152124342*^9}, {
   3.882285520522181*^9, 3.882285577626505*^9}, {3.882285715818123*^9, 
   3.8822857318732967`*^9}},
 CellLabel->"In[196]:=",
 CellID->1545762005,ExpressionUUID->"5a0978ec-7bcc-440e-b3c1-a7b521cfaa9c"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{"\<\"c\"\>", ",", "x", ",", 
   RowBox[{"{", 
    RowBox[{"5", ",", "2", ",", "4", ",", "4", ",", "9"}], "}"}]}], 
  "}"}]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{
  3.882285667143174*^9, {3.882285724492118*^9, 3.882285733378401*^9}},
 CellLabel->"Out[196]=",
 CellID->772835037,ExpressionUUID->"ffe3eb89-861b-44a5-96cf-f3078491656d"]
}, Open  ]],

Cell[TextData[{
 "With Version 13, there are convenient ways to create Lists whose elements \
are homogeneous in their types. Here, for example, I represent the second \
column of ",
 Cell[BoxData[
 "nestedList"], "InlineCode",ExpressionUUID->
  "0ccf5881-f200-4bd4-af29-66be9fca2a47"],
 " as a ",
 ButtonBox["NumericArray",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/NumericArray.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/NumericArray.html"],
 " of signed integers with 16 possible binary digits. When speed or data size \
is at a premium, this ability may prove useful."
}], "TechNote",
 CellChangeTimes->{{3.769169943639777*^9, 3.769170019283996*^9}, {
   3.769170052701721*^9, 3.769170093741818*^9}, 3.7754776530702095`*^9, {
   3.865549382259968*^9, 3.865549382346068*^9}, 3.877769734655899*^9},
 CellID->252755601,ExpressionUUID->"1fe49ccd-9470-475d-bfcb-fde17a7cf35c"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"NumericArray", "[", 
  RowBox[{
   RowBox[{"nestedList", "[", 
    RowBox[{"[", 
     RowBox[{"All", ",", "2"}], "]"}], "]"}], ",", 
   "\"\<SignedInteger16\>\""}], "]"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.769169968029169*^9, 3.769169970768467*^9}, {
  3.7691700212320004`*^9, 3.769170070833252*^9}},
 CellLabel->"In[197]:=",
 CellID->715753166,ExpressionUUID->"62250b59-a256-4ac1-b36b-4882faf351e6"],

Cell[BoxData[
 InterpretationBox[
  RowBox[{
   TagBox["NumericArray",
    "SummaryHead"], "[", 
   DynamicModuleBox[{Typeset`open$$ = False, Typeset`embedState$$ = "Ready"}, 
    TemplateBox[{
      PaneSelectorBox[{False -> GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxOpener"], 
               ImageSizeCache -> {
                8.778820312499999, {0., 8.778820312499999}}], Appearance -> 
              None, BaseStyle -> {}, 
              ButtonFunction :> (Typeset`open$$ = True), Evaluator -> 
              Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Integer16\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Dimensions: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", "5", "}"}], "SummaryItem"]}]}}, AutoDelete -> 
             False, BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], True -> 
        GridBox[{{
            PaneBox[
             ButtonBox[
              DynamicBox[
               FEPrivate`FrontEndResource["FEBitmaps", "SummaryBoxCloser"]], 
              Appearance -> None, BaseStyle -> {}, 
              ButtonFunction :> (Typeset`open$$ = False), Evaluator -> 
              Automatic, Method -> "Preemptive"], 
             Alignment -> {Center, Center}, ImageSize -> 
             Dynamic[{
               Automatic, 
                3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
                 Magnification])}]], 
            GridBox[{{
               RowBox[{
                 TagBox["\"Type: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox["\"Integer16\"", "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Dimensions: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  RowBox[{"{", "5", "}"}], "SummaryItem"]}]}, {
               RowBox[{
                 TagBox["\"Data: \"", "SummaryItemAnnotation"], 
                 "\[InvisibleSpace]", 
                 TagBox[
                  
                  TemplateBox[{
                   "5", "\", \"", "2", "\", \"", "4", "\", \"", "4", "\", \"",
                     "9"}, "RowDefault"], "SummaryItem"]}]}}, AutoDelete -> 
             False, BaseStyle -> {
              ShowStringCharacters -> False, NumberMarks -> False, 
               PrintPrecision -> 3, ShowSyntaxStyles -> False}, 
             GridBoxAlignment -> {
              "Columns" -> {{Left}}, "Rows" -> {{Automatic}}}, 
             GridBoxItemSize -> {
              "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
             GridBoxSpacings -> {
              "Columns" -> {{2}}, "Rows" -> {{Automatic}}}]}}, AutoDelete -> 
          False, BaselinePosition -> {1, 1}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}, "Rows" -> {{Top}}}, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}]}, 
       Dynamic[Typeset`open$$], ImageSize -> Automatic]},
     "SummaryPanel"],
    DynamicModuleValues:>{}], "]"}],
  RawArray["Integer16",{5, 2, 4, 4, 9}],
  Editable->False,
  SelectWithContents->True,
  Selectable->False]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{3.7691700253978157`*^9, 3.769170071748269*^9, 
  3.7697727003032913`*^9, 3.76997555730189*^9, 3.771923599729632*^9, 
  3.7719292248302803`*^9, 3.771929534375005*^9, 3.881418215506364*^9},
 CellLabel->"Out[197]=",
 CellID->2113656226,ExpressionUUID->"d9dbd9bc-ea39-44b0-88c6-bfb1fefa2de6"]
}, Open  ]],

Cell[TextData[{
 "In the main text, I just showed ",
 ButtonBox["MapIndexed",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/MapIndexed.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/MapIndexed.html"],
 " where the ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " indices reflected what was on level 1 of the expression, but I can also \
ask for it to use ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " indices reflecting what is in deeper levels of an expression. Here I ask \
it to find those Parts at level 2 of the expression and then, for each one, \
apply the ",
 Cell[BoxData[
 "f"], "InlineCode",ExpressionUUID->"8c74846c-d0af-4038-8105-150c58951a41"],
 " function to a sequence of arguments, the first of which is the original ",
 ButtonBox["Part",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/Part.html"], None},
  ButtonNote->"https://reference.wolfram.com/language/ref/Part.html"],
 " and the second of which is its position in the original expression."
}], "TechNote",
 CellChangeTimes->{{3.7691704162204514`*^9, 3.769170458016856*^9}, {
   3.7691705546029787`*^9, 3.76917057471434*^9}, {3.7691706274710617`*^9, 
   3.769170674246875*^9}, {3.775477966854209*^9, 3.775477979479209*^9}, {
   3.775478277286209*^9, 3.775478278149209*^9}, {3.775478335842209*^9, 
   3.7754783427052093`*^9}, 3.8855551742778935`*^9, {3.889695126666805*^9, 
   3.889695154614879*^9}},
 CellTags->"i:86",
 CellID->1461046402,ExpressionUUID->"5ea5ffe8-4190-4adf-bda2-5984cfd5d8c9"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"MapIndexed", "[", 
  RowBox[{"f", ",", 
   RowBox[{"g", "[", 
    RowBox[{"8", ",", 
     RowBox[{"h", "[", 
      RowBox[{"x", ",", "y", ",", "9"}], "]"}]}], "]"}], ",", 
   RowBox[{"{", "2", "}"}]}], "]"}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.7691705772992477`*^9, 3.7691705792999477`*^9}, {
  3.769170617768044*^9, 3.769170619793882*^9}},
 CellLabel->"In[198]:=",
 CellID->373643176,ExpressionUUID->"9c346a5b-dacc-412d-957e-c5561f841f72"],

Cell[BoxData[
 RowBox[{"g", "[", 
  RowBox[{"8", ",", 
   RowBox[{"h", "[", 
    RowBox[{
     RowBox[{"f", "[", 
      RowBox[{"x", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "1"}], "}"}]}], "]"}], ",", 
     RowBox[{"f", "[", 
      RowBox[{"y", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "2"}], "}"}]}], "]"}], ",", 
     RowBox[{"f", "[", 
      RowBox[{"9", ",", 
       RowBox[{"{", 
        RowBox[{"2", ",", "3"}], "}"}]}], "]"}]}], "]"}]}], 
  "]"}]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{3.7691706201249847`*^9, 3.769772700347385*^9, 
  3.769975557358103*^9, 3.771923599750375*^9, 3.7719295344194736`*^9, 
  3.881418220509787*^9, 3.882285817852573*^9},
 CellLabel->"Out[198]=",
 CellID->1243225100,ExpressionUUID->"4650b2d7-2b06-43e0-9d5e-8a0b9ba51ee3"]
}, Open  ]],

Cell[TextData[{
 "Most of the time in this book and in Wolfram Language code generally, it is \
conventional to use prefix notation and write the operator first, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{
    RowBox[{"f", 
     RowBox[{"{", 
      RowBox[{"[", 
       RowBox[{"x", ",", " ", "y"}]}]}]}], "}"}], "]"}]], "InlineCode",
  ExpressionUUID->"53a7be7c-a6af-4ca4-be36-28783cd598a8"],
 ", but it is sometimes useful to put the operator last. To use this postfix \
notation, you use the double slash, ",
 Cell[BoxData[
  RowBox[{
   RowBox[{"{", 
    RowBox[{"x", ",", " ", "y"}], "}"}], 
   ButtonBox["//",
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/Postfix.html"], None},
    ButtonNote->"https://reference.wolfram.com/language/ref/Postfix.html"], 
   "f"}]], "InlineCode",ExpressionUUID->
  "0f5d98a5-f684-4b2b-a4e5-8f63c78c359e"],
 ". I find that postfix notation complements well the use of ",
 ButtonBox["RightComposition",
  BaseStyle->"FunctionHyperlink",
  ButtonData->{
    URL["https://reference.wolfram.com/language/ref/RightComposition.html"], 
    None},
  ButtonNote->
   "https://reference.wolfram.com/language/ref/RightComposition.html"],
 ", so I could write the following. "
}], "TechNote",
 CellTags->{"LastCellOfAPage", "i:87"},
 CellID->2128183295,ExpressionUUID->"f08f8d43-1854-4305-92bb-fc65bcca3305"],

Cell[CellGroupData[{

Cell[BoxData[
 RowBox[{"mls2", "//", 
  RowBox[{"(", 
   RowBox[{
   "team1", "/*", "team2", "/*", "team3", "/*", "team4", "/*", "team5"}], 
   ")"}]}]], "ExerciseInput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{{3.7691703036348257`*^9, 3.7691703076718197`*^9}},
 CellTags->"p: 63",
 CellLabel->"In[199]:=",
 CellID->165522244,ExpressionUUID->"f738d90a-08d0-4f68-bb49-6390ad437334"],

Cell[BoxData[
 RowBox[{"{", 
  RowBox[{
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.239981527`*^7", 2.239981527*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.2136512029999997`*^7", 2.2136512029999997`*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.179850857`*^7", 2.179850857*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.126757475`*^7", 2.126757475*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "2.112777663`*^7", 2.112777663*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"LA\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2016\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2016", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.810573604`*^7", 1.810573604*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2017\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2017", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.793036569`*^7", 1.793036569*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NYCFC\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2015\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2015", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.741426789`*^7", 1.741426789*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"NY\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2012\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2012", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox["1.67281078`*^7", 1.67281078*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}], ",", 
   RowBox[{
    RowBox[{"{", 
     RowBox[{"\<\"TOR\"\>", ",", 
      TemplateBox[{
        RowBox[{
          StyleBox["\"Year: \"", "DateObjectLabel"], "\"2014\""}], 
        RowBox[{"DateObject", "[", 
          RowBox[{
            RowBox[{"{", "2014", "}"}], ",", "\"Year\""}], "]"}]},
       "DateObject",
       Editable->False]}], "}"}], "\[Rule]", 
    TemplateBox[{
      InterpretationBox[
      "1.671260318`*^7", 1.671260318*^7, Selectable -> False], 
      RowBox[{
        FormBox["\"$\"", TraditionalForm], "\[VeryThinSpace]"}], "US dollars",
       "\"USDollars\""},
     "QuantityPrefix"]}]}], "}"}]], "ExerciseOutput",
 ShowCellLabel->Automatic,
 CellLabelAutoDelete->Automatic,
 CellChangeTimes->{3.7691703089371634`*^9, 3.769772700548894*^9, 
  3.7699755575863323`*^9, 3.77192359981187*^9, 3.7719292101049147`*^9, 
  3.771929534598914*^9, 3.88141822660948*^9, 3.882285775432796*^9},
 CellLabel->"Out[199]=",
 CellID->1369711421,ExpressionUUID->"cbbe8896-7c7e-4584-8a96-10054bdd0a53"]
}, Open  ]],

Cell[TextData[{
 "Visually, this looks more like a pipeline: start with ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"ba83320c-d052-4ede-bb95-016b794e71ad"],
 " and then feed it ",
 Cell[BoxData[
 "team1"], "InlineCode",ExpressionUUID->
  "c2ad1a17-6ace-484e-a1cf-653f4e673857"],
 ", then feed it ",
 Cell[BoxData[
 "team2"], "InlineCode",ExpressionUUID->
  "5e3c97cc-9ac3-424b-9466-e15959288b8d"],
 ", etc. I can\[CloseCurlyQuote]t do ",
 Cell[BoxData[
  RowBox[{"mls2", 
   ButtonBox["/*",
    BaseStyle->"FunctionHyperlink",
    ButtonData->{
      URL["https://reference.wolfram.com/language/ref/RightComposition.html"],
       None},
    ButtonNote->
     "https://reference.wolfram.com/language/ref/RightComposition.html"], 
   RowBox[{"(", 
    RowBox[{"team1", 
     ButtonBox["/*",
      BaseStyle->"FunctionHyperlink",
      ButtonData->{
        URL[
        "https://reference.wolfram.com/language/ref/RightComposition.html"], 
        None},
      ButtonNote->
       "https://reference.wolfram.com/language/ref/RightComposition.html"], 
     "team2", 
     ButtonBox["/*",
      BaseStyle->"FunctionHyperlink",
      ButtonData->{
        URL[
        "https://reference.wolfram.com/language/ref/RightComposition.html"], 
        None},
      ButtonNote->
       "https://reference.wolfram.com/language/ref/RightComposition.html"], 
     "team3", 
     ButtonBox["/*",
      BaseStyle->"FunctionHyperlink",
      ButtonData->{
        URL[
        "https://reference.wolfram.com/language/ref/RightComposition.html"], 
        None},
      ButtonNote->
       "https://reference.wolfram.com/language/ref/RightComposition.html"], 
     "team4", 
     ButtonBox["/*",
      BaseStyle->"FunctionHyperlink",
      ButtonData->{
        URL[
        "https://reference.wolfram.com/language/ref/RightComposition.html"], 
        None},
      ButtonNote->
       "https://reference.wolfram.com/language/ref/RightComposition.html"], 
     RowBox[{"team5", ")"}]}]}]}]], "InlineCode",ExpressionUUID->
  "9e0f0a85-7600-40ff-bf48-4f2039485ca9"],
 " because ",
 Cell[BoxData[
 "mls2"], "InlineCode",ExpressionUUID->"0a6184a6-b062-4616-a101-0655d923092f"],
 " is not itself a function."
}], "TechNote",
 CellDingbat->None,
 CellChangeTimes->{{3.769170311905202*^9, 3.769170371342867*^9}, {
  3.775480119231694*^9, 3.7754801801717877`*^9}, {3.8856434240600376`*^9, 
  3.885643439839806*^9}, {3.897746161801641*^9, 3.897746168227192*^9}},
 CellTags->"LastCellOfAPage",
 CellID->1088437716,ExpressionUUID->"3804d0ae-4cc0-4700-baf5-555a1c4618d3"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
Saveable->False,
ScreenStyleEnvironment->"Working",
WindowToolbars->{},
WindowSize->{808, 911},
WindowMargins->{{4, Automatic}, {Automatic, 4}},
WindowPersistentStyles->{
 WindowFrame, WindowMargins, WindowSize, Magnification},
WindowTitle->"2 | Data Structures and Functions",
DockedCells->{
  Cell[
   TagBox[
    GridBox[{{
       PaneBox[
        TagBox[
         GridBox[{{
            TemplateBox[{
              StyleBox[
               GraphicsBox[
                TagBox[
                 RasterBox[CompressedData["
1:eJztnU2O5MqSnS9aGvQwlxDaQQ01pIaaFVrQnN3Q64YmT4lXAgTNuISaacol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                  "], {{0, 36.24}, {302.88, 0}}, {0, 255}, ColorFunction -> 
                  RGBColor, ImageResolution -> {300, 300}], 
                 BoxForm`ImageTag[
                 "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                 Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                ImageSizeRaw -> {302.88, 36.24}, 
                PlotRange -> {{0, 302.88}, {0, 36.24}}, 
                ImagePadding -> {{0, 10}, {1, -10}}, ImageSize -> 
                Magnification[0.7]]], 
              TemplateBox[{
                GraphicsBox[
                 TagBox[
                  RasterBox[CompressedData["
1:eJztnUuu7Dhyhhu2Bx6eJcg7uEMP5aFniTY8VzfcbnhSPqgyYHimJZwlaAln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                   "], {{0, 26.88}, {230.4, 0}}, {0, 255}, ColorFunction -> 
                   RGBColor, ImageResolution -> {300, 300}], 
                  BoxForm`ImageTag[
                  "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                  Selectable -> False], DefaultBaseStyle -> "ImageGraphics", 
                 ImageSizeRaw -> {230.4, 26.88}, 
                 PlotRange -> {{0, 230.4}, {0, 26.88}}, 
                 ImagePadding -> {{2, 0}, {1, -10}}, ImageSize -> 
                 Magnification[0.7]], 
                "https://www.youtube.com/sethjchandler"}, "HyperlinkURL"]}, 
             "RowDefault"], "\[SpanFromLeft]"}, {
            GraphicsBox[
             TagBox[
              RasterBox[CompressedData["
1:eJztXQe4LEWVZkUBCYKSFIQ3BCXDImKGeQRRgoBECXKJkhQkSJYBERAQxEAU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               "], {{0, 22.08}, {236.88, 0}}, {0, 255}, ColorFunction -> 
               RGBColor, ImageResolution -> {300, 300}], 
              BoxForm`ImageTag[
              "Byte", ColorSpace -> ColorProfileData[CompressedData["
1:eJydlndUVNcWh8+9d3qhzTDSGXqvUgYQ6R2kV1EZZgYYygDDDIhdRFQwoohI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                 "], "RGB", "XYZ"], Interleaving -> True], Selectable -> 
              False], DefaultBaseStyle -> "ImageGraphics", 
             ImageSize -> {365, Automatic}, ImageSizeRaw -> {236.88, 22.08}, 
             PlotRange -> {{0, 236.88}, {0, 22.08}}, 
             ImagePadding -> {{1, 1}, {3, -10}}, ImageSize -> 
             Magnification[1]], "\[SpanFromLeft]"}, {
            TemplateBox[{
              FrameBox[
               StyleBox[
               "\"Buy on Amazon\"", 16, FontWeight -> "Bold", FontColor -> 
                RGBColor[0.768627, 0.949019, 1.], FontFamily -> 
                "Source Sans"], RoundingRadius -> 3, FrameStyle -> Directive[
                 RGBColor[0.768627, 0.949019, 1.], 
                 Thickness[Large]], FrameMargins -> {{10, 10}, {6, 6}}, 
               StripOnInput -> False], 
              "https://www.amazon.com/Query-Getting-Information-Wolfram-\
Language/dp/1579550851"}, "HyperlinkURL"], "\[SpanFromLeft]"}}, 
          GridBoxAlignment -> {"Columns" -> {{Left}}}, AutoDelete -> False, 
          GridBoxItemSize -> {
           "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
          GridBoxSpacings -> {"Columns" -> {{1}}, "Rows" -> {1, 1, 1}}], 
         "Grid"], ImageSize -> Full, FrameMargins -> {{20, 20}, {23, 10}}], 
       PaneBox[
        PaneBox[
         TemplateBox[{"\[ThinSpace]", "\" \"", 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{"Query-01-introduction.nb", ""}, 
                   FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Evaluator -> Automatic, Method -> "Preemptive"], True -> 
               ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAPiDmBmIUBO/j//z8jEDcA8W8g3oBFnhmIZ/9HgE9o8mxAvBZJ/hsQuyPJ
8wPxfiT5N0BsjiQvCsTnkOSfALEWkrwSEN9Bkr8OxDJobniAJP8ZZCYWfxCj
RpGQXcS4mVi/ExuGxMYFmlp4nAIAG14fWQ==
                    "], {{0, 14}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 14}, PlotRange -> {{0, 9}, {0, 14}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{"Query-01-introduction.nb", ""}, 
                   FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Enabled -> True, Appearance -> 
                 None, Background -> GrayLevel[0.2], Evaluator -> Automatic, 
                 Method -> "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], "\"1: Introduction\"", TooltipDelay -> 0.15,
              LabelStyle -> "TextStyling"], 
            Annotation[#, "1: Introduction", "Tooltip"]& ], 
           InterpretationBox[
            StyleBox[
             
             GraphicsBox[{}, ImageSize -> {5, 0}, BaselinePosition -> 
              Baseline], "CacheGraphics" -> False], 
            Spacer[5], Selectable -> False], 
           TagBox[
            TooltipBox[
             PaneSelectorBox[{False -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{"Query-03-association.nb", ""}, 
                   FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Evaluator -> 
                 Automatic, Method -> "Preemptive"], True -> ButtonBox[
                 PaneBox[
                  GraphicsBox[
                   TagBox[
                    RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UJAfiDmBmAWI////vwKIfwFxMQMOAJT7+R8B6nGoSf+PCjpwqMskUl0SEP9F
UtcHxIxY1EWjqZuOQ10Mmr2TcNj7BEnNP1LNIeQeIDsZn78IhQ8x4fwfNb4a
cPgTFu8l2ORBAAC+1hnm
                    "], {{0, 15}, {9, 0}}, {0, 255}, ColorFunction -> 
                    RGBColor], 
                    BoxForm`ImageTag[
                    "Byte", ColorSpace -> "RGB", Interleaving -> True], 
                    Selectable -> False], DefaultBaseStyle -> "ImageGraphics",
                    ImageSizeRaw -> {9, 15}, PlotRange -> {{0, 9}, {0, 15}}, 
                   ImageSize -> Magnification[1]], ImageSize -> {35, 30}, 
                  Alignment -> Center], 
                 ButtonFunction :> (
                  NotebookLocate[{"Query-03-association.nb", ""}, 
                   FrontEnd`HistoryData :> {
                    EvaluationNotebook[]}]& ), Appearance -> None, Background -> 
                 GrayLevel[0.2], Evaluator -> Automatic, Method -> 
                 "Preemptive"]}, 
              Dynamic[
               CurrentValue["MouseOver"]], ImageSize -> Automatic, 
              FrameMargins -> 0], "\"3: Association\"", TooltipDelay -> 0.15, 
             LabelStyle -> "TextStyling"], 
            Annotation[#, "3: Association", "Tooltip"]& ]}, 
          "RowWithSeparators"], Alignment -> Right], ImageSize -> {100, 30}, 
        FrameMargins -> {{0, 6}, {0, 0}}, Alignment -> Right], 
       TagBox[
        ActionMenuBox[
         PaneSelectorBox[{True -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> GrayLevel[0.2], 
             ImageSize -> {35, 30}, Alignment -> Center], False -> PanelBox[
             GraphicsBox[
              TagBox[
               RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UBAkIQ3ELED8////Jf/pA0D2/KWTXSB7ZtPBPrA9DKOAYgAMR1Eg9gPiABpi
P6g912mcLmAAZM9XOtkFsicKiNcD8QYaYpD5UQOdXoYD+E/HMooO9iDbR7c6
BQDxtyEt
                "], {{0, 16}, {27, 0}}, {0, 255}, ColorFunction -> RGBColor], 
               BoxForm`ImageTag[
               "Byte", ColorSpace -> "RGB", Interleaving -> True, 
                Magnification -> 1], Selectable -> False], DefaultBaseStyle -> 
              "ImageGraphics", ImageSize -> Magnification[1], 
              ImageSizeRaw -> {27, 16}, PlotRange -> {{0, 27}, {0, 16}}], 
             Appearance -> None, Background -> 
             RGBColor[0.0941176, 0.101961, 0.258824], ImageSize -> {35, 30}, 
             Alignment -> Center]}, 
          Dynamic[
           CurrentValue["MouseOver"]]], {
         "1: Introduction" :> 
          NotebookLocate[{"Query-01-introduction.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "2: Data Structures and Functions" :> 
          NotebookLocate[{"Query-02-data-structures-and-functions.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "3: Association" :> 
          NotebookLocate[{"Query-03-association.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "4: Query" :> 
          NotebookLocate[{"Query-04-query.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "5: The Dataset" :> 
          NotebookLocate[{"Query-05-the-dataset.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "6: Basic Recipes" :> 
          NotebookLocate[{"Query-06-basic-recipes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "7: Advanced Recipes" :> 
          NotebookLocate[{"Query-07-advanced-recipes.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "8: Import and Export" :> 
          NotebookLocate[{"Query-08-import-and-export.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Answers to Exercises" :> 
          NotebookLocate[{"Query-09-answers-to-exercises.nb", ""}, 
            FrontEnd`HistoryData :> {
              EvaluationNotebook[]}], "Index" :> 
          NotebookLocate[{"Query-10-index.nb", ""}, FrontEnd`HistoryData :> {
              EvaluationNotebook[]}]}, Appearance -> None], 
        MouseAppearanceTag["LinkHand"]]}}, AutoDelete -> False, 
     GridBoxItemSize -> {
      "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], "Grid"], 
   Background -> RGBColor[0.07450980392156863, 0.1450980392156863, 0.2], 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrameColor -> 
   RGBColor[0.863264, 0.898009, 0.999619], CellFrame -> {{0, 1}, {0, 0}}, 
   CellFrameMargins -> {{18, 20}, {1, 1}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, CellGroupingRules -> {"SectionGrouping", 0}, 
   CellContext -> CellGroup], 
  Cell[
   BoxData[
    DynamicModuleBox[{$CellContext`open$$ = False}, 
     PaneSelectorBox[{True -> ButtonBox[
         TemplateBox[{
           StyleBox[
           "\"ATTRIBUTION FOR USAGE \"", 12, FontFamily -> "Source Sans Pro", 
            FontWeight -> "Bold", FontColor -> 
            RGBColor[
             0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
           GraphicsBox[
            TagBox[
             RasterBox[CompressedData["
1:eJxTTMoPSmNiYGAo5gASQYnljkVFiZXBAkBOaF5xZnpeaopnXklqemqRRRIz
UFAMiNWAmAWIN23atACIDxCBJ/z//5+BEgw0Q4FIuzYAsQMQ/ycSO1DorgNE
2lMAVT+BSPUPKHBTAJF2HEDSIwCyk0h9DWS4iVjzP4DiGk0vsfGJoZcIdzWQ
En9Y9BMbnwdIcJMBpWaSGJ8BVEzrBOOAhPgEuV+AgFkJlMQfBfGJMw9Aw/4D
EWZcoEH+AWEDCv2GVT8V4hMjvZKgl+Qyh0Q/J6Dpu0DN+KMgPj/A8gAoDdMi
/iiIkwkkpHWy4o+C+CSmrCI7/ijMnzSNPwrik+bxR0F8YsME6wcK3UZMGYAN
O9DKTVB3Eds+QMmrtHQTktuIbU/RPP4oiE+y4g8ANP3HuQ==
              "], {{0, 5.28}, {9.12, 0}}, {0, 255}, ColorFunction -> RGBColor,
               ImageResolution -> {300, 300}], 
             BoxForm`ImageTag[
             "Byte", ColorSpace -> "RGB", Interleaving -> True], Selectable -> 
             False], DefaultBaseStyle -> "ImageGraphics", 
            ImageSizeRaw -> {9.12, 5.28}, PlotRange -> {{0, 9.12}, {0, 5.28}},
             ImageSize -> Magnification[1]]}, "RowDefault"], ButtonFunction :> 
         If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
           False, $CellGroupContext`open$$ = True], Appearance -> None, 
         Evaluator -> Automatic, Method -> "Preemptive"], False -> ButtonBox[
         TemplateBox[{
           StyleBox[
           "\"ATTRIBUTION FOR USAGE \"", 12, FontFamily -> "Source Sans PRo", 
            FontWeight -> "Bold", FontColor -> 
            RGBColor[
             0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
           GraphicsBox[
            TagBox[
             RasterBox[CompressedData["
1:eJy1ljEOgkAQRYlaWFJZa2VLaamlndHYCxGNDRIwMXYcwSN4BMIJPIJH8Ajc
YJ1N1oQsgrOzQ/FJgPDymJ3dzCQ4rw89x3HSIVzW/nWRJP5t48LNNkpPxyjc
L6NLeAyTWdCHh1PICDKAFEWRQcZCCIczwHxCSkjcAVeoPLncNa7gcv/Brbp7
HXC/yTriyrxM3ZFcY3dDLtqdwEW5w/ud6i0K+w2Zt7BdyIPIlrlLRgt/rhzY
3RU/s6jNP/cxJKe6I/plRakNssddVRtWrlYbVL8Tz5TVv3UlcmNOrurvF/O6
3TnXrSCeHy08D7v2P1Jy/LMWuUddjUnaW19H+T213w0cYwtezbHCpXrWHC25
jY4WXPT8huQaz2wILmnGbOFazZUNXOs5WOOyze0VLtusrrg5l6PGbdwzNvkA
H9MJ6g==
              "], {{0, 9.36}, {5.28, 0}}, {0, 255}, ColorFunction -> RGBColor,
               ImageResolution -> {300, 300}], 
             BoxForm`ImageTag[
             "Byte", ColorSpace -> "RGB", Interleaving -> True], Selectable -> 
             False], DefaultBaseStyle -> "ImageGraphics", 
            ImageSizeRaw -> {5.28, 9.36}, PlotRange -> {{0, 5.28}, {0, 9.36}},
             ImageSize -> Magnification[1]]}, "RowDefault"], ButtonFunction :> 
         If[$CellGroupContext`open$$, $CellGroupContext`open$$ = 
           False, $CellGroupContext`open$$ = True], Appearance -> None, 
         Evaluator -> Automatic, Method -> "Preemptive"]}, 
      Dynamic[$CellGroupContext`open$$]], 
     Initialization :> ($CellGroupContext`open$$ = False), 
     DynamicModuleValues :> {}]], "Text", CellMargins -> {{0, 0}, {0, 0}}, 
   CellFrame -> {{0, 0}, {0, 0}}, CellFrameColor -> 
   RGBColor[0.8588235294117647, 0.9333333333333333, 1.], 
   CellFrameMargins -> {{18, 0}, {1, 3}}, ShowStringCharacters -> False, 
   ShowCellBracket -> False, Background -> 
   RGBColor[0.8588235294117647, 0.9333333333333333, 1.], CellContext -> 
   CellGroup], 
  Cell[
   BoxData[
    TemplateBox[{
      StyleBox[
      "\"Content present in this notebook can be reused with the following \
attribution:\[LineSeparator]\"", FontSize -> 12, FontWeight -> "Regular", 
       FontFamily -> "Source Sans Pro", FontColor -> 
       RGBColor[0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
      TemplateBox[{
        TemplateBox[{
          StyleBox[
          "\"S. Chandler (2023),  \"", FontWeight -> Bold, FontSize -> 11, 
           FontFamily -> "Source Sans Pro", FontColor -> 
           RGBColor[
            0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
          StyleBox[
          "\"Query: Getting Information from Data with the Wolfram \
Language\"", Selectable -> True, Copyable -> True, FontSlant -> Italic, 
           FontWeight -> Bold, FontSize -> 11, FontFamily -> 
           "Source Sans Pro", FontColor -> 
           RGBColor[
            0.2784313725490196, 0.403921568627451, 0.5137254901960784]], 
          StyleBox[
          "\", Wolfram \
Media.\[LineSeparator]https://www.wolfram.com/language/query-getting-\
information-from-data-with-the-wolfram-language\"", FontWeight -> Bold, 
           FontSize -> 12, FontFamily -> "Source Sans Pro", FontColor -> 
           RGBColor[
            0.2784313725490196, 0.403921568627451, 0.5137254901960784]]}, 
         "RowDefault"], 
        "\"S. Chandler (2023), Query: Getting Information from Data with the \
Wolfram Language, Wolfram Media. \
www.wolfram.com/language/query-getting-information-from-data-with-the-wolfram-\
language\""}, "ClickToCopy2"]}, "RowDefault"]], "Text", 
   CellElementSpacings -> {"CellMinHeight" -> 4, "ClosedCellHeight" -> 1}, 
   Background -> RGBColor[0.8588235294117647, 0.9333333333333333, 1.], 
   CellMargins -> {{0, 0}, {0, 0}}, CellFrame -> {{0, 0}, {0, 0}}, 
   CellFrameColor -> RGBColor[0.8588235294117647, 0.9333333333333333, 1.], 
   CellFrameMargins -> {{18, 0}, {5, 5}}, ShowCellBracket -> False, 
   ShowStringCharacters -> False, CellOpen -> 
   Dynamic[$CellGroupContext`open$$], CellContext -> CellGroup, Copyable -> 
   True, Selectable -> True, LineSpacing -> {1, -3}]},
PageHeaders->{{
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Page"], "PageNumber"], 
      StyleBox[
      "    Query: Getting Information from Data with the Wolfram Language", 
       "Header"]}], "Header", 
    CellMargins -> {{37, Inherited}, {Inherited, Inherited}}], None, None}, {
  None, None, 
   Cell[
    TextData[{
      StyleBox[
       CounterBox["Section"], "Header"], 
      StyleBox["  |  Data Structures and Functions", "Header"], 
      StyleBox["    ", "Header"], 
      StyleBox[
       CounterBox["Page"], "PageNumber"]}], "Header", 
    CellMargins -> {{Inherited, 34}, {Inherited, Inherited}}]}},
TaggingRules->{
 "IndexEntries" -> {{"i:1", "Wolfram Language{history}"}, {
    "i:2", "Wolfram Language expression{as unifying paradigm}"}, {
    "i:2", "Expression?"}, {"i:2", "Mathematica"}, {
    "i:3", "Atomic expressions"}, {"i:4", "Expression{head of}"}, {
    "i:4", "Head{of expression}"}, {
    "i:4", "Head{as similar to type or class in other languages}"}, {
    "i:4", "Python"}, {"i:4", "Java"}, {"i:4", "C++"}, {
    "i:5", "Compound expressions"}, {"i:5", "FullForm?"}, {"i:5", "Head"}, {
    "i:5", "InputForm?"}, {
    "i:6", "Head{use of syntactic sugar to avoid explicit representation}"}, {
    "i:6", "List?"}, {"i:6", "List?{use of curly braces to denote}"}, {
    "i:7", "FullForm?"}, {"i:7", "StandardForm?"}, {"i:8", "Part?"}, {
    "i:9", "TreeForm?"}, {"i:10", "Part?{negative indices}"}, {
    "i:11", "Head?{equivalent of part 0}"}, {
    "i:11", "Part?{zeroth part as equivalent of Head?}"}, {
    "i:12", "Part?{use of double square bracket as syntactic sugar}"}, {
    "i:13", "Span?"}, {"i:14", "CharacterRange?"}, {
    "i:15", "Span?{use of ;; as syntactic sugar}"}, {
    "i:16", "Functions{in Wolfram Language}"}, {
    "i:16", "Poetry{resemblance to good Wolfram Language programming}"}, {
    "i:17", "Function{definition with Function?}"}, {"i:17", "Function?"}, {
    "i:18", "Function{definition with infix notation arrow}"}, {
    "i:19", "Function?{application to data using brackets}"}, {
    "i:20", "Function?{localization of variables}"}, {
    "i:20", "Function?{scope of variables}"}, {
    "i:21", "Function?{use of @ to denote application}"}, {
    "i:22", "Function?{with multiple arguments}"}, {
    "i:23", "Function?{using Slot? to denote positional arguments}"}, {
    "i:24", "Function?{precedence of functions denoted with &}"}, {
    "i:25", "Slot?{use of # as syntactic sugar}"}, {
    "i:26", "Function composition"}, {"i:26", "Composition of functions"}, {
    "i:27", "Composition?"}, {
    "i:28", "Composition?{distinguished from RightComposition?}"}, {
    "i:29", "Composition?{use of @* syntactic sugar}"}, {
    "i:30", "RightComposition?{use of /* syntactic sugar}"}, {
    "i:31", "List?"}, {"i:32", "List?{in FullForm?}"}, {
    "i:32", "FullForm?{of List?}"}, {
    "i:33", "List?{containing elements with different heads}"}, {
    "i:34", "List?{with Lists as elements}"}, {"i:35", "Part?{with All?}"}, {
    "i:36", "Grid?"}, {"i:37", "Dividers?"}, {"i:38", "TableForm?"}, {
    "i:39", "DatasetForm"}, {"i:39", "ResourceFunction?{DatasetForm}"}, {
    "i:40", "Level?"}, {"i:40", "Expressions{levels of}"}, {
    "i:41", "Position?"}, {"i:42", "Position?{with level restrictions}"}, {
    "i:43", "Extract?"}, {
    "i:43", "Extract?{working in conjunction with Position?}"}, {
    "i:43", "Position?{List? wrapping}"}, {
    "i:44", "Functional programming"}, {"i:45", "Map?"}, {
    "i:46", "TreeForm?"}, {"i:47", "Map?{with level specification}"}, {
    "i:48", "Map{operator form}"}, {"i:49", "MapLevel"}, {
    "i:49", "ResourceFunction?{MapLevel}"}, {
    "i:50", "Map?{with composed functions}"}, {"i:51", "MapThread?"}, {
    "i:52", "MapIndexed?"}, {"i:53", "MapAt?"}, {"i:54", "Apply?"}, {
    "i:54", "Apply?{distinguished from Map?}"}, {"i:55", "ApplyLevel"}, {
    "i:55", "ResourceFunction?{ApplyLevel}"}, {"i:56", "Thread?"}, {
    "i:57", "Thread?{compared with MapThread?}"}, {
    "i:57", "MapThread?{compared with Thread?}"}, {"i:58", "Listable?"}, {
    "i:58", "Function?{attributes}"}, {"i:59", "Length?"}, {
    "i:60", "SortBy?"}, {"i:61", "ReverseSortBy?"}, {"i:62", "GatherBy?"}, {
    "i:63", "Select?"}, {"i:64", "Transpose?"}, {"i:65", "Terse"}, {
    "i:65", "ResourceFunction?{Terse}"}, {
    "i:65", "Short?{compared to Terse}"}, {"i:65", "RandomDate?"}, {
    "i:65", "DateString?"}, {"i:66", "EchoTiming?"}, {
    "i:66", "Interpreter?"}, {"i:67", "Listability{speed advantages}"}, {
    "i:68", "Transpose?"}, {"i:68", "Entity?"}, {
    "i:69", "Major League Soccer data"}, {"i:70", "AugmentedTerse"}, {
    "i:70", "ResourceFunction?{AugmentedTerse}"}, {"i:71", "Grid?"}, {
    "i:72", "Position?{with level specification}"}, {
    "i:73", "Missing data{fixing with DeleteMissing?}"}, {
    "i:73", "Missing data{fixing with SynthesizeMissingValues?}"}, {
    "i:73", "Missing data{fixing with Select?}"}, {"i:74", "Sorting"}, {
    "i:75", "Scatter plots{with ListPlot?}"}, {"i:75", "ListPlot?"}, {
    "i:76", "Sorting{with selection}"}, {
    "i:77", "Take?{instead of Part? for adjacent elements}"}, {
    "i:78", "GatherBy?"}, {"i:79", "DateListPlot?"}, {"i:80", "GatherBy?"}, {
    "i:81", "Dimensions?"}, {"i:82", "Operators{use of pipelines}"}, {
    "i:83", "RightComposition?"}, {"i:84", "TreeForm?"}, {
    "i:84", "FullForm?"}, {"i:85", "ResourceFunction?{use of}"}, {
    "i:86", "MapIndexed?{with level specifications}"}, {
    "i:87", "Postfix notation{use of //}"}}, 
  "PaginationCache" -> {{
    2023, 8, 31, 16, 23, 57.3737737`9.511288249778318}, CompressedData["
1:eJxtwdcBwjAMBUDBApTQCSV0CL1378AIWYBZ2YifOJbkdxcl30+SI6JfnqiQ
KjIlpSwEWAWoKjVf3dcAmlhLaXMh0gG6Uk/qcxEwkIbKyBlzE2UKzKA5sNBi
bZlZOWtmY22VnbUXDtLROgln5+K5cjfnnnkwT+6VenPGmD8NB2ps
    "], Automatic}, 
  "IndexItemsAndPageNumbers" -> {{"i:1", 15}, {"i:2", 15}, {"i:3", 16}, {
    "i:4", 16}, {"i:5", 16}, {"i:6", 17}, {"i:7", 17}, {"i:8", 17}, {
    "i:9", 18}, {"i:10", 18}, {"i:11", 19}, {"i:12", 19}, {"i:13", 20}, {
    "i:14", 20}, {"i:15", 20}, {"i:16", 20}, {"i:17", 21}, {"i:18", 21}, {
    "i:19", 21}, {"i:20", 21}, {"i:21", 22}, {"i:22", 22}, {"i:23", 23}, {
    "i:24", 23}, {"i:25", 23}, {"i:26", 23}, {"i:27", 24}, {"i:28", 24}, {
    "i:29", 24}, {"i:30", 24}, {"i:31", 25}, {"i:32", 25}, {"i:33", 25}, {
    "i:34", 26}, {"i:35", 26}, {"i:36", 26}, {"i:37", 26}, {"i:38", 27}, {
    "i:39", 27}, {"i:40", 27}, {"i:41", 28}, {"i:42", 29}, {"i:43", 29}, {
    "i:44", 29}, {"i:45", 29}, {"i:46", 30}, {"i:47", 31}, {"i:48", 32}, {
    "i:49", 32}, {"i:50", 33}, {"i:51", 33}, {"i:52", 34}, {"i:53", 36}, {
    "i:54", 37}, {"i:55", 38}, {"i:56", 39}, {"i:57", 39}, {"i:58", 39}, {
    "i:59", 40}, {"i:60", 40}, {"i:61", 41}, {"i:62", 41}, {"i:63", 43}, {
    "i:64", 43}, {"i:65", 43}, {"i:66", 44}, {"i:67", 44}, {"i:68", 45}, {
    "i:69", 46}, {"i:70", 47}, {"i:71", 47}, {"i:72", 47}, {"i:73", 48}, {
    "i:74", 48}, {"i:75", 49}, {"i:76", 50}, {"i:77", 50}, {"i:78", 50}, {
    "i:79", 52}, {"i:80", 53}, {"i:81", 53}, {"i:82", 55}, {"i:83", 58}, {
    "i:84", 61}, {"i:85", 61}, {"i:86", 62}, {"i:87", 62}}},
ShowCellLabel->Automatic,
CellLabelAutoDelete->Automatic,
ShowAutoSpellCheck->False,
FrontEndVersion->"13.3 for Mac OS X x86 (64-bit) (June 3, 2023)",
StyleDefinitions->Notebook[{
   Cell[
    StyleData[StyleDefinitions -> "Default.nb"]], 
   Cell[
    CellGroupData[{
      Cell[
      "Style Environments", "Section", 
       CellChangeTimes -> {{3.64661165091824*^9, 3.646611654013329*^9}, 
         3.6485723794335403`*^9, 3.651347081728628*^9, 3.651347179462186*^9, 
         3.651347384135805*^9, 3.651348171662589*^9}], 
      Cell[
       StyleData[All, "Working"], CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> None}, $CellContext`CellInsertionPointCell -> 
       FEPrivate`FrontEndResource[
        "FEExpressions", 
         "CellInsertionMenu"], $CellContext`GhostCellInEmptyNotebook -> 
       False], 
      Cell[
       StyleData[All, "Printout"], 
       PrintingOptions -> {"PageSize" -> {504, 720}}, 
       AutoStyleOptions -> {"UndefinedSymbolStyle" -> None}, Magnification -> 
       0.6], 
      Cell[
       StyleData[All, "Invisibles"], DockedCells -> {
         Cell[
          BoxData[
           GridBox[{{
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]], 
              ActionMenuBox[
              "\"Insert\"", {
               "\"Subsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsectionStyle[]), 
                "\"Subsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsectionStyle[]), 
                "\"Subsubsubsection\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToSubsubsubsectionStyle[]), 
                Delimiter, 
                "\"Text\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTConvertToTextStyle[]), "\"CodeText\"" :> 
                Module[{$CellContext`bn = ButtonNotebook[]}, 
                  If[Developer`CellInformation[$CellContext`bn] =!= $Failed, 
                    While[
                    FreeQ[
                    Developer`CellInformation[$CellContext`bn], 
                    "CellBracket"], 
                    FrontEndExecute[
                    
                    FrontEnd`SelectionMove[$CellContext`bn, All, Cell, 
                    AutoScroll -> False]]]; 
                    SelectionMove[$CellContext`bn, After, Cell]]; 
                  NotebookWrite[$CellContext`bn, 
                    Cell["XXXX", "CodeText"], All]; 
                  SelectionMove[$CellContext`bn, All, CellContents]], 
                "\"Hyperlink\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTGenerateHyperlinkDialog[]), Delimiter, 
                "\"Vocabulary 2Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd2ColTable[]), 
                "\"Vocabulary 3Col\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertVocabularySectionAnd3ColTable[]), 
                "\"Add Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[]), 
                "\"Remove Row\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["RemoveRow" -> True]), 
                "\"Apply Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow["AddDivider" -> True]), 
                "\"Remove Divider\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTVocabTableAddRow[
                  "RemoveDivider" -> True]), Delimiter, 
                "\"Exercises\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Exercise\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertExerciseSection[]), 
                "\"Q&A | Tech Notes | More\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQAndATechNotesMore[]), 
                "\"Question\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertQuestion[]), 
                "\"Answer\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertAnswer[]), 
                "\"Tech Note\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertTechNote[]), 
                "\"More to Explore\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertMoreExplore[]), 
                "\"References Section\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTInsertReferencesSection[]), Delimiter, 
                "\"Comment\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyComment[])}, Appearance -> 
               "PopupMenu", FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              ActionMenuBox[
              "\"Function Name\"", {
               "\"Link\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTMakeSymbolLink[]), 
                "\"Format\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTFormatSymbol[])}, Appearance -> 
               "PopupMenu", Method -> "Queued", FrameMargins -> 2.4], 
              ButtonBox[
              "\"Resource Function Link\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTResourceFunctionLink[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ButtonBox[
              "\"Inline Code\"", 
               ButtonFunction :> (Needs["WolframBookTools`"]; 
                WolframBookTools`WBTConvertToInlineCode[]), Evaluator -> 
               Automatic, Appearance -> "DialogBox", Method -> "Queued"], 
              ActionMenuBox[
              "\"Mark Cells\"", {
               "\"Tentative\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyTentative[]), Delimiter, 
                "\"Print Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyPrintOnly[]), 
                "\"Web Only\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyWebOnly[]), Delimiter, 
                "\"Locked\"" :> (Needs["WolframBookTools`"]; 
                 WolframBookTools`WBTApplyLock[])}, Method -> "Queued", 
               FrameMargins -> 2.4], 
              ItemBox["", ItemSize -> Fit], 
              GridBox[{{
                 TooltipBox[
                  ButtonBox[
                  "\"Index Field\"", Appearance -> {"AbuttingRight"}, 
                   ButtonFunction :> (Needs["WolframBookTools`"]; 
                    WolframBookTools`WBTInsertIndexField[]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "First put the cursor in a cell to insert a corresponding \
field above to insert index entries.\nList main index entries corresponding \
to the cell separated by commas. Any associated sub-entries\nshould be put \
immediately after in braces.\nExample: programming{functional, rule based}, \
function, relation, lists{flat, nested}\n If $Language is \"ChineseSimplified\
\", \"ChineseTraditional\", \"Japanese\", \"Korean\" or \"Russian\"\ntwo \
index fields get inserted above a selected cell, the top one for inserting \
entries\nintended for the Englsh index and the bottom for the index in the \
language given by $Language.", TooltipDelay -> 0.3], 
                 TooltipBox[
                  ButtonBox[
                  "\"Toggle\"", Appearance -> {"AbuttingLeft"}, 
                   ButtonFunction :> (CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] = 
                    If[CurrentValue[
                    ButtonNotebook[], ScreenStyleEnvironment] === 
                    "Invisibles", "Working", "Invisibles"]), Evaluator -> 
                   Automatic, Method -> "Queued"], 
                  "Toggles index entry fields.", TooltipDelay -> 0.3]}}, 
               GridBoxItemSize -> {
                "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}, 
               GridBoxSpacings -> {
                "ColumnsIndexed" -> {2 -> 0}, "Rows" -> {{Automatic}}}], 
              InterpretationBox[
               StyleBox[
                
                GraphicsBox[{}, BaselinePosition -> Baseline, 
                 ImageSize -> {4, 0}], CacheGraphics -> False], 
               Spacer[4]]}}]], "DockedCell", 
          CellFrameMargins -> {{0, 0}, {8, 8}}]}, CreateCellID -> True, 
       ShowPredictiveInterface -> False, 
       AutoStyleOptions -> {
        "UndefinedSymbolStyle" -> None}, $CellContext`CellInsertionPointCell -> 
       FEPrivate`FrontEndResource[
        "FEExpressions", 
         "CellInsertionMenu"], $CellContext`GhostCellInEmptyNotebook -> 
       False]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell["Styles for Headers and Footers", "Section"], 
      Cell[
       StyleData["Header"], 
       PrintingOptions -> {"PageHeaderMargins" -> {28, 28}}, StyleMenuListing -> 
       None, FontFamily -> "Source Sans Pro", FontSize -> 8, FontWeight -> 
       "Regular", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0.45]], 
      Cell[
       StyleData["PageNumber"], CellMargins -> {{0, 0}, {4, 1}}, 
       StyleMenuListing -> None, FontFamily -> "Source Sans Pro", FontSize -> 
       8, FontWeight -> "Bold", FontSlant -> "Plain", 
       PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, FontColor -> 
       GrayLevel[0]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Custom Styles", "Section", 
       CellChangeTimes -> {{3.646611660445352*^9, 3.646611669493331*^9}}], 
      Cell[
       StyleData["Notebook"], PageWidth :> 700, 
       PrintingOptions -> {
        "FirstPageHeader" -> True, "InnerOuterMargins" -> {30, 30}, 
         "PaperOrientation" -> "Portrait", "PaperSize" -> {504, 720}, 
         "PrintingMargins" -> {{20, 20}, {54, 54}}}, CellLabelAutoDelete -> 
       False, ShowSyntaxStyles -> True, MenuSortingValue -> None, 
       GraphicsBoxOptions -> {ImageSize -> 240}, 
       Graphics3DBoxOptions -> {ImageSize -> 240}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Title"], CellMargins -> {{64, Inherited}, {50, 72}}, 
          MenuCommandKey :> None, FontFamily -> "Verdana", FontSize -> 42, 
          FontWeight -> "Bold", FontColor -> GrayLevel[0.4]], 
         Cell[
          StyleData["Title", "Printout"], 
          CellMargins -> {{64, Inherited}, {50, 72}}]}, Closed]], 
      Cell[
       StyleData["Chapter"], MenuCommandKey :> None], 
      Cell[
       StyleData["Subchapter"], MenuCommandKey :> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Section"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{64, Inherited}, {12, 64}}, 
          CellGroupingRules -> {"SectionGrouping", 30}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["Section", "Printout"], 
          CellMargins -> {{62, 4}, {52, 182}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionDoubleDigit"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellDingbat -> Cell[
            TextData[
             CounterBox["Section"], 
             StyleBox[
             "|\[NegativeThinSpace]\[VeryThinSpace]", FontColor -> 
              RGBColor[
               0.9019607843137255, 0.4117647058823529, 0.027450980392156862`],
               FontFamily -> "Courier", FontSize -> 36, FontWeight -> Plain]],
             "SectionNumber"], CellMargins -> {{112, Inherited}, {12, 64}}, 
          Evaluatable -> True, CellGroupingRules -> {"SectionGrouping", 60}, 
          PageBreakAbove -> True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionDoubleDigit", "Printout"], 
          CellMargins -> {{112, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNumber"], CellBaseline -> Baseline, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 26, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionBar"], FontFamily -> "Source Sans Pro", 
          FontWeight -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionBar", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionInline"], FontFamily -> 
          "Source Sans Pro Semibold", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SectionInline", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SectionNoDingbat"], 
          CellMargins -> {{64, Inherited}, {12, 64}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakAbove -> 
          True, ShowCellLabel -> False, 
          CellFrameLabelMargins -> {{2, Inherited}, {Inherited, Inherited}}, 
          CellChangeTimes -> {3.652728456208679*^9, 3.652728527108994*^9}, 
          CounterIncrements -> "Section", 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro Semibold", 
          FontSize -> 26, FontSlant -> "Plain", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          InterpretationBoxOptions -> {Editable -> True}], 
         Cell[
          StyleData["SectionNoDingbat", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 2}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumbered"], CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Subsection"]}], "SubsectionNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{98, Inherited}, {Inherited, 32}}, 
          CounterIncrements -> "Subsection", FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsectionNumbered", "Printout"], 
          CellMargins -> {{102, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionNumber"], FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          GrayLevel[0.25]], 
         Cell[
          StyleData["SubsectionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsectionFirst"], 
          CellMargins -> {{64, Inherited}, {2, 72}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {12, 32}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsection"], CellMargins -> {{64, Inherited}, {2, 32}}, 
          FontFamily -> "Source Sans Pro Semibold", FontSize -> 18, FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["Subsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SubsubsectionTopMargin"], 
          CellMargins -> {{64, Inherited}, {2, 14}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 16, FontSlant -> "Italic", 
          FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["SubsubsectionTopMargin", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Subsubsubsection"], 
          CellMargins -> {{64, Inherited}, {2, 32}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.45]], 
         Cell[
          StyleData["Subsubsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesSubsection"], 
          CellMargins -> {{64, Inherited}, {4, 16}}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourcesSubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 16}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["VocabularySection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 24}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsection"], 
          CellMargins -> {{64, Inherited}, {2, 10}}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularySubsectionSM"], 
          CellFrame -> {{0, 0}, {0.75, 0}}, 
          CellMargins -> {{64, Inherited}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontWeight -> "Bold", FontSlant -> 
          "Regular", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["VocabularySubsubsectionSM", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 15}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyTable", StyleDefinitions -> StyleData["Text"]],
           SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"VocabularyCode", Inherited, Inherited}, 
              "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "VocabularyTable3Column", StyleDefinitions -> StyleData["Text"]], 
          SpanMaxSize -> 1, FontFamily -> "Source Sans Pro Light", FontColor -> 
          GrayLevel[0.8], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False, {
                 Directive[
                  Thickness[0.5], "VocabDivColor"]}, False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {
               "VocabularyCode", Inherited, "VocabularyCode", Inherited, 
                Inherited}, "Rows" -> {{Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0, 1, 2, 1, 2}}, "Rows" -> {{1}}}}], 
         Cell[
          StyleData["VocabularyTable3Column", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["VocabularyText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabularyCode", StyleDefinitions -> StyleData["Text"]], 
          Deletable -> False, FontFamily -> "Source Sans Pro", FontSize -> 14,
           FontWeight -> "Bold", FontColor -> GrayLevel[0.25], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["VocabularyCode", "Printout"], FontColor -> 
          GrayLevel[0.25]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["GrayPointSix"], FontColor -> GrayLevel[0.6]], 
         Cell[
          StyleData["GrayPointSix", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["VocabDivColor"], FontColor -> GrayLevel[0.8]], 
         Cell[
          StyleData["VocabDivColor", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, Evaluatable -> True, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, ShowCellLabel -> False, CellFrameMargins -> {{8, 8}, {4, 6}},
           CellFrameColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Exercise", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ExerciseSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsection"], PageWidth :> 500, 
          CellFrame -> {{False, False}, {1, False}}, 
          CellMargins -> {{64, Inherited}, {8, 18}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6], FontFamily -> "Source Sans Pro", FontSize -> 
          18, FontSlant -> "Italic", FontColor -> RGBColor[0.65, 0.6, 0.6]], 
         Cell[
          StyleData["ExerciseSubsection", "Printout"], 
          CellFrame -> {{False, False}, {1, False}}, CellFrameColor -> 
          RGBColor[0.65, 0.6, 0.6]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseSubsectionSM"], 
          CellMargins -> {{64, Inherited}, {4, 12}}, 
          CellGroupingRules -> {"SectionGrouping", 61}, FontFamily -> 
          "Source Sans Pro Semibold", FontSize -> 15, FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ExerciseSubsectionSM", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Exercise"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"  ", 
              CounterBox["Section"], ".", 
              CounterBox["Exercise"]}], "ExerciseNumber", FontColor -> 
            RGBColor[
             0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          ShowGroupOpener -> True, CellMargins -> {{106, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 62}, DefaultNewCellStyle -> 
          "ExerciseInput", CounterIncrements -> "Exercise", MenuSortingValue -> 
          10020, MenuCommandKey :> "2", FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["Exercise", "Printout"], ShowGroupOpener -> False, 
          CellMargins -> {{108, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["ExerciseNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseNote"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, 
          CellGroupingRules -> {"SectionGrouping", 62.}, PageBreakBelow -> 
          False, LineSpacing -> {1., 1., 2.}, MenuSortingValue -> 10050, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ExerciseNote", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, 
          LineSpacing -> {0.8, 1., 2.}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QASection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          CounterAssignments -> {{"Subsection", 0}, {"Subsubsection", 0}, {
            "Question", 0}}, FontFamily -> "Source Sans Pro", FontSize -> 18, 
          FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["QASection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Question"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {2, 12}}, PageBreakBelow -> False, 
          CounterIncrements -> "Question", MenuSortingValue -> 10030, 
          MenuCommandKey :> "3", FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Bold", FontSlant -> 
          "Plain", $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Answer"], 
         Cell[
          StyleData["Question", "Printout"], 
          CellMargins -> {{65, Inherited}, {2, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Answer"], PageWidth :> 700, 
          CellMargins -> {{66, 10}, {4, 1}}, LineSpacing -> {1.125, 1., 2.}, 
          MenuSortingValue -> 10032, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True, $CellContext`DefaultReturnCreatedCellStyle -> "Question"], 
         Cell[
          StyleData["Answer", "Printout"], 
          CellMargins -> {{66, 10}, {4, 1}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["QuestionNumber"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Bold", FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["QuestionNumber", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["TechNoteSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteSubsection"], 
          CellMargins -> {{64, Inherited}, {2, 10}}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
         Cell[
          StyleData["TechNoteSubsubsection", "Printout"], 
          CellMargins -> {{64, Inherited}, {6, 14}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteItem"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontSize -> 12, FontWeight -> 
            Bold, FontColor -> GrayLevel[0.25]], 
          CellMargins -> {{93, Inherited}, {4, 8}}, CellFrameLabelMargins -> 
          4, CellChangeTimes -> {{3.651515120816633*^9, 3.651515125814807*^9},
             3.6515155174947033`*^9}, LineSpacing -> {1.25, 1., 2.}, 
          CounterIncrements -> "ItemNumbered", MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["TechNoteItem", "Printout"], 
          CellMargins -> {{93, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteNoDingbat"], PageWidth :> 700, 
          CellMargins -> {{82, Inherited}, {4, 8}}, CellFrameLabelMargins -> 
          4, LineSpacing -> {1.25, 1., 2.}, MenuSortingValue -> 10040, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["TechNote", "Printout"], 
          CellMargins -> {{82, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNote"], PageWidth :> 700, CellDingbat -> Cell[
            TextData[{"\[FilledSquare]"}], FontSize -> 12, FontColor -> 
            GrayLevel[0.5]], CellMargins -> {{78, Inherited}, {4, 8}}, 
          CellFrameLabelMargins -> 4, LineSpacing -> {1.25, 1., 2.}, 
          MenuSortingValue -> 10040, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0.25], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TechNote", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TechNoteInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 1, FontSize -> 
          14], 
         Cell[
          StyleData["TechNoteInput", "Printout"], 
          CellMargins -> {{99, 10}, {3, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TechNoteOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 14], 
         Cell[
          StyleData["TechNoteOutput", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["MoreExploreSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExplore"], PageWidth :> 700, 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          MenuSortingValue -> 10050, FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["MoreExplore", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["MoreExploreShortURL"], 
          CellMargins -> {{64, Inherited}, {4, 8}}, PageBreakBelow -> False, 
          FontFamily -> "Source Sans Pro Light", FontSize -> 14, FontSlant -> 
          "Plain", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["MoreExploreShortURL", "Printout"], 
          CellMargins -> {{64, Inherited}, {4, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysSection"], PageWidth :> 700, 
          CellFrame -> {{1, 1}, {1, 1}}, CellMargins -> {{52, -12}, {-1, 30}},
           CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{16, 8}, {6, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "Bold", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[1], Background -> 
          RGBColor[0.901961, 0.411765, 0.027451]], 
         Cell[
          StyleData["TakeawaysSection", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysHeader"], 
          CellMargins -> {{64, Inherited}, {5, 15}}, 
          CellFrameMargins -> {{8, 8}, {5, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontWeight -> "SemiBold", 
          FontSlant -> "Regular", FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysHeader", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysTable"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 0}}, CellMargins -> {{52, -12}, {12, -1}},
           CellFrameMargins -> {{18, 12}, {20, 12}}, CellFrameLabelMargins -> 
          6, LineSpacing -> {1.25, 1., 2.}, SpanMaxSize -> 1, FontFamily -> 
          "Source Sans Pro Light", FontColor -> GrayLevel[0.25], Background -> 
          RGBColor[1., 0.9490196078431372, 0.8509803921568627], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {"Columns" -> {{False}}, "Rows" -> {False}}, 
            GridBoxItemStyle -> {
             "Columns" -> {"TakeawaysDingbat", Inherited}, 
              "Rows" -> {{SpanFromLeft, Automatic}}}, 
            GridBoxSpacings -> {
             "Columns" -> {{0.5}}, 
              "Rows" -> {{0.75}}}}, $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["TakeawaysTable", "Printout"], 
          CellMargins -> {{51.5, -12.5}, {12, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TakeawaysText"], FontFamily -> "Source Sans Pro", 
          FontSize -> 14, FontWeight -> "Plain", FontSlant -> "Plain", 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["TakeawaysText", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "TakeawaysDingbat", StyleDefinitions -> StyleData["Text"]], 
          FontFamily -> "Source Sans Pro", FontSize -> 10, FontWeight -> 
          "SemiBold", FontColor -> RGBColor[0.901961, 0.411765, 0.027451], 
          GridBoxOptions -> {
           GridBoxAlignment -> {"Columns" -> {{Left}}}, 
            GridBoxDividers -> {
             "Columns" -> {{False}}, "ColumnsIndexed" -> {}, 
              "Rows" -> {True, {True}, True}, "RowsIndexed" -> {}}}], 
         Cell[
          StyleData["TakeawaysDingbat", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeText", StyleDefinitions -> StyleData["Text"]], 
          CellMargins -> {{66, 10}, {3, 15}}, LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 1540, 
          MenuCommandKey :> $CellContext`MenuKey[
           "7", $CellContext`Modifiers -> {"Shift"}], FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeText", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeCaption"], CellFrame -> {{0, 0}, {0, 0}}, 
          CellMargins -> {{66, 10}, {4, 12}}, PageBreakBelow -> False, 
          CellFrameColor -> GrayLevel[0.4], LineSpacing -> {1, 1, 1}, 
          MenuSortingValue -> 10010, MenuCommandKey :> "1", FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontColor -> GrayLevel[0.25]], 
         Cell[
          StyleData["CodeCaption", "Printout"], 
          CellMargins -> {{66, 10}, {4, 12}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DisplayFormula"], 
          CellMargins -> {{99, Inherited}, {2, 12}}, DefaultFormatType -> 
          DefaultInputFormatType, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           LanguageCategory -> "Formula", ScriptLevel -> 0, 
          SingleLetterItalics -> True, MenuSortingValue -> 1700, FontFamily -> 
          "Baskerville", FontSize -> 16, FontWeight -> "Regular", FontSlant -> 
          "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}, 
          FontColor -> GrayLevel[0.2], 
          UnderoverscriptBoxOptions -> {
           LimitsPositioning -> True}, $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["DisplayFormula", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "DisplayFormulaNumbered", StyleDefinitions -> 
           StyleData["DisplayFormula"]], CellFrameLabels -> {{None, 
             Cell[
              TextData[{"(", 
                CounterBox["DisplayFormulaNumbered"], ")"}], 
              "DisplayFormulaEquationNumber"]}, {None, None}}, 
          CounterIncrements -> "DisplayFormulaNumbered", MenuSortingValue -> 
          1710, FontFamily -> "Baskerville", FontSize -> 16, FontWeight -> 
          "Regular", FontSlant -> "Plain", 
          PrivateFontOptions -> {"FontPostScriptName" -> "Automatic"}], 
         Cell[
          StyleData["DisplayFormulaNumbered", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Print"], CellMargins -> {{99, 10}, {4, 4}}, FontSize -> 
          15], 
         Cell[
          StyleData["Print", "Presentation"], 
          CellMargins -> {{100, Inherited}, {1.5 Inherited, 1.5 Inherited}}], 
         Cell[
          StyleData["Print", "SlideShow"], 
          CellMargins -> {{
            0.135 FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}], 0.01 
             FrontEnd`AbsoluteCurrentValue[{WindowSize, 1}]}, {8, 15}}, 
          FontSize -> 18], 
         Cell[
          StyleData["Print", "Condensed"], 
          CellMargins -> {{18, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "Printout"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Print", "PrintoutGray"], 
          CellMargins -> {{49, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Item"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontFamily -> Automatic, FontSize -> 
            18, FontWeight -> GrayLevel[0], 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{81, 10}, {4, 8}}, 
          StyleKeyMapping -> {"Tab" -> "Subitem", "*" -> "Subitem"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "Item", 
          CounterAssignments -> {{"Subitem", 0}, {"Subsubitem", 0}}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Item", "Printout"], CellDingbat -> 
          StyleBox[
           "\:203a", Alignment -> Baseline, FontSize -> 17, FontFamily -> 
            "Automatic", FontWeight -> "Black", 
            RGBColor[
            0.9019607843137255, 0.4117647058823529, 0.027450980392156862`]], 
          CellMargins -> {{80, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> {
           "GroupTogetherNestedGrouping", 1.073741821*^9}, 
          CellChangeTimes -> {{3.8855684925344048`*^9, 
           3.885568495926271*^9}, {3.885643888233819*^9, 
           3.8856439007210073`*^9}}, $CellContext`CellDingbatMargin -> 2]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemParagraph"], CellMargins -> {{81, 10}, {4, 1}}, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          MenuSortingValue -> 1600, FontFamily -> "Source Sans Pro", FontSize -> 
          15, FontColor -> GrayLevel[0.2], $CellContext`ReturnCreatesNewCell -> 
          True], 
         Cell[
          StyleData["ItemParagraph", "Printout"], 
          CellMargins -> {{80, Inherited}, {Inherited, 0.5 Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ItemNumbered"], CellDingbat -> Cell[
            TextData[{
              CounterBox["ItemNumbered"], "."}], FontWeight -> "Bold"], 
          CellMargins -> {{85, 10}, {4, 8}}, 
          StyleKeyMapping -> {"Tab" -> "SubitemNumbered"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameLabelMargins -> 4, CounterIncrements -> "ItemNumbered", 
          CounterAssignments -> {{"SubitemNumbered", 0}, {
            "SubsubitemNumbered", 0}}, MenuSortingValue -> 1630, FontFamily -> 
          "Source Sans Pro", FontSize -> 
          15, $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ItemNumbered", "Printout"], 
          CellMargins -> {{90, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Note"], CellFrame -> {{0, 0}, {0, 1}}, 
          CellMargins -> {{66, 0}, {8, 6}}, 
          StyleKeyMapping -> {"Tab" -> "SubitemParagraph"}, 
          CellGroupingRules -> {"GroupTogetherNestedGrouping", 15000}, 
          CellFrameMargins -> {{14, 14}, {12, 12}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], 
          LineSpacing -> {1.2, 1., 2.}, MenuSortingValue -> 1600, FontFamily -> 
          "Source Sans Pro", FontSize -> 15, FontColor -> GrayLevel[0.2], 
          Background -> 
          RGBColor[
           1., 0.9647058823529412, 
            0.9411764705882353], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Note", "Printout"], CellMargins -> {{66, 0}, {10, 8}}, 
          FontSize -> 14]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Echo"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["Echo", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EchoTiming"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}], 
         Cell[
          StyleData["EchoTiming", "Printout"], 
          CellMargins -> {{99, Inherited}, {Inherited, Inherited}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Epigraph"], CellMargins -> {{100, 78}, {6, 24}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, TextAlignment -> Left, Hyphenation -> 
          True, HyphenationOptions -> {"HyphenationMinLengths" -> {3, 5}}, 
          LineSpacing -> {1, 2}, TabSpacings -> {1.2, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontWeight -> "Plain", FontSlant -> 
          "Plain"], 
         Cell[
          StyleData["Epigraph", "Printout", StyleDefinitions -> None]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EpigraphAuthor"], CellMargins -> {{125, 100}, {12, 12}}, 
          TextAlignment -> Left, LineSpacing -> {1, 2}, 
          ParagraphIndent -> -17, TabSpacings -> {1.5, 2.5}, FontFamily -> 
          "Source Sans Pro", FontSize -> 16, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontTracking -> -0.05], 
         Cell[
          StyleData["EpigraphAuthor", "Printout", StyleDefinitions -> None]]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ReferenceSection"], PageWidth :> 700, 
          CellFrame -> {{0, 0}, {0, 3}}, 
          CellMargins -> {{64, Inherited}, {8, 30}}, 
          CellGroupingRules -> {"SectionGrouping", 60}, PageBreakBelow -> 
          False, CellFrameMargins -> {{8, 8}, {4, 6}}, CellFrameColor -> 
          RGBColor[0.901961, 0.411765, 0.027451], FontFamily -> 
          "Source Sans Pro", FontSize -> 18, FontSlant -> "Italic", FontColor -> 
          RGBColor[
           0.9019607843137255, 0.4117647058823529, 0.027450980392156862`], 
          GridBoxOptions -> {GridBoxAlignment -> {}}], 
         Cell[
          StyleData["ReferenceSection", "Printout"], 
          CellMargins -> {{64, Inherited}, {8, 30}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Reference"], CellDingbat -> Cell[
            TextData[{
              CounterBox["Reference"]}], "SR", FontSize -> 13, 
            CellSize -> {30, Inherited}, TextAlignment -> Right], 
          CellMargins -> {{80, 10}, {3, 4}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, 
          CellFrameLabelMargins -> 8, 
          CellChangeTimes -> {{3.7385995432110577`*^9, 3.738599549834622*^9}},
           LineSpacing -> {1, 2}, ParagraphIndent -> -8, 
          TabSpacings -> {0.7, 2.5}, CounterIncrements -> "Reference", 
          MenuSortingValue -> 1870, FontFamily -> "Source Sans Pro", FontSize -> 
          14, FontWeight -> "Plain", FontSlant -> "Plain"], 
         Cell[
          StyleData["Reference", "Printout", StyleDefinitions -> None], 
          CellMargins -> {{66, 10}, {3, 4}}, TabSpacings -> {1.2, 2.5}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["TextFirst"], CellMargins -> {{66, 10}, {4, 72}}, 
          FontFamily -> "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"], CellMargins -> {{66, 10}, {7, 7}}]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Text"], CellMargins -> {{66, 10}, {4, 12}}, FontFamily -> 
          "Baskerville", FontSize -> 18, FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["Text", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["SmallText"], CellMargins -> {{66, 10}, {6, 6}}, 
          LineSpacing -> {1, 3}, TabSpacings -> {2.5}, LanguageCategory -> 
          "NaturalLanguage", CounterIncrements -> "SmallText", 
          MenuSortingValue -> 1750, StyleMenuListing -> None, FontFamily -> 
          "Source Sans Pro", FontSize -> 14, FontColor -> GrayLevel[0.2]], 
         Cell[
          StyleData["SmallText", "Printout"], 
          CellMargins -> {{66, 10}, {7, 7}}, Hyphenation -> True]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesText"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Plain", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesText", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ResourcesLink"], CellMargins -> {{66, 10}, {2, 0}}, 
          FontFamily -> "Source Sans Pro", FontSize -> 14, FontWeight -> 
          "Plain", FontSlant -> "Italic", FontColor -> 
          GrayLevel[0], $CellContext`ReturnCreatesNewCell -> True], 
         Cell[
          StyleData["ResourcesLink", "Printout"], 
          CellMargins -> {{66, 10}, {2, 0}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Input"], CellMargins -> {{99, 10}, {3, 7}}, SpanMaxSize -> 
          1, FontSize -> 15], 
         Cell[
          StyleData["Input", "Printout"], CellMargins -> {{99, 10}, {3, 7}}]},
         Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Output"], CellMargins -> {{99, 10}, {14, 7}}, FontSize -> 
          15], 
         Cell[
          StyleData["Output", "Printout"], 
          CellMargins -> {{99, 10}, {14, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputOnly"], CellMargins -> {{99, 10}, {25, 10}}, 
          SpanMaxSize -> 1, MenuSortingValue -> 1500, FontSize -> 15], 
         Cell[
          StyleData["InputOnly", "Printout"], 
          CellMargins -> {{99, 10}, {15, 10}}]}, Closed]], 
      Cell[
       StyleData["InitializationCell"], Background -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CellLabel"], 
          CellLabelMargins -> {{18, Inherited}, {Inherited, Inherited}}, 
          LanguageCategory -> None, StyleMenuListing -> None, FontFamily -> 
          "Helvetica Neue", FontSize -> 9, FontWeight -> "Plain", FontSlant -> 
          "Plain", FontColor -> GrayLevel[0.5]], 
         Cell[
          StyleData["CellLabel", "Printout"], FontSize -> 8, FontColor -> 
          GrayLevel[0.5]]}, Closed]], 
      Cell[
       StyleData[
       "CellLabelExpired", StyleDefinitions -> StyleData["CellLabel"]], 
       CellLabelMargins -> 6, FontSlant -> Italic, FontTracking -> 0.4, 
       FontColor -> GrayLevel[0.6]], 
      Cell[
       StyleData["SummaryPanel"], GeneratedCell -> True, CellAutoOverwrite -> 
       True, CellChangeTimes -> {3.84753348107472*^9}, FontFamily :> 
       CurrentValue["PanelFontFamily"], FontSize :> 0.8 Inherited, FontWeight -> 
       "Plain", FontSlant -> "Plain", FontColor :> 
       CurrentValue[{"SystemColors", "DialogText"}], 
       TemplateBoxOptions -> {
        DisplayFunction -> (
          ButtonBox[#, Active -> False, Alignment -> Left, 
           Appearance -> {"Default" -> Image[CompressedData["
1:eJzNlk0KgkAUgKVatGzRAWohXqFty7ZFB1AyaWOgQXQozyIPZmCgxYBLQUQ6
gL2R/ElcBKWvgU+cQd/3ZhxnZmmdt8eRpmn+FC9b87r2PPO2m2Fl7/onx7UP
G/diO7a3ssbYOEcWyATJvyw/CFGECcNQRwIkQ3J4Eb4BrXqjDT55togdYFxd
OUs5ABj4fipllMdxnCdJ0gsqdoQOzC3FPIyGP1DtfXnbSCkLZ/ntGEDWZ7+7
xgGAPSo/Y4O5SxiDau5yAj/nrPZzTuDnlV9wMbhfCFH4Fep+cP9d1P2n9hOO
/z/MP+r/j3r9oV5/qfcf6v2X4vyB+XQenMo1sS/a5QlC6exw
               "], "Byte", ColorSpace -> "RGB", Interleaving -> True]}, 
           FrameMargins -> 7, BaseStyle -> {Deployed -> False}, 
           DefaultBaseStyle -> {"Pane", Background -> None}, BaselinePosition -> 
           Baseline]& ), Tooltip -> None}, 
       GraphicsBoxOptions -> {
        Axes -> False, 
         DefaultBaseStyle -> {"GraphicsNoFontOrMenu", CacheGraphics -> False},
          ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}, 
       Graphics3DBoxOptions -> {
        Axes -> False, DefaultBaseStyle -> {"Graphics3DNoFontOrMenu"}, 
         ImageSize -> 
         Dynamic[{
           Automatic, 
            3.5 (CurrentValue["FontCapHeight"]/AbsoluteCurrentValue[
             Magnification])}]}], 
      Cell[
       StyleData["IconizedDefaultName"], FontSize -> 12, 
       PrivateFontOptions -> {"OperatorSubstitution" -> False}, FontColor -> 
       GrayLevel[0.15]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Message"], Editable -> False, 
          CellMargins -> {{66, Inherited}, {Inherited, Inherited}}, 
          CellGroupingRules -> "OutputGrouping", TextClipboardType -> 
          "PlainText", PageBreakWithin -> False, GroupPageBreakWithin -> 
          False, GeneratedCell -> True, CellAutoOverwrite -> True, 
          ShowCellLabel -> False, DefaultFormatType -> 
          DefaultOutputFormatType, ContextMenu -> 
          FEPrivate`FrontEndResource["ContextMenus", "Output"], 
          ShowAutoStyles -> False, ShowSyntaxStyles -> False, 
          AutoStyleOptions -> {
           "StringStyle" -> None, "SyntaxErrorStyle" -> None}, 
          HyphenationOptions -> {"HyphenationCharacter" -> "\[Continuation]"},
           AutoItalicWords -> {}, AutoQuoteCharacters -> {}, 
          PasteAutoQuoteCharacters -> {}, LanguageCategory -> None, 
          FormatType -> InputForm, ShowStringCharacters -> False, 
          CounterIncrements -> "Message", MenuSortingValue -> 1600, 
          StyleMenuListing -> None, FontFamily :> 
          CurrentValue["PanelFontFamily"], FontSize -> 11, FontColor -> 
          RGBColor[0.5072, 0.16933, 0.15221], $CellContext`StripStyleOnPaste -> 
          True], 
         Cell[
          StyleData["Message", "Printout"], 
          CellMargins -> {{100, Inherited}, {Inherited, Inherited}}, 
          CellFrameLabels -> {{None, None}, {None, None}}, FontColor -> 
          GrayLevel[0]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExerciseInput", StyleDefinitions -> StyleData["Input"]], 
          CellMargins -> {{106, 10}, {4, 7}}, ShowCellLabel -> False, 
          SpanMaxSize -> 1, FontSize -> 
          14, $CellContext`GeneratedCellStyles -> {
           "Output" -> "ExerciseOutput"}], 
         Cell[
          StyleData["ExerciseInput", "Printout"], 
          CellMargins -> {{106, 10}, {4, 7}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ExerciseOutput", StyleDefinitions -> StyleData["Output"]], 
          CellMargins -> {{106, 10}, {10, 4}}, ShowCellLabel -> False, 
          FontSize -> 14], 
         Cell[
          StyleData["ExerciseOutput", "Printout"], 
          CellMargins -> {{106, 10}, {10, 4}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Picture"], CellMargins -> {{66, 10}, {10, 10}}, 
          CellGroupingRules -> "GraphicsGrouping", StyleMenuListing -> None], 
         Cell[
          StyleData["Picture", "Printout"], 
          CellMargins -> {{66, 10}, {8, 8}}]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Comment"], FontFamily -> "Verdana", FontSize -> 13, 
          FontColor -> RGBColor[0.3, 0.3, 0.2], Background -> 
          RGBColor[1, 0.9, 0.8]], 
         Cell[
          StyleData["Comment", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Suggestion"], 
          CellFrameLabels -> {{Inherited, Inherited}, {Inherited, 
             Cell[
              BoxData[
               TagBox[
                GridBox[{{
                   ButtonBox[
                   "\"  Insert  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`ReplaceWithSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    ContentPadding -> False, Appearance -> Automatic, Method -> 
                    "Queued"], 
                   ButtonBox[
                   "\"  Stet  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; DocuTools`StetSuggestion[]), 
                    Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "    ", 
                   ButtonBox[
                   "\"  Next  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindNextSuggestion[]), Evaluator -> Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], 
                   ButtonBox[
                   "\"  Previous  \"", 
                    ButtonFunction :> (Needs["DocuTools`"]; 
                    DocuTools`DocuToolsLoader[]; 
                    DocuTools`FindPreviousSuggestion[]), Evaluator -> 
                    Automatic, 
                    BaseStyle -> {FontSize -> 10, FontFamily -> "Verdana"}, 
                    Appearance -> Automatic, Method -> "Queued"], "\"\""}}, 
                 AutoDelete -> False, 
                 GridBoxItemSize -> {
                  "Columns" -> {{Automatic}}, "Rows" -> {{Automatic}}}], 
                "Grid"]], ShowStringCharacters -> False, Background -> 
              None]}}, Background -> RGBColor[1, 0.8, 0.8]], 
         Cell[
          StyleData["Suggestion", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Tentative"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[
          0.30000000000000016`, 0.6000000000000003, 0.7000000000000003], 
         "Thickness" -> 5}, Evaluatable -> False, CellFrameMargins -> 4, 
       StyleMenuListing -> None, Background -> 
       RGBColor[0.8500000000000003, 0.9500000000000003, 1]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["PrintOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.89, 0.867, 0.99], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.89, 0.867, 0.99]], 
         Cell[
          StyleData["PrintOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01], 
         Cell[
          StyleData["Tentative", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["WebOnly"], 
          CellBracketOptions -> {
           "Color" -> RGBColor[0.91, 0.92, 0.9], "Thickness" -> 5}, 
          CellFrameMargins -> 4, StyleMenuListing -> None, Background -> 
          RGBColor[0.91, 0.92, 0.86]], 
         Cell[
          StyleData["WebOnly", "Printout"], 
          CellElementSpacings -> {"CellMinHeight" -> 0.1}, CellOpen -> False, 
          CellFrameMargins -> 0, FontSize -> 0.1, Magnification -> 0.01]}, 
        Open]], 
      Cell[
       StyleData["Lockdown"], 
       CellBracketOptions -> {
        "Color" -> RGBColor[0.8, 0.5, 0.4], "Thickness" -> 3}, Evaluatable -> 
       False, StyleMenuListing -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["IndexField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["IndexField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["ExplanationField"], CellFrame -> True, CellFrameColor -> 
          GrayLevel[0.7], FontFamily -> "Verdana", FontSize -> 12], 
         Cell[
          StyleData["ExplanationField", "Invisibles"], CellFrame -> False, 
          ShowCellBracket -> False, CellOpen -> False, FontSize -> 1]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["EnglishHighlight"], FontFamily -> "WolframCodeSans"], 
         Cell[
          StyleData["EnglishHighlight", "Printout"]]}, Closed]]}, Closed]], 
   Cell[
    CellGroupData[{
      Cell[
      "Inline and special formatting", "Section", 
       CellChangeTimes -> {{3.646681732592888*^9, 3.646681749414035*^9}}], 
      Cell[
       StyleData["Graphics"], MenuSortingValue -> None], 
      Cell[
       StyleData["Graphics3D"], MenuSortingValue -> None], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["StandardForm"], LineSpacing -> {1.25, 0, 2}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["StandardForm", "Printout"], LineSpacing -> {1.25, 0, 2}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["OutputForm"], LineSpacing -> {0.6, 1}, FontFamily -> 
          "Source Sans Code"], 
         Cell[
          StyleData["OutputForm", "Printout"], LineSpacing -> {0.6, 1}, 
          FontFamily -> "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["InputForm"], FontFamily -> "Source Sans Code"], 
         Cell[
          StyleData["InputForm", "Printout"], FontFamily -> 
          "Source Sans Code"]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FormattedFunction"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]]], 
         Cell[
          StyleData["FormattedFunction", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Link"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["Link", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["DetailsLink"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0], 
          ButtonBoxOptions -> {
           ButtonFunction :> (
             Function[$CellContext`t, 
              NotebookFind[$CellContext`t, "Notes", All, CellStyle]; 
              NotebookFind[$CellContext`t, "NotesSection", All, CellStyle, 
                AutoScroll -> Top]][
              Documentation`HelpLookup["ref/" <> #]]& ), ButtonSource -> 
            ButtonContents, Evaluator -> Automatic}], 
         Cell[
          StyleData["DetailsLink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["LinkAlt"], FontFamily -> "Source Sans Pro", FontSize :> 
          If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["LinkAlt", "Printout"], FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Hyperlink"], MenuSortingValue -> None, FontColor -> 
          RGBColor[0.3, 0.35, 0.5]], 
         Cell[
          StyleData["Hyperlink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["FunctionLink", StyleDefinitions -> StyleData["Link"]], 
          FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["FunctionLink", "Printout"]]}, Closed]], 
      Cell[
       StyleData["FunctionHyperlink", StyleDefinitions -> StyleData["Link"]], 
       FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData[
          "ResourceFunctionlink", StyleDefinitions -> StyleData["Hyperlink"]],
           MenuSortingValue -> None, FontFamily -> "Source Sans Pro", 
          FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.9]], FontColor -> GrayLevel[0]], 
         Cell[
          StyleData["ResourceFunctionlink", "Printout"], FontFamily -> 
          "Source Sans Pro", FontSize :> If[CurrentValue[
              EvaluationCell[], "FontFamily"] === "Source Sans Pro", 
            Inherited, 
            If[CurrentValue[
               EvaluationCell[], "FontFamily"] === "WolframCodeSans", 
             Inherited, Inherited 0.88]], FontColor -> GrayLevel[0]]}, 
        Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["Crosslink"], 
          ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
               
               NotebookLocate[#2, "OpenInNewWindow" -> 
                CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None,
             Method -> "Queued"}], 
         Cell[
          StyleData["Crosslink", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeLink"], 
          ButtonBoxOptions -> {
           Appearance -> None, ButtonFunction :> (Documentation`HelpLookup[
              Part[#, 1]]& ), ButtonSource -> ButtonContents, Evaluator -> 
            Automatic}], 
         Cell[
          StyleData["CodeLink", "Printout"]]}, Closed]], 
      Cell[
       StyleData["VocabularyLink"], FontColor -> GrayLevel[0], 
       ButtonBoxOptions -> {ButtonFunction :> (FrontEndExecute[{
            
            NotebookLocate[#2, "OpenInNewWindow" -> 
             CurrentValue["HyperlinkModifierKey"]]}]& ), Evaluator -> None, 
         Method -> "Queued"}], 
      Cell[
       StyleData["InlineMath"], SpanMaxSize -> 0, FontColor -> GrayLevel[0], 
       CellID -> 644119144], 
      Cell[
       StyleData["InlineCode"], SpanMaxSize -> 0, FontColor -> GrayLevel[0]], 
      Cell[
       StyleData["InlineCodeText"], SpanMaxSize -> 0, FontFamily -> 
       "Source Sans Pro", FontSize -> 0.94 Inherited], 
      Cell[
       StyleData["NoLabel"], ShowCellLabel -> 
       False, $CellContext`GeneratedCellStyles -> {
        "Output" -> "ExerciseOutput"}], 
      Cell[
       StyleData["MenuName"], FontFamily -> "Verdana", FontWeight -> "Bold", 
       FontColor -> GrayLevel[0.286275]], 
      Cell[
       StyleData["DialogElementName"], 
       CellChangeTimes -> {3.642251807158844*^9, 3.8358753610849867`*^9, 
        3.835875471581566*^9}, FontFamily -> "Source Sans Pro SemiBold", 
       FontSize -> 0.95 Inherited, FontWeight -> "Regular"], 
      Cell[
       StyleData["KeyEvent"], CellFrame -> {{0.5, 0.5}, {0.5, 0.5}}, 
       CellFrameMargins -> {{2, 2}, {2, 2}}, CellFrameColor -> GrayLevel[0.7],
        FontFamily -> "Verdana", FontColor -> GrayLevel[0.4]], 
      Cell[
       StyleData["KeyEventDelimiter"], FontColor -> GrayLevel[0.5]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariable"], FontFamily -> "Times", FontSize -> 
          1.05 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariable", "Printout"]]}, Closed]], 
      Cell[
       CellGroupData[{
         Cell[
          StyleData["CodeVariableLrg"], FontFamily -> "Times", FontSize -> 
          1.1 Inherited, FontWeight -> "Plain", FontSlant -> "Italic"], 
         Cell[
          StyleData["CodeVariableLrg", "Printout"]]}, Closed]], 
      Cell["Key Styles", "Subsubsection"], 
      Cell[
       StyleData["Key0"], TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
           TagBox[
            GridBox[{{
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                False]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
             False, GridBoxDividers -> {"Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}}, 
             BaselinePosition -> {{1, 1}, Baseline}], "Grid"], RoundingRadius -> 
           4, Background -> GrayLevel[0.9333333333333333], 
           FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
             GrayLevel[0.8352941176470589], 
             AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
           StripOnInput -> False]& )}], 
      Cell[
       StyleData["Key1"], TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
           TagBox[
            GridBox[{{
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                False]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
             False, GridBoxDividers -> {
              "ColumnsIndexed" -> {2 -> GrayLevel[0.8352941176470589]}, 
               "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}}, 
             BaselinePosition -> {{1, 1}, Baseline}], "Grid"], RoundingRadius -> 
           4, Background -> GrayLevel[0.9333333333333333], 
           FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
             GrayLevel[0.8352941176470589], 
             AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
           StripOnInput -> False]& )}], 
      Cell[
       StyleData["Key2"], TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
           TagBox[
            GridBox[{{
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                False]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
             False, GridBoxDividers -> {
              "ColumnsIndexed" -> {
                2 -> GrayLevel[0.8352941176470589], 3 -> 
                 GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}}, 
             BaselinePosition -> {{1, 1}, Baseline}], "Grid"], RoundingRadius -> 
           4, Background -> GrayLevel[0.9333333333333333], 
           FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
             GrayLevel[0.8352941176470589], 
             AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
           StripOnInput -> False]& )}], 
      Cell[
       StyleData["Key3"], TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
           TagBox[
            GridBox[{{
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #2, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #3, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[0.9333333333333333], 
                StripOnInput -> False], 
               ItemBox[
                
                TemplateBox[{"\[ThickSpace]", #4, "\[ThickSpace]"}, 
                 "RowDefault"], Background -> GrayLevel[1], StripOnInput -> 
                False]}}, 
             GridBoxAlignment -> {
              "Columns" -> {{Center}}, "Rows" -> {{Baseline}}}, AutoDelete -> 
             False, GridBoxDividers -> {
              "ColumnsIndexed" -> {
                2 -> GrayLevel[0.8352941176470589], 3 -> 
                 GrayLevel[0.8352941176470589], 4 -> 
                 GrayLevel[0.8352941176470589]}, "Rows" -> {{None}}}, 
             GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{1.45}}}, 
             GridBoxSpacings -> {"Columns" -> {{0}}}, 
             BaselinePosition -> {{1, 1}, Baseline}], "Grid"], RoundingRadius -> 
           4, Background -> GrayLevel[0.9333333333333333], 
           FrameMargins -> {{0, 0}, {-1, -1}}, FrameStyle -> {
             GrayLevel[0.8352941176470589], 
             AbsoluteThickness[1]}, BaselinePosition -> Baseline, 
           StripOnInput -> False]& )}], 
      Cell["Entity styles", "Subsubsection"], 
      Cell[
       StyleData["Entity"], ContextMenu -> 
       FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
       AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
       ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           FrameBox[
            PaneSelectorBox[{True -> GridBox[{{
                  
                  StyleBox[#, FontSize -> 0.85 Inherited, FontColor -> 
                   RGBColor[0.395437, 0.20595, 0.061158]], 
                  PaneBox[
                   StyleBox[#4, "EntityTypeLabel"], BaselinePosition -> 
                   Baseline, ContentPadding -> False]}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.5}}, "Rows" -> {{0}}}, 
                BaselinePosition -> {1, 1}], False -> 
              PaneBox[#, 
                BaseStyle -> {
                 FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
                BaselinePosition -> Baseline]}, 
             Dynamic[
              CurrentValue[Evaluatable]], ImageSize -> Automatic, 
             BaselinePosition -> Baseline, 
             BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
            Directive[
              RGBColor[1., 0.504768, 0.], 
              AbsoluteThickness[1]], Background -> 
            RGBColor[1., 0.980392, 0.921569], 
            FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
            ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline, 
            RoundingRadius -> 4, BaseStyle -> {FontFamily -> "Courier"}], #3, 
           BaseStyle -> {
            ShowStringCharacters -> False, LineIndent -> 0, 
             PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
           TooltipDelay -> 0.4]& ), Editable -> False, 
         InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityFrameless"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           PaneSelectorBox[{True -> GridBox[{{
                 
                 StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]], 
                 StyleBox[
                  RowBox[{"(", #4, ")"}], FontFamily -> "Source Sans Pro", 
                  FontWeight -> "Plain", FontColor -> GrayLevel[0.65], 
                  Selectable -> False]}}, 
               GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
               BaselinePosition -> {1, 1}], False -> 
             PaneBox[#, 
               BaseStyle -> {
                FontColor -> RGBColor[0.395437, 0.20595, 0.061158]}, 
               BaselinePosition -> Baseline]}, 
            Dynamic[
             CurrentValue[Evaluatable]], ImageSize -> Automatic, 
            BaselinePosition -> Baseline, 
            BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
           BaseStyle -> {
            ShowStringCharacters -> False, LineIndent -> 0, 
             PrivateFontOptions -> {
              FontWeight -> "Plain", "OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityFramelessHot"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {
        DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                
                StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                 "Source Sans Pro", FontColor -> GrayLevel[0]], 
                StyleBox[
                 RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                 "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                 False]}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
              BaselinePosition -> {1, 1}], False -> 
            PaneBox[#, BaseStyle -> {FontColor -> GrayLevel[0]}, 
              BaselinePosition -> Baseline]}, 
           Dynamic[
            CurrentValue[Evaluatable]], ImageSize -> Automatic, 
           BaselinePosition -> Baseline, 
           BaseStyle -> {
            FontWeight -> "Plain", FontFamily -> "Helvetica", 
             ShowStringCharacters -> False, LineIndent -> 0, 
             PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityClass"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           FrameBox[
            PaneSelectorBox[{True -> GridBox[{{
                  PaneBox[
                   DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                   BaselinePosition -> Bottom], 
                  
                  StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                   "Source Sans Pro", FontColor -> 
                   RGBColor[0.395437, 0.20595, 0.061158]], 
                  StyleBox[
                   RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                   "Source Sans Pro", FontColor -> GrayLevel[0.65], 
                   Selectable -> False]}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                BaselinePosition -> {1, 2}], False -> GridBox[{{
                  PaneBox[
                   DynamicBox[
                    FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                   BaselinePosition -> Bottom], 
                  
                  StyleBox[#, FontColor -> 
                   RGBColor[0.395437, 0.20595, 0.061158]]}}, 
                GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
                GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
                BaselinePosition -> {1, 2}]}, 
             Dynamic[
              CurrentValue[Evaluatable]], ImageSize -> Automatic, 
             BaselinePosition -> Baseline, 
             BaseStyle -> {FontFamily -> "Helvetica"}], FrameStyle -> 
            RGBColor[1., 0.504768, 0.], Background -> 
            RGBColor[1., 0.980392, 0.921569], 
            FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
            ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline, 
            RoundingRadius -> 4], #3, 
           BaseStyle -> {
            FontWeight -> "Plain", ShowStringCharacters -> False, LineIndent -> 
             0, PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityClassFrameless"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           PaneSelectorBox[{True -> GridBox[{{
                 PaneBox[
                  DynamicBox[
                   FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                  BaselinePosition -> Bottom], 
                 
                 StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                  "Source Sans Pro", FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]], 
                 StyleBox[
                  RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                  "Source Sans Pro", FontColor -> GrayLevel[0.65], Selectable -> 
                  False]}}, 
               GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
               BaselinePosition -> {1, 2}], False -> GridBox[{{
                 PaneBox[
                  DynamicBox[
                   FEPrivate`ImportImage[
                    
                    FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                  BaselinePosition -> Bottom], 
                 
                 StyleBox[#, FontColor -> 
                  RGBColor[0.395437, 0.20595, 0.061158]]}}, 
               GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
               GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
               BaselinePosition -> {1, 2}]}, 
            Dynamic[
             CurrentValue[Evaluatable]], ImageSize -> Automatic, 
            BaselinePosition -> Baseline, 
            BaseStyle -> {FontFamily -> "Helvetica"}], #3, 
           BaseStyle -> {
            FontWeight -> "Plain", ShowStringCharacters -> False, LineIndent -> 
             0, PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityClassFramelessHot"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {
        DisplayFunction -> (PaneSelectorBox[{True -> GridBox[{{
                PaneBox[
                 DynamicBox[
                  FEPrivate`ImportImage[
                   
                   FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                 BaselinePosition -> Bottom], 
                
                StyleBox[#, FontWeight -> "Bold", FontFamily -> 
                 "Source Sans Pro", FontColor -> GrayLevel[0]], 
                StyleBox[
                 RowBox[{"(", #4, ")"}], FontWeight -> "Plain", FontFamily -> 
                 "Source Sans Pro", FontColor -> GrayLevel[0], Selectable -> 
                 False]}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
              BaselinePosition -> {1, 2}], False -> GridBox[{{
                PaneBox[
                 DynamicBox[
                  FEPrivate`ImportImage[
                   
                   FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                 BaselinePosition -> Bottom], 
                StyleBox[#, FontColor -> GrayLevel[0]]}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
              BaselinePosition -> {1, 2}]}, 
           Dynamic[
            CurrentValue[Evaluatable]], ImageSize -> Automatic, 
           BaselinePosition -> Baseline, 
           BaseStyle -> {
            FontWeight -> "Plain", FontFamily -> "Helvetica", 
             ShowStringCharacters -> False, LineIndent -> 0, 
             PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityProperty"], ContextMenu -> 
       FEPrivate`FrontEndResource["ContextMenus", "Entity"], 
       AutoStyleOptions -> {"HighlightSyntaxErrors" -> False}, 
       ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           FrameBox[
            
            PaneBox[#, 
             BaseStyle -> {
              FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
               "Helvetica", FontSize -> 0.85 Inherited, FontColor -> 
               RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
             Baseline], FrameStyle -> Directive[
              RGBColor[0.94227, 0.703639, 0.033387], 
              AbsoluteThickness[1]], Background -> 
            RGBColor[1., 0.980392, 0.921569], 
            FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
            ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline, 
            RoundingRadius -> 4, BaseStyle -> {FontFamily -> "Courier"}], #3, 
           BaseStyle -> {
            ShowStringCharacters -> False, LineIndent -> 0, 
             PrivateFontOptions -> {"OperatorSubstitution" -> False}}, 
           TooltipDelay -> 0.4]& ), Editable -> False, 
         InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityPropertyClass"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (TooltipBox[
           FrameBox[
            PaneBox[
             GridBox[{{
                PaneBox[
                 DynamicBox[
                  FEPrivate`ImportImage[
                   
                   FrontEnd`ToFileName[{"Typeset", "Entity"}, 
                    "EntityClass.png"]], ImageSizeCache -> {8., {2., 6.}}], 
                 BaselinePosition -> Bottom], #}}, 
              GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
              GridBoxSpacings -> {"Columns" -> {{0.2}}, "Rows" -> {{0}}}, 
              BaselinePosition -> {1, 2}], 
             BaseStyle -> {
              FontSlant -> Italic, FontWeight -> Plain, FontFamily -> 
               "Source Sans Pro", FontColor -> 
               RGBColor[0.395437, 0.20595, 0.061158]}, BaselinePosition -> 
             Baseline], FrameStyle -> RGBColor[0.94227, 0.703639, 0.033387], 
            Background -> RGBColor[1., 0.980392, 0.921569], 
            FrameMargins -> {{5, 5}, {1.5, 1.5}}, 
            ImageMargins -> {{2, 2}, {2, 2}}, BaselinePosition -> Baseline, 
            RoundingRadius -> 4], #3, 
           BaseStyle -> {
            FontWeight -> "Plain", ShowStringCharacters -> False, LineIndent -> 
             0, PrivateFontOptions -> {"OperatorSubstitution" -> False}}]& ), 
         Editable -> False, InterpretationFunction -> (#2& )}], 
      Cell[
       StyleData["EntityValue"], ShowStringCharacters -> False, 
       TemplateBoxOptions -> {DisplayFunction -> (FrameBox[
           
           GridBox[{{#, #2}}, GridBoxAlignment -> {"Rows" -> {{Baseline}}}, 
            GridBoxItemSize -> {"Columns" -> {{All}}, "Rows" -> {{All}}}, 
            GridBoxSpacings -> {"Columns" -> {{0}}}, 
            BaselinePosition -> {1, 1}], Background -> 
           RGBColor[{0.9921568627450981, 0.9529411764705882, 
             0.8509803921568627}], BaselinePosition -> Baseline, 
           FrameMargins -> {{1, 1}, {1, 1}}, ImageMargins -> 2, FrameStyle -> 
           RGBColor[{0.9333333333333333, 0.8470588235294118, 
             0.5529411764705883}], RoundingRadius -> 5]& )}]}, Closed]]}, 
  Visible -> False, FrontEndVersion -> 
  "13.3 for Mac OS X x86 (64-bit) (June 3, 2023)", StyleDefinitions -> 
  "PrivateStylesheetFormatting.nb"],
ExpressionUUID->"22779b43-bb6d-42cf-a1d4-c453c7355b44"
]
(* End of Notebook Content *)

(* Internal cache information *)
(*CellTagsOutline
CellTagsIndex->{
 "p: 15"->{
  Cell[627, 23, 339, 9, 110, "Section",ExpressionUUID->"5fb1942b-26df-4888-9847-67421344e9aa",
   CounterAssignments->{{"Section", 1}},
   CellTags->"p: 15",
   CellID->702470296]},
 "i:1"->{
  Cell[969, 34, 2353, 42, 263, "Text",ExpressionUUID->"a50ed8a8-4753-44ea-9496-1ae1d2a3f708",
   CellTags->"i:1",
   CellID->426547642]},
 "LastCellOfAPage"->{
  Cell[25557, 525, 1081, 18, 213, "Text",ExpressionUUID->"1dbeb66a-dfaa-42c0-8ab4-97b941c27ddf",
   CellTags->{"LastCellOfAPage", "i:2", "p: 16"},
   CellID->685805408],
  Cell[38147, 797, 2696, 46, 213, "Text",ExpressionUUID->"a3f2149e-424c-40cf-89de-5f7013756d48",
   CellTags->{"LastCellOfAPage", "i:5"},
   CellID->590421032],
  Cell[53980, 1165, 1097, 20, 113, "Text",ExpressionUUID->"ea725a32-3aa8-42b2-8c2a-fb56e97fa64e",
   CellTags->"LastCellOfAPage",
   CellID->276342406],
  Cell[70618, 1581, 932, 17, 88, "Text",ExpressionUUID->"adc9c446-ac64-481c-ae7f-749221b317a3",
   CellTags->{"LastCellOfAPage", "i:10"},
   CellID->932131830],
  Cell[83144, 1894, 560, 12, 37, "Output",ExpressionUUID->"85384623-4d2f-4b75-b6b9-a738f1b307ce",
   CellTags->"LastCellOfAPage",
   CellID->1134670365],
  Cell[94149, 2182, 758, 12, 213, "Text",ExpressionUUID->"6a1c8591-a8ff-40d5-96a4-b8ae67d10d23",
   CellTags->{"LastCellOfAPage", "i:16"},
   CellID->643009229],
  Cell[104079, 2410, 361, 6, 37, "Output",ExpressionUUID->"12b4b5b4-5ef7-45a4-b62f-91367f9d69e0",
   CellTags->"LastCellOfAPage",
   CellID->1082927782],
  Cell[113435, 2643, 446, 10, 45, "Output",ExpressionUUID->"01c3ca49-2fc2-4c3d-b6e7-6cda74aa0449",
   CellTags->"LastCellOfAPage",
   CellID->2088562438],
  Cell[124384, 2922, 959, 17, 114, "Text",ExpressionUUID->"09fca2cb-88e7-4ceb-add8-476a98b0982a",
   CellTags->{"LastCellOfAPage", "i:26"},
   CellID->872447341],
  Cell[134832, 3178, 1970, 47, 113, "Text",ExpressionUUID->"3df484e1-6d58-4182-af4b-857dfadd946a",
   CellTags->{"LastCellOfAPage", "i:30"},
   CellID->592772282],
  Cell[149894, 3573, 541, 12, 37, "Output",ExpressionUUID->"39d1caf2-4331-4fcb-8834-e957b96b7d2c",
   CellTags->"LastCellOfAPage",
   CellID->1910323796],
  Cell[174061, 4188, 1074, 24, 38, "Text",ExpressionUUID->"995b208a-cab2-48c0-a1c6-856cd7b92b2f",
   CellTags->{"LastCellOfAPage", "i:37"},
   CellID->764986273],
  Cell[228923, 5388, 2174, 49, 163, "Text",ExpressionUUID->"e960addd-9b6d-4178-afe7-e5f68876d769",
   CellTags->{"LastCellOfAPage", "i:40"},
   CellID->1008574251],
  Cell[246565, 5835, 2540, 61, 88, "Text",ExpressionUUID->"d147055a-0010-49de-81e0-5ad268e097ba",
   CellTags->"LastCellOfAPage",
   CellID->1498922560],
  Cell[263079, 6257, 999, 21, 63, "Text",ExpressionUUID->"9098402d-b8dd-4816-b906-fa5d0340e837",
   CellTags->"LastCellOfAPage",
   CellID->1592898165],
  Cell[282850, 6779, 15649, 393, 287, "Output",ExpressionUUID->"e2a76795-7c93-4a1f-88f9-eea89d71f0e3",
   CellTags->"LastCellOfAPage",
   CellID->890892849],
  Cell[334838, 8097, 882, 26, 114, "Output",ExpressionUUID->"1d631abd-a1c5-4e00-bdd8-d716d98544ff",
   CellTags->"LastCellOfAPage",
   CellID->311315197],
  Cell[346824, 8424, 1261, 30, 63, "Text",ExpressionUUID->"75ce24a0-fc8c-4d9f-b8e3-08d0cb19a5d2",
   CellTags->"LastCellOfAPage",
   CellID->1535474437],
  Cell[371297, 9054, 504, 12, 37, "Output",ExpressionUUID->"5971dc72-abbc-401f-b43d-5920a4dc6949",
   CellTags->"LastCellOfAPage",
   CellID->422790878],
  Cell[384244, 9392, 2314, 49, 163, "Text",ExpressionUUID->"39590882-a79d-418f-885c-eb6aa32fad5d",
   CellTags->"LastCellOfAPage",
   CellID->606608944],
  Cell[402622, 9866, 1198, 38, 57, "Output",ExpressionUUID->"73ca8356-28d5-4fad-9bfb-334a13602a28",
   CellTags->"LastCellOfAPage",
   CellID->97357396],
  Cell[414175, 10169, 575, 13, 38, "Text",ExpressionUUID->"eeda2d21-6b06-4f43-978d-f0509742ff16",
   CellTags->"LastCellOfAPage",
   CellID->1260116051],
  Cell[427249, 10513, 6008, 158, 302, "Output",ExpressionUUID->"b29e7876-7953-4758-b14e-192ebe6ae75e",
   CellTags->"LastCellOfAPage",
   CellID->1232306257],
  Cell[463978, 11468, 2425, 63, 63, "Text",ExpressionUUID->"ca19dbc3-1bc9-42ba-9b78-e908f873596c",
   CellTags->"LastCellOfAPage",
   CellID->684075409],
  Cell[478650, 11852, 2824, 60, 138, "Text",ExpressionUUID->"dfdbdc8d-f178-4703-8a31-feed756d9a21",
   CellTags->{"LastCellOfAPage", "i:58"},
   CellID->382985419],
  Cell[492740, 12214, 536, 12, 38, "Text",ExpressionUUID->"1c3bfab2-eb9a-4d15-9f5f-1bb440065010",
   CellTags->"LastCellOfAPage",
   CellID->1274898801],
  Cell[507908, 12614, 1209, 28, 63, "Text",ExpressionUUID->"7a8f1bbc-14c3-47b9-ba0b-2145f07bdc4e",
   CellTags->"LastCellOfAPage",
   CellID->1650910852],
  Cell[523393, 13028, 2578, 70, 114, "Output",ExpressionUUID->"325b814e-35be-4212-b9f9-c9d3e1f43e72",
   CellTags->"LastCellOfAPage",
   CellID->1683184762],
  Cell[541086, 13473, 3767, 88, 1299, "Text",ExpressionUUID->"d3da8d07-5627-4657-a338-310452796ea8",
   CellTags->{"LastCellOfAPage", "i:65", "p: 44"},
   CellID->1190543782],
  Cell[564178, 14083, 988, 20, 63, "Text",ExpressionUUID->"5570ec7e-3c57-4fab-9531-43f4cd37460f",
   CellTags->{"LastCellOfAPage", "i:67"},
   CellID->747614211],
  Cell[581463, 14552, 2462, 56, 113, "Text",ExpressionUUID->"bed66ccf-688d-4262-8778-024328c09e39",
   CellTags->"LastCellOfAPage",
   CellID->1350776468],
  Cell[612771, 15211, 2929, 66, 138, "Text",ExpressionUUID->"87f2ba43-969f-4ff7-bf1c-c5cb0bd09bf3",
   CellTags->{"LastCellOfAPage", "i:69"},
   CellID->121026861],
  Cell[642324, 15937, 815, 15, 63, "Text",ExpressionUUID->"3e68f07e-3f08-417e-aff9-ba694376b8ee",
   CellTags->{"LastCellOfAPage", "i:72"},
   CellID->1536241901],
  Cell[655348, 16277, 426, 8, 38, "Text",ExpressionUUID->"656c0d9f-7c7f-46d0-982f-3b3209acac89",
   CellTags->{"LastCellOfAPage", "i:74"},
   CellID->1847183370],
  Cell[670994, 16681, 36696, 641, 335, "Output",ExpressionUUID->"e597848a-580f-4d3e-9eaf-c427e79ac277",
   CellTags->"LastCellOfAPage",
   CellID->990161061],
  Cell[730070, 17894, 1194, 32, 57, "Output",ExpressionUUID->"68cc9deb-2f39-4e5e-8467-1ba32ce2baec",
   CellTags->"LastCellOfAPage",
   CellID->2011476000],
  Cell[744037, 18252, 6951, 199, 177, "Output",ExpressionUUID->"9a0f9848-20d8-4a89-8314-eefe242056d5",
   CellTags->"LastCellOfAPage",
   CellID->1745520635],
  Cell[782075, 19252, 325, 5, 38, "Text",ExpressionUUID->"0bd6a873-645e-4b2d-bde4-e97fe67d64bb",
   CellTags->"LastCellOfAPage",
   CellID->1136515825],
  Cell[800275, 19697, 17270, 444, 293, "Output",ExpressionUUID->"1f5eec67-fafe-4b51-acb1-0ce615928afa",
   CellTags->"LastCellOfAPage",
   CellID->159701592],
  Cell[836962, 20628, 6750, 191, 177, "Output",ExpressionUUID->"f3931303-cda1-4eb7-a13d-6641f78dacad",
   CellTags->"LastCellOfAPage",
   CellID->970630517],
  Cell[854533, 21102, 540, 14, 38, "Text",ExpressionUUID->"77d52c6b-7dee-4d98-aa25-dea516de28ec",
   CellTags->"LastCellOfAPage",
   CellID->71094693],
  Cell[881486, 21821, 484, 9, 37, "Output",ExpressionUUID->"4745ea4e-49e3-4b7d-80a9-7f6572f37fc7",
   CellTags->"LastCellOfAPage",
   CellID->311509173],
  Cell[919201, 22732, 1788, 44, 88, "Text",ExpressionUUID->"66544aab-47db-48e7-9f8b-7765f6051e18",
   CellTags->"LastCellOfAPage",
   CellID->948824146],
  Cell[960038, 23758, 599, 14, 38, "Text",ExpressionUUID->"021f1402-90ca-430e-b65f-c081f816739c",
   CellTags->{"LastCellOfAPage", "i:83"},
   CellID->38294597],
  Cell[979297, 24311, 1697, 33, 188, "Text",ExpressionUUID->"c182b241-0ebe-46d5-86eb-178c94fe0838",
   CellTags->"LastCellOfAPage",
   CellID->1458935525],
  Cell[995391, 24708, 996, 22, 46, "Exercise",ExpressionUUID->"20ac2b81-8b67-44fe-ab01-17ec9e8c0175",
   CellTags->{"Exercise", "LastCellOfAPage"},
   CellID->205547354],
  Cell[1053544, 26183, 7748, 192, 34, "ExerciseOutput",ExpressionUUID->"c4dacfcc-9a02-4a6a-9ab0-2a216a226adf",
   CellTags->"LastCellOfAPage",
   CellID->1686671003],
  Cell[1122652, 27856, 1395, 35, 102, "TechNote",ExpressionUUID->"f08f8d43-1854-4305-92bb-fc65bcca3305",
   CellTags->{"LastCellOfAPage", "i:87"},
   CellID->2128183295],
  Cell[1131107, 28099, 2554, 71, 55, "TechNote",ExpressionUUID->"3804d0ae-4cc0-4700-baf5-555a1c4618d3",
   CellTags->"LastCellOfAPage",
   CellID->1088437716]},
 "i:2"->{
  Cell[25557, 525, 1081, 18, 213, "Text",ExpressionUUID->"1dbeb66a-dfaa-42c0-8ab4-97b941c27ddf",
   CellTags->{"LastCellOfAPage", "i:2", "p: 16"},
   CellID->685805408]},
 "p: 16"->{
  Cell[25557, 525, 1081, 18, 213, "Text",ExpressionUUID->"1dbeb66a-dfaa-42c0-8ab4-97b941c27ddf",
   CellTags->{"LastCellOfAPage", "i:2", "p: 16"},
   CellID->685805408]},
 "i:3"->{
  Cell[26641, 545, 2435, 47, 218, "Text",ExpressionUUID->"504d9dd4-055f-4d04-a729-57c38f1c52ca",
   CellTags->"i:3",
   CellID->786758807]},
 "i:4"->{
  Cell[33291, 690, 989, 15, 138, "Text",ExpressionUUID->"44f277d6-bdfb-4562-a481-145dd1f55423",
   CellTags->"i:4",
   CellID->1393188976]},
 "i:5"->{
  Cell[38147, 797, 2696, 46, 213, "Text",ExpressionUUID->"a3f2149e-424c-40cf-89de-5f7013756d48",
   CellTags->{"LastCellOfAPage", "i:5"},
   CellID->590421032]},
 "p: 17"->{
  Cell[40846, 845, 1025, 16, 37, "CodeCaption",ExpressionUUID->"77cec30f-065c-4b2c-8f01-c09c8686e77a",
   CellTags->"p: 17",
   CellID->889805339]},
 "i:6"->{
  Cell[42939, 892, 2942, 60, 213, "Text",ExpressionUUID->"00ebf5bb-a424-47e2-b99e-99e828abdbcf",
   CellTags->"i:6",
   CellID->1372229709]},
 "i:7"->{
  Cell[47104, 990, 1180, 23, 113, "Text",ExpressionUUID->"8a37c9d7-4439-4ffa-a0ef-c7575efb5c4e",
   CellTags->"i:7",
   CellID->910539663]},
 "i:8"->{
  Cell[50827, 1092, 1970, 39, 138, "Text",ExpressionUUID->"ab7f8a5d-e5ed-481c-9081-cd00896fa107",
   CellTags->"i:8",
   CellID->247141058]},
 "p: 18"->{
  Cell[55080, 1187, 538, 12, 37, "CodeCaption",ExpressionUUID->"3271066d-5989-4611-8420-122bc08663c9",
   CellTags->"p: 18",
   CellID->2041117656]},
 "i:9"->{
  Cell[57232, 1241, 950, 18, 88, "Text",ExpressionUUID->"7a578177-bcf0-4713-871b-aedcc4111c0d",
   CellTags->"i:9",
   CellID->1836959298]},
 "i:10"->{
  Cell[70618, 1581, 932, 17, 88, "Text",ExpressionUUID->"adc9c446-ac64-481c-ae7f-749221b317a3",
   CellTags->{"LastCellOfAPage", "i:10"},
   CellID->932131830]},
 "p: 19"->{
  Cell[71553, 1600, 259, 4, 37, "CodeCaption",ExpressionUUID->"7f73b7ec-9ca4-4277-b69d-3d0764bef296",
   CellTags->"p: 19",
   CellID->427695515]},
 "i:11"->{
  Cell[74149, 1667, 876, 19, 65, "Text",ExpressionUUID->"901883db-5cb9-4c41-8b88-a471c5708350",
   CellTags->"i:11",
   CellID->1005068699]},
 "i:12"->{
  Cell[76720, 1736, 789, 12, 138, "Text",ExpressionUUID->"a2b16fe6-44b4-4138-ae28-07ccce2bf1cf",
   CellTags->"i:12",
   CellID->1717012398]},
 "p: 20"->{
  Cell[83741, 1911, 1076, 27, 55, "Subsubsection",ExpressionUUID->"f918684b-a944-476b-aa75-a2d0ae62bf15",
   CellTags->"p: 20",
   CellID->1306406695]},
 "i:13"->{
  Cell[84820, 1940, 1174, 24, 89, "Text",ExpressionUUID->"3c6ba220-9a90-4636-b243-7ad35ad42815",
   CellTags->"i:13",
   CellID->431835590]},
 "i:14"->{
  Cell[85997, 1966, 508, 12, 37, "CodeCaption",ExpressionUUID->"d1ac31e6-3eb0-497d-a518-be2c498e98ca",
   CellTags->"i:14",
   CellID->58107445]},
 "i:15"->{
  Cell[87381, 2005, 652, 13, 37, "CodeCaption",ExpressionUUID->"8f750d26-6fec-4d73-be13-90d061e5799d",
   CellTags->"i:15",
   CellID->1378388831]},
 "i:16"->{
  Cell[94149, 2182, 758, 12, 213, "Text",ExpressionUUID->"6a1c8591-a8ff-40d5-96a4-b8ae67d10d23",
   CellTags->{"LastCellOfAPage", "i:16"},
   CellID->643009229]},
 "i:17"->{
  Cell[94910, 2196, 522, 9, 88, "Text",ExpressionUUID->"57db0482-361c-4f5a-a5e4-ea89b0842b60",
   CellTags->{"i:17", "p: 21"},
   CellID->918400099]},
 "p: 21"->{
  Cell[94910, 2196, 522, 9, 88, "Text",ExpressionUUID->"57db0482-361c-4f5a-a5e4-ea89b0842b60",
   CellTags->{"i:17", "p: 21"},
   CellID->918400099]},
 "i:18"->{
  Cell[98186, 2274, 1416, 26, 163, "Text",ExpressionUUID->"ad7dbd58-79b9-4f9a-8cf6-a7a32f36465b",
   CellTags->"i:18",
   CellID->1522233933]},
 "i:19"->{
  Cell[100987, 2335, 525, 9, 88, "Text",ExpressionUUID->"0296603f-8332-45a7-b3ab-ec9c4f60e8dc",
   CellTags->"i:19",
   CellID->860448642]},
 "i:20"->{
  Cell[102419, 2370, 999, 19, 63, "Text",ExpressionUUID->"aa99f80e-8105-4f02-b825-aaef2a52e51b",
   CellTags->"i:20",
   CellID->385411241]},
 "p: 22"->{
  Cell[104455, 2419, 1890, 33, 238, "Text",ExpressionUUID->"418f989e-cc4f-41f9-aeec-bf08c5706f74",
   CellTags->"p: 22",
   CellID->357884135]},
 "i:21"->{
  Cell[107801, 2494, 660, 14, 63, "Text",ExpressionUUID->"46ae72d4-f8c1-4792-9b5c-4766d446a26e",
   CellTags->"i:21",
   CellID->2004445345]},
 "i:22"->{
  Cell[109588, 2542, 817, 13, 113, "Text",ExpressionUUID->"4c1a606f-e31d-455c-9ac4-03579a549b31",
   CellTags->"i:22",
   CellID->290266276]},
 "i:23"->{
  Cell[113896, 2656, 1012, 16, 113, "Text",ExpressionUUID->"6edbeb82-e1e4-4d74-af10-682899d2e88b",
   CellTags->{"i:23", "p: 23"},
   CellID->2101180113]},
 "p: 23"->{
  Cell[113896, 2656, 1012, 16, 113, "Text",ExpressionUUID->"6edbeb82-e1e4-4d74-af10-682899d2e88b",
   CellTags->{"i:23", "p: 23"},
   CellID->2101180113]},
 "i:24"->{
  Cell[117830, 2752, 947, 15, 113, "Text",ExpressionUUID->"8cf48b15-ad40-46aa-8e77-45a15ab0ded9",
   CellTags->"i:24",
   CellID->232786262]},
 "i:25"->{
  Cell[119992, 2805, 1654, 34, 88, "Text",ExpressionUUID->"be4b7efb-76be-43d6-9a0a-c9477e411b7c",
   CellTags->"i:25",
   CellID->29196308]},
 "i:26"->{
  Cell[124384, 2922, 959, 17, 114, "Text",ExpressionUUID->"09fca2cb-88e7-4ceb-add8-476a98b0982a",
   CellTags->{"LastCellOfAPage", "i:26"},
   CellID->872447341]},
 "p: 24"->{
  Cell[125346, 2941, 240, 3, 37, "CodeCaption",ExpressionUUID->"90633732-7bf4-47c9-aa5b-2f4d1c166688",
   CellTags->"p: 24",
   CellID->265070891]},
 "i:27"->{
  Cell[128344, 3015, 989, 21, 68, "Text",ExpressionUUID->"e39cbd51-9a4e-4ea9-b9d5-e8ae7a6b9ae6",
   CellTags->"i:27",
   CellID->867761911]},
 "i:28"->{
  Cell[130409, 3066, 686, 16, 88, "Text",ExpressionUUID->"21fbd00c-5681-4a91-8064-a9e8c7745a8f",
   CellTags->"i:28",
   CellID->1107578992]},
 "i:29"->{
  Cell[132437, 3121, 969, 17, 113, "Text",ExpressionUUID->"4929c1e9-02a0-42c4-b12b-caba7c0a09c9",
   CellTags->"i:29",
   CellID->969184320]},
 "i:30"->{
  Cell[134832, 3178, 1970, 47, 113, "Text",ExpressionUUID->"3df484e1-6d58-4182-af4b-857dfadd946a",
   CellTags->{"LastCellOfAPage", "i:30"},
   CellID->592772282]},
 "p: 25"->{
  Cell[136805, 3227, 986, 25, 37, "CodeCaption",ExpressionUUID->"593b0635-acc4-4ae5-bd2d-aedd14481001",
   CellTags->"p: 25",
   CellID->703232801]},
 "i:31"->{
  Cell[141253, 3350, 1268, 26, 113, "Text",ExpressionUUID->"6d416926-7540-4ebc-9a0e-2dd5eb7c7894",
   CellTags->"i:31",
   CellID->1811325823]},
 "i:32"->{
  Cell[143631, 3413, 1220, 27, 88, "Text",ExpressionUUID->"ad24de9a-a73b-4ca1-a6eb-999f66413fa8",
   CellTags->"i:32",
   CellID->781727503]},
 "i:33"->{
  Cell[146505, 3486, 734, 15, 63, "Text",ExpressionUUID->"af3e74ef-95bc-42b1-9352-f3c4875a574b",
   CellTags->"i:33",
   CellID->1450196465]},
 "p: 26"->{
  Cell[150472, 3590, 203, 3, 55, "Subsubsection",ExpressionUUID->"8a05e491-2edf-4d99-bcb9-c6a58c970659",
   CellTags->"p: 26",
   CellID->2119931017]},
 "i:34"->{
  Cell[150678, 3595, 1680, 36, 88, "Text",ExpressionUUID->"47eb0d05-c63c-4cf7-9e30-d5438770ba4f",
   CellTags->"i:34",
   CellID->779415342]},
 "i:35"->{
  Cell[167727, 4020, 1453, 30, 113, "Text",ExpressionUUID->"5bb1635a-df43-4f10-9562-d93be55ff154",
   CellTags->"i:35",
   CellID->1189708234]},
 "i:36"->{
  Cell[170617, 4092, 602, 13, 63, "Text",ExpressionUUID->"2b277dad-67e3-4dce-9076-8a9a69d0cd15",
   CellTags->"i:36",
   CellID->1451164714]},
 "i:37"->{
  Cell[174061, 4188, 1074, 24, 38, "Text",ExpressionUUID->"995b208a-cab2-48c0-a1c6-856cd7b92b2f",
   CellTags->{"LastCellOfAPage", "i:37"},
   CellID->764986273]},
 "p: 27"->{
  Cell[175138, 4214, 756, 19, 37, "CodeCaption",ExpressionUUID->"633c3e5a-75d2-4635-94d0-1fb745da4b39",
   CellTags->"p: 27",
   CellID->303065152]},
 "i:38"->{
  Cell[178399, 4306, 789, 15, 88, "Text",ExpressionUUID->"9d4f7fac-6535-443d-a447-a1dd68baae4a",
   CellTags->"i:38",
   CellID->1096113171]},
 "i:39"->{
  Cell[183566, 4453, 1650, 37, 88, "Text",ExpressionUUID->"52f8ee55-f480-468f-b7bc-1c9c998520a2",
   CellTags->"i:39",
   CellID->1772517426]},
 "i:40"->{
  Cell[228923, 5388, 2174, 49, 163, "Text",ExpressionUUID->"e960addd-9b6d-4178-afe7-e5f68876d769",
   CellTags->{"LastCellOfAPage", "i:40"},
   CellID->1008574251]},
 "p: 28"->{
  Cell[231100, 5439, 500, 8, 37, "CodeCaption",ExpressionUUID->"276737a9-ae1c-4740-997c-ef0fcdf61add",
   CellTags->"p: 28",
   CellID->279242158]},
 "i:41"->{
  Cell[240257, 5679, 4534, 105, 163, "Text",ExpressionUUID->"6071cd4f-024e-4620-85ce-d038ee2cf3fa",
   CellTags->"i:41",
   CellID->1290938635]},
 "p: 29"->{
  Cell[249108, 5898, 1041, 26, 37, "CodeCaption",ExpressionUUID->"55c61946-2418-4290-bc94-fb6c0c0cc0dd",
   CellTags->"p: 29",
   CellID->184227891]},
 "i:42"->{
  Cell[251413, 5960, 1693, 37, 88, "Text",ExpressionUUID->"95e0008b-092d-46ae-acb1-21f381c9ca32",
   CellTags->"i:42",
   CellID->1660103225]},
 "i:43"->{
  Cell[255885, 6076, 2192, 50, 113, "Text",ExpressionUUID->"de0c1359-7cd5-4ae2-991a-70ffd2e25ebb",
   CellTags->"i:43",
   CellID->997560408]},
 "i:44"->{
  Cell[259481, 6172, 560, 11, 55, "Subsubsection",ExpressionUUID->"c7e9e824-c0c7-4dc5-9d04-4d370e9d8c63",
   CellTags->"i:44",
   CellID->1909995810]},
 "i:45"->{
  Cell[260044, 6185, 1029, 19, 138, "Text",ExpressionUUID->"deaabc33-1969-4c7e-9e45-7b99da9dea8e",
   CellTags->"i:45",
   CellID->553735833]},
 "p: 30"->{
  Cell[264081, 6280, 525, 13, 37, "CodeCaption",ExpressionUUID->"16a1d0a9-b162-4300-bf39-0f1b35bd20f1",
   CellTags->"p: 30",
   CellID->345461069]},
 "i:46"->{
  Cell[265377, 6317, 1493, 37, 88, "Text",ExpressionUUID->"f0e94f6c-e1e9-4c88-8017-437bd04e0d8c",
   CellTags->"i:46",
   CellID->298487107]},
 "i:47"->{
  Cell[298514, 7175, 1262, 23, 88, "Text",ExpressionUUID->"9bdc4065-d01f-4bd0-965c-f9cd09706c05",
   CellTags->{"i:47", "p: 31"},
   CellID->1091975022]},
 "p: 31"->{
  Cell[298514, 7175, 1262, 23, 88, "Text",ExpressionUUID->"9bdc4065-d01f-4bd0-965c-f9cd09706c05",
   CellTags->{"i:47", "p: 31"},
   CellID->1091975022]},
 "p: 32"->{
  Cell[335757, 8128, 413, 9, 26, "Input",ExpressionUUID->"765935a0-697e-43cf-a8c4-a6d6bcc7e6d6",
   CellTags->"p: 32",
   CellID->2138288348]},
 "i:48"->{
  Cell[337936, 8186, 1240, 24, 88, "Text",ExpressionUUID->"f9c69dbf-78e1-43c3-a7ec-40f8b2ed7ab3",
   CellTags->"i:48",
   CellID->1754054077]},
 "i:49"->{
  Cell[340430, 8247, 2448, 62, 139, "Text",ExpressionUUID->"ca7143cd-b56f-4d4d-ab84-a159a6dcb461",
   CellTags->"i:49",
   CellID->1335418946]},
 "p: 33"->{
  Cell[348088, 8456, 787, 22, 37, "CodeCaption",ExpressionUUID->"a0550e92-b927-4b7c-b2ff-08290cadd485",
   CellTags->"p: 33",
   CellID->1551121061]},
 "i:50"->{
  Cell[358898, 8731, 2473, 66, 88, "Text",ExpressionUUID->"4ae8c18b-1aa4-4e55-8f57-384dd5cb5197",
   CellTags->"i:50",
   CellID->599170125]},
 "i:51"->{
  Cell[368432, 8985, 1949, 41, 113, "Text",ExpressionUUID->"e83ebe2c-15dd-428b-ae95-65d3822bf700",
   CellTags->"i:51",
   CellID->1219127502]},
 "p: 34"->{
  Cell[371816, 9069, 711, 17, 38, "Text",ExpressionUUID->"7eb1ae1f-b3dc-45e0-8d03-1305f41f45be",
   CellTags->"p: 34",
   CellID->2123458214]},
 "i:52"->{
  Cell[380633, 9306, 3608, 84, 213, "Text",ExpressionUUID->"a8e2127c-ddce-45e4-b8e2-0560a7a2f71b",
   CellTags->"i:52",
   CellID->184130491]},
 "p: 35"->{
  Cell[386561, 9443, 1010, 26, 59, "CodeCaption",ExpressionUUID->"e72f9de7-367d-4245-bddb-05e3e3bb57eb",
   CellTags->"p: 35",
   CellID->914741257]},
 "p: 36"->{
  Cell[403835, 9907, 775, 14, 63, "Text",ExpressionUUID->"4d887762-65a9-41da-a694-45bd7e33dc6b",
   CellTags->"p: 36",
   CellID->1582731546]},
 "i:53"->{
  Cell[405143, 9936, 1141, 24, 113, "Text",ExpressionUUID->"67077beb-ebdd-44d5-92e6-8c5826cd9e5f",
   CellTags->"i:53",
   CellID->2123712673]},
 "p: 37"->{
  Cell[414753, 10184, 727, 18, 37, "CodeCaption",ExpressionUUID->"38955627-95f7-449c-beb8-73b1be55ed12",
   CellTags->"p: 37",
   CellID->87742728]},
 "i:54"->{
  Cell[419073, 10304, 1344, 25, 188, "Text",ExpressionUUID->"8bb7c308-48e4-4d5b-bf7a-7a1450b3141e",
   CellTags->"i:54",
   CellID->111233947]},
 "p: 38"->{
  Cell[433272, 10674, 2184, 51, 88, "Text",ExpressionUUID->"61de52c5-56a4-441b-bc9b-9814c1cc9841",
   CellTags->"p: 38",
   CellID->1082026607]},
 "i:55"->{
  Cell[454186, 11220, 904, 24, 59, "CodeCaption",ExpressionUUID->"11b2b7a2-b60f-42a8-9687-94f3ae4bfd9e",
   CellTags->"i:55",
   CellID->2111128489]},
 "p: 39"->{
  Cell[466440, 11536, 538, 10, 54, "Subsubsubsection",ExpressionUUID->"2a155ad8-5784-4770-bc7d-694d0f608a81",
   PageBreakAbove->True,
   CellTags->"p: 39",
   CellID->956965639]},
 "i:56"->{
  Cell[466981, 11548, 861, 19, 63, "Text",ExpressionUUID->"8cfb8c49-3427-4687-9b44-860f0324783f",
   CellTags->"i:56",
   CellID->1222765007]},
 "i:57"->{
  Cell[469317, 11613, 1010, 24, 88, "Text",ExpressionUUID->"835870e3-a8c9-4bbb-9cdc-236ec51e9d9d",
   CellTags->"i:57",
   CellID->1491901077]},
 "i:58"->{
  Cell[478650, 11852, 2824, 60, 138, "Text",ExpressionUUID->"dfdbdc8d-f178-4703-8a31-feed756d9a21",
   CellTags->{"LastCellOfAPage", "i:58"},
   CellID->382985419]},
 "p: 40"->{
  Cell[481477, 11914, 524, 13, 37, "CodeCaption",ExpressionUUID->"90dc00c9-4961-4b3f-b42a-097fd355d8b1",
   CellTags->"p: 40",
   CellID->143558437]},
 "i:59"->{
  Cell[487574, 12078, 526, 12, 63, "Text",ExpressionUUID->"992eb565-a951-4c7c-b977-3e450739ba49",
   CellTags->"i:59",
   CellID->1235558941]},
 "i:60"->{
  Cell[490062, 12149, 1573, 35, 88, "Text",ExpressionUUID->"e22260e3-7db1-413e-aa3f-df0d36a62cf9",
   CellTags->"i:60",
   CellID->1695096994]},
 "p: 41"->{
  Cell[493279, 12228, 479, 12, 37, "CodeCaption",ExpressionUUID->"00402900-fdd9-48db-af26-59351debf13d",
   CellTags->"p: 41",
   CellID->399629588]},
 "i:61"->{
  Cell[495649, 12297, 963, 25, 37, "CodeCaption",ExpressionUUID->"f9b9a923-565b-4906-9fb3-040a9f718ba5",
   CellTags->"i:61",
   CellID->175348173]},
 "i:62"->{
  Cell[500487, 12426, 2122, 45, 163, "Text",ExpressionUUID->"ce2b1d0e-b312-4310-aa52-6ae6ad541d57",
   CellTags->"i:62",
   CellID->1563893249]},
 "p: 42"->{
  Cell[509120, 12644, 336, 9, 37, "CodeCaption",ExpressionUUID->"cf5bacb6-c1b4-4de9-9408-3059f6fdfd32",
   CellTags->"p: 42",
   CellID->75047153]},
 "p: 43"->{
  Cell[525986, 13101, 1903, 40, 113, "Text",ExpressionUUID->"ea50a8e1-1e14-4182-b104-8626a1da9b94",
   CellTags->"p: 43",
   CellID->988630503]},
 "i:63"->{
  Cell[528484, 13158, 1848, 36, 163, "Text",ExpressionUUID->"9955ac2c-82ce-4bde-b456-88e5165afda7",
   CellTags->"i:63",
   CellID->874784024]},
 "i:64"->{
  Cell[535354, 13330, 1682, 34, 163, "Text",ExpressionUUID->"06583cdc-b3b4-421a-a0c5-a149cc37a160",
   CellTags->"i:64",
   CellID->647260802]},
 "i:65"->{
  Cell[541086, 13473, 3767, 88, 1299, "Text",ExpressionUUID->"d3da8d07-5627-4657-a338-310452796ea8",
   CellTags->{"LastCellOfAPage", "i:65", "p: 44"},
   CellID->1190543782]},
 "p: 44"->{
  Cell[541086, 13473, 3767, 88, 1299, "Text",ExpressionUUID->"d3da8d07-5627-4657-a338-310452796ea8",
   CellTags->{"LastCellOfAPage", "i:65", "p: 44"},
   CellID->1190543782]},
 "i:66"->{
  Cell[555685, 13828, 1203, 25, 113, "Text",ExpressionUUID->"75826578-da33-406c-bf0f-39507bbe0c9e",
   CellTags->"i:66",
   CellID->232582819]},
 "i:67"->{
  Cell[564178, 14083, 988, 20, 63, "Text",ExpressionUUID->"5570ec7e-3c57-4fab-9531-43f4cd37460f",
   CellTags->{"LastCellOfAPage", "i:67"},
   CellID->747614211]},
 "p: 45"->{
  Cell[565169, 14105, 516, 12, 37, "CodeCaption",ExpressionUUID->"b24ab022-8cb3-49cb-9223-11afd2920737",
   CellTags->"p: 45",
   CellID->48558757]},
 "i:68"->{
  Cell[572502, 14337, 3560, 79, 163, "Text",ExpressionUUID->"b9e999f7-83a3-4a04-8a65-728e495c42be",
   CellTags->"i:68",
   CellID->1928899909]},
 "p: 46"->{
  Cell[583928, 14610, 685, 14, 37, "CodeCaption",ExpressionUUID->"f6112bb9-9afe-4eff-8674-0a7bfedab5a9",
   CellTags->"p: 46",
   CellID->340339881]},
 "i:69"->{
  Cell[612771, 15211, 2929, 66, 138, "Text",ExpressionUUID->"87f2ba43-969f-4ff7-bf1c-c5cb0bd09bf3",
   CellTags->{"LastCellOfAPage", "i:69"},
   CellID->121026861]},
 "i:70"->{
  Cell[615703, 15279, 1087, 26, 59, "CodeCaption",ExpressionUUID->"e46768c6-f8a3-4ddc-bce8-ea293a0ac50f",
   CellTags->{"i:70", "p: 47"},
   CellID->137313122]},
 "p: 47"->{
  Cell[615703, 15279, 1087, 26, 59, "CodeCaption",ExpressionUUID->"e46768c6-f8a3-4ddc-bce8-ea293a0ac50f",
   CellTags->{"i:70", "p: 47"},
   CellID->137313122]},
 "i:71"->{
  Cell[633400, 15718, 1382, 24, 188, "Text",ExpressionUUID->"6aa010c3-7341-4059-9446-67d8fe1ff483",
   CellTags->"i:71",
   CellID->688375747]},
 "i:72"->{
  Cell[642324, 15937, 815, 15, 63, "Text",ExpressionUUID->"3e68f07e-3f08-417e-aff9-ba694376b8ee",
   CellTags->{"LastCellOfAPage", "i:72"},
   CellID->1536241901]},
 "p: 48"->{
  Cell[643142, 15954, 734, 18, 37, "CodeCaption",ExpressionUUID->"6a7f5811-f62a-4c4b-ac1e-34043d081d63",
   CellTags->"p: 48",
   CellID->246038905]},
 "i:73"->{
  Cell[647278, 16080, 546, 12, 63, "Text",ExpressionUUID->"3766d413-3a2b-4bbb-8deb-43416cc63c4c",
   CellTags->"i:73",
   CellID->1826551503]},
 "i:74"->{
  Cell[655348, 16277, 426, 8, 38, "Text",ExpressionUUID->"656c0d9f-7c7f-46d0-982f-3b3209acac89",
   CellTags->{"LastCellOfAPage", "i:74"},
   CellID->1847183370]},
 "p: 49"->{
  Cell[655777, 16287, 679, 15, 37, "CodeCaption",ExpressionUUID->"97af765f-2160-4aac-9dcf-243ce2868133",
   CellTags->"p: 49",
   CellID->1908282140]},
 "i:75"->{
  Cell[666597, 16576, 2216, 47, 163, "Text",ExpressionUUID->"3d8e0c22-db41-44f2-80fc-5a215eb981d3",
   CellTags->"i:75",
   CellID->51966467]},
 "p: 50"->{
  Cell[707739, 17328, 266, 4, 54, "Subsubsubsection",ExpressionUUID->"860f23f7-281b-44f1-ab40-c85f10c6b08a",
   CellTags->"p: 50",
   CellID->548822030]},
 "i:76"->{
  Cell[708008, 17334, 1327, 26, 113, "Text",ExpressionUUID->"b397d02c-8b3a-4f6e-9c18-15da11facee9",
   CellTags->"i:76",
   CellID->710098879]},
 "i:77"->{
  Cell[725058, 17764, 822, 19, 63, "Text",ExpressionUUID->"e858c192-b04f-41db-ae20-8c5237b01211",
   CellTags->"i:77",
   CellID->1297442800]},
 "i:78"->{
  Cell[728209, 17850, 775, 12, 113, "Text",ExpressionUUID->"21e936b0-84ad-4cec-8cc7-fd2468614943",
   CellTags->"i:78",
   CellID->629872765]},
 "p: 51"->{
  Cell[731279, 17929, 926, 18, 88, "Text",ExpressionUUID->"a46ba477-f1db-410c-9cde-276de4d047da",
   CellTags->"p: 51",
   CellID->246154164]},
 "i:79"->{
  Cell[751003, 18454, 696, 14, 63, "Text",ExpressionUUID->"459cf7d2-c2ef-4ec6-a788-f8275d1b50a7",
   CellTags->{"i:79", "p: 52"},
   CellID->1105562149]},
 "p: 52"->{
  Cell[751003, 18454, 696, 14, 63, "Text",ExpressionUUID->"459cf7d2-c2ef-4ec6-a788-f8275d1b50a7",
   CellTags->{"i:79", "p: 52"},
   CellID->1105562149]},
 "p: 53"->{
  Cell[782437, 19262, 280, 4, 54, "Subsubsubsection",ExpressionUUID->"84036eed-4393-4dd2-9889-e87496cbf72d",
   CellTags->"p: 53",
   CellID->562117424]},
 "i:80"->{
  Cell[782720, 19268, 694, 14, 88, "Text",ExpressionUUID->"50be217a-b749-4b07-8096-8be4e862acb0",
   CellTags->"i:80",
   CellID->1301156318]},
 "i:81"->{
  Cell[785100, 19328, 3712, 83, 164, "Text",ExpressionUUID->"3a4fed04-ab78-47c2-9c9d-2504eeaa31ee",
   CellTags->"i:81",
   CellID->1286503873]},
 "p: 54"->{
  Cell[817560, 20144, 697, 18, 37, "CodeCaption",ExpressionUUID->"d8e86c9c-b94a-4567-9ecf-af6505112c76",
   CellTags->"p: 54",
   CellID->586624606]},
 "p: 55"->{
  Cell[843773, 20826, 310, 4, 55, "Subsubsection",ExpressionUUID->"74dcfbb8-dc7b-49a8-ac27-4bfcec0318cc",
   CellTags->"p: 55",
   CellID->2115950892]},
 "i:82"->{
  Cell[844086, 20832, 1016, 19, 113, "Text",ExpressionUUID->"d6552f14-8e3a-43c6-a6b8-863b521979f9",
   CellTags->"i:82",
   CellID->1995702086]},
 "p: 56"->{
  Cell[855076, 21118, 632, 15, 37, "CodeCaption",ExpressionUUID->"da69efa7-b4f0-4799-9676-5f593db923eb",
   CellTags->"p: 56",
   CellID->10482146]},
 "p: 57"->{
  Cell[881985, 21833, 820, 15, 113, "Text",ExpressionUUID->"21675a59-815f-4fd9-a7da-35e9763b4f35",
   CellTags->"p: 57",
   CellID->404930289]},
 "p: 58"->{
  Cell[920992, 22778, 1396, 38, 59, "CodeCaption",ExpressionUUID->"cb0b135a-4067-4c81-bb6a-3f7ec27c1a06",
   CellTags->"p: 58",
   CellID->466694603]},
 "i:83"->{
  Cell[960038, 23758, 599, 14, 38, "Text",ExpressionUUID->"021f1402-90ca-430e-b65f-c081f816739c",
   CellTags->{"LastCellOfAPage", "i:83"},
   CellID->38294597]},
 "p: 59"->{
  Cell[960640, 23774, 325, 7, 37, "CodeCaption",ExpressionUUID->"4de3fb1a-ea03-47e8-98d5-eb344671247d",
   CellTags->"p: 59",
   CellID->409418610]},
 "p: 60"->{
  Cell[981019, 24348, 181, 4, 65, "ExerciseSection",ExpressionUUID->"89dcba58-2102-40b3-971e-38edb2e73355",
   CellTags->"p: 60",
   CellID->2000071317]},
 "Exercise"->{
  Cell[981203, 24354, 1403, 32, 54, "Exercise",ExpressionUUID->"667d000f-a65a-40bb-aba3-d4a86b7fdabe",
   CellTags->"Exercise",
   CellID->345108167],
  Cell[982609, 24388, 1692, 36, 64, "Exercise",ExpressionUUID->"46f9dee9-aef3-44a4-ada0-c61fae050a00",
   CellTags->"Exercise",
   CellID->607597237],
  Cell[984304, 24426, 1466, 36, 45, "Exercise",ExpressionUUID->"b4e54741-dfb1-4d0a-ab81-88e04d4dec1b",
   CellTags->"Exercise",
   CellID->1158908686],
  Cell[985795, 24466, 2804, 61, 121, "Exercise",ExpressionUUID->"ed5200ef-0192-4b38-bb35-e05c150b9e66",
   CellTags->"Exercise",
   CellID->2069077201],
  Cell[988602, 24529, 575, 15, 44, "ExerciseInput",ExpressionUUID->"470cf254-7c43-4a7a-adea-ab36afc871af",
   CellTags->"Exercise",
   CellID->1084903328],
  Cell[989192, 24547, 715, 18, 50, "Exercise",ExpressionUUID->"435df473-d9b5-490f-ba28-5b0f3b1dd9a6",
   CounterIncrements->None,
   CellTags->"Exercise",
   CellID->332482727],
  Cell[989910, 24567, 494, 10, 45, "Exercise",ExpressionUUID->"c440deaf-04c6-4b7c-b9b8-5a83f565d1a7",
   CounterAssignments->{{$CellContext`Exercise, 4}},
   CellTags->"Exercise",
   CellID->393275140],
  Cell[990407, 24579, 383, 9, 26, "Exercise",ExpressionUUID->"a17d3e2c-28cb-47aa-924e-ffba11ce4381",
   CellTags->"Exercise",
   CellID->1808053344],
  Cell[990793, 24590, 411, 9, 26, "Exercise",ExpressionUUID->"83f09d36-ca48-463d-91f4-d88b14297558",
   CellTags->"Exercise",
   CellID->1457862554],
  Cell[991207, 24601, 1901, 40, 64, "Exercise",ExpressionUUID->"cceb4aa1-d415-440a-bdec-ea61c420fb4b",
   CellTags->"Exercise",
   CellID->1596278989],
  Cell[993111, 24643, 2277, 63, 71, "Exercise",ExpressionUUID->"d4551e4e-798f-4dfd-9009-4fcc45821567",
   CellTags->"Exercise",
   CellID->707323200],
  Cell[995391, 24708, 996, 22, 46, "Exercise",ExpressionUUID->"20ac2b81-8b67-44fe-ab01-17ec9e8c0175",
   CellTags->{"Exercise", "LastCellOfAPage"},
   CellID->205547354]},
 "p: 61"->{
  Cell[996424, 24735, 133, 2, 70, "TechNoteSection",ExpressionUUID->"c7deca42-6f80-40d1-808f-f89e2f023be7",
   CellTags->"p: 61",
   CellID->2102209134]},
 "i:84"->{
  Cell[996560, 24739, 2467, 53, 124, "TechNote",ExpressionUUID->"2e208e72-23fd-4281-bf19-fded56c1db83",
   CellTags->"i:84",
   CellID->1139233202]},
 "i:85"->{
  Cell[1051834, 26136, 1431, 36, 124, "TechNote",ExpressionUUID->"fffe9658-da63-481e-b72b-aa4af1a77b61",
   CellTags->"i:85",
   CellID->1440151497]},
 "p: 62"->{
  Cell[1061307, 26378, 1984, 45, 150, "TechNote",ExpressionUUID->"ca5de65c-ea88-4320-99da-abef09f5daae",
   CellTags->"p: 62",
   CellID->2064321573]},
 "i:86"->{
  Cell[1119290, 27770, 1947, 40, 124, "TechNote",ExpressionUUID->"5ea5ffe8-4190-4adf-bda2-5984cfd5d8c9",
   CellTags->"i:86",
   CellID->1461046402]},
 "i:87"->{
  Cell[1122652, 27856, 1395, 35, 102, "TechNote",ExpressionUUID->"f08f8d43-1854-4305-92bb-fc65bcca3305",
   CellTags->{"LastCellOfAPage", "i:87"},
   CellID->2128183295]},
 "p: 63"->{
  Cell[1124072, 27895, 420, 11, 25, "ExerciseInput",ExpressionUUID->"f738d90a-08d0-4f68-bb49-6390ad437334",
   CellTags->"p: 63",
   CellID->165522244]}
 }
*)
(*CellTagsIndex
CellTagsIndex->{
 {"p: 15", 1315403, 31688},
 {"i:1", 1315595, 31693},
 {"LastCellOfAPage", 1315755, 31697},
 {"i:2", 1323560, 31845},
 {"p: 16", 1323743, 31849},
 {"i:3", 1323924, 31853},
 {"i:4", 1324075, 31857},
 {"i:5", 1324226, 31861},
 {"p: 17", 1324400, 31865},
 {"i:6", 1324559, 31869},
 {"i:7", 1324711, 31873},
 {"i:8", 1324862, 31877},
 {"p: 18", 1325016, 31881},
 {"i:9", 1325176, 31885},
 {"i:10", 1325328, 31889},
 {"p: 19", 1325502, 31893},
 {"i:11", 1325661, 31897},
 {"i:12", 1325814, 31901},
 {"p: 20", 1325969, 31905},
 {"i:13", 1326133, 31909},
 {"i:14", 1326286, 31913},
 {"i:15", 1326444, 31917},
 {"i:16", 1326604, 31921},
 {"i:17", 1326778, 31925},
 {"p: 21", 1326941, 31929},
 {"i:18", 1327103, 31933},
 {"i:19", 1327258, 31937},
 {"i:20", 1327410, 31941},
 {"p: 22", 1327564, 31945},
 {"i:21", 1327720, 31949},
 {"i:22", 1327874, 31953},
 {"i:23", 1328028, 31957},
 {"p: 23", 1328196, 31961},
 {"i:24", 1328363, 31965},
 {"i:25", 1328517, 31969},
 {"i:26", 1328670, 31973},
 {"p: 24", 1328846, 31977},
 {"i:27", 1329006, 31981},
 {"i:28", 1329159, 31985},
 {"i:29", 1329313, 31989},
 {"i:30", 1329467, 31993},
 {"p: 25", 1329644, 31997},
 {"i:31", 1329805, 32001},
 {"i:32", 1329961, 32005},
 {"i:33", 1330115, 32009},
 {"p: 26", 1330270, 32013},
 {"i:34", 1330433, 32017},
 {"i:35", 1330587, 32021},
 {"i:36", 1330743, 32025},
 {"i:37", 1330897, 32029},
 {"p: 27", 1331073, 32033},
 {"i:38", 1331234, 32037},
 {"i:39", 1331388, 32041},
 {"i:40", 1331543, 32045},
 {"p: 28", 1331721, 32049},
 {"i:41", 1331881, 32053},
 {"p: 29", 1332039, 32057},
 {"i:42", 1332201, 32061},
 {"i:43", 1332356, 32065},
 {"i:44", 1332511, 32069},
 {"i:45", 1332674, 32073},
 {"p: 30", 1332830, 32077},
 {"i:46", 1332991, 32081},
 {"i:47", 1333145, 32085},
 {"p: 31", 1333312, 32089},
 {"p: 32", 1333479, 32093},
 {"i:48", 1333634, 32097},
 {"i:49", 1333789, 32101},
 {"p: 33", 1333946, 32105},
 {"i:50", 1334108, 32109},
 {"i:51", 1334262, 32113},
 {"p: 34", 1334419, 32117},
 {"i:52", 1334574, 32121},
 {"p: 35", 1334730, 32125},
 {"p: 36", 1334893, 32129},
 {"i:53", 1335048, 32133},
 {"p: 37", 1335205, 32137},
 {"i:54", 1335366, 32141},
 {"p: 38", 1335523, 32145},
 {"i:55", 1335680, 32149},
 {"p: 39", 1335843, 32153},
 {"i:56", 1336035, 32158},
 {"i:57", 1336190, 32162},
 {"i:58", 1336346, 32166},
 {"p: 40", 1336524, 32170},
 {"i:59", 1336686, 32174},
 {"i:60", 1336841, 32178},
 {"p: 41", 1336998, 32182},
 {"i:61", 1337160, 32186},
 {"i:62", 1337321, 32190},
 {"p: 42", 1337479, 32194},
 {"p: 43", 1337640, 32198},
 {"i:63", 1337797, 32202},
 {"i:64", 1337953, 32206},
 {"i:65", 1338109, 32210},
 {"p: 44", 1338298, 32214},
 {"i:66", 1338486, 32218},
 {"i:67", 1338642, 32222},
 {"p: 45", 1338818, 32226},
 {"i:68", 1338979, 32230},
 {"p: 46", 1339137, 32234},
 {"i:69", 1339299, 32238},
 {"i:70", 1339476, 32242},
 {"p: 47", 1339650, 32246},
 {"i:71", 1339823, 32250},
 {"i:72", 1339979, 32254},
 {"p: 48", 1340156, 32258},
 {"i:73", 1340318, 32262},
 {"i:74", 1340473, 32266},
 {"p: 49", 1340649, 32270},
 {"i:75", 1340812, 32274},
 {"p: 50", 1340968, 32278},
 {"i:76", 1341134, 32282},
 {"i:77", 1341290, 32286},
 {"i:78", 1341445, 32290},
 {"p: 51", 1341601, 32294},
 {"i:79", 1341756, 32298},
 {"p: 52", 1341923, 32302},
 {"p: 53", 1342090, 32306},
 {"i:80", 1342256, 32310},
 {"i:81", 1342411, 32314},
 {"p: 54", 1342569, 32318},
 {"p: 55", 1342732, 32322},
 {"i:82", 1342896, 32326},
 {"p: 56", 1343054, 32330},
 {"p: 57", 1343216, 32334},
 {"p: 58", 1343373, 32338},
 {"i:83", 1343536, 32342},
 {"p: 59", 1343711, 32346},
 {"p: 60", 1343873, 32350},
 {"Exercise", 1344043, 32354},
 {"p: 61", 1345974, 32393},
 {"i:84", 1346140, 32397},
 {"i:85", 1346301, 32401},
 {"p: 62", 1346464, 32405},
 {"i:86", 1346627, 32409},
 {"i:87", 1346789, 32413},
 {"p: 63", 1346973, 32417}
 }
*)
(*NotebookFileOutline
Notebook[{
Cell[CellGroupData[{
Cell[627, 23, 339, 9, 110, "Section",ExpressionUUID->"5fb1942b-26df-4888-9847-67421344e9aa",
 CounterAssignments->{{"Section", 1}},
 CellTags->"p: 15",
 CellID->702470296],
Cell[969, 34, 2353, 42, 263, "Text",ExpressionUUID->"a50ed8a8-4753-44ea-9496-1ae1d2a3f708",
 CellTags->"i:1",
 CellID->426547642],
Cell[3325, 78, 1111, 23, 63, "Text",ExpressionUUID->"2609f246-92e2-415c-beb9-fbfa7cc954f9",
 CellID->1532866539],
Cell[4439, 103, 579, 14, 37, "CodeCaption",ExpressionUUID->"0f329d3e-7fad-453a-b4cf-afcb301eb8f9",
 CellID->336964028],
Cell[CellGroupData[{
Cell[5043, 121, 297, 7, 26, "Input",ExpressionUUID->"a65cd152-dccb-4faf-aeaa-7ff3afa64416",
 CellID->443800812],
Cell[5343, 130, 20007, 386, 152, "Output",ExpressionUUID->"c28bba0f-ac05-47e1-ac7d-aca1004c2ef6",
 CellID->1590202819]
}, Open  ]],
Cell[CellGroupData[{
Cell[25387, 521, 167, 2, 57, "Subsection",ExpressionUUID->"450c392e-bea9-43c0-af64-21708afec750",
 CellID->398617365],
Cell[25557, 525, 1081, 18, 213, "Text",ExpressionUUID->"1dbeb66a-dfaa-42c0-8ab4-97b941c27ddf",
 CellTags->{"LastCellOfAPage", "i:2", "p: 16"},
 CellID->685805408],
Cell[26641, 545, 2435, 47, 218, "Text",ExpressionUUID->"504d9dd4-055f-4d04-a729-57c38f1c52ca",
 CellTags->"i:3",
 CellID->786758807],
Cell[29079, 594, 974, 17, 37, "CodeCaption",ExpressionUUID->"07a5c61e-ed61-48ff-ba31-03e528faecde",
 CellID->412663331],
Cell[CellGroupData[{
Cell[30078, 615, 2320, 52, 74, "Input",ExpressionUUID->"17f66242-35f0-4823-82b4-485af99b345d",
 CellID->998454670],
Cell[32401, 669, 590, 11, 37, "Output",ExpressionUUID->"67003e05-2d64-49a1-87ff-9d6e532dee12",
 CellID->50388199]
}, Open  ]],
Cell[CellGroupData[{
Cell[33028, 685, 260, 3, 55, "Subsubsection",ExpressionUUID->"a4893abb-dbff-4442-b03b-02a4b5f1548d",
 CellID->109983855],
Cell[33291, 690, 989, 15, 138, "Text",ExpressionUUID->"44f277d6-bdfb-4562-a481-145dd1f55423",
 CellTags->"i:4",
 CellID->1393188976],
Cell[34283, 707, 688, 9, 37, "CodeCaption",ExpressionUUID->"1174dab3-3b71-4c62-9b2e-77ff2001c88b",
 CellID->1657187447],
Cell[CellGroupData[{
Cell[34996, 720, 2267, 52, 74, "Input",ExpressionUUID->"2bb3d6ec-b4c5-4289-b556-6e66f6b2a7f1",
 CellID->1305550552],
Cell[37266, 774, 536, 11, 37, "Output",ExpressionUUID->"f0259c63-2b86-478b-a068-95587d0edbbe",
 CellID->730622150]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[37851, 791, 293, 4, 55, "Subsubsection",ExpressionUUID->"3343b2cd-c6fb-4567-9551-11bdeced9576",
 CellID->196721535],
Cell[38147, 797, 2696, 46, 213, "Text",ExpressionUUID->"a3f2149e-424c-40cf-89de-5f7013756d48",
 CellTags->{"LastCellOfAPage", "i:5"},
 CellID->590421032],
Cell[40846, 845, 1025, 16, 37, "CodeCaption",ExpressionUUID->"77cec30f-065c-4b2c-8f01-c09c8686e77a",
 CellTags->"p: 17",
 CellID->889805339],
Cell[41874, 863, 1062, 27, 27, "Input",ExpressionUUID->"c8641900-79f9-43e7-a5d1-098ca5c81612",
 CellID->1831835684],
Cell[42939, 892, 2942, 60, 213, "Text",ExpressionUUID->"00ebf5bb-a424-47e2-b99e-99e828abdbcf",
 CellTags->"i:6",
 CellID->1372229709],
Cell[45884, 954, 668, 16, 39, "CodeText",ExpressionUUID->"985d047b-6f92-4695-88ed-be9042b9f47a",
 CellID->82217185],
Cell[CellGroupData[{
Cell[46577, 974, 247, 5, 26, "Input",ExpressionUUID->"cfc7aced-184a-4803-9bc2-214f9c052a01",
 CellID->1141266688],
Cell[46827, 981, 262, 6, 37, "Output",ExpressionUUID->"8ba27a33-11cd-4a93-9eed-b8f29249e97a",
 CellID->961298532]
}, Open  ]],
Cell[47104, 990, 1180, 23, 113, "Text",ExpressionUUID->"8a37c9d7-4439-4ffa-a0ef-c7575efb5c4e",
 CellTags->"i:7",
 CellID->910539663],
Cell[48287, 1015, 446, 9, 39, "CodeText",ExpressionUUID->"0ea16ac6-f2a9-4ca2-bc59-37d0b25a3fe6",
 CellID->1810807761],
Cell[CellGroupData[{
Cell[48758, 1028, 919, 27, 46, "Input",ExpressionUUID->"358c2798-2446-427d-a028-ff7dd5b73a17",
 CellID->1315079915],
Cell[49680, 1057, 373, 11, 65, "Output",ExpressionUUID->"8121912a-9373-4403-9608-3c20955bf830",
 CellID->646436481]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[50114, 1075, 710, 15, 57, "Subsection",ExpressionUUID->"3c6a2bb0-3898-4b8e-96f0-4d8f5f19d387",
 CellID->1336777596],
Cell[50827, 1092, 1970, 39, 138, "Text",ExpressionUUID->"ab7f8a5d-e5ed-481c-9081-cd00896fa107",
 CellTags->"i:8",
 CellID->247141058],
Cell[52800, 1133, 505, 11, 37, "CodeCaption",ExpressionUUID->"06c22fb9-c464-40ad-a90b-693abba7ad45",
 CellID->890813444],
Cell[CellGroupData[{
Cell[53330, 1148, 298, 7, 26, "Input",ExpressionUUID->"9f9a2433-631d-46d9-985f-3c3904fd676a",
 CellID->466388508],
Cell[53631, 1157, 334, 5, 37, "Output",ExpressionUUID->"b471f653-0c54-46f9-aae0-835f252f0738",
 CellID->827012536]
}, Open  ]],
Cell[53980, 1165, 1097, 20, 113, "Text",ExpressionUUID->"ea725a32-3aa8-42b2-8c2a-fb56e97fa64e",
 CellTags->"LastCellOfAPage",
 CellID->276342406],
Cell[55080, 1187, 538, 12, 37, "CodeCaption",ExpressionUUID->"3271066d-5989-4611-8420-122bc08663c9",
 CellTags->"p: 18",
 CellID->2041117656],
Cell[CellGroupData[{
Cell[55643, 1203, 503, 12, 26, "Input",ExpressionUUID->"e19488c3-2a11-447f-af2a-ed4bb4ddf3ed",
 CellID->1627172828],
Cell[56149, 1217, 431, 7, 37, "Output",ExpressionUUID->"e32aa0f3-7075-4c17-a9d8-078205d47e07",
 CellID->1553943897]
}, Open  ]],
Cell[56595, 1227, 634, 12, 63, "Text",ExpressionUUID->"ccfc0900-1f15-48d6-8088-8b288349cc92",
 CellID->279149526],
Cell[57232, 1241, 950, 18, 88, "Text",ExpressionUUID->"7a578177-bcf0-4713-871b-aedcc4111c0d",
 CellTags->"i:9",
 CellID->1836959298],
Cell[58185, 1261, 1097, 24, 37, "CodeCaption",ExpressionUUID->"023e5eb4-221d-4d93-8abe-07b2127513bb",
 CellID->67674739],
Cell[CellGroupData[{
Cell[59307, 1289, 490, 10, 26, "Input",ExpressionUUID->"64d72f14-72f8-4e65-9e9b-d7ae32f4df84",
 CellID->1550012214],
Cell[59800, 1301, 5599, 147, 252, "Output",ExpressionUUID->"45923161-e0d4-44bd-942a-8d28742ad155",
 CellID->2073804615]
}, Open  ]],
Cell[65414, 1451, 2352, 62, 113, "Text",ExpressionUUID->"cc5c120d-252e-4493-84d5-53eb7dae8c67",
 CellID->2078642588],
Cell[67769, 1515, 1301, 24, 113, "Text",ExpressionUUID->"a550081b-e4fd-462d-898d-967930eb6ed4",
 CellID->482007120],
Cell[69073, 1541, 232, 3, 37, "CodeCaption",ExpressionUUID->"3ecaf931-116c-45f1-b628-78c757bf3423",
 CellID->1899507007],
Cell[CellGroupData[{
Cell[69330, 1548, 596, 14, 26, "Input",ExpressionUUID->"6f8cbb11-e172-4e5a-87bb-1eaf5e5bf6f5",
 CellID->785349356],
Cell[69929, 1564, 674, 14, 37, "Output",ExpressionUUID->"3af0518f-20aa-47ba-9597-eead1d38c8b6",
 CellID->615515707]
}, Open  ]],
Cell[70618, 1581, 932, 17, 88, "Text",ExpressionUUID->"adc9c446-ac64-481c-ae7f-749221b317a3",
 CellTags->{"LastCellOfAPage", "i:10"},
 CellID->932131830],
Cell[71553, 1600, 259, 4, 37, "CodeCaption",ExpressionUUID->"7f73b7ec-9ca4-4277-b69d-3d0764bef296",
 CellTags->"p: 19",
 CellID->427695515],
Cell[CellGroupData[{
Cell[71837, 1608, 460, 11, 26, "Input",ExpressionUUID->"01f866d1-d48a-44d3-a368-967896d7f455",
 CellID->446461945],
Cell[72300, 1621, 355, 6, 37, "Output",ExpressionUUID->"d450349f-5b0f-4966-8f7f-f06be0978911",
 CellID->222991843]
}, Open  ]],
Cell[72670, 1630, 234, 4, 38, "Text",ExpressionUUID->"04d32a5f-2afb-4fc6-840e-7db6556fea57",
 CellID->378046997],
Cell[72907, 1636, 347, 4, 37, "CodeCaption",ExpressionUUID->"5f625981-2143-4943-8c3d-8f5c5df38c81",
 CellID->1928208512],
Cell[CellGroupData[{
Cell[73279, 1644, 488, 12, 26, "Input",ExpressionUUID->"f137e36b-cc0a-4017-af8f-f25e45b14506",
 CellID->1579250753],
Cell[73770, 1658, 364, 6, 37, "Output",ExpressionUUID->"67f7331d-6006-495f-86bc-c11a1d9299c9",
 CellID->809342058]
}, Open  ]],
Cell[74149, 1667, 876, 19, 65, "Text",ExpressionUUID->"901883db-5cb9-4c41-8b88-a471c5708350",
 CellTags->"i:11",
 CellID->1005068699],
Cell[75028, 1688, 653, 13, 37, "CodeCaption",ExpressionUUID->"d16cd3ce-86a0-4e63-943f-33cac02c2514",
 CellID->342325258],
Cell[CellGroupData[{
Cell[75706, 1705, 631, 19, 26, "Input",ExpressionUUID->"9b345531-a5ca-4e99-a16a-d81c97bfb1f5",
 CellID->1204062296],
Cell[76340, 1726, 365, 7, 37, "Output",ExpressionUUID->"8e47787a-cc40-45fd-bf1d-c18e283865e0",
 CellID->1076063832]
}, Open  ]],
Cell[76720, 1736, 789, 12, 138, "Text",ExpressionUUID->"a2b16fe6-44b4-4138-ae28-07ccce2bf1cf",
 CellTags->"i:12",
 CellID->1717012398],
Cell[77512, 1750, 693, 15, 37, "CodeCaption",ExpressionUUID->"1d18a8da-46ec-4155-af91-c0ab68c7daec",
 CellID->417260322],
Cell[CellGroupData[{
Cell[78230, 1769, 431, 10, 27, "Input",ExpressionUUID->"0272148d-d893-49a5-8a20-b419236dcef6",
 CellID->2089608447],
Cell[78664, 1781, 421, 8, 37, "Output",ExpressionUUID->"8baf630f-f761-4422-8dd6-c21c6b8f54b3",
 CellID->1032471710]
}, Open  ]],
Cell[79100, 1792, 296, 5, 38, "Text",ExpressionUUID->"a1c5d69b-6de7-47f8-ae59-be37c983f1b1",
 CellID->101605691],
Cell[79399, 1799, 1106, 23, 37, "CodeCaption",ExpressionUUID->"971c2489-8dc8-4d1f-bc3f-66666300f355",
 CellID->530410008],
Cell[CellGroupData[{
Cell[80530, 1826, 480, 12, 27, "Input",ExpressionUUID->"df0de466-17ad-4e57-9d4b-d5981a50e74c",
 CellID->437349272],
Cell[81013, 1840, 339, 5, 37, "Output",ExpressionUUID->"5c302b8b-e1b4-4247-95f3-46dfc10aaff5",
 CellID->197153837]
}, Open  ]],
Cell[81367, 1848, 353, 7, 38, "Text",ExpressionUUID->"c68fc838-cc5a-4671-935d-d9b9b475880b",
 CellID->1840174470],
Cell[81723, 1857, 838, 17, 37, "CodeCaption",ExpressionUUID->"ca3126e1-ab0c-4685-82bb-bba7d7c00c01",
 CellID->433393526],
Cell[CellGroupData[{
Cell[82586, 1878, 555, 14, 27, "Input",ExpressionUUID->"1674c363-a6d6-48aa-8abd-0ed80ae80673",
 CellID->1900316843],
Cell[83144, 1894, 560, 12, 37, "Output",ExpressionUUID->"85384623-4d2f-4b75-b6b9-a738f1b307ce",
 CellTags->"LastCellOfAPage",
 CellID->1134670365]
}, Open  ]],
Cell[CellGroupData[{
Cell[83741, 1911, 1076, 27, 55, "Subsubsection",ExpressionUUID->"f918684b-a944-476b-aa75-a2d0ae62bf15",
 CellTags->"p: 20",
 CellID->1306406695],
Cell[84820, 1940, 1174, 24, 89, "Text",ExpressionUUID->"3c6ba220-9a90-4636-b243-7ad35ad42815",
 CellTags->"i:13",
 CellID->431835590],
Cell[85997, 1966, 508, 12, 37, "CodeCaption",ExpressionUUID->"d1ac31e6-3eb0-497d-a518-be2c498e98ca",
 CellTags->"i:14",
 CellID->58107445],
Cell[CellGroupData[{
Cell[86530, 1982, 392, 9, 27, "Input",ExpressionUUID->"d3f78d9c-fe6a-449a-9c0f-a305da933d77",
 CellID->1312297989],
Cell[86925, 1993, 441, 9, 37, "Output",ExpressionUUID->"adb83dd4-04ed-4af2-a563-fbc473957009",
 CellID->1569769643]
}, Open  ]],
Cell[87381, 2005, 652, 13, 37, "CodeCaption",ExpressionUUID->"8f750d26-6fec-4d73-be13-90d061e5799d",
 CellTags->"i:15",
 CellID->1378388831],
Cell[CellGroupData[{
Cell[88058, 2022, 363, 8, 27, "Input",ExpressionUUID->"0d1f8391-ede5-42e0-95f1-c04cf0f92f3e",
 CellID->1140561712],
Cell[88424, 2032, 388, 8, 37, "Output",ExpressionUUID->"201e9ce6-178c-4fa6-abd7-7738810bb3a1",
 CellID->1870452427]
}, Open  ]],
Cell[88827, 2043, 626, 13, 37, "CodeCaption",ExpressionUUID->"54799772-d4e1-4aba-9e3b-81a945064f6d",
 CellID->895416376],
Cell[CellGroupData[{
Cell[89478, 2060, 352, 8, 27, "Input",ExpressionUUID->"f6b49a0a-ce81-4de9-bf62-5339285048cc",
 CellID->411930243],
Cell[89833, 2070, 385, 8, 37, "Output",ExpressionUUID->"a0ee61a3-4b87-4951-a6c0-e14a3c74ddbb",
 CellID->1618809395]
}, Open  ]],
Cell[90233, 2081, 410, 7, 59, "CodeCaption",ExpressionUUID->"7a5ded73-c706-4f45-a29c-b96476f0e0de",
 CellID->2336424],
Cell[CellGroupData[{
Cell[90668, 2092, 563, 15, 27, "Input",ExpressionUUID->"3361b4fa-f298-42fe-b71c-c8bfbcaa06e6",
 CellID->1105442357],
Cell[91234, 2109, 592, 13, 37, "Output",ExpressionUUID->"273207e4-64bb-4c0d-a962-4f8b6cd54522",
 CellID->1033630717]
}, Open  ]],
Cell[91841, 2125, 648, 13, 37, "CodeCaption",ExpressionUUID->"32f193dc-593f-400a-85a9-03c5f29300e1",
 CellID->207099372],
Cell[CellGroupData[{
Cell[92514, 2142, 328, 7, 27, "Input",ExpressionUUID->"08cf841f-b4d2-43a9-852d-b911e57187a5",
 CellID->2084639956],
Cell[92845, 2151, 807, 13, 37, "Output",ExpressionUUID->"9f28b140-a61d-449e-be9b-8f7e64f369af",
 CellID->2038967451]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[93713, 2171, 225, 3, 57, "Subsection",ExpressionUUID->"3414d6c1-c73d-42b7-bce5-07b124c5c333",
 CellID->1248382117],
Cell[CellGroupData[{
Cell[93963, 2178, 183, 2, 55, "Subsubsection",ExpressionUUID->"73c644c4-5c22-49ab-bfb0-2628fb1942ea",
 CellID->1298300964],
Cell[94149, 2182, 758, 12, 213, "Text",ExpressionUUID->"6a1c8591-a8ff-40d5-96a4-b8ae67d10d23",
 CellTags->{"LastCellOfAPage", "i:16"},
 CellID->643009229],
Cell[94910, 2196, 522, 9, 88, "Text",ExpressionUUID->"57db0482-361c-4f5a-a5e4-ea89b0842b60",
 CellTags->{"i:17", "p: 21"},
 CellID->918400099],
Cell[95435, 2207, 234, 3, 37, "CodeCaption",ExpressionUUID->"6dff4acf-daed-427f-b8d2-647ec2603777",
 CellID->1487034866],
Cell[95672, 2212, 348, 8, 29, "Input",ExpressionUUID->"3f2c824b-c362-4cd1-9c30-a1ea56f8c178",
 CellID->1585492904],
Cell[96023, 2222, 2160, 50, 163, "Text",ExpressionUUID->"a75138aa-9c0c-4a6a-8ccb-5377e16d0f68",
 CellID->1402145552],
Cell[98186, 2274, 1416, 26, 163, "Text",ExpressionUUID->"ad7dbd58-79b9-4f9a-8cf6-a7a32f36465b",
 CellTags->"i:18",
 CellID->1522233933],
Cell[99605, 2302, 552, 12, 39, "CodeText",ExpressionUUID->"271c9697-1339-4a4f-a9d8-6fb7765c6fde",
 CellID->599898325],
Cell[100160, 2316, 318, 7, 29, "Input",ExpressionUUID->"c8ae6bcf-2342-4270-b2c0-6105ede87da1",
 CellID->1213025220],
Cell[100481, 2325, 503, 8, 88, "Text",ExpressionUUID->"bb8e7288-c525-456e-9390-890674c23482",
 CellID->1252611569],
Cell[100987, 2335, 525, 9, 88, "Text",ExpressionUUID->"0296603f-8332-45a7-b3ab-ec9c4f60e8dc",
 CellTags->"i:19",
 CellID->860448642],
Cell[101515, 2346, 222, 3, 37, "CodeCaption",ExpressionUUID->"9bc3daf4-939c-4bad-95d5-ea281f482738",
 CellID->320761331],
Cell[CellGroupData[{
Cell[101762, 2353, 304, 7, 29, "Input",ExpressionUUID->"e5deef0f-11b3-4bfb-9883-a584f5db222d",
 CellID->405447196],
Cell[102069, 2362, 335, 5, 37, "Output",ExpressionUUID->"26cdb8e3-9625-4a07-9d2b-ef32c1901106",
 CellID->442648017]
}, Open  ]],
Cell[102419, 2370, 999, 19, 63, "Text",ExpressionUUID->"aa99f80e-8105-4f02-b825-aaef2a52e51b",
 CellTags->"i:20",
 CellID->385411241],
Cell[103421, 2391, 224, 3, 37, "CodeCaption",ExpressionUUID->"28a4c438-5ee9-41fe-9b4b-05d6571a34ae",
 CellID->1229764635],
Cell[CellGroupData[{
Cell[103670, 2398, 406, 10, 49, "Input",ExpressionUUID->"90bb3db7-6db8-415d-9116-ec7b556abd7b",
 CellID->796048135],
Cell[104079, 2410, 361, 6, 37, "Output",ExpressionUUID->"12b4b5b4-5ef7-45a4-b62f-91367f9d69e0",
 CellTags->"LastCellOfAPage",
 CellID->1082927782]
}, Open  ]],
Cell[104455, 2419, 1890, 33, 238, "Text",ExpressionUUID->"418f989e-cc4f-41f9-aeec-bf08c5706f74",
 CellTags->"p: 22",
 CellID->357884135],
Cell[106348, 2454, 553, 12, 63, "Text",ExpressionUUID->"6a501838-a616-47d1-ac67-c9223b5d2b1f",
 CellID->1127747226],
Cell[106904, 2468, 263, 5, 37, "CodeCaption",ExpressionUUID->"8ac4555c-ec1d-4a09-a51a-ddf641ca03d9",
 CellID->1638048248],
Cell[CellGroupData[{
Cell[107192, 2477, 302, 7, 26, "Input",ExpressionUUID->"ff0480fa-9759-4cf9-8bcf-35a819346187",
 CellID->50149414],
Cell[107497, 2486, 289, 5, 37, "Output",ExpressionUUID->"2a640931-0fcc-4493-8a20-85512ab7f8a4",
 CellID->1357344321]
}, Open  ]],
Cell[107801, 2494, 660, 14, 63, "Text",ExpressionUUID->"46ae72d4-f8c1-4792-9b5c-4766d446a26e",
 CellTags->"i:21",
 CellID->2004445345],
Cell[108464, 2510, 444, 11, 37, "CodeCaption",ExpressionUUID->"92435d63-c5dc-44ef-af63-b60e94b97bdd",
 CellID->24148734],
Cell[CellGroupData[{
Cell[108933, 2525, 302, 7, 29, "Input",ExpressionUUID->"73a294d6-61b1-4fc4-89ec-467e4e0e3b3f",
 CellID->1136942926],
Cell[109238, 2534, 335, 5, 37, "Output",ExpressionUUID->"031d3af2-98e7-4254-9360-160b81e2337a",
 CellID->2144914409]
}, Open  ]],
Cell[109588, 2542, 817, 13, 113, "Text",ExpressionUUID->"4c1a606f-e31d-455c-9ac4-03579a549b31",
 CellTags->"i:22",
 CellID->290266276],
Cell[110408, 2557, 243, 3, 37, "CodeCaption",ExpressionUUID->"1b5310a9-8e5c-4ee1-968a-dcebd3e56d4f",
 CellID->813178404],
Cell[110654, 2562, 466, 13, 40, "Input",ExpressionUUID->"b3079c7b-d948-4c21-b8e5-657e33070a95",
 CellID->1569938395],
Cell[111123, 2577, 355, 7, 37, "CodeCaption",ExpressionUUID->"3756f455-f75c-487c-987d-6775f21295b0",
 CellID->944882402],
Cell[CellGroupData[{
Cell[111503, 2588, 496, 14, 40, "Input",ExpressionUUID->"ff496740-4678-4f0e-8458-0d0a2cea6dd4",
 CellID->1970517723],
Cell[112002, 2604, 361, 6, 37, "Output",ExpressionUUID->"d1a0f065-f204-4af3-8ae1-5def5821b242",
 CellID->361820142]
}, Open  ]],
Cell[112378, 2613, 344, 6, 63, "Text",ExpressionUUID->"bf345389-27c9-4ab6-9467-dbbd37b89dea",
 CellID->2146050074],
Cell[112725, 2621, 229, 3, 37, "CodeCaption",ExpressionUUID->"2b65614a-0603-496a-b4a3-f74220b767a9",
 CellID->911218462],
Cell[CellGroupData[{
Cell[112979, 2628, 453, 13, 40, "Input",ExpressionUUID->"02933a06-cacf-4eb3-b3f2-4d26657a77b9",
 CellID->1675742353],
Cell[113435, 2643, 446, 10, 45, "Output",ExpressionUUID->"01c3ca49-2fc2-4c3d-b6e7-6cda74aa0449",
 CellTags->"LastCellOfAPage",
 CellID->2088562438]
}, Open  ]],
Cell[113896, 2656, 1012, 16, 113, "Text",ExpressionUUID->"6edbeb82-e1e4-4d74-af10-682899d2e88b",
 CellTags->{"i:23", "p: 23"},
 CellID->2101180113],
Cell[114911, 2674, 477, 11, 37, "CodeCaption",ExpressionUUID->"f1580907-89c6-4ced-8581-acde4ec40e79",
 CellID->757841845],
Cell[115391, 2687, 334, 8, 29, "Input",ExpressionUUID->"d8a237e0-e062-4d52-aed4-5dd905287b0f",
 CellID->1313067923],
Cell[115728, 2697, 891, 20, 113, "Text",ExpressionUUID->"949840ea-741d-4e16-9812-28ed0354b9d4",
 CellID->1190625289],
Cell[116622, 2719, 336, 5, 38, "Text",ExpressionUUID->"2bb6b431-4455-43a1-aa56-ae30cd51b775",
 CellID->586609477],
Cell[116961, 2726, 500, 11, 37, "CodeCaption",ExpressionUUID->"f4dc088d-0eac-4c29-b824-b19b9e9e0524",
 CellID->522703068],
Cell[117464, 2739, 363, 11, 39, "Input",ExpressionUUID->"71a2450c-6d30-4dec-a060-ef3c32bbf63a",
 CellID->48056562],
Cell[117830, 2752, 947, 15, 113, "Text",ExpressionUUID->"8cf48b15-ad40-46aa-8e77-45a15ab0ded9",
 CellTags->"i:24",
 CellID->232786262],
Cell[118780, 2769, 508, 11, 37, "CodeCaption",ExpressionUUID->"9b59fd15-87a4-4d69-b81c-5f7dd0629510",
 CellID->613544091],
Cell[119291, 2782, 698, 21, 39, "Input",ExpressionUUID->"0fc44996-9d84-4492-8f1c-1b5496d1334d",
 CellID->1870984247],
Cell[119992, 2805, 1654, 34, 88, "Text",ExpressionUUID->"be4b7efb-76be-43d6-9a0a-c9477e411b7c",
 CellTags->"i:25",
 CellID->29196308],
Cell[121649, 2841, 477, 13, 37, "CodeCaption",ExpressionUUID->"4e36a2a6-a766-4022-86b3-3234f9ddfaf8",
 CellID->602116721],
Cell[122129, 2856, 302, 7, 29, "Input",ExpressionUUID->"a9b62e55-dd36-4c84-b267-416f01d8cbdf",
 CellID->1076077040],
Cell[122434, 2865, 298, 9, 37, "Input",ExpressionUUID->"b3707299-14c9-41eb-b309-238be479367d",
 CellID->1667019893],
Cell[122735, 2876, 644, 13, 63, "Text",ExpressionUUID->"ca81d940-27a5-4b45-aab7-4eb1a0971332",
 CellID->1531682889],
Cell[123382, 2891, 496, 13, 37, "CodeCaption",ExpressionUUID->"68c0ec02-2b89-443c-99ff-413b49f248bd",
 CellID->653372160],
Cell[123881, 2906, 278, 7, 29, "Input",ExpressionUUID->"bb5265da-9ffc-43d8-8810-1f78b2b003aa",
 CellID->1107838834]
}, Open  ]],
Cell[CellGroupData[{
Cell[124196, 2918, 185, 2, 55, "Subsubsection",ExpressionUUID->"6e5965ac-999a-408a-a15b-cb8e8f87cd53",
 CellID->394832717],
Cell[124384, 2922, 959, 17, 114, "Text",ExpressionUUID->"09fca2cb-88e7-4ceb-add8-476a98b0982a",
 CellTags->{"LastCellOfAPage", "i:26"},
 CellID->872447341],
Cell[125346, 2941, 240, 3, 37, "CodeCaption",ExpressionUUID->"90633732-7bf4-47c9-aa5b-2f4d1c166688",
 CellTags->"p: 24",
 CellID->265070891],
Cell[125589, 2946, 345, 9, 26, "Input",ExpressionUUID->"5ab91f41-f6a6-40e1-ab5c-41c6cae4068a",
 CellID->1095109029],
Cell[125937, 2957, 428, 10, 26, "Input",ExpressionUUID->"e58d9b60-501d-48cd-91cf-e50accab3b28",
 CellID->1917193191],
Cell[126368, 2969, 842, 15, 93, "Text",ExpressionUUID->"4bfa33ac-dc1e-4ec0-bc71-39ef6466411b",
 CellID->835391362],
Cell[127213, 2986, 326, 4, 37, "CodeCaption",ExpressionUUID->"b674ad1e-05c8-4f26-a653-dc2d2ace08c7",
 CellID->1744487226],
Cell[CellGroupData[{
Cell[127564, 2994, 325, 7, 26, "Input",ExpressionUUID->"21aac23b-47a5-4a79-a16b-1b25d6ede027",
 CellID->1028916997],
Cell[127892, 3003, 437, 9, 57, "Output",ExpressionUUID->"26496fbb-02b1-4777-97aa-23fe0842b363",
 CellID->661424598]
}, Open  ]],
Cell[128344, 3015, 989, 21, 68, "Text",ExpressionUUID->"e39cbd51-9a4e-4ea9-b9d5-e8ae7a6b9ae6",
 CellTags->"i:27",
 CellID->867761911],
Cell[129336, 3038, 239, 3, 37, "CodeCaption",ExpressionUUID->"17fd4020-ba06-4078-814b-78c24fe16a09",
 CellID->753595102],
Cell[CellGroupData[{
Cell[129600, 3045, 356, 8, 26, "Input",ExpressionUUID->"b093e066-3579-49c8-a286-af25db4772b1",
 CellID->900875438],
Cell[129959, 3055, 435, 8, 57, "Output",ExpressionUUID->"0826f100-c1a1-47ac-b91d-0e2978bc0c34",
 CellID->1029740592]
}, Open  ]],
Cell[130409, 3066, 686, 16, 88, "Text",ExpressionUUID->"21fbd00c-5681-4a91-8064-a9e8c7745a8f",
 CellTags->"i:28",
 CellID->1107578992],
Cell[131098, 3084, 529, 12, 37, "CodeCaption",ExpressionUUID->"a4e723bf-7f78-40ea-8565-20201775fdb0",
 CellID->989926529],
Cell[CellGroupData[{
Cell[131652, 3100, 362, 8, 26, "Input",ExpressionUUID->"0ef6143a-ce7c-4745-9c39-7cb69641f9f0",
 CellID->453738476],
Cell[132017, 3110, 405, 8, 57, "Output",ExpressionUUID->"2d2a6c2c-71dc-45ee-b804-a3b2a35f9a41",
 CellID->1708246479]
}, Open  ]],
Cell[132437, 3121, 969, 17, 113, "Text",ExpressionUUID->"4929c1e9-02a0-42c4-b12b-caba7c0a09c9",
 CellTags->"i:29",
 CellID->969184320],
Cell[133409, 3140, 727, 17, 37, "CodeCaption",ExpressionUUID->"32efa313-e73d-4951-820a-e8ac7794c504",
 CellID->154141905],
Cell[CellGroupData[{
Cell[134161, 3161, 276, 6, 26, "Input",ExpressionUUID->"5b44205d-9ff8-4d0d-a4d3-63c791232e57",
 CellID->826737048],
Cell[134440, 3169, 377, 6, 37, "Output",ExpressionUUID->"f42b261a-a464-466f-a400-3f5f7619652b",
 CellID->329265210]
}, Open  ]],
Cell[134832, 3178, 1970, 47, 113, "Text",ExpressionUUID->"3df484e1-6d58-4182-af4b-857dfadd946a",
 CellTags->{"LastCellOfAPage", "i:30"},
 CellID->592772282],
Cell[136805, 3227, 986, 25, 37, "CodeCaption",ExpressionUUID->"593b0635-acc4-4ae5-bd2d-aedd14481001",
 CellTags->"p: 25",
 CellID->703232801],
Cell[CellGroupData[{
Cell[137816, 3256, 345, 8, 26, "Input",ExpressionUUID->"9a7a713a-c293-4a75-b74a-6ed47ed96ea2",
 CellID->1296352807],
Cell[138164, 3266, 411, 8, 57, "Output",ExpressionUUID->"ed19ddf2-928d-4d3e-b120-e7a8143c467c",
 CellID->192554715]
}, Open  ]],
Cell[138590, 3277, 795, 19, 63, "Text",ExpressionUUID->"f66538a4-80fa-4848-b418-1836e29de881",
 CellID->1618610007],
Cell[139388, 3298, 553, 13, 37, "CodeCaption",ExpressionUUID->"0a2b7379-5041-4c8d-90b4-c0327ff1dccf",
 CellID->34950019],
Cell[CellGroupData[{
Cell[139966, 3315, 304, 7, 26, "Input",ExpressionUUID->"2dbe7d43-ce45-4948-9f8f-af062b9d0607",
 CellID->1530695480],
Cell[140273, 3324, 350, 5, 37, "Output",ExpressionUUID->"34d09b22-7be3-4248-ba56-7bee7143ad44",
 CellID->1004480746]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[140684, 3336, 566, 12, 57, "Subsection",ExpressionUUID->"f82827a7-6812-43f6-a3c0-1ca339a7cf53",
 CellID->764063548],
Cell[141253, 3350, 1268, 26, 113, "Text",ExpressionUUID->"6d416926-7540-4ebc-9a0e-2dd5eb7c7894",
 CellTags->"i:31",
 CellID->1811325823],
Cell[142524, 3378, 809, 24, 37, "CodeCaption",ExpressionUUID->"52bb63f6-3215-4993-80d3-1f2590a5a896",
 CellID->496083972],
Cell[143336, 3404, 292, 7, 26, "Input",ExpressionUUID->"76699f35-953b-4f45-a2f0-b0515a7b6f4c",
 CellID->224927289],
Cell[143631, 3413, 1220, 27, 88, "Text",ExpressionUUID->"ad24de9a-a73b-4ca1-a6eb-999f66413fa8",
 CellTags->"i:32",
 CellID->781727503],
Cell[144854, 3442, 967, 23, 37, "CodeCaption",ExpressionUUID->"64d2bc88-a02f-44c7-a44b-861587165190",
 CellID->56744392],
Cell[CellGroupData[{
Cell[145846, 3469, 257, 5, 26, "Input",ExpressionUUID->"c8e56a31-8d72-4c31-bfc2-5a60abdeee10",
 CellID->189190575],
Cell[146106, 3476, 384, 7, 37, "Output",ExpressionUUID->"3f1b4f9e-0bbd-4a07-b555-f5dba425df35",
 CellID->172088276]
}, Open  ]],
Cell[146505, 3486, 734, 15, 63, "Text",ExpressionUUID->"af3e74ef-95bc-42b1-9352-f3c4875a574b",
 CellTags->"i:33",
 CellID->1450196465],
Cell[147242, 3503, 207, 2, 37, "CodeCaption",ExpressionUUID->"969343f1-516b-4632-9491-70421548fc96",
 CellID->601579293],
Cell[CellGroupData[{
Cell[147474, 3509, 315, 7, 26, "Input",ExpressionUUID->"56dec8aa-16d8-414c-aa0a-f0f0c9a4c21c",
 CellID->1660077452],
Cell[147792, 3518, 424, 8, 37, "Output",ExpressionUUID->"628a8f3f-16f4-42c4-8478-bed032c4652f",
 CellID->500294549]
}, Open  ]],
Cell[148231, 3529, 867, 19, 38, "Text",ExpressionUUID->"2d8d6aea-8793-46c9-bf7b-37245a32efed",
 CellID->814193940],
Cell[149101, 3550, 216, 3, 37, "CodeCaption",ExpressionUUID->"8231123b-83b9-4299-b051-3c1c65e89e0a",
 CellID->202843215],
Cell[CellGroupData[{
Cell[149342, 3557, 549, 14, 27, "Input",ExpressionUUID->"ce07c42a-8323-4210-a91d-3952080f24ea",
 CellID->391750896],
Cell[149894, 3573, 541, 12, 37, "Output",ExpressionUUID->"39d1caf2-4331-4fcb-8834-e957b96b7d2c",
 CellTags->"LastCellOfAPage",
 CellID->1910323796]
}, Open  ]],
Cell[CellGroupData[{
Cell[150472, 3590, 203, 3, 55, "Subsubsection",ExpressionUUID->"8a05e491-2edf-4d99-bcb9-c6a58c970659",
 CellTags->"p: 26",
 CellID->2119931017],
Cell[150678, 3595, 1680, 36, 88, "Text",ExpressionUUID->"47eb0d05-c63c-4cf7-9e30-d5438770ba4f",
 CellTags->"i:34",
 CellID->779415342],
Cell[152361, 3633, 444, 11, 37, "CodeCaption",ExpressionUUID->"b6159391-a483-4ab5-ad34-60722d618616",
 CellID->740456988],
Cell[152808, 3646, 457, 13, 26, "Input",ExpressionUUID->"b47c6448-9afd-4782-a076-84f87841ee15",
 CellID->2130889941],
Cell[153268, 3661, 1392, 28, 88, "Text",ExpressionUUID->"bc47541a-1fc6-4305-b9c7-69ff10c1caef",
 CellID->282457368],
Cell[154663, 3691, 489, 11, 37, "CodeCaption",ExpressionUUID->"c3ef57b1-0b49-4be6-9935-83dd21dabd66",
 CellID->242438384],
Cell[155155, 3704, 12569, 314, 103, "Input",ExpressionUUID->"d2d9a0fd-e75f-4efe-943a-ffd40612d944",
 CellID->926554033],
Cell[167727, 4020, 1453, 30, 113, "Text",ExpressionUUID->"5bb1635a-df43-4f10-9562-d93be55ff154",
 CellTags->"i:35",
 CellID->1189708234],
Cell[169183, 4052, 687, 18, 37, "CodeCaption",ExpressionUUID->"eca38608-9ec5-4d1c-b4b4-b0fe77f8a051",
 CellID->166129341],
Cell[CellGroupData[{
Cell[169895, 4074, 266, 5, 26, "Input",ExpressionUUID->"65103f99-ef63-4909-91f7-f8406344bcbc",
 CellID->206051621],
Cell[170164, 4081, 438, 8, 37, "Output",ExpressionUUID->"296f4533-29c3-4e51-8cda-fa1850cdf873",
 CellID->1778589521]
}, Open  ]],
Cell[170617, 4092, 602, 13, 63, "Text",ExpressionUUID->"2b277dad-67e3-4dce-9076-8a9a69d0cd15",
 CellTags->"i:36",
 CellID->1451164714],
Cell[171222, 4107, 457, 11, 37, "CodeCaption",ExpressionUUID->"45998334-ced3-42ea-b156-b83056db897e",
 CellID->210163303],
Cell[CellGroupData[{
Cell[171704, 4122, 231, 4, 26, "Input",ExpressionUUID->"204509ba-8521-4a99-85ba-9c2d9e1031aa",
 CellID->366146117],
Cell[171938, 4128, 2108, 57, 123, "Output",ExpressionUUID->"9981317a-32de-4026-8e29-e01c479911d8",
 CellID->145845957]
}, Open  ]],
Cell[174061, 4188, 1074, 24, 38, "Text",ExpressionUUID->"995b208a-cab2-48c0-a1c6-856cd7b92b2f",
 CellTags->{"LastCellOfAPage", "i:37"},
 CellID->764986273],
Cell[175138, 4214, 756, 19, 37, "CodeCaption",ExpressionUUID->"633c3e5a-75d2-4635-94d0-1fb745da4b39",
 CellTags->"p: 27",
 CellID->303065152],
Cell[CellGroupData[{
Cell[175919, 4237, 295, 6, 26, "Input",ExpressionUUID->"8d4a6a4f-a205-47b8-a224-371fd147a2b1",
 CellID->573066320],
Cell[176217, 4245, 2167, 58, 135, "Output",ExpressionUUID->"5ef7259f-0e30-40c2-bcba-a8211a18c0d4",
 CellID->708300154]
}, Open  ]],
Cell[178399, 4306, 789, 15, 88, "Text",ExpressionUUID->"9d4f7fac-6535-443d-a447-a1dd68baae4a",
 CellTags->"i:38",
 CellID->1096113171],
Cell[179191, 4323, 476, 11, 37, "CodeCaption",ExpressionUUID->"8dfb85c2-46bc-4fc7-b644-6b2aad09bb79",
 CellID->478809283],
Cell[CellGroupData[{
Cell[179692, 4338, 567, 14, 65, "Input",ExpressionUUID->"62475009-07a0-480a-9146-ed2ad64faef2",
 CellID->625197812],
Cell[180262, 4354, 3289, 96, 158, "Output",ExpressionUUID->"c56f0a78-11a9-429f-842e-50a7b1c00b5d",
 CellID->158831440]
}, Open  ]],
Cell[183566, 4453, 1650, 37, 88, "Text",ExpressionUUID->"52f8ee55-f480-468f-b7bc-1c9c998520a2",
 CellTags->"i:39",
 CellID->1772517426],
Cell[185219, 4492, 929, 24, 37, "CodeCaption",ExpressionUUID->"86d1ec2d-4792-432c-a6d1-99baaefdbbe8",
 CellID->288590451],
Cell[CellGroupData[{
Cell[186173, 4520, 8062, 195, 31, "Input",ExpressionUUID->"6cc9d457-ca6f-45ab-91f5-5b85c0eee452",
 CellID->2087513403],
Cell[194238, 4717, 34451, 660, 177, "Output",ExpressionUUID->"7857257f-3a5c-4718-8073-b69483b98b18",
 CellID->850191113]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[228750, 5384, 170, 2, 57, "Subsection",ExpressionUUID->"1fda4ca4-f25b-4f76-bd61-82d00c0a6170",
 CellID->1365955183],
Cell[228923, 5388, 2174, 49, 163, "Text",ExpressionUUID->"e960addd-9b6d-4178-afe7-e5f68876d769",
 CellTags->{"LastCellOfAPage", "i:40"},
 CellID->1008574251],
Cell[231100, 5439, 500, 8, 37, "CodeCaption",ExpressionUUID->"276737a9-ae1c-4740-997c-ef0fcdf61add",
 CellTags->"p: 28",
 CellID->279242158],
Cell[CellGroupData[{
Cell[231625, 5451, 517, 12, 26, "Input",ExpressionUUID->"ebbaf352-34d9-4f68-a207-a794451fb84c",
 CellID->1019010786],
Cell[232145, 5465, 492, 10, 37, "Output",ExpressionUUID->"396c290b-9cad-4f34-b337-b2bc4ea40646",
 CellID->1859117186]
}, Open  ]],
Cell[232652, 5478, 1227, 35, 63, "Text",ExpressionUUID->"2213a7f1-406d-481d-9d33-7def6cd6eb51",
 CellID->332195477],
Cell[233882, 5515, 415, 6, 37, "CodeCaption",ExpressionUUID->"2636509e-1536-42c1-93e1-79dd7487fa04",
 CellID->112790141],
Cell[CellGroupData[{
Cell[234322, 5525, 468, 11, 26, "Input",ExpressionUUID->"11a48138-3b45-4ded-85ef-ced2b0c0d1ea",
 CellID->1899383386],
Cell[234793, 5538, 440, 8, 37, "Output",ExpressionUUID->"29b6863c-4293-4872-9ff2-792152ad13db",
 CellID->699765098]
}, Open  ]],
Cell[235248, 5549, 896, 19, 63, "Text",ExpressionUUID->"3694d896-8496-47da-a974-d2b50621bdbc",
 CellID->592155847],
Cell[236147, 5570, 330, 5, 37, "CodeCaption",ExpressionUUID->"6e7af4f9-27bc-45c0-a35e-dc98e58b6754",
 CellID->28169798],
Cell[CellGroupData[{
Cell[236502, 5579, 498, 12, 26, "Input",ExpressionUUID->"c9ef4949-8309-4067-b808-6bd82d6d7836",
 CellID->924100331],
Cell[237003, 5593, 500, 10, 37, "Output",ExpressionUUID->"97a80cfa-49d0-4351-bc05-40c83d010370",
 CellID->719684050]
}, Open  ]],
Cell[237518, 5606, 384, 9, 38, "Text",ExpressionUUID->"29961850-88a0-46b6-a74b-bfc9959aecf3",
 CellID->752528013],
Cell[237905, 5617, 272, 4, 37, "CodeCaption",ExpressionUUID->"1d17dfcb-4858-4bd3-8aa4-1f447db6760d",
 CellID->49967241],
Cell[CellGroupData[{
Cell[238202, 5625, 518, 12, 26, "Input",ExpressionUUID->"2acf3541-d5c0-449a-a1ee-dd165921a1f7",
 CellID->1207117308],
Cell[238723, 5639, 529, 11, 37, "Output",ExpressionUUID->"5abde7e6-a440-4b52-a7af-fbf05a1da073",
 CellID->1028379244]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[239301, 5656, 953, 21, 57, "Subsection",ExpressionUUID->"0595fde7-078b-4cb0-b182-d1ca4f8eed78",
 CellID->425278697],
Cell[240257, 5679, 4534, 105, 163, "Text",ExpressionUUID->"6071cd4f-024e-4620-85ce-d038ee2cf3fa",
 CellTags->"i:41",
 CellID->1290938635],
Cell[244794, 5786, 765, 18, 37, "CodeCaption",ExpressionUUID->"84905a27-bcdb-4b65-84d1-404572d90145",
 CellID->241990379],
Cell[CellGroupData[{
Cell[245584, 5808, 455, 10, 26, "Input",ExpressionUUID->"82c537d7-2d23-4e13-9ed2-8fab03cafb3a",
 CellID->2055454417],
Cell[246042, 5820, 508, 12, 37, "Output",ExpressionUUID->"baa25597-a8b9-4ecb-b4d9-9c92abffb3dd",
 CellID->2801802]
}, Open  ]],
Cell[246565, 5835, 2540, 61, 88, "Text",ExpressionUUID->"d147055a-0010-49de-81e0-5ad268e097ba",
 CellTags->"LastCellOfAPage",
 CellID->1498922560],
Cell[249108, 5898, 1041, 26, 37, "CodeCaption",ExpressionUUID->"55c61946-2418-4290-bc94-fb6c0c0cc0dd",
 CellTags->"p: 29",
 CellID->184227891],
Cell[CellGroupData[{
Cell[250174, 5928, 568, 13, 26, "Input",ExpressionUUID->"a7dfce08-555e-492b-9dfc-c056fbbc984c",
 CellID->1953882829],
Cell[250745, 5943, 653, 14, 37, "Output",ExpressionUUID->"727b0430-3ea0-4459-bd1e-d0447ec190d7",
 CellID->1080048314]
}, Open  ]],
Cell[251413, 5960, 1693, 37, 88, "Text",ExpressionUUID->"95e0008b-092d-46ae-acb1-21f381c9ca32",
 CellTags->"i:42",
 CellID->1660103225],
Cell[253109, 5999, 744, 18, 37, "CodeCaption",ExpressionUUID->"7c82288c-c4b2-4f7f-875a-8805fc952d16",
 CellID->513024105],
Cell[CellGroupData[{
Cell[253878, 6021, 577, 13, 26, "Input",ExpressionUUID->"dc96c89b-d114-4f1f-8b12-609989026c54",
 CellID->1709748384],
Cell[254458, 6036, 353, 7, 37, "Output",ExpressionUUID->"8fd0c0bb-4918-42c6-9d91-81a48c87d51e",
 CellID->614550584]
}, Open  ]],
Cell[CellGroupData[{
Cell[254848, 6048, 618, 14, 26, "Input",ExpressionUUID->"34f154ee-9e11-489a-b98f-d80f8b896bd9",
 CellID->1163936563],
Cell[255469, 6064, 401, 9, 37, "Output",ExpressionUUID->"aba2ebee-e0d5-4181-9747-30ebeb813a94",
 CellID->61129908]
}, Open  ]],
Cell[255885, 6076, 2192, 50, 113, "Text",ExpressionUUID->"de0c1359-7cd5-4ae2-991a-70ffd2e25ebb",
 CellTags->"i:43",
 CellID->997560408],
Cell[258080, 6128, 281, 5, 61, "CodeText",ExpressionUUID->"f74b0b32-2f29-43af-bf8f-7a8f3ca28142",
 CellID->601735443],
Cell[CellGroupData[{
Cell[258386, 6137, 597, 16, 26, "Input",ExpressionUUID->"6c09cbfe-bc5e-4e61-a40b-ef5f446dcb27",
 CellID->1512527923],
Cell[258986, 6155, 247, 5, 37, "Output",ExpressionUUID->"4c821ecf-be6b-4ae3-aabc-57d10325c9ea",
 CellID->1782610583]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[259282, 6166, 174, 2, 57, "Subsection",ExpressionUUID->"1459df95-b03d-4d99-af8a-8f11e03a86a7",
 CellID->305459416],
Cell[CellGroupData[{
Cell[259481, 6172, 560, 11, 55, "Subsubsection",ExpressionUUID->"c7e9e824-c0c7-4dc5-9d04-4d370e9d8c63",
 CellTags->"i:44",
 CellID->1909995810],
Cell[260044, 6185, 1029, 19, 138, "Text",ExpressionUUID->"deaabc33-1969-4c7e-9e45-7b99da9dea8e",
 CellTags->"i:45",
 CellID->553735833],
Cell[261076, 6206, 1094, 23, 37, "CodeCaption",ExpressionUUID->"8e0ee743-f9fb-44f0-bcd9-d29356aa6b7e",
 CellID->2035395226],
Cell[CellGroupData[{
Cell[262195, 6233, 360, 8, 26, "Input",ExpressionUUID->"ee8f759c-401b-45f6-a095-817d0832fe86",
 CellID->2048594276],
Cell[262558, 6243, 506, 11, 37, "Output",ExpressionUUID->"e63d9899-dd7d-423c-a268-b9fe3d0ea111",
 CellID->1967075738]
}, Open  ]],
Cell[263079, 6257, 999, 21, 63, "Text",ExpressionUUID->"9098402d-b8dd-4816-b906-fa5d0340e837",
 CellTags->"LastCellOfAPage",
 CellID->1592898165],
Cell[264081, 6280, 525, 13, 37, "CodeCaption",ExpressionUUID->"16a1d0a9-b162-4300-bf39-0f1b35bd20f1",
 CellTags->"p: 30",
 CellID->345461069],
Cell[CellGroupData[{
Cell[264631, 6297, 311, 7, 26, "Input",ExpressionUUID->"ec29c792-09e2-47b5-b34e-1cb7fc79c83c",
 CellID->521059780],
Cell[264945, 6306, 417, 8, 37, "Output",ExpressionUUID->"e9cc4e60-1ba3-49d4-9c01-22c8518e19d5",
 CellID->1704077162]
}, Open  ]],
Cell[265377, 6317, 1493, 37, 88, "Text",ExpressionUUID->"f0e94f6c-e1e9-4c88-8017-437bd04e0d8c",
 CellTags->"i:46",
 CellID->298487107],
Cell[266873, 6356, 440, 11, 37, "CodeCaption",ExpressionUUID->"d5a721d3-7bbf-4111-87b8-9077eb88b1f2",
 CellID->61660882],
Cell[CellGroupData[{
Cell[267338, 6371, 599, 16, 26, "Input",ExpressionUUID->"6579734a-093e-4285-aac2-83968b1a0329",
 CellID->954497156],
Cell[267940, 6389, 10643, 271, 275, "Output",ExpressionUUID->"0a5d27aa-5d9d-451c-ac1e-77c5bf6443d0",
 CellID->82050695]
}, Open  ]],
Cell[278598, 6663, 409, 10, 38, "Text",ExpressionUUID->"f6a3f43f-8bd6-4fc4-b124-79039a66f7ba",
 CellID->659213111],
Cell[279010, 6675, 497, 11, 37, "CodeCaption",ExpressionUUID->"3c43a4b3-3fc9-45e2-97c1-63949ea906f2",
 CellID->586079971],
Cell[CellGroupData[{
Cell[279532, 6690, 527, 12, 26, "Input",ExpressionUUID->"9cb643c6-da01-4e12-8f6c-8d465d1afd84",
 CellID->670712328],
Cell[280062, 6704, 591, 13, 37, "Output",ExpressionUUID->"a6d9c112-2561-46a6-b42b-765b96ba6a58",
 CellID->1786279908]
}, Open  ]],
Cell[280668, 6720, 783, 17, 63, "Text",ExpressionUUID->"b329b65c-6836-4e03-b1eb-793384ef3140",
 CellID->823382524],
Cell[281454, 6739, 517, 12, 37, "CodeCaption",ExpressionUUID->"3dc83ba6-bc29-411a-b01e-46d48c6607a1",
 CellID->420237797],
Cell[CellGroupData[{
Cell[281996, 6755, 851, 22, 26, "Input",ExpressionUUID->"46cb5c30-99c4-4566-a976-b3d028d079cf",
 CellID->162508876],
Cell[282850, 6779, 15649, 393, 287, "Output",ExpressionUUID->"e2a76795-7c93-4a1f-88f9-eea89d71f0e3",
 CellTags->"LastCellOfAPage",
 CellID->890892849]
}, Open  ]],
Cell[298514, 7175, 1262, 23, 88, "Text",ExpressionUUID->"9bdc4065-d01f-4bd0-965c-f9cd09706c05",
 CellTags->{"i:47", "p: 31"},
 CellID->1091975022],
Cell[299779, 7200, 454, 11, 37, "CodeCaption",ExpressionUUID->"2ef9969b-04cc-42e0-be22-cc959929d8f1",
 CellID->499480920],
Cell[CellGroupData[{
Cell[300258, 7215, 501, 12, 26, "Input",ExpressionUUID->"687f958b-74b4-4a41-9573-c83bd5195530",
 CellID->1580004596],
Cell[300762, 7229, 613, 14, 37, "Output",ExpressionUUID->"970224e2-f281-4e7c-8f79-edaa7acedb4d",
 CellID->450748411]
}, Open  ]],
Cell[301390, 7246, 512, 10, 38, "Text",ExpressionUUID->"7fe3237b-8e4f-477c-b9c7-a7dc885a45c5",
 CellID->141699391],
Cell[301905, 7258, 455, 11, 37, "CodeCaption",ExpressionUUID->"f9cae6e7-5ce6-469c-b43e-5aa5010acc2b",
 CellID->48761906],
Cell[CellGroupData[{
Cell[302385, 7273, 862, 22, 46, "Input",ExpressionUUID->"625879aa-8b7b-4cb7-ab2a-3d858af918a3",
 CellID->300098921],
Cell[303250, 7297, 16671, 416, 305, "Output",ExpressionUUID->"55fe0635-e549-49dd-89c0-7de2b941ae43",
 CellID->692679997]
}, Open  ]],
Cell[319936, 7716, 1323, 27, 113, "Text",ExpressionUUID->"f3ad1def-1987-4d65-ab71-d71db1d29e75",
 CellID->493352970],
Cell[321262, 7745, 497, 11, 37, "CodeCaption",ExpressionUUID->"4bbe17a8-c290-45f1-8b74-6996188e5f41",
 CellID->192307659],
Cell[321762, 7758, 12264, 309, 103, "Input",ExpressionUUID->"44c21efb-4567-4117-904f-d14f09b9b4b1",
 CellID->310986164],
Cell[CellGroupData[{
Cell[334051, 8071, 253, 6, 26, "Input",ExpressionUUID->"3b710e29-4d68-4cdd-929d-1e887bab2b08",
 CellID->1916745197],
Cell[334307, 8079, 265, 6, 37, "Output",ExpressionUUID->"6c8bef09-4723-4c2e-9c06-f8137717a315",
 CellID->334337332]
}, Open  ]],
Cell[CellGroupData[{
Cell[334609, 8090, 226, 5, 26, "Input",ExpressionUUID->"0dcdebe5-4423-48d1-b8d3-8c54e9b94355",
 CellID->1390318372],
Cell[334838, 8097, 882, 26, 114, "Output",ExpressionUUID->"1d631abd-a1c5-4e00-bdd8-d716d98544ff",
 CellTags->"LastCellOfAPage",
 CellID->311315197]
}, Open  ]],
Cell[CellGroupData[{
Cell[335757, 8128, 413, 9, 26, "Input",ExpressionUUID->"765935a0-697e-43cf-a8c4-a6d6bcc7e6d6",
 CellTags->"p: 32",
 CellID->2138288348],
Cell[336173, 8139, 1748, 44, 114, "Output",ExpressionUUID->"98dbaae4-724f-4431-921b-125cbca4702d",
 CellID->766684527]
}, Open  ]],
Cell[337936, 8186, 1240, 24, 88, "Text",ExpressionUUID->"f9c69dbf-78e1-43c3-a7ec-40f8b2ed7ab3",
 CellTags->"i:48",
 CellID->1754054077],
Cell[339179, 8212, 491, 11, 37, "CodeCaption",ExpressionUUID->"767846c2-7ea6-4346-ad4e-84d91e4063c0",
 CellID->787405553],
Cell[CellGroupData[{
Cell[339695, 8227, 312, 7, 26, "Input",ExpressionUUID->"62dcc9c6-d18e-4d55-bb7e-378cd3a0edd2",
 CellID->1441744213],
Cell[340010, 8236, 405, 8, 37, "Output",ExpressionUUID->"3be55859-44ed-4832-8f49-a9a5ab4d801a",
 CellID->98315348]
}, Open  ]],
Cell[340430, 8247, 2448, 62, 139, "Text",ExpressionUUID->"ca7143cd-b56f-4d4d-ab84-a159a6dcb461",
 CellTags->"i:49",
 CellID->1335418946],
Cell[342881, 8311, 527, 11, 37, "CodeCaption",ExpressionUUID->"c6966a14-4c1a-4e05-9224-010318f624cc",
 CellID->235030631],
Cell[CellGroupData[{
Cell[343433, 8326, 298, 7, 26, "Input",ExpressionUUID->"99fb0534-1065-41d7-8dc4-bc8b8118f48f",
 CellID->1720926597],
Cell[343734, 8335, 1036, 28, 114, "Output",ExpressionUUID->"be2b8d0a-7caa-420a-81e1-fb2a68607d81",
 CellID->434343204]
}, Open  ]],
Cell[CellGroupData[{
Cell[344807, 8368, 329, 8, 26, "Input",ExpressionUUID->"4f90e5a4-c079-4159-bf6a-83aa6965fa37",
 CellID->522834485],
Cell[345139, 8378, 1670, 43, 114, "Output",ExpressionUUID->"239fba63-011d-4c6d-a4a1-1c130ed0f9f0",
 CellID->1292018600]
}, Open  ]],
Cell[346824, 8424, 1261, 30, 63, "Text",ExpressionUUID->"75ce24a0-fc8c-4d9f-b8e3-08d0cb19a5d2",
 CellTags->"LastCellOfAPage",
 CellID->1535474437],
Cell[348088, 8456, 787, 22, 37, "CodeCaption",ExpressionUUID->"a0550e92-b927-4b7c-b2ff-08290cadd485",
 CellTags->"p: 33",
 CellID->1551121061],
Cell[CellGroupData[{
Cell[348900, 8482, 8427, 203, 31, "Input",ExpressionUUID->"e140afbd-804a-4f50-9640-9d5c32b407ee",
 CellID->2101992953],
Cell[357330, 8687, 1553, 41, 114, "Output",ExpressionUUID->"d8258422-caa4-4e23-8be4-26094630527b",
 CellID->1882880621]
}, Open  ]],
Cell[358898, 8731, 2473, 66, 88, "Text",ExpressionUUID->"4ae8c18b-1aa4-4e55-8f57-384dd5cb5197",
 CellTags->"i:50",
 CellID->599170125],
Cell[361374, 8799, 457, 11, 37, "CodeCaption",ExpressionUUID->"91606ca6-9a44-4398-94cf-b4462eb3d0d0",
 CellID->181301775],
Cell[CellGroupData[{
Cell[361856, 8814, 460, 11, 26, "Input",ExpressionUUID->"4212e2a0-7355-4e13-9ab0-2480e151ca0a",
 CellID->357355651],
Cell[362319, 8827, 559, 12, 57, "Output",ExpressionUUID->"9f898989-617f-4b30-9330-30e9862accc2",
 CellID->613083487]
}, Open  ]],
Cell[362893, 8842, 575, 12, 39, "CodeText",ExpressionUUID->"8e746747-a150-4338-8a0d-91cbd8998af2",
 CellID->566498279],
Cell[CellGroupData[{
Cell[363493, 8858, 368, 9, 26, "Input",ExpressionUUID->"355eacfb-350b-444f-b398-55b7bb52590f",
 CellID->1189100753],
Cell[363864, 8869, 479, 10, 37, "Output",ExpressionUUID->"d3dc7d5d-fcc8-459e-9270-4b4cc5c2288c",
 CellID->1561412736]
}, Open  ]],
Cell[364358, 8882, 1744, 37, 113, "Text",ExpressionUUID->"656469c4-ffff-43a0-aca4-58bef42b0c68",
 CellID->113603876],
Cell[366105, 8921, 684, 18, 37, "CodeCaption",ExpressionUUID->"ea5a7b1b-5560-4af5-8bdc-5ef66add7af4",
 CellID->78954144],
Cell[CellGroupData[{
Cell[366814, 8943, 273, 6, 26, "Input",ExpressionUUID->"8f1b3917-4328-4b74-bbf0-b978fe7f3f56",
 CellID->1946098998],
Cell[367090, 8951, 457, 10, 37, "Output",ExpressionUUID->"42718461-f28d-4fd3-a2f5-ad6e7e81556e",
 CellID->997953597]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[367596, 8967, 303, 4, 55, "Subsubsection",ExpressionUUID->"9829ec01-932b-484e-9166-a746d966b8ca",
 CellID->1782190060],
Cell[CellGroupData[{
Cell[367924, 8975, 505, 8, 54, "Subsubsubsection",ExpressionUUID->"41cff5d0-e94f-403e-b0c1-a210c2cf26c3",
 CellID->1659344783],
Cell[368432, 8985, 1949, 41, 113, "Text",ExpressionUUID->"e83ebe2c-15dd-428b-ae95-65d3822bf700",
 CellTags->"i:51",
 CellID->1219127502],
Cell[370384, 9028, 433, 10, 39, "CodeText",ExpressionUUID->"bf6acba1-8341-4c7d-aa52-03d56a7d8dd6",
 CellID->1472305551],
Cell[CellGroupData[{
Cell[370842, 9042, 452, 10, 26, "Input",ExpressionUUID->"f56e8d6d-b869-449c-b4c2-b329437fc8d7",
 CellID->152859042],
Cell[371297, 9054, 504, 12, 37, "Output",ExpressionUUID->"5971dc72-abbc-401f-b43d-5920a4dc6949",
 CellTags->"LastCellOfAPage",
 CellID->422790878]
}, Open  ]],
Cell[371816, 9069, 711, 17, 38, "Text",ExpressionUUID->"7eb1ae1f-b3dc-45e0-8d03-1305f41f45be",
 CellTags->"p: 34",
 CellID->2123458214],
Cell[372530, 9088, 458, 11, 37, "CodeCaption",ExpressionUUID->"88e9d883-596a-4217-bcf0-999516619fae",
 CellID->456570819],
Cell[CellGroupData[{
Cell[373013, 9103, 500, 12, 26, "Input",ExpressionUUID->"c9aa241c-04ea-488a-9783-d9e3d8161c28",
 CellID->1975564201],
Cell[373516, 9117, 600, 14, 37, "Output",ExpressionUUID->"0903a580-8289-4d12-a54b-c79f16896bec",
 CellID->1271978155]
}, Open  ]],
Cell[374131, 9134, 266, 5, 37, "CodeCaption",ExpressionUUID->"6f6ea88e-0827-45ee-8af0-a3c45bd17dec",
 CellID->1797302397],
Cell[CellGroupData[{
Cell[374422, 9143, 401, 11, 26, "Input",ExpressionUUID->"70ce5e5b-de76-48a0-a73d-7e1a6428f2e3",
 CellID->523442690],
Cell[374826, 9156, 408, 11, 37, "Output",ExpressionUUID->"9ff14368-30d6-4784-a330-3e192cbc2a84",
 CellID->1361115754]
}, Open  ]],
Cell[375249, 9170, 2337, 55, 138, "Text",ExpressionUUID->"c3b1e2d3-ec29-4a75-9c62-bccf16c09da5",
 CellID->513607383],
Cell[377589, 9227, 714, 13, 138, "Text",ExpressionUUID->"d3ce843b-58fd-4cf3-986f-3b7320c1f1e4",
 CellID->775575769],
Cell[378306, 9242, 572, 12, 37, "CodeCaption",ExpressionUUID->"4fd2ccc7-d412-4b84-b531-ae65136ca358",
 CellID->9740974],
Cell[CellGroupData[{
Cell[378903, 9258, 574, 16, 26, "Input",ExpressionUUID->"f416f68a-33ae-42ec-9724-5f6e6637f35e",
 CellID->1471861292],
Cell[379480, 9276, 594, 14, 37, "Output",ExpressionUUID->"8de9b473-0ebe-44d1-b5ca-0b544856fede",
 CellID->1816568413]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[380123, 9296, 507, 8, 54, "Subsubsubsection",ExpressionUUID->"007effd3-52ef-4e0a-bf3a-8fd0503f8e04",
 CellID->777347503],
Cell[380633, 9306, 3608, 84, 213, "Text",ExpressionUUID->"a8e2127c-ddce-45e4-b8e2-0560a7a2f71b",
 CellTags->"i:52",
 CellID->184130491],
Cell[384244, 9392, 2314, 49, 163, "Text",ExpressionUUID->"39590882-a79d-418f-885c-eb6aa32fad5d",
 CellTags->"LastCellOfAPage",
 CellID->606608944],
Cell[386561, 9443, 1010, 26, 59, "CodeCaption",ExpressionUUID->"e72f9de7-367d-4245-bddb-05e3e3bb57eb",
 CellTags->"p: 35",
 CellID->914741257],
Cell[CellGroupData[{
Cell[387596, 9473, 1147, 27, 104, "Input",ExpressionUUID->"737b0ab2-d260-45bc-82cd-8fff0fce8766",
 CellID->220877526],
Cell[388746, 9502, 339, 9, 21, "Echo",ExpressionUUID->"674ba09a-029d-4b16-9ded-1318c8d44b80",
 CellID->2134996429],
Cell[389088, 9513, 2590, 65, 114, "Output",ExpressionUUID->"17f704f2-072a-4d1d-aeca-4414a4504321",
 CellID->580724480]
}, Open  ]],
Cell[391693, 9581, 659, 13, 63, "Text",ExpressionUUID->"14d48c18-6b49-4fd5-b9e0-831c9f08d563",
 CellID->1315068279],
Cell[392355, 9596, 461, 11, 37, "CodeCaption",ExpressionUUID->"07b18725-7d88-49a9-9a13-6dd3dcd33488",
 CellID->409133792],
Cell[CellGroupData[{
Cell[392841, 9611, 542, 13, 27, "Input",ExpressionUUID->"32c55b19-4b16-46fa-a30a-cd347f054a10",
 CellID->1296074320],
Cell[393386, 9626, 2457, 63, 114, "Output",ExpressionUUID->"5b466b52-8be3-47c0-9936-4fd8898f9a5a",
 CellID->1754372011]
}, Open  ]],
Cell[395858, 9692, 1831, 36, 88, "Text",ExpressionUUID->"801d6257-b237-461b-a5e0-5dbc327ec3aa",
 CellID->365064426],
Cell[397692, 9730, 697, 15, 37, "CodeCaption",ExpressionUUID->"ade4547f-d5bc-4407-8b13-e1b599b63843",
 CellID->1734301627],
Cell[CellGroupData[{
Cell[398414, 9749, 407, 11, 27, "Input",ExpressionUUID->"ba131732-13b0-4e63-bb9e-c3ff7ddf9e7c",
 CellID->1852243537],
Cell[398824, 9762, 2239, 60, 114, "Output",ExpressionUUID->"74e4ba7d-e147-4aeb-913b-b1914cc91f89",
 CellID->1334883087]
}, Open  ]],
Cell[401078, 9825, 530, 11, 38, "Text",ExpressionUUID->"1ddcab83-8e7e-4951-b9aa-35ea06905f48",
 CellID->145195687],
Cell[401611, 9838, 511, 10, 37, "CodeCaption",ExpressionUUID->"2faadd64-6341-4e23-b77e-83bbd2e6a01f",
 CellID->1627334601],
Cell[CellGroupData[{
Cell[402147, 9852, 472, 12, 26, "Input",ExpressionUUID->"591cc3c2-d0cf-4ce2-8068-a7845cee1d8f",
 CellID->512026645],
Cell[402622, 9866, 1198, 38, 57, "Output",ExpressionUUID->"73ca8356-28d5-4fad-9bfb-334a13602a28",
 CellTags->"LastCellOfAPage",
 CellID->97357396]
}, Open  ]],
Cell[403835, 9907, 775, 14, 63, "Text",ExpressionUUID->"4d887762-65a9-41da-a694-45bd7e33dc6b",
 CellTags->"p: 36",
 CellID->1582731546]
}, Open  ]],
Cell[CellGroupData[{
Cell[404647, 9926, 493, 8, 54, "Subsubsubsection",ExpressionUUID->"940af334-193c-428d-9c8d-876f91aa6668",
 CellID->1743256220],
Cell[405143, 9936, 1141, 24, 113, "Text",ExpressionUUID->"67077beb-ebdd-44d5-92e6-8c5826cd9e5f",
 CellTags->"i:53",
 CellID->2123712673],
Cell[406287, 9962, 524, 11, 37, "CodeCaption",ExpressionUUID->"36bfd1f3-c251-4d05-9b50-2004e2e4618e",
 CellID->71967055],
Cell[CellGroupData[{
Cell[406836, 9977, 526, 13, 26, "Input",ExpressionUUID->"4adc83dc-2d6c-4f14-b0a5-c4a57dce716a",
 CellID->1395622584],
Cell[407365, 9992, 2267, 60, 235, "Output",ExpressionUUID->"b2233bbc-9403-4b85-8796-5be79425d525",
 CellID->1229755306]
}, Open  ]],
Cell[409647, 10055, 1136, 19, 163, "Text",ExpressionUUID->"ba111c1c-01a7-4f17-90f4-9c9e402f3cbd",
 CellID->138589008],
Cell[410786, 10076, 448, 10, 37, "CodeCaption",ExpressionUUID->"90091b1f-4960-4797-ba4c-dd60a2a5c2b2",
 CellID->861981625],
Cell[CellGroupData[{
Cell[411259, 10090, 593, 13, 26, "Input",ExpressionUUID->"347571ec-cb7b-4520-a2bc-de86ba389bb5",
 CellID->344223888],
Cell[411855, 10105, 2305, 61, 143, "Output",ExpressionUUID->"6ede1dcc-b3f6-48f9-b701-3b0e974e6a89",
 CellID->453509200]
}, Open  ]],
Cell[414175, 10169, 575, 13, 38, "Text",ExpressionUUID->"eeda2d21-6b06-4f43-978d-f0509742ff16",
 CellTags->"LastCellOfAPage",
 CellID->1260116051],
Cell[414753, 10184, 727, 18, 37, "CodeCaption",ExpressionUUID->"38955627-95f7-449c-beb8-73b1be55ed12",
 CellTags->"p: 37",
 CellID->87742728],
Cell[CellGroupData[{
Cell[415505, 10206, 552, 13, 26, "Input",ExpressionUUID->"baa424a8-483b-4a9a-b8c7-7610707170d4",
 CellID->2038438949],
Cell[416060, 10221, 2469, 67, 189, "Output",ExpressionUUID->"5c95dfd9-7214-4829-9835-063b201d3704",
 CellID->396021245]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[418578, 10294, 492, 8, 54, "Subsubsubsection",ExpressionUUID->"eb8101d9-2ef6-4aca-bb9b-ef183d858ca0",
 CellID->257251033],
Cell[419073, 10304, 1344, 25, 188, "Text",ExpressionUUID->"8bb7c308-48e4-4d5b-bf7a-7a1450b3141e",
 CellTags->"i:54",
 CellID->111233947],
Cell[420420, 10331, 448, 11, 37, "CodeCaption",ExpressionUUID->"da04b07a-8530-4160-8ae5-a5d59afa8b76",
 CellID->12392933],
Cell[CellGroupData[{
Cell[420893, 10346, 356, 8, 26, "Input",ExpressionUUID->"7f876aaa-b410-4487-a324-97aa85544b72",
 CellID->74760028],
Cell[421252, 10356, 315, 5, 37, "Output",ExpressionUUID->"e115e32b-074f-4f77-85c9-3c220b8e054d",
 CellID->911184165]
}, Open  ]],
Cell[421582, 10364, 2312, 57, 63, "Text",ExpressionUUID->"03875d53-2d1b-4b70-a644-625ccd34b7ef",
 CellID->293600159],
Cell[423897, 10423, 1587, 40, 63, "Text",ExpressionUUID->"6f1b256d-ad11-4a94-9915-4796ffbcb58f",
 CellID->847495178],
Cell[425487, 10465, 1109, 25, 59, "CodeCaption",ExpressionUUID->"c0f3fdfd-52a5-4c8f-a0c9-ac55cf86ea92",
 CellID->219345899],
Cell[CellGroupData[{
Cell[426621, 10494, 625, 17, 26, "Input",ExpressionUUID->"b43962e3-5de1-4e6c-90ec-4c7968010e99",
 CellID->1961728579],
Cell[427249, 10513, 6008, 158, 302, "Output",ExpressionUUID->"b29e7876-7953-4758-b14e-192ebe6ae75e",
 CellTags->"LastCellOfAPage",
 CellID->1232306257]
}, Open  ]],
Cell[433272, 10674, 2184, 51, 88, "Text",ExpressionUUID->"61de52c5-56a4-441b-bc9b-9814c1cc9841",
 CellTags->"p: 38",
 CellID->1082026607],
Cell[435459, 10727, 496, 11, 37, "CodeCaption",ExpressionUUID->"acd4cd96-e464-452f-8a10-68732f8849de",
 CellID->420475458],
Cell[CellGroupData[{
Cell[435980, 10742, 816, 22, 46, "Input",ExpressionUUID->"ac509e22-36c1-44fd-8951-60c6391d775b",
 CellID->911727825],
Cell[436799, 10766, 11658, 295, 316, "Output",ExpressionUUID->"8883a571-a7a4-48d1-a3db-5420ff44be9f",
 CellID->780482359]
}, Open  ]],
Cell[448472, 11064, 608, 12, 38, "Text",ExpressionUUID->"e5a19467-26a2-4347-9449-39f4dc85b690",
 CellID->170762455],
Cell[449083, 11078, 752, 17, 39, "CodeText",ExpressionUUID->"0a38401f-9d92-41a8-845d-9dbbc2d20745",
 CellID->2103618955],
Cell[CellGroupData[{
Cell[449860, 11099, 869, 24, 46, "Input",ExpressionUUID->"ee6eb42e-32b7-4030-9b35-a55adc4f698e",
 CellID->1098759784],
Cell[450732, 11125, 1304, 34, 76, "Output",ExpressionUUID->"64d47c2a-474a-45eb-8366-59c0050a04bb",
 CellID->729574479]
}, Open  ]],
Cell[452051, 11162, 1142, 26, 88, "Text",ExpressionUUID->"e72d4152-091a-40c6-abb5-5d50a4fc05e3",
 CellID->1674011242],
Cell[453196, 11190, 450, 11, 37, "CodeCaption",ExpressionUUID->"ac2d480c-c2a4-4833-979d-5f91ef21681f",
 CellID->461651975],
Cell[CellGroupData[{
Cell[453671, 11205, 304, 7, 26, "Input",ExpressionUUID->"10e6d758-9013-4525-95e7-5076661a6610",
 CellID->140397775],
Cell[453978, 11214, 193, 3, 37, "Output",ExpressionUUID->"6cea534c-1dfc-450b-ac92-6eea3235c7c5",
 CellID->579967694]
}, Open  ]],
Cell[454186, 11220, 904, 24, 59, "CodeCaption",ExpressionUUID->"11b2b7a2-b60f-42a8-9687-94f3ae4bfd9e",
 CellTags->"i:55",
 CellID->2111128489],
Cell[CellGroupData[{
Cell[455115, 11248, 8582, 209, 31, "Input",ExpressionUUID->"1c33371b-74e9-4823-b149-5e6f69c0f161",
 CellID->1516278644],
Cell[463700, 11459, 263, 6, 37, "Output",ExpressionUUID->"5118fc69-3355-42f6-a69c-f253929e31cc",
 CellID->1975872469]
}, Open  ]],
Cell[463978, 11468, 2425, 63, 63, "Text",ExpressionUUID->"ca19dbc3-1bc9-42ba-9b78-e908f873596c",
 CellTags->"LastCellOfAPage",
 CellID->684075409]
}, Open  ]],
Cell[CellGroupData[{
Cell[466440, 11536, 538, 10, 54, "Subsubsubsection",ExpressionUUID->"2a155ad8-5784-4770-bc7d-694d0f608a81",
 PageBreakAbove->True,
 CellTags->"p: 39",
 CellID->956965639],
Cell[466981, 11548, 861, 19, 63, "Text",ExpressionUUID->"8cfb8c49-3427-4687-9b44-860f0324783f",
 CellTags->"i:56",
 CellID->1222765007],
Cell[467845, 11569, 452, 11, 37, "CodeCaption",ExpressionUUID->"7d7571a5-4a97-42e0-932c-8e8348d4581a",
 CellID->42688470],
Cell[CellGroupData[{
Cell[468322, 11584, 400, 10, 26, "Input",ExpressionUUID->"23dfdbde-ef3c-44a6-9922-f3678e171744",
 CellID->1365141791],
Cell[468725, 11596, 577, 14, 37, "Output",ExpressionUUID->"526b58f4-0c24-4ad4-8fb9-2f3b38572d7d",
 CellID->1191941046]
}, Open  ]],
Cell[469317, 11613, 1010, 24, 88, "Text",ExpressionUUID->"835870e3-a8c9-4bbb-9cdc-236ec51e9d9d",
 CellTags->"i:57",
 CellID->1491901077],
Cell[470330, 11639, 924, 19, 63, "Text",ExpressionUUID->"7f48a898-5480-4ff2-905a-d6886e967289",
 CellID->847319374],
Cell[471257, 11660, 744, 16, 37, "CodeCaption",ExpressionUUID->"552fb5a2-9da7-40e0-97d3-4378c0c43371",
 CellID->145983669],
Cell[CellGroupData[{
Cell[472026, 11680, 369, 10, 26, "Input",ExpressionUUID->"aae865bd-c9c3-44f7-96b3-1dbc97887bb4",
 CellID->2136244131],
Cell[472398, 11692, 883, 16, 28, "Message",ExpressionUUID->"ce66d673-fb4b-4489-8489-644bccde87b3",
 CellID->72059448],
Cell[473284, 11710, 506, 12, 37, "Output",ExpressionUUID->"4cbd093e-d21b-4320-bfa9-acf0cec1f051",
 CellID->215424652]
}, Open  ]],
Cell[473805, 11725, 981, 19, 88, "Text",ExpressionUUID->"06468bfd-350a-4586-8b1d-24cafe4b3dc1",
 CellID->191890356],
Cell[474789, 11746, 546, 11, 37, "CodeCaption",ExpressionUUID->"b79a4811-b04b-4017-aae6-4324f024cf29",
 CellID->866140152],
Cell[CellGroupData[{
Cell[475360, 11761, 342, 9, 26, "Input",ExpressionUUID->"3cbefbf6-d4e5-4ca0-87b0-88ea473b7110",
 CellID->1376850713],
Cell[475705, 11772, 586, 14, 37, "Output",ExpressionUUID->"5c4a0071-6638-4919-b65e-e26fd2276998",
 CellID->1252440185]
}, Open  ]],
Cell[476306, 11789, 826, 18, 38, "Text",ExpressionUUID->"b2573d3f-6040-4c08-8af1-aad3e8bb58bb",
 CellID->916129082],
Cell[477135, 11809, 681, 17, 37, "CodeCaption",ExpressionUUID->"426cd13a-cea6-4caa-b680-155c1bab6c3d",
 CellID->428972552],
Cell[CellGroupData[{
Cell[477841, 11830, 314, 7, 26, "Input",ExpressionUUID->"f2863c78-19ad-4d18-a035-31a986f25e67",
 CellID->148211364],
Cell[478158, 11839, 477, 10, 37, "Output",ExpressionUUID->"c6f07bf6-7b34-40bb-b217-4bd13bd2dcea",
 CellID->1110103062]
}, Open  ]],
Cell[478650, 11852, 2824, 60, 138, "Text",ExpressionUUID->"dfdbdc8d-f178-4703-8a31-feed756d9a21",
 CellTags->{"LastCellOfAPage", "i:58"},
 CellID->382985419],
Cell[481477, 11914, 524, 13, 37, "CodeCaption",ExpressionUUID->"90dc00c9-4961-4b3f-b42a-097fd355d8b1",
 CellTags->"p: 40",
 CellID->143558437],
Cell[CellGroupData[{
Cell[482026, 11931, 368, 9, 26, "Input",ExpressionUUID->"ac8b6c41-8d07-43f7-94d6-885c0eb6c187",
 CellID->1483139215],
Cell[482397, 11942, 484, 10, 37, "Output",ExpressionUUID->"06a19753-6083-4938-a3f8-70b900d16a45",
 CellID->1787142219]
}, Open  ]],
Cell[482896, 11955, 971, 23, 38, "Text",ExpressionUUID->"d1e021c8-7092-49f9-bc6c-5be56b5eea3d",
 CellID->1941302877],
Cell[483870, 11980, 712, 16, 37, "CodeCaption",ExpressionUUID->"77f0467f-b4aa-447b-928a-80f8ba0707cb",
 CellID->92874239],
Cell[CellGroupData[{
Cell[484607, 12000, 363, 9, 26, "Input",ExpressionUUID->"577b0789-a0b6-4741-b366-e13617d71480",
 CellID->1482873745],
Cell[484973, 12011, 443, 9, 37, "Output",ExpressionUUID->"ff440f4e-daa0-49be-a584-f4b4bced6e47",
 CellID->420566703]
}, Open  ]],
Cell[CellGroupData[{
Cell[485453, 12025, 302, 7, 26, "Input",ExpressionUUID->"65c7af6a-7ead-4f5a-bd90-05a96106fc30",
 CellID->993332672],
Cell[485758, 12034, 391, 7, 37, "Output",ExpressionUUID->"9443cb37-0a5e-45c6-a945-3fa704931da7",
 CellID->268044286]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[486222, 12049, 190, 2, 57, "Subsection",ExpressionUUID->"4a03c6df-3bd1-416d-95f4-65fd5871b173",
 CellID->699787974],
Cell[486415, 12053, 575, 9, 113, "Text",ExpressionUUID->"52fe420d-441a-468e-a37f-653971a88c6d",
 CellID->1250616598],
Cell[CellGroupData[{
Cell[487015, 12066, 556, 10, 55, "Subsubsection",ExpressionUUID->"3fedcc64-fc7c-459f-b88d-856d3c47fb88",
 CellID->1649917466],
Cell[487574, 12078, 526, 12, 63, "Text",ExpressionUUID->"992eb565-a951-4c7c-b977-3e450739ba49",
 CellTags->"i:59",
 CellID->1235558941],
Cell[488103, 12092, 452, 11, 37, "CodeCaption",ExpressionUUID->"5e6b12ab-6cf8-4003-99ce-e4ccf74e8847",
 CellID->555924890],
Cell[CellGroupData[{
Cell[488580, 12107, 625, 17, 26, "Input",ExpressionUUID->"64a7c8af-541a-4d96-b6fc-e31045fae371",
 CellID->1271558542],
Cell[489208, 12126, 246, 5, 37, "Output",ExpressionUUID->"30363631-c1f5-489a-881f-32d08e69a405",
 CellID->183755095]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[489503, 12137, 556, 10, 55, "Subsubsection",ExpressionUUID->"9687753a-f409-4210-ae95-b9044789eda1",
 CellID->1736504741],
Cell[490062, 12149, 1573, 35, 88, "Text",ExpressionUUID->"e22260e3-7db1-413e-aa3f-df0d36a62cf9",
 CellTags->"i:60",
 CellID->1695096994],
Cell[491638, 12186, 207, 2, 37, "CodeCaption",ExpressionUUID->"3daf0467-c7d1-47db-9180-04764855b5ef",
 CellID->203368130],
Cell[CellGroupData[{
Cell[491870, 12192, 395, 9, 26, "Input",ExpressionUUID->"ea2818b7-a212-416d-bfa0-0f6f5bed9ac8",
 CellID->1318898366],
Cell[492268, 12203, 457, 8, 37, "Output",ExpressionUUID->"62577255-4259-49a8-8362-c63e39a5affd",
 CellID->1637357366]
}, Open  ]],
Cell[492740, 12214, 536, 12, 38, "Text",ExpressionUUID->"1c3bfab2-eb9a-4d15-9f5f-1bb440065010",
 CellTags->"LastCellOfAPage",
 CellID->1274898801],
Cell[493279, 12228, 479, 12, 37, "CodeCaption",ExpressionUUID->"00402900-fdd9-48db-af26-59351debf13d",
 CellTags->"p: 41",
 CellID->399629588],
Cell[CellGroupData[{
Cell[493783, 12244, 597, 17, 26, "Input",ExpressionUUID->"6eb295fd-5c27-4eeb-95b3-21466928cbcb",
 CellID->750290687],
Cell[494383, 12263, 635, 16, 37, "Output",ExpressionUUID->"809e6703-1c9c-4d94-9bc5-9c33fafbd522",
 CellID->182194538]
}, Open  ]],
Cell[495033, 12282, 613, 13, 38, "Text",ExpressionUUID->"81f2e740-45b7-4e99-a8ae-603a6b4bca23",
 CellID->725389429],
Cell[495649, 12297, 963, 25, 37, "CodeCaption",ExpressionUUID->"f9b9a923-565b-4906-9fb3-040a9f718ba5",
 CellTags->"i:61",
 CellID->175348173],
Cell[CellGroupData[{
Cell[496637, 12326, 401, 9, 26, "Input",ExpressionUUID->"c907ed33-ada9-464d-8e13-b8a742be1d5e",
 CellID->343496413],
Cell[497041, 12337, 482, 9, 37, "Output",ExpressionUUID->"8273e1a4-408f-4b0f-a7cc-c0e2b634313c",
 CellID->1262001460]
}, Open  ]],
Cell[497538, 12349, 219, 2, 38, "Text",ExpressionUUID->"5602ae1e-08d6-4ee5-97fc-00317fca5a8b",
 CellID->2135673558],
Cell[497760, 12353, 777, 19, 37, "CodeCaption",ExpressionUUID->"76153ad4-ce27-4d12-9cd1-80c9a02b3821",
 CellID->583362609],
Cell[CellGroupData[{
Cell[498562, 12376, 669, 17, 46, "Input",ExpressionUUID->"8bd6e81a-dd45-4147-93fb-e87187a46288",
 CellID->1226091640],
Cell[499234, 12395, 638, 13, 37, "Output",ExpressionUUID->"c6ced6ec-c707-4481-ac30-44f510c02c01",
 CellID->1704892287]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[499921, 12414, 563, 10, 55, "Subsubsection",ExpressionUUID->"1cb981e4-1b76-4f2b-9b50-3ad7e7bd5726",
 CellID->437998704],
Cell[500487, 12426, 2122, 45, 163, "Text",ExpressionUUID->"ce2b1d0e-b312-4310-aa52-6ae6ad541d57",
 CellTags->"i:62",
 CellID->1563893249],
Cell[502612, 12473, 235, 4, 37, "CodeCaption",ExpressionUUID->"371127de-3786-4740-a323-e68eeaaf44a5",
 CellID->174040160],
Cell[CellGroupData[{
Cell[502872, 12481, 526, 12, 27, "Input",ExpressionUUID->"8ebe2038-0e26-4fcd-8251-4d619b34a6bc",
 CellID->537849349],
Cell[503401, 12495, 671, 15, 43, "Output",ExpressionUUID->"95caad6a-e1c4-424a-ad17-80e478d53b24",
 CellID->1774813756]
}, Open  ]],
Cell[504087, 12513, 579, 12, 59, "CodeCaption",ExpressionUUID->"268f58ee-af94-4cae-b664-b95b069b576e",
 CellID->1771601541],
Cell[CellGroupData[{
Cell[504691, 12529, 479, 9, 26, "Input",ExpressionUUID->"40b85976-74d4-4ce7-989d-79036d5e7beb",
 CellID->1406754689],
Cell[505173, 12540, 2720, 71, 114, "Output",ExpressionUUID->"f9460b68-8db0-429c-a8c4-a543f2f499e2",
 CellID->2015535995]
}, Open  ]],
Cell[507908, 12614, 1209, 28, 63, "Text",ExpressionUUID->"7a8f1bbc-14c3-47b9-ba0b-2145f07bdc4e",
 CellTags->"LastCellOfAPage",
 CellID->1650910852],
Cell[509120, 12644, 336, 9, 37, "CodeCaption",ExpressionUUID->"cf5bacb6-c1b4-4de9-9408-3059f6fdfd32",
 CellTags->"p: 42",
 CellID->75047153],
Cell[CellGroupData[{
Cell[509481, 12657, 250, 5, 27, "Input",ExpressionUUID->"f0e5b446-3a7e-45ef-85f7-3447c90173f9",
 CellID->478816448],
Cell[509734, 12664, 1636, 43, 76, "Output",ExpressionUUID->"c8cc5417-64e8-4cc4-a180-d2576eed8860",
 CellID->1927714207]
}, Open  ]],
Cell[511385, 12710, 333, 7, 38, "Text",ExpressionUUID->"2470cdeb-221a-44d3-b670-5bdd387efea8",
 CellID->281379911],
Cell[511721, 12719, 317, 8, 37, "CodeCaption",ExpressionUUID->"cae44e65-9ee6-4890-8e6d-928d27a743df",
 CellID->51868181],
Cell[CellGroupData[{
Cell[512063, 12731, 299, 6, 27, "Input",ExpressionUUID->"292a47b0-4f58-4bbe-899c-270cb7cd2dcb",
 CellID->1416096887],
Cell[512365, 12739, 1133, 28, 57, "Output",ExpressionUUID->"869ca331-5dad-479a-b8ad-f45fa36e0541",
 CellID->1031174353]
}, Open  ]],
Cell[513513, 12770, 1087, 21, 88, "Text",ExpressionUUID->"978c6016-0fc4-4e04-a882-c36f0637c779",
 CellID->1408211335],
Cell[514603, 12793, 732, 17, 37, "CodeCaption",ExpressionUUID->"8c1268b5-61e1-46a2-9835-4a2e49ebdd73",
 CellID->78898118],
Cell[CellGroupData[{
Cell[515360, 12814, 375, 9, 27, "Input",ExpressionUUID->"a4a77e58-ff87-4b5e-b7f2-43a90e24978e",
 CellID->447096387],
Cell[515738, 12825, 462, 10, 38, "Output",ExpressionUUID->"54eb72af-ccc5-4f3d-8947-6732c7704d23",
 CellID->510714406]
}, Open  ]],
Cell[CellGroupData[{
Cell[516237, 12840, 430, 9, 26, "Input",ExpressionUUID->"34977c1a-0824-40b2-849d-3fa4f6005460",
 CellID->1188914369],
Cell[516670, 12851, 2776, 74, 114, "Output",ExpressionUUID->"75097af5-8da5-46a1-b346-92e95438262e",
 CellID->634098257]
}, Open  ]],
Cell[519461, 12928, 2823, 69, 163, "Text",ExpressionUUID->"7ca927c0-888a-4717-b4fd-6c82a98f3491",
 CellID->1789701143],
Cell[522287, 12999, 519, 11, 37, "CodeCaption",ExpressionUUID->"728d5006-15c3-4e00-b889-d68af00b75b8",
 CellID->21305542],
Cell[CellGroupData[{
Cell[522831, 13014, 559, 12, 26, "Input",ExpressionUUID->"fe1b1122-744c-42b7-afb7-810737133a5d",
 CellID->483942409],
Cell[523393, 13028, 2578, 70, 114, "Output",ExpressionUUID->"325b814e-35be-4212-b9f9-c9d3e1f43e72",
 CellTags->"LastCellOfAPage",
 CellID->1683184762]
}, Open  ]],
Cell[525986, 13101, 1903, 40, 113, "Text",ExpressionUUID->"ea50a8e1-1e14-4182-b104-8626a1da9b94",
 CellTags->"p: 43",
 CellID->988630503]
}, Open  ]],
Cell[CellGroupData[{
Cell[527926, 13146, 555, 10, 55, "Subsubsection",ExpressionUUID->"3e69a535-ebf6-46de-9130-a55e10fd991f",
 CellID->803122163],
Cell[528484, 13158, 1848, 36, 163, "Text",ExpressionUUID->"9955ac2c-82ce-4bde-b456-88e5165afda7",
 CellTags->"i:63",
 CellID->874784024],
Cell[530335, 13196, 468, 11, 37, "CodeCaption",ExpressionUUID->"fb9b0e52-11bc-47d1-9dcf-2bf7a15e274b",
 CellID->191784724],
Cell[CellGroupData[{
Cell[530828, 13211, 275, 5, 26, "Input",ExpressionUUID->"414bb4d5-9f7f-4140-82dc-f8a3ab0f9ec1",
 CellID->1207445190],
Cell[531106, 13218, 1127, 28, 57, "Output",ExpressionUUID->"2a7506dc-3416-4ced-b597-f618d949fc34",
 CellID->869259118]
}, Open  ]],
Cell[532248, 13249, 570, 11, 63, "Text",ExpressionUUID->"5b51faf6-7507-4c49-b0ee-4a4d73f4e50d",
 CellID->1719925492],
Cell[532821, 13262, 442, 10, 37, "CodeCaption",ExpressionUUID->"1579c861-f514-4681-bf71-7459dee3e2f4",
 CellID->264107795],
Cell[CellGroupData[{
Cell[533288, 13276, 283, 6, 26, "Input",ExpressionUUID->"5a0dd856-8e05-48c0-a515-e10d43811138",
 CellID->689310341],
Cell[533574, 13284, 1164, 28, 57, "Output",ExpressionUUID->"53e27708-1d7d-47a2-9384-4c89c7e24db7",
 CellID->1991491309]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[534787, 13318, 564, 10, 55, "Subsubsection",ExpressionUUID->"5e21b9c3-aea2-46e2-b807-1ee39b995ae4",
 CellID->888505878],
Cell[535354, 13330, 1682, 34, 163, "Text",ExpressionUUID->"06583cdc-b3b4-421a-a0c5-a149cc37a160",
 CellTags->"i:64",
 CellID->647260802],
Cell[537039, 13366, 489, 11, 37, "CodeCaption",ExpressionUUID->"8a05cfe5-9a49-4fdf-b055-c1575907aff9",
 CellID->90032010],
Cell[CellGroupData[{
Cell[537553, 13381, 237, 4, 26, "Input",ExpressionUUID->"352607ca-5e8d-45b2-94d9-4b8693cd6bde",
 CellID->446525748],
Cell[537793, 13387, 2341, 61, 95, "Output",ExpressionUUID->"8a9d53c0-cadb-4a93-af00-901d79ef71a9",
 CellID->398473053]
}, Open  ]],
Cell[540149, 13451, 934, 20, 88, "Text",ExpressionUUID->"11c8cac4-571f-4069-b989-90a990d93123",
 CellID->2042694667],
Cell[541086, 13473, 3767, 88, 1299, "Text",ExpressionUUID->"d3da8d07-5627-4657-a338-310452796ea8",
 CellTags->{"LastCellOfAPage", "i:65", "p: 44"},
 CellID->1190543782],
Cell[544856, 13563, 1140, 25, 59, "CodeCaption",ExpressionUUID->"5c07beb4-435d-4cec-9c41-0ac4377b73b3",
 CellID->491201136],
Cell[CellGroupData[{
Cell[546021, 13592, 9022, 219, 88, "Input",ExpressionUUID->"622e66e1-da85-4154-b0fc-43b198e8fc38",
 CellID->8373282],
Cell[555046, 13813, 624, 12, 57, "Output",ExpressionUUID->"44b1705d-8130-4ad1-901f-27ffd5712e34",
 CellID->1284417596]
}, Open  ]],
Cell[555685, 13828, 1203, 25, 113, "Text",ExpressionUUID->"75826578-da33-406c-bf0f-39507bbe0c9e",
 CellTags->"i:66",
 CellID->232582819],
Cell[556891, 13855, 577, 13, 37, "CodeCaption",ExpressionUUID->"d11895cd-876c-4181-9230-aeef0ebb2786",
 CellID->416203485],
Cell[CellGroupData[{
Cell[557493, 13872, 636, 12, 26, "Input",ExpressionUUID->"089a2230-a213-49b2-b476-b1660dab470e",
 CellID->412705545],
Cell[558132, 13886, 158, 2, 21, "EchoTiming",ExpressionUUID->"1c084def-5997-4669-9181-2b357b7b6a4f",
 CellID->2010412335],
Cell[558293, 13890, 5870, 190, 137, "Output",ExpressionUUID->"7297c1ac-798d-4c11-8b7f-89ccbf006ad0",
 CellID->492412447]
}, Open  ]],
Cell[564178, 14083, 988, 20, 63, "Text",ExpressionUUID->"5570ec7e-3c57-4fab-9531-43f4cd37460f",
 CellTags->{"LastCellOfAPage", "i:67"},
 CellID->747614211],
Cell[565169, 14105, 516, 12, 37, "CodeCaption",ExpressionUUID->"b24ab022-8cb3-49cb-9223-11afd2920737",
 CellTags->"p: 45",
 CellID->48558757],
Cell[CellGroupData[{
Cell[565710, 14121, 516, 10, 26, "Input",ExpressionUUID->"343b483f-7145-4249-bebb-2746b9ccc365",
 CellID->1030202654],
Cell[566229, 14133, 159, 2, 21, "EchoTiming",ExpressionUUID->"e809cddc-a760-44b3-9357-1f520e898ad5",
 CellID->601469678],
Cell[566391, 14137, 5805, 190, 137, "Output",ExpressionUUID->"d791ab06-fb3c-4c5c-9013-25d36f15d951",
 CellID->695351717]
}, Open  ]],
Cell[572211, 14330, 288, 5, 38, "Text",ExpressionUUID->"7affba0d-178e-4b9f-b639-47e01ec0f124",
 CellID->956976611],
Cell[572502, 14337, 3560, 79, 163, "Text",ExpressionUUID->"b9e999f7-83a3-4a04-8a65-728e495c42be",
 CellTags->"i:68",
 CellID->1928899909],
Cell[576065, 14418, 627, 13, 37, "CodeCaption",ExpressionUUID->"37b708f8-8ed7-4a36-9394-652ed71408ee",
 CellID->49643145],
Cell[CellGroupData[{
Cell[576717, 14435, 868, 18, 26, "Input",ExpressionUUID->"fb096d58-cba6-46e2-852f-240612f43d4b",
 CellID->815520100],
Cell[577588, 14455, 156, 2, 21, "EchoTiming",ExpressionUUID->"434f5578-3e2f-498e-956a-02253703ad13",
 CellID->790355281],
Cell[577747, 14459, 3701, 90, 181, "Output",ExpressionUUID->"385839eb-715d-4a39-834c-fb47ce6fdd68",
 CellID->1314851072]
}, Open  ]],
Cell[581463, 14552, 2462, 56, 113, "Text",ExpressionUUID->"bed66ccf-688d-4262-8778-024328c09e39",
 CellTags->"LastCellOfAPage",
 CellID->1350776468],
Cell[583928, 14610, 685, 14, 37, "CodeCaption",ExpressionUUID->"f6112bb9-9afe-4eff-8674-0a7bfedab5a9",
 CellTags->"p: 46",
 CellID->340339881],
Cell[CellGroupData[{
Cell[584638, 14628, 707, 15, 46, "Input",ExpressionUUID->"abf96da3-9ff6-4d3e-ab52-6d3e2d2da4d6",
 CellID->1768262311],
Cell[585348, 14645, 157, 2, 21, "EchoTiming",ExpressionUUID->"b914bdb5-e22a-47e2-97a6-3b1730006a58",
 CellID->320333128],
Cell[585508, 14649, 3554, 88, 181, "Output",ExpressionUUID->"588a2ba9-34e4-43c0-b3c9-c2e79b8a72ba",
 CellID->97379267]
}, Open  ]],
Cell[589077, 14740, 904, 13, 138, "Text",ExpressionUUID->"fbaf5206-6e60-4acb-bd52-8ba56372f986",
 CellID->276686938]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[590030, 14759, 327, 4, 57, "Subsection",ExpressionUUID->"7d129b6a-1d53-45a3-9a51-33d871768838",
 CellID->604870805],
Cell[CellGroupData[{
Cell[590382, 14767, 180, 2, 55, "Subsubsection",ExpressionUUID->"1abd6f24-b3dd-45a5-9540-7172b3c7e814",
 CellID->161362593],
Cell[590565, 14771, 1303, 23, 88, "Text",ExpressionUUID->"b661e44f-045d-4bf3-a105-fb10d8b213e0",
 CellID->1069548003],
Cell[591871, 14796, 553, 13, 37, "CodeCaption",ExpressionUUID->"426259f7-291e-4b68-a212-e7d7d8623fef",
 CellID->1255197607],
Cell[CellGroupData[{
Cell[592449, 14813, 297, 7, 26, "Input",ExpressionUUID->"f54f8216-3ad5-402e-ae1f-d53ac2a9e898",
 CellID->834729015],
Cell[592749, 14822, 20007, 386, 152, "Output",ExpressionUUID->"641d84d5-9b8e-4690-817f-e7500f80af17",
 CellID->1927372901]
}, Open  ]],
Cell[612771, 15211, 2929, 66, 138, "Text",ExpressionUUID->"87f2ba43-969f-4ff7-bf1c-c5cb0bd09bf3",
 CellTags->{"LastCellOfAPage", "i:69"},
 CellID->121026861],
Cell[615703, 15279, 1087, 26, 59, "CodeCaption",ExpressionUUID->"e46768c6-f8a3-4ddc-bce8-ea293a0ac50f",
 CellTags->{"i:70", "p: 47"},
 CellID->137313122],
Cell[CellGroupData[{
Cell[616815, 15309, 8698, 207, 31, "Input",ExpressionUUID->"3c978a01-b63b-4130-8725-6c5c2880105d",
 CellID->1943618907],
Cell[625516, 15518, 7650, 190, 235, "Output",ExpressionUUID->"6b6ca072-e38e-425d-978e-74bb537f3234",
 CellID->127527510]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[633215, 15714, 182, 2, 55, "Subsubsection",ExpressionUUID->"fea58898-51f5-472c-a643-371e7541db27",
 CellID->121986215],
Cell[633400, 15718, 1382, 24, 188, "Text",ExpressionUUID->"6aa010c3-7341-4059-9446-67d8fe1ff483",
 CellTags->"i:71",
 CellID->688375747],
Cell[634785, 15744, 254, 4, 37, "CodeCaption",ExpressionUUID->"4d2fba34-3a53-48b6-8727-e4c2179ba53d",
 CellID->265353070],
Cell[CellGroupData[{
Cell[635064, 15752, 427, 10, 27, "Input",ExpressionUUID->"b5c8b40f-a037-49d7-a971-55044ff37a2d",
 CellID->459511348],
Cell[635494, 15764, 6815, 170, 175, "Output",ExpressionUUID->"49b0807e-4e54-48ec-92fd-420144e63603",
 CellID->606192375]
}, Open  ]],
Cell[642324, 15937, 815, 15, 63, "Text",ExpressionUUID->"3e68f07e-3f08-417e-aff9-ba694376b8ee",
 CellTags->{"LastCellOfAPage", "i:72"},
 CellID->1536241901],
Cell[643142, 15954, 734, 18, 37, "CodeCaption",ExpressionUUID->"6a7f5811-f62a-4c4b-ac1e-34043d081d63",
 CellTags->"p: 48",
 CellID->246038905],
Cell[CellGroupData[{
Cell[643901, 15976, 293, 6, 26, "Input",ExpressionUUID->"ce267a53-84de-411c-af72-9760b363fdb8",
 CellID->817164804],
Cell[644197, 15984, 3066, 93, 133, "Output",ExpressionUUID->"87f5bfbe-45d5-435d-887e-86b9f451b2a3",
 CellID->329301839]
}, Open  ]],
Cell[647278, 16080, 546, 12, 63, "Text",ExpressionUUID->"3766d413-3a2b-4bbb-8deb-43416cc63c4c",
 CellTags->"i:73",
 CellID->1826551503],
Cell[647827, 16094, 1107, 28, 39, "CodeText",ExpressionUUID->"f2b4f03e-7d1a-4803-9e42-de96979036ec",
 CellID->2145942334],
Cell[CellGroupData[{
Cell[648959, 16126, 247, 5, 26, "Input",ExpressionUUID->"2ed04ef9-9a06-4858-992a-9678e83c29ee",
 CellID->26858423],
Cell[649209, 16133, 662, 11, 57, "Output",ExpressionUUID->"7489fe4e-31f0-45cb-a796-44bde3171a59",
 CellID->337180613]
}, Open  ]],
Cell[649886, 16147, 1167, 17, 213, "Text",ExpressionUUID->"d54c1ccd-cffd-41b6-b2b9-d68f1d9dea68",
 CellID->304759050],
Cell[651056, 16166, 594, 12, 38, "Text",ExpressionUUID->"0c90ac82-79c6-4dc1-86c9-d4c87a3c28f5",
 CellID->1198000130],
Cell[651653, 16180, 1243, 29, 61, "CodeText",ExpressionUUID->"5502f81a-85c6-46c5-a81a-dd2e7b35c185",
 CellID->882612603],
Cell[CellGroupData[{
Cell[652921, 16213, 865, 23, 85, "Input",ExpressionUUID->"ebbf4be7-d644-4214-a5c6-2561b7238160",
 CellID->565657255],
Cell[653789, 16238, 313, 6, 37, "Output",ExpressionUUID->"26cd36da-7ecd-41bd-80a8-86738a632b45",
 CellID->238026837]
}, Open  ]],
Cell[654117, 16247, 799, 15, 63, "Text",ExpressionUUID->"f201becc-1b66-408b-b009-9b2121eb0e50",
 CellID->1090138224]
}, Open  ]],
Cell[CellGroupData[{
Cell[654953, 16267, 188, 2, 55, "Subsubsection",ExpressionUUID->"228e3bcf-a4ea-4d9c-a47d-c2b17b76eb0b",
 CellID->135643774],
Cell[CellGroupData[{
Cell[655166, 16273, 179, 2, 54, "Subsubsubsection",ExpressionUUID->"44b5e2d7-6fca-483d-8639-f8f05bb85e79",
 CellID->1694358496],
Cell[655348, 16277, 426, 8, 38, "Text",ExpressionUUID->"656c0d9f-7c7f-46d0-982f-3b3209acac89",
 CellTags->{"LastCellOfAPage", "i:74"},
 CellID->1847183370],
Cell[655777, 16287, 679, 15, 37, "CodeCaption",ExpressionUUID->"97af765f-2160-4aac-9dcf-243ce2868133",
 CellTags->"p: 49",
 CellID->1908282140],
Cell[CellGroupData[{
Cell[656481, 16306, 563, 15, 27, "Input",ExpressionUUID->"a67d9964-4173-4c5d-8240-102d827f0b3d",
 CellID->501925993],
Cell[657047, 16323, 8701, 231, 325, "Output",ExpressionUUID->"7c6e3cc4-cb8d-49a7-8b91-af144ac9a8d8",
 CellID->277777813]
}, Open  ]],
Cell[665763, 16557, 616, 10, 63, "Text",ExpressionUUID->"df50a99b-6ada-43d0-b3f0-e7bfbda5e4a3",
 CellID->1414820192]
}, Open  ]],
Cell[CellGroupData[{
Cell[666416, 16572, 178, 2, 54, "Subsubsubsection",ExpressionUUID->"b62cae03-7860-4cf8-a8c0-c22550783f9f",
 CellID->1418350088],
Cell[666597, 16576, 2216, 47, 163, "Text",ExpressionUUID->"3d8e0c22-db41-44f2-80fc-5a215eb981d3",
 CellTags->"i:75",
 CellID->51966467],
Cell[668816, 16625, 524, 12, 37, "CodeCaption",ExpressionUUID->"4822b8e4-c05c-4a22-99d2-1ad8699ff002",
 CellID->64051613],
Cell[CellGroupData[{
Cell[669365, 16641, 1626, 38, 32, "Input",ExpressionUUID->"6c1ff94f-828b-4287-9e87-51c0bd31bcdc",
 CellID->87773158],
Cell[670994, 16681, 36696, 641, 335, "Output",ExpressionUUID->"e597848a-580f-4d3e-9eaf-c427e79ac277",
 CellTags->"LastCellOfAPage",
 CellID->990161061]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[707739, 17328, 266, 4, 54, "Subsubsubsection",ExpressionUUID->"860f23f7-281b-44f1-ab40-c85f10c6b08a",
 CellTags->"p: 50",
 CellID->548822030],
Cell[708008, 17334, 1327, 26, 113, "Text",ExpressionUUID->"b397d02c-8b3a-4f6e-9c18-15da11facee9",
 CellTags->"i:76",
 CellID->710098879],
Cell[709338, 17362, 822, 20, 37, "CodeCaption",ExpressionUUID->"a6d5774c-0fa4-4622-9a9f-c930d31e07a9",
 CellID->1134921],
Cell[CellGroupData[{
Cell[710185, 17386, 824, 20, 27, "Input",ExpressionUUID->"06d41cb5-af6e-4126-8ab3-e974ffb028a1",
 CellID->552175843],
Cell[711012, 17408, 14031, 353, 325, "Output",ExpressionUUID->"be44958f-0c9b-4954-b48f-3986d123685c",
 CellID->1120730804]
}, Open  ]],
Cell[725058, 17764, 822, 19, 63, "Text",ExpressionUUID->"e858c192-b04f-41db-ae20-8c5237b01211",
 CellTags->"i:77",
 CellID->1297442800],
Cell[725883, 17785, 486, 11, 37, "CodeCaption",ExpressionUUID->"98d45cb8-a940-442d-9e8e-866b16b82645",
 CellID->15260860],
Cell[CellGroupData[{
Cell[726394, 17800, 1058, 29, 48, "Input",ExpressionUUID->"e2d44eee-a791-45e2-9b28-7f20e6f7c575",
 CellID->1628499304],
Cell[727455, 17831, 457, 8, 37, "Output",ExpressionUUID->"54662d09-9778-4c20-91c7-e0de546c64af",
 CellID->537555172]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[727961, 17845, 245, 3, 54, "Subsubsubsection",ExpressionUUID->"b478f179-b329-4fc6-bfb6-2f763d0417e3",
 CellID->205602557],
Cell[728209, 17850, 775, 12, 113, "Text",ExpressionUUID->"21e936b0-84ad-4cec-8cc7-fd2468614943",
 CellTags->"i:78",
 CellID->629872765],
Cell[728987, 17864, 467, 11, 37, "CodeCaption",ExpressionUUID->"5e26ff0f-3630-4cb0-8b39-128899b81ace",
 CellID->140116007],
Cell[CellGroupData[{
Cell[729479, 17879, 588, 13, 27, "Input",ExpressionUUID->"1e293fc6-11da-4dfb-ac87-7f204208ca99",
 CellID->1159000034],
Cell[730070, 17894, 1194, 32, 57, "Output",ExpressionUUID->"68cc9deb-2f39-4e5e-8467-1ba32ce2baec",
 CellTags->"LastCellOfAPage",
 CellID->2011476000]
}, Open  ]],
Cell[731279, 17929, 926, 18, 88, "Text",ExpressionUUID->"a46ba477-f1db-410c-9cde-276de4d047da",
 CellTags->"p: 51",
 CellID->246154164],
Cell[732208, 17949, 297, 6, 109, "CodeCaption",ExpressionUUID->"2da01586-a13d-418e-bf7d-43ee65c36763",
 CellID->856564760],
Cell[CellGroupData[{
Cell[732530, 17959, 704, 15, 27, "Input",ExpressionUUID->"57bda192-9206-4083-861f-35c5dcc601ea",
 CellID->1701035479],
Cell[733237, 17976, 1252, 32, 57, "Output",ExpressionUUID->"339d72d6-fca9-4777-9036-7c7f11a9f82c",
 CellID->1376280383]
}, Open  ]],
Cell[734504, 18011, 361, 4, 38, "Text",ExpressionUUID->"2d6de410-c054-49f8-9cf5-82b5bcd766a9",
 CellID->349930657],
Cell[734868, 18017, 215, 2, 37, "CodeCaption",ExpressionUUID->"09bdd8a6-d9a4-4c60-8de8-982612ce484c",
 CellID->32079444],
Cell[CellGroupData[{
Cell[735108, 18023, 370, 8, 27, "Input",ExpressionUUID->"edbe4e2a-2f9a-4b9c-b5da-7fcb8d7a9d36",
 CellID->1904637586],
Cell[735481, 18033, 4382, 116, 80, "Output",ExpressionUUID->"213b209b-a7b2-4808-8176-d932837cc9fb",
 CellID->1192867431]
}, Open  ]],
Cell[739878, 18152, 1285, 24, 163, "Text",ExpressionUUID->"51a81055-744e-4ebe-9ab2-ed1fdb9c4dc1",
 CellID->1791646266],
Cell[741166, 18178, 285, 5, 38, "Text",ExpressionUUID->"fef39cfe-39f7-4ba6-ad8a-e32d6a403900",
 CellID->1530152877],
Cell[741454, 18185, 700, 14, 59, "CodeCaption",ExpressionUUID->"ae55b62b-d449-4eb9-9ce4-c038e360d6bc",
 CellID->284599811],
Cell[742157, 18201, 617, 17, 27, "Input",ExpressionUUID->"904a39f8-7b25-4cfc-8ea8-c72c52863eb3",
 CellID->172782680],
Cell[742777, 18220, 706, 16, 37, "CodeCaption",ExpressionUUID->"304d4d0b-ebb7-4c65-ad8d-64de43f2df29",
 CellID->1269423376],
Cell[CellGroupData[{
Cell[743508, 18240, 526, 10, 26, "Input",ExpressionUUID->"97580554-b511-4f1e-9bd8-5bb74a13b59a",
 CellID->52370275],
Cell[744037, 18252, 6951, 199, 177, "Output",ExpressionUUID->"9a0f9848-20d8-4a89-8314-eefe242056d5",
 CellTags->"LastCellOfAPage",
 CellID->1745520635]
}, Open  ]],
Cell[751003, 18454, 696, 14, 63, "Text",ExpressionUUID->"459cf7d2-c2ef-4ec6-a788-f8275d1b50a7",
 CellTags->{"i:79", "p: 52"},
 CellID->1105562149],
Cell[751702, 18470, 579, 12, 37, "CodeCaption",ExpressionUUID->"75898072-3e0f-47a0-8415-f0b7dcfddc52",
 CellID->1721805856],
Cell[CellGroupData[{
Cell[752306, 18486, 1465, 33, 32, "Input",ExpressionUUID->"7fc00ab4-b4e4-41cc-884a-d682ec972cfb",
 CellID->1245916292],
Cell[753774, 18521, 12726, 327, 330, "Output",ExpressionUUID->"74dc01b9-19e4-46e3-b884-acedd237cb03",
 CellID->1191607268]
}, Open  ]],
Cell[766515, 18851, 603, 10, 63, "Text",ExpressionUUID->"25292037-276f-426b-8995-c9c11130aaac",
 CellID->1553562708],
Cell[767121, 18863, 460, 10, 37, "CodeCaption",ExpressionUUID->"7010edff-26a9-4b29-9e1c-f7524fdb3bb1",
 CellID->1452548128],
Cell[CellGroupData[{
Cell[767606, 18877, 1857, 46, 52, "Input",ExpressionUUID->"530a9059-d389-4673-9aa0-5b4bfcf3b5e7",
 CellID->525491609],
Cell[769466, 18925, 12594, 324, 330, "Output",ExpressionUUID->"3d6642cb-0a5a-474d-b57b-b6dbdc119ab1",
 CellID->1432550493]
}, Open  ]],
Cell[782075, 19252, 325, 5, 38, "Text",ExpressionUUID->"0bd6a873-645e-4b2d-bde4-e97fe67d64bb",
 CellTags->"LastCellOfAPage",
 CellID->1136515825]
}, Open  ]],
Cell[CellGroupData[{
Cell[782437, 19262, 280, 4, 54, "Subsubsubsection",ExpressionUUID->"84036eed-4393-4dd2-9889-e87496cbf72d",
 CellTags->"p: 53",
 CellID->562117424],
Cell[782720, 19268, 694, 14, 88, "Text",ExpressionUUID->"50be217a-b749-4b07-8096-8be4e862acb0",
 CellTags->"i:80",
 CellID->1301156318],
Cell[783417, 19284, 223, 4, 63, "Text",ExpressionUUID->"a988711b-5517-4ccd-b5eb-f2f72f95111a",
 CellID->1486998922],
Cell[783643, 19290, 225, 3, 37, "CodeCaption",ExpressionUUID->"f329c0db-680e-40a2-85a9-59941b30b42c",
 CellID->64004257],
Cell[CellGroupData[{
Cell[783893, 19297, 735, 18, 27, "Input",ExpressionUUID->"0f831a6d-103e-4651-b889-71d7a863dff6",
 CellID->276765543],
Cell[784631, 19317, 454, 8, 37, "Output",ExpressionUUID->"cdf777cb-4ed6-418f-9f05-84fbab2633ae",
 CellID->1769351917]
}, Open  ]],
Cell[785100, 19328, 3712, 83, 164, "Text",ExpressionUUID->"3a4fed04-ab78-47c2-9c9d-2504eeaa31ee",
 CellTags->"i:81",
 CellID->1286503873],
Cell[788815, 19413, 507, 11, 37, "CodeCaption",ExpressionUUID->"6e32d9f8-070e-4bfc-b56a-b46ae87e6510",
 CellID->70676224],
Cell[CellGroupData[{
Cell[789347, 19428, 627, 16, 46, "Input",ExpressionUUID->"5d828a93-ccfd-482b-93bf-0e7e47862d89",
 CellID->624914140],
Cell[789977, 19446, 436, 7, 37, "Output",ExpressionUUID->"a6ed801a-6eae-4e1e-89d0-d82aacda1cc7",
 CellID->689738866]
}, Open  ]],
Cell[790428, 19456, 562, 11, 89, "Text",ExpressionUUID->"271a833f-3932-46fa-ba48-0cf1367ab9a7",
 CellID->1852832392],
Cell[790993, 19469, 807, 18, 37, "CodeCaption",ExpressionUUID->"02d0a5a6-188b-4cc6-8d77-61be39c9dbd0",
 CellID->212455070],
Cell[CellGroupData[{
Cell[791825, 19491, 8447, 204, 31, "Input",ExpressionUUID->"9e3d99c7-a71f-4fd6-91d5-ac5d0b6a9c2a",
 CellID->1542127400],
Cell[800275, 19697, 17270, 444, 293, "Output",ExpressionUUID->"1f5eec67-fafe-4b51-acb1-0ce615928afa",
 CellTags->"LastCellOfAPage",
 CellID->159701592]
}, Open  ]],
Cell[817560, 20144, 697, 18, 37, "CodeCaption",ExpressionUUID->"d8e86c9c-b94a-4567-9ecf-af6505112c76",
 CellTags->"p: 54",
 CellID->586624606],
Cell[CellGroupData[{
Cell[818282, 20166, 573, 12, 26, "Input",ExpressionUUID->"2cec139e-aca6-43dc-aa60-be069891fb2b",
 CellID->2024623710],
Cell[818858, 20180, 11808, 293, 277, "Output",ExpressionUUID->"339c0c5e-c36f-4054-9671-ff913f813ccf",
 CellID->1885962532]
}, Open  ]],
Cell[830681, 20476, 811, 12, 138, "Text",ExpressionUUID->"5a25a487-d0e8-43ca-9dc7-9e98cc1e3c44",
 CellID->673357807],
Cell[831495, 20490, 512, 11, 37, "CodeCaption",ExpressionUUID->"0cad255c-0284-4893-b8d0-0dd53f6ae597",
 CellID->1542437680],
Cell[CellGroupData[{
Cell[832032, 20505, 576, 13, 26, "Input",ExpressionUUID->"425efa83-52f3-4c90-ac08-eb95d3cace46",
 CellID->1404530533],
Cell[832611, 20520, 1673, 43, 48, "Output",ExpressionUUID->"6efc886c-a92e-413e-a86f-1bfad865f578",
 CellID->1373574914]
}, Open  ]],
Cell[834299, 20566, 1207, 22, 113, "Text",ExpressionUUID->"9aae9d7f-f39d-4911-a008-6afab02db28c",
 CellID->1976171894],
Cell[835509, 20590, 820, 19, 59, "CodeCaption",ExpressionUUID->"858be087-aed6-4459-973e-882cdc64397b",
 CellID->1994189223],
Cell[CellGroupData[{
Cell[836354, 20613, 605, 13, 46, "Input",ExpressionUUID->"720753ea-7fff-4137-903e-02c624d5280c",
 CellID->1457366262],
Cell[836962, 20628, 6750, 191, 177, "Output",ExpressionUUID->"f3931303-cda1-4eb7-a13d-6641f78dacad",
 CellTags->"LastCellOfAPage",
 CellID->970630517]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[843773, 20826, 310, 4, 55, "Subsubsection",ExpressionUUID->"74dcfbb8-dc7b-49a8-ac27-4bfcec0318cc",
 CellTags->"p: 55",
 CellID->2115950892],
Cell[844086, 20832, 1016, 19, 113, "Text",ExpressionUUID->"d6552f14-8e3a-43c6-a6b8-863b521979f9",
 CellTags->"i:82",
 CellID->1995702086],
Cell[845105, 20853, 490, 11, 37, "CodeCaption",ExpressionUUID->"70683553-7e32-4bcf-bdef-54874f44c92f",
 CellID->625649664],
Cell[845598, 20866, 702, 15, 27, "Input",ExpressionUUID->"9166924e-70f6-4fe8-ae24-4a3488df7c51",
 CellID->1950636151],
Cell[846303, 20883, 203, 2, 37, "CodeCaption",ExpressionUUID->"f5eeebc8-dbb9-40ab-a9a0-b65ab49f23fd",
 CellID->457990957],
Cell[CellGroupData[{
Cell[846531, 20889, 292, 6, 26, "Input",ExpressionUUID->"9cea0f51-bd33-4876-9801-5a52ad1ccf5a",
 CellID->2050162285],
Cell[846826, 20897, 1125, 31, 57, "Output",ExpressionUUID->"32db56a4-8dc0-4140-b194-c9af1a57515f",
 CellID->971179826]
}, Open  ]],
Cell[847966, 20931, 789, 18, 63, "Text",ExpressionUUID->"fa481d78-7808-40da-9b63-256b20555933",
 CellID->434375078],
Cell[848758, 20951, 217, 2, 37, "CodeCaption",ExpressionUUID->"b40724e0-fe1d-445e-bc8d-2dd4ff14a2af",
 CellID->441478470],
Cell[848978, 20955, 433, 11, 27, "Input",ExpressionUUID->"7a6a0b5e-315c-4f0c-b8fb-58fde897c38c",
 CellID->1173565537],
Cell[849414, 20968, 561, 10, 63, "Text",ExpressionUUID->"c5a9dad1-80e4-4e97-bd28-16255041e5be",
 CellID->82297698],
Cell[849978, 20980, 564, 14, 37, "CodeCaption",ExpressionUUID->"6ac9b483-9d4c-4b85-a826-609229bdf749",
 CellID->341298345],
Cell[CellGroupData[{
Cell[850567, 20998, 355, 9, 26, "Input",ExpressionUUID->"3594b45d-dc94-49f8-aa5b-da27a66b2c8f",
 CellID->1953201954],
Cell[850925, 21009, 1096, 30, 57, "Output",ExpressionUUID->"f60e1884-89d2-4ead-92fe-5c5214e9121d",
 CellID->1993833756]
}, Open  ]],
Cell[852036, 21042, 1343, 25, 113, "Text",ExpressionUUID->"301f0d6f-07b5-4d47-aead-22895bc555dd",
 CellID->666163788],
Cell[853382, 21069, 468, 11, 37, "CodeCaption",ExpressionUUID->"c15dd16c-b35e-4657-8e1d-d59f5305d10b",
 CellID->125374504],
Cell[853853, 21082, 677, 18, 27, "Input",ExpressionUUID->"329e2f85-5e5d-4259-a7ed-c73885f9db13",
 CellID->179586518],
Cell[854533, 21102, 540, 14, 38, "Text",ExpressionUUID->"77d52c6b-7dee-4d98-aa25-dea516de28ec",
 CellTags->"LastCellOfAPage",
 CellID->71094693],
Cell[855076, 21118, 632, 15, 37, "CodeCaption",ExpressionUUID->"da69efa7-b4f0-4799-9676-5f593db923eb",
 CellTags->"p: 56",
 CellID->10482146],
Cell[CellGroupData[{
Cell[855733, 21137, 358, 8, 26, "Input",ExpressionUUID->"7420a3af-2f42-4bb3-8ca4-0bca180f3357",
 CellID->1574016729],
Cell[856094, 21147, 6847, 196, 177, "Output",ExpressionUUID->"eda1d7c6-b900-4627-9ef3-262273ddcd0d",
 CellID->92876686]
}, Open  ]],
Cell[862956, 21346, 1111, 21, 63, "Text",ExpressionUUID->"e5b69205-6edd-420c-8352-717367f31ef8",
 CellID->215245591],
Cell[864070, 21369, 518, 11, 37, "CodeCaption",ExpressionUUID->"812a1f07-17de-46d2-9c05-500bb3b53349",
 CellID->136900161],
Cell[CellGroupData[{
Cell[864613, 21384, 1635, 38, 32, "Input",ExpressionUUID->"8b9f1ba6-bbcd-4b3b-a4c7-e6c39e138c21",
 CellID->1409645418],
Cell[866251, 21424, 12648, 326, 330, "Output",ExpressionUUID->"c462f5d5-adb6-442f-8f52-7362e10f1b24",
 CellID->535661732]
}, Open  ]],
Cell[878914, 21753, 621, 10, 88, "Text",ExpressionUUID->"910498b6-b830-4567-b057-c2df47775466",
 CellID->856434755],
Cell[879538, 21765, 475, 11, 37, "CodeCaption",ExpressionUUID->"27466176-9d93-4877-947f-8925826da96b",
 CellID->46614440],
Cell[880016, 21778, 582, 17, 27, "Input",ExpressionUUID->"3ccb8f7e-bbba-4b30-b01a-bb58bc276062",
 CellID->1701959274],
Cell[880601, 21797, 515, 11, 37, "CodeCaption",ExpressionUUID->"4dd95af8-d886-4fad-ab3e-f4c3f6797761",
 CellID->228933502],
Cell[CellGroupData[{
Cell[881141, 21812, 342, 7, 26, "Input",ExpressionUUID->"9ad13d5c-3403-491d-87a3-9003c23059ca",
 CellID->533955254],
Cell[881486, 21821, 484, 9, 37, "Output",ExpressionUUID->"4745ea4e-49e3-4b7d-80a9-7f6572f37fc7",
 CellTags->"LastCellOfAPage",
 CellID->311509173]
}, Open  ]],
Cell[881985, 21833, 820, 15, 113, "Text",ExpressionUUID->"21675a59-815f-4fd9-a7da-35e9763b4f35",
 CellTags->"p: 57",
 CellID->404930289],
Cell[882808, 21850, 752, 18, 37, "CodeCaption",ExpressionUUID->"22440d01-069d-4cba-b089-38af7bd80bf1",
 CellID->206325492],
Cell[883563, 21870, 625, 17, 26, "Input",ExpressionUUID->"9b8402fa-7dd5-45ed-8906-f7ff5dc6b7b8",
 CellID->905771872],
Cell[884191, 21889, 1434, 33, 113, "Text",ExpressionUUID->"7655e20c-499e-4f8d-a20f-205df635af87",
 CellID->1802164790],
Cell[885628, 21924, 1285, 34, 59, "CodeCaption",ExpressionUUID->"d5354dd2-8386-4f35-b689-770af9d28657",
 CellID->918421238],
Cell[CellGroupData[{
Cell[886938, 21962, 8838, 208, 31, "Input",ExpressionUUID->"c572902e-5efc-4629-af54-583b50278923",
 CellID->16957113],
Cell[895779, 22172, 20350, 486, 349, "Output",ExpressionUUID->"4d810cb6-8143-4e69-a695-65903988715a",
 CellID->1530356787]
}, Open  ]],
Cell[916144, 22661, 1766, 39, 88, "Text",ExpressionUUID->"dde24822-446b-4192-beae-bb139fdd238f",
 CellID->1268362144],
Cell[917913, 22702, 554, 12, 37, "CodeCaption",ExpressionUUID->"101cfdf2-9640-4aa3-8ff8-d5f5571b3d59",
 CellID->24700960],
Cell[918470, 22716, 728, 14, 26, "Input",ExpressionUUID->"f70a20b0-0ed8-4788-a332-f5c285ca8735",
 CellID->1688975429],
Cell[919201, 22732, 1788, 44, 88, "Text",ExpressionUUID->"66544aab-47db-48e7-9f8b-7765f6051e18",
 CellTags->"LastCellOfAPage",
 CellID->948824146],
Cell[920992, 22778, 1396, 38, 59, "CodeCaption",ExpressionUUID->"cb0b135a-4067-4c81-bb6a-3f7ec27c1a06",
 CellTags->"p: 58",
 CellID->466694603],
Cell[CellGroupData[{
Cell[922413, 22820, 8716, 206, 31, "Input",ExpressionUUID->"a9c0149a-5fb8-4ba9-8586-a656ce36b74f",
 CellID->1868670835],
Cell[931132, 23028, 24814, 619, 532, "Output",ExpressionUUID->"1ceb56fe-66af-4b4e-96e3-c3bffccb8d4e",
 CellID->657239823]
}, Open  ]],
Cell[955961, 23650, 1016, 24, 63, "Text",ExpressionUUID->"249d27af-e2db-466c-9b66-31da2e90d9bb",
 CellID->1623631799],
Cell[956980, 23676, 490, 12, 37, "CodeCaption",ExpressionUUID->"ef12db14-4670-4d3b-b042-47cff5400419",
 CellID->88412202],
Cell[957473, 23690, 724, 18, 27, "Input",ExpressionUUID->"b47b76b4-19ec-4b18-bb8e-c122778e9237",
 CellID->1866250991],
Cell[958200, 23710, 846, 19, 63, "Text",ExpressionUUID->"a9bd87cc-7bca-4d7b-8ef8-580b851c2abc",
 CellID->886172334],
Cell[959049, 23731, 516, 11, 37, "CodeCaption",ExpressionUUID->"cce11058-4cbe-4a9f-b5e1-5e2e3176d6fc",
 CellID->272293802],
Cell[959568, 23744, 467, 12, 26, "Input",ExpressionUUID->"19c1b48a-1686-4b4e-91dc-b9115d229644",
 CellID->1000588128],
Cell[960038, 23758, 599, 14, 38, "Text",ExpressionUUID->"021f1402-90ca-430e-b65f-c081f816739c",
 CellTags->{"LastCellOfAPage", "i:83"},
 CellID->38294597],
Cell[960640, 23774, 325, 7, 37, "CodeCaption",ExpressionUUID->"4de3fb1a-ea03-47e8-98d5-eb344671247d",
 CellTags->"p: 59",
 CellID->409418610],
Cell[CellGroupData[{
Cell[960990, 23785, 436, 10, 26, "Input",ExpressionUUID->"82793ebe-27fc-42de-ad1d-492ca69f9224",
 CellID->1975202494],
Cell[961429, 23797, 6830, 191, 177, "Output",ExpressionUUID->"a1735097-4274-4ec1-be63-f6a2d84a5dee",
 CellID->884589934]
}, Open  ]],
Cell[968274, 23991, 519, 13, 38, "Text",ExpressionUUID->"5b718345-99d7-4c3e-a50b-ecefa35775d4",
 CellID->452835264],
Cell[968796, 24006, 541, 14, 37, "CodeCaption",ExpressionUUID->"ed0885c2-2393-4fa0-9686-b4ce9e9297b5",
 CellID->404998412],
Cell[CellGroupData[{
Cell[969362, 24024, 388, 9, 26, "Input",ExpressionUUID->"979c862d-2243-4415-b753-3a03e45aeb19",
 CellID->1888289210],
Cell[969753, 24035, 1808, 49, 78, "Output",ExpressionUUID->"0674c530-4c31-4726-b500-cb00b1fc66ac",
 CellID->194461468]
}, Open  ]],
Cell[971576, 24087, 574, 14, 37, "CodeCaption",ExpressionUUID->"59542eb7-b366-4c96-851b-9d52569efe54",
 CellID->2049498201],
Cell[CellGroupData[{
Cell[972175, 24105, 267, 5, 26, "Input",ExpressionUUID->"f1c0b62e-486c-4e03-8d50-e2a4cedc44d2",
 CellID->1974514058],
Cell[972445, 24112, 6614, 188, 177, "Output",ExpressionUUID->"f41d3d9f-8eb6-4270-b280-b15b28baee3b",
 CellID->392257524]
}, Open  ]]
}, Open  ]]
}, Open  ]],
Cell[CellGroupData[{
Cell[979120, 24307, 174, 2, 57, "Subsection",ExpressionUUID->"d4a76011-6a74-455c-a8a1-8a2b4ded091c",
 CellID->1863754633],
Cell[979297, 24311, 1697, 33, 188, "Text",ExpressionUUID->"c182b241-0ebe-46d5-86eb-178c94fe0838",
 CellTags->"LastCellOfAPage",
 CellID->1458935525],
Cell[CellGroupData[{
Cell[981019, 24348, 181, 4, 65, "ExerciseSection",ExpressionUUID->"89dcba58-2102-40b3-971e-38edb2e73355",
 CellTags->"p: 60",
 CellID->2000071317],
Cell[981203, 24354, 1403, 32, 54, "Exercise",ExpressionUUID->"667d000f-a65a-40bb-aba3-d4a86b7fdabe",
 CellTags->"Exercise",
 CellID->345108167],
Cell[982609, 24388, 1692, 36, 64, "Exercise",ExpressionUUID->"46f9dee9-aef3-44a4-ada0-c61fae050a00",
 CellTags->"Exercise",
 CellID->607597237],
Cell[984304, 24426, 1466, 36, 45, "Exercise",ExpressionUUID->"b4e54741-dfb1-4d0a-ab81-88e04d4dec1b",
 CellTags->"Exercise",
 CellID->1158908686],
Cell[CellGroupData[{
Cell[985795, 24466, 2804, 61, 121, "Exercise",ExpressionUUID->"ed5200ef-0192-4b38-bb35-e05c150b9e66",
 CellTags->"Exercise",
 CellID->2069077201],
Cell[988602, 24529, 575, 15, 44, "ExerciseInput",ExpressionUUID->"470cf254-7c43-4a7a-adea-ab36afc871af",
 CellTags->"Exercise",
 CellID->1084903328]
}, Open  ]],
Cell[989192, 24547, 715, 18, 50, "Exercise",ExpressionUUID->"435df473-d9b5-490f-ba28-5b0f3b1dd9a6",
 CounterIncrements->None,
 CellTags->"Exercise",
 CellID->332482727],
Cell[989910, 24567, 494, 10, 45, "Exercise",ExpressionUUID->"c440deaf-04c6-4b7c-b9b8-5a83f565d1a7",
 CounterAssignments->{{$CellContext`Exercise, 4}},
 CellTags->"Exercise",
 CellID->393275140],
Cell[990407, 24579, 383, 9, 26, "Exercise",ExpressionUUID->"a17d3e2c-28cb-47aa-924e-ffba11ce4381",
 CellTags->"Exercise",
 CellID->1808053344],
Cell[990793, 24590, 411, 9, 26, "Exercise",ExpressionUUID->"83f09d36-ca48-463d-91f4-d88b14297558",
 CellTags->"Exercise",
 CellID->1457862554],
Cell[991207, 24601, 1901, 40, 64, "Exercise",ExpressionUUID->"cceb4aa1-d415-440a-bdec-ea61c420fb4b",
 CellTags->"Exercise",
 CellID->1596278989],
Cell[993111, 24643, 2277, 63, 71, "Exercise",ExpressionUUID->"d4551e4e-798f-4dfd-9009-4fcc45821567",
 CellTags->"Exercise",
 CellID->707323200],
Cell[995391, 24708, 996, 22, 46, "Exercise",ExpressionUUID->"20ac2b81-8b67-44fe-ab01-17ec9e8c0175",
 CellTags->{"Exercise", "LastCellOfAPage"},
 CellID->205547354]
}, Open  ]],
Cell[CellGroupData[{
Cell[996424, 24735, 133, 2, 70, "TechNoteSection",ExpressionUUID->"c7deca42-6f80-40d1-808f-f89e2f023be7",
 CellTags->"p: 61",
 CellID->2102209134],
Cell[996560, 24739, 2467, 53, 124, "TechNote",ExpressionUUID->"2e208e72-23fd-4281-bf19-fded56c1db83",
 CellTags->"i:84",
 CellID->1139233202],
Cell[CellGroupData[{
Cell[999052, 24796, 1389, 40, 51, "ExerciseInput",ExpressionUUID->"2d98a5aa-2eca-4bdc-9c17-fc98163f06ee",
 CellID->1598642278],
Cell[1000444, 24838, 49618, 1254, 499, "ExerciseOutput",ExpressionUUID->"e4e6d65a-7d82-4dd8-abf4-6399d8715173",
 CellID->904898394]
}, Open  ]],
Cell[1050077, 26095, 1754, 39, 126, "TechNote",ExpressionUUID->"4bb86d37-c9e9-4153-b320-832eea46480f",
 CellID->371344384],
Cell[1051834, 26136, 1431, 36, 124, "TechNote",ExpressionUUID->"fffe9658-da63-481e-b72b-aa4af1a77b61",
 CellTags->"i:85",
 CellID->1440151497],
Cell[CellGroupData[{
Cell[1053290, 26176, 251, 5, 25, "ExerciseInput",ExpressionUUID->"11e60e73-2e6c-45ae-b05c-c499ead96b11",
 CellID->668326244],
Cell[1053544, 26183, 7748, 192, 34, "ExerciseOutput",ExpressionUUID->"c4dacfcc-9a02-4a6a-9ab0-2a216a226adf",
 CellTags->"LastCellOfAPage",
 CellID->1686671003]
}, Open  ]],
Cell[1061307, 26378, 1984, 45, 150, "TechNote",ExpressionUUID->"ca5de65c-ea88-4320-99da-abef09f5daae",
 CellTags->"p: 62",
 CellID->2064321573],
Cell[CellGroupData[{
Cell[1063316, 26427, 9066, 215, 31, "ExerciseInput",ExpressionUUID->"0eb7ecfc-00a4-4601-825c-805c166e06e4",
 CellID->1681167398],
Cell[1072385, 26644, 507, 11, 28, "ExerciseOutput",ExpressionUUID->"3950ea3c-c4e7-4728-89a8-4ea5bad199ce",
 CellID->1414837077]
}, Open  ]],
Cell[1072907, 26658, 1239, 28, 55, "TechNote",ExpressionUUID->"87e7095d-2fec-480c-bbac-7ed983c2d507",
 CellID->1933530066],
Cell[CellGroupData[{
Cell[1074171, 26690, 38463, 922, 127, "ExerciseInput",ExpressionUUID->"5a0978ec-7bcc-440e-b3c1-a7b521cfaa9c",
 CellID->1545762005],
Cell[1112637, 27614, 432, 11, 28, "ExerciseOutput",ExpressionUUID->"ffe3eb89-861b-44a5-96cf-f3078491656d",
 CellID->772835037]
}, Open  ]],
Cell[1113084, 27628, 965, 19, 101, "TechNote",ExpressionUUID->"1fe49ccd-9470-475d-bfcb-fde17a7cf35c",
 CellID->252755601],
Cell[CellGroupData[{
Cell[1114074, 27651, 490, 12, 27, "ExerciseInput",ExpressionUUID->"62250b59-a256-4ac1-b36b-4882faf351e6",
 CellID->715753166],
Cell[1114567, 27665, 4708, 102, 63, "ExerciseOutput",ExpressionUUID->"d9dbd9bc-ea39-44b0-88c6-bfb1fefa2de6",
 CellID->2113656226]
}, Open  ]],
Cell[1119290, 27770, 1947, 40, 124, "TechNote",ExpressionUUID->"5ea5ffe8-4190-4adf-bda2-5984cfd5d8c9",
 CellTags->"i:86",
 CellID->1461046402],
Cell[CellGroupData[{
Cell[1121262, 27814, 529, 13, 25, "ExerciseInput",ExpressionUUID->"9c346a5b-dacc-412d-957e-c5561f841f72",
 CellID->373643176],
Cell[1121794, 27829, 843, 24, 28, "ExerciseOutput",ExpressionUUID->"4650b2d7-2b06-43e0-9d5e-8a0b9ba51ee3",
 CellID->1243225100]
}, Open  ]],
Cell[1122652, 27856, 1395, 35, 102, "TechNote",ExpressionUUID->"f08f8d43-1854-4305-92bb-fc65bcca3305",
 CellTags->{"LastCellOfAPage", "i:87"},
 CellID->2128183295],
Cell[CellGroupData[{
Cell[1124072, 27895, 420, 11, 25, "ExerciseInput",ExpressionUUID->"f738d90a-08d0-4f68-bb49-6390ad437334",
 CellTags->"p: 63",
 CellID->165522244],
Cell[1124495, 27908, 6597, 188, 160, "ExerciseOutput",ExpressionUUID->"cbbe8896-7c7e-4584-8a96-10054bdd0a53",
 CellID->1369711421]
}, Open  ]],
Cell[1131107, 28099, 2554, 71, 55, "TechNote",ExpressionUUID->"3804d0ae-4cc0-4700-baf5-555a1c4618d3",
 CellTags->"LastCellOfAPage",
 CellID->1088437716]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)

(* NotebookSignature GLNQUd33pAKHBKOFm@vM8HH6 *)
